(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    739024,      21039]
NotebookOptionsPosition[    676072,      19479]
NotebookOutlinePosition[    713299,      20308]
CellTagsIndexPosition[    713180,      20302]
WindowTitle->S21 Working with Data Collections
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Working with Data Collections", "Title"],

Cell[TextData[{
 StyleBox["Wolfram",
  FontSlant->"Plain"],
 " ",
 StyleBox["Online Seminar Series",
  FontColor->RGBColor[0.811765, 0.117647, 0.145098]]
}], "Subtitle"],

Cell[TextData[{
 StyleBox["Presenter:",
  FontSlant->"Plain"],
 " Paul Wellin",
 "\n",
 "seminars@wolfram.com"
}], "Subsubtitle"],

Cell[TextData[{
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[
     DateString[], FontFamily -> "Lucida Grande"], StandardForm],
   ImageSizeCache->{269., {5., 17.}},
   UpdateInterval:>1]]],
 StyleBox["  (GMT ",
  StripOnInput->False,
  FontFamily->"Lucida Grande"],
 Cell[BoxData[
  DynamicBox[ToBoxes[
    Style[$TimeZone, FontFamily -> "Lucida Grande"], StandardForm],
   ImageSizeCache->{35., {0., 16.}}]]],
 ")"
}], "DateSection"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Overview", "Section"],

Cell["Users of data are typically faced with the following issues:", "Text"],

Cell[CellGroupData[{

Cell["difficult to locate and extract from sources", "Item"],

Cell["\<\
data from seemingly unrelated fields is scattered across the vastness of the \
Internet\
\>", "Item"],

Cell["\<\
different disciplines use different conventions for naming, units, methods, \
etc.\
\>", "Item"],

Cell["data comes in many different file formats", "Item"],

Cell["databases are not always easy to use", "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Scope", "Section"],

Cell[TextData[{
 "Computable data collections gather data from a wide range of disciplines \
and makes this available to you through a unified computational framework for \
immediate and direct use in calculations. In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8 we now have over 20 data functions:"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Physical and chemical data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["ElementData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ElementData"],
 ", ",
 ButtonBox["ChemicalData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ChemicalData"],
 ", ",
 ButtonBox["IsotopeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsotopeData"],
 ", ",
 ButtonBox["ParticleData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ParticleData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/ScientificAndTechnicalData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Earth and astronomical data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["WeatherData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeatherData"],
 ", ",
 ButtonBox["GeodesyData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeodesyData"],
 ", ",
 ButtonBox["CityData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CityData"],
 ", ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 ", ",
 ButtonBox["GeoDistance",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GeoDistance"],
 ", ",
 ButtonBox["AstronomicalData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AstronomicalData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/ScientificAndTechnicalData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Life science data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["GenomeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GenomeData"],
 ", ",
 ButtonBox["GenomeLookup",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GenomeLookup"],
 ", ",
 ButtonBox["SequenceAlignment",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/SequenceAlignment"],
 ", ",
 ButtonBox["ProteinData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ProteinData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/ScientificAndTechnicalData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Finance and economic data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["FinancialData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FinancialData"],
 ", ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/FinancialAndEconomicData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Mathematical data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["FiniteGroupData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FiniteGroupData"],
 ", ",
 ButtonBox["GraphData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphData"],
 ", ",
 ButtonBox["KnotData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/KnotData"],
 ", ",
 ButtonBox["LatticeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LatticeData"],
 ", ",
 ButtonBox["PolyhedronData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PolyhedronData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/MathematicalData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Linguistic data",
  FontWeight->"Bold"],
 ": ",
 ButtonBox["DictionaryLookup",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/DictionaryLookup"],
 ", ",
 ButtonBox["WordData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WordData"],
 ", ",
 ButtonBox["ExampleData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ExampleData"],
 ", ",
 ButtonBox["\[RightGuillemet]",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/LinguisticData"]
}], "Item"]
}, Open  ]],

Cell[TextData[{
 "This seminar will introduce you to data collections in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", starting with a brief discussion of their scope. We will then turn to \
syntax and usage, and finally look at several concrete examples so that you \
can begin to get an idea of the kinds of things you can do with them in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Introduction to Data Collections", "Section"],

Cell[TextData[{
 "A data function works much the same way as any other function in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", but returns stored data. "
}], "Text"],

Cell[TextData[{
 "The basic syntax is ",
 Cell[BoxData[
  RowBox[{"xxxData", "[", "\"\<\!\(\*
StyleBox[\"str\", \"TI\"]\)\>\"", "]"}]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"FinancialData", "[", "\"\<AAPL\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", "\"\<CyclosporinA\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"AstronomicalData", "[", "\"\<StarBrightest10\>\"", "]"}]], "Input",
 CellChangeTimes->{3.479219396228943*^9}],

Cell[BoxData[
 RowBox[{"GenomeData", "[", "\"\<COX6BP3\>\"", "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Introduction to Data Collections: Basic examples", "Section"],

Cell["\<\
The interface to the data collections is much easier than standard database \
querying methods.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"CityData", "[", "\"\<Paris\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"CityData", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<Paris\>\"", ",", "\"\<IleDeFrance\>\"", ",", "\"\<France\>\""}], 
    "}"}], ",", "\"\<Population\>\""}], "]"}]], "Input"],

Cell["You can compute with them.", "MathCaption"],

Cell[BoxData[
 FractionBox[
  RowBox[{"AstronomicalData", "[", 
   RowBox[{"\"\<Saturn\>\"", ",", "\"\<OrbitPeriod\>\""}], "]"}], 
  RowBox[{"AstronomicalData", "[", 
   RowBox[{"\"\<Earth\>\"", ",", "\"\<OrbitPeriod\>\""}], "]"}]]], "Input"],

Cell["You can plot them.", "MathCaption"],

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{"FinancialData", "[", 
   RowBox[{"\"\<AAPL\>\"", ",", "\"\<2005\>\""}], "]"}], "]"}]], "Input"],

Cell["You can manipulate them.", "MathCaption"],

Cell[BoxData[
 RowBox[{"TabView", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "\[Rule]", 
      RowBox[{"PolyhedronData", "[", "#", "]"}]}], "&"}], ",", 
    RowBox[{"PolyhedronData", "[", "\"\<Platonic\>\"", "]"}]}], "]"}], 
  "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Introduction to Data Collections: Extensible data", "Section"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not ship with (most of) the data: it is stored on our servers and \
pushed to the user over the internet."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "The first time you use a data function, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " contacts our data server, which sends basic indexing info."
}], "Item"],

Cell[TextData[{
 "The first time you query for an entity/property in a session, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " downloads the most updated data from our server, which gets stored locally \
on your hard drive in a compressed file."
}], "Item"],

Cell[TextData[{
 "In a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session, after a data function is first used, data gets cached in memory."
}], "Item"]
}, Open  ]],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Wolfram|Alpha Data", "Section"],

Cell[TextData[{
 "There is an additional data source in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \[LongDash] Wolfram|Alpha. With it, you can ask questions using plain \
English."
}], "Text"],

Cell["population of Paris", "WolframAlphaShort"],

Cell["orbital period of Saturn vs. Earth", "WolframAlphaShort"],

Cell[TextData[{
 "In fact, there is a programmatic interface to Wolfram|Alpha in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"?", "WolframAlpha"}]], "Input"],

Cell[BoxData[
 RowBox[{"WolframAlpha", "[", 
  RowBox[{"\"\<Apple close Jan 1, 2011 to Jan 21 2011\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<DateRangeSpecified:Close:FinancialData\>\"", ",", "1"}], 
      "}"}], ",", "\"\<TimeSeriesData\>\""}], "}"}]}], "]"}]], "Input"],

Cell[TextData[{
 "For example, this uses data from Wolfram|Alpha and processes it in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to create a \[OpenCurlyDoubleQuote]weather pod\[CloseCurlyDoubleQuote]."
}], "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"info", "=", 
   RowBox[{"WolframAlpha", "[", 
    RowBox[{"\"\<weather Chicago\>\"", ",", "\"\<PodInformation\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ids", "=", 
   RowBox[{"Rest", "[", 
    RowBox[{"DeleteDuplicates", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], "&"}], " ", "/@", 
      " ", "info"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"titles", "=", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"#", ",", " ", "0"}], "}"}], ",", "\"\<Title\>\""}], "}"}], 
       "&"}], ",", "ids"}], "]"}], " ", "/.", " ", "info"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"contents", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{"Cases", "[", 
       RowBox[{"info", ",", 
        RowBox[{
         RowBox[{"_", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"#", ",", "_"}], "}"}], ",", "\"\<Content\>\""}], "}"}],
            ",", "val_"}], "]"}], "\[RuleDelayed]", "val"}]}], "]"}], "]"}], 
     "&"}], " ", "/@", " ", "ids"}]}], ";"}], "\n", 
 RowBox[{"MenuView", "[", 
  RowBox[{
   RowBox[{"Thread", "[", 
    RowBox[{"titles", " ", "\[Rule]", " ", "contents"}], "]"}], ",", 
   RowBox[{"ImageSize", " ", "\[Rule]", " ", "Automatic"}]}], "]"}]}], "Input"],

Cell["\<\

\
\>", "Spacer"],

Cell["\<\
Several Wolfram|Alpha resources are available and so we will not focus on it \
in this seminar. \
\>", "Text"],

Cell["", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Introduction to Data Collections: Initial scope", "Section"],

Cell["There are three different types of data collections:", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Pre-computed",
  FontWeight->"Bold"],
 ": ",
 StyleBox["most of the mathematical data is precomputed in-house: ",
  FontWeight->"Plain"],
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", ",
 ButtonBox["GraphData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/GraphData"],
 ", ",
 ButtonBox["KnotData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/KnotData"],
 ", ",
 ButtonBox["LatticeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LatticeData"],
 ", ",
 ButtonBox["PolyhedronData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/PolyhedronData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Aggregated from publicly available sources",
  FontWeight->"Bold"],
 StyleBox[": ",
  FontWeight->"Plain"],
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", ",
 ButtonBox["AstronomicalData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/AstronomicalData"],
 ", ",
 ButtonBox["CityData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CityData"],
 ", ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 ", ",
 ButtonBox["ChemicalData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ChemicalData"],
 ", ",
 ButtonBox["ElementData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ElementData"],
 ", ",
 ButtonBox["IsotopeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/IsotopeData"],
 ", ",
 ButtonBox["ParticleData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ParticleData"],
 ", ",
 ButtonBox["WordData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WordData"]
}], "Item"],

Cell[TextData[{
 StyleBox["Direct connection to web services-based provider",
  FontWeight->"Bold"],
 StyleBox[": ",
  FontWeight->"Plain"],
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", ",
 ButtonBox["FinancialData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeatherData"],
 ", ",
 ButtonBox["WeatherData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WeatherData"]
}], "Item"]
}, Open  ]],

Cell["", "Spacer"],

Cell[TextData[{
 "Integrated data sources: ",
 ButtonBox["Documentation",
  BaseStyle->"Link",
  ButtonData->"guide/DataCollections"]
}], "Text"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Syntax", "Section"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"XXXXData", "[", 
   RowBox[{"\"\<\!\(\*
StyleBox[\"Entity\", \"TI\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"Property\", \"TI\"]\)\>\""}], "]"}]]],
 " returns a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " expression. Arguments are generally given as strings."
}], "Text"],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{"\"\<Einsteinium\>\"", ",", "\"\<DiscoveryYear\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"\"\<Tokyo\>\"", ",", "\"\<WindSpeed\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"FinancialData", "[", 
  RowBox[{"\"\<^DJI\>\"", ",", "\"\<Members\>\""}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell["\<\
Sometimes data is not available from the sources for a particular entity.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"CountryData", "[", 
  RowBox[{"\"\<Cuba\>\"", ",", "\"\<PovertyFraction\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{"\"\<Helium\>\"", ",", "\"\<MohsHardness\>\""}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell["Missing values are ignored in plotting functions.", "MathCaption"],

Cell[BoxData[
 RowBox[{"mh", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ElementData", "[", 
     RowBox[{"#", ",", "\"\<MohsHardness\>\""}], "]"}], "&"}], "/@", 
   RowBox[{"ElementData", "[", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", "mh", "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Syntax: Getting additional information", "Section"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"XXXXData", "[", 
   RowBox[{"\"\<\!\(\*
StyleBox[\"Entity\", \"TI\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"Property\", \"TI\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"Annotation\", \"TI\"]\)\>\""}], "]"}]]],
 " gives additional info. ",
 StyleBox["Annotation",
  FontSlant->"Italic"],
 " can be used to get information such as units, and notes on entity \
properties."
}], "Text"],

Cell["Units:", "MathCaption"],

Cell[BoxData[
 RowBox[{"AstronomicalData", "[", 
  RowBox[{"\"\<Earth\>\"", ",", "\"\<RotationPeriod\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"AstronomicalData", "[", 
  RowBox[{
  "\"\<Earth\>\"", ",", "\"\<RotationPeriod\>\"", ",", "\"\<Units\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"\"\<KCMI\>\"", ",", "\"\<Temperature\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"\"\<KCMI\>\"", ",", "\"\<Temperature\>\"", ",", "\"\<Units\>\""}], 
  "]"}]], "Input"],

Cell["", "Spacer"],

Cell[TextData[{
 "Significant digits using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s built-in precision tagging:"
}], "MathCaption",
 CellChangeTimes->{{3.4191680292936*^9, 3.4191680304955997`*^9}}],

Cell[BoxData[
 RowBox[{"d", "=", 
  RowBox[{"ChemicalData", "[", 
   RowBox[{"\"\<Aspirin\>\"", ",", "\"\<Density\>\""}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Precision", "[", "d", "]"}]], "Input"],

Cell["", "Spacer"],

Cell["The decay width in MeV for the muon particle.", "MathCaption"],

Cell[BoxData[
 RowBox[{"ParticleData", "[", 
  RowBox[{"\"\<Muon\>\"", ",", "\"\<Width\>\""}], "]"}]], "Input"],

Cell["", "Spacer"],

Cell["Uncertainty interval:", "MathCaption"],

Cell[BoxData[
 RowBox[{"ParticleData", "[", 
  RowBox[{"\"\<Muon\>\"", ",", "\"\<Width\>\"", ",", "\"\<Interval\>\""}], 
  "]"}]], "Input"],

Cell["", "Spacer"],

Cell["Notes:", "MathCaption"],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{"\"\<Helium\>\"", ",", "\"\<MeltingPoint\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{
  "\"\<Helium\>\"", ",", "\"\<MeltingPoint\>\"", ",", "\"\<Note\>\""}], 
  "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Syntax: Getting lists of entities", "Section"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"XXXXData", "[", "All", "]"}]]],
 " gives a list of entities."
}], "Text"],

Cell[BoxData[
 RowBox[{"ElementData", "[", "All", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AstronomicalData", "[", "All", "]"}], "//", "Length"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Syntax: Getting lists of properties", "Section"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"XXXXData", "[", "\"\<Properties\>\"", "]"}]]],
 " gives a list of properties."
}], "Text"],

Cell[BoxData[
 RowBox[{"ProteinData", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellID->426380316],

Cell[BoxData[
 RowBox[{"WeatherData", "[", "\"\<Properties\>\"", "]"}]], "Input",
 CellID->12846291],

Cell[BoxData[
 RowBox[{"GenomeData", "[", "\"\<Properties\>\"", "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Syntax: Getting lists of classes", "Section"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"XXXXData", "[", "\"\<Classes\>\"", "]"}]]],
 " gives a list of classes."
}], "Text"],

Cell[BoxData[
 RowBox[{"AstronomicalData", "[", "\"\<Classes\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"GenomeData", "[", "\"\<Classes\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"CountryData", "[", "\"\<Classes\>\"", "]"}], ",", "20"}], 
  "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell["\<\
In the remaining sections we will work through some examples from several \
different data collections. These will range from fairly basic to examples \
combining some more significant programming.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: CountryData", "Section"],

Cell["\<\
Properties of countries, including current and time-series data.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "CountryData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["CountryData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "239", 
     RowBox[{"{", 
      RowBox[{"\<\"Greece\"\>", ",", "\<\"Belgium\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "223", 
     RowBox[{"{", 
      RowBox[{"\<\"NaturalHazards\"\>", ",", "\<\"NaturalGasExports\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "306", 
     RowBox[{"{", 
      RowBox[{"\<\"PersianGulf\"\>", ",", "\<\"Mediterranean\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of CountryData", "PictureCaption"],

Cell["Display the flag of Greenland.", "MathCaption"],

Cell[BoxData[
 RowBox[{"CountryData", "[", 
  RowBox[{"\"\<Greenland\>\"", ",", "\"\<Flag\>\""}], "]"}]], "Input"],

Cell["Some miscellaneous data on Greenland.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"#", "\[Rule]", 
      RowBox[{"CountryData", "[", 
       RowBox[{"\"\<Greenland\>\"", ",", "#"}], "]"}]}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Languages\>\"", ",", "\"\<LifeExpectancy\>\"", ",", 
      "\"\<MedianAge\>\"", ",", "\"\<PhoneLines\>\"", ",", 
      "\"\<InternetUsers\>\"", ",", "\"\<MajorIndustries\>\"", ",", 
      "\"\<GDP\>\"", ",", "\"\<ElectricalGridPlugImages\>\"", ",", 
      "\"\<Population\>\""}], "}"}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{3.431260158275526*^9}],

Cell["\<\
Find the countries with the 10 highest rate of oil consumption.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"DisplayTable", "[", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"SortBy", "[", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#1", ",", 
             RowBox[{"CountryData", "[", 
              RowBox[{"#1", ",", "\"\<OilConsumption\>\""}], "]"}]}], "}"}], 
           "&"}], ")"}], "/@", 
         RowBox[{"CountryData", "[", "]"}]}], ",", 
        RowBox[{
         RowBox[{"FreeQ", "[", 
          RowBox[{"#1", ",", "_Missing"}], "]"}], "&"}]}], "]"}], ",", 
      "Last"}], "]"}], ",", 
    RowBox[{"-", "10"}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"CountryData", "[", 
  RowBox[{
  "\"\<China\>\"", ",", "\"\<OilConsumption\>\"", ",", "\"\<Units\>\""}], 
  "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"],

Cell[CellGroupData[{

Cell["GDP vs. life expectancy", "MoreExamplesSection",
 CellChangeTimes->{{3.47922516240084*^9, 3.479225164807898*^9}}],

Cell[TextData[{
 "Plot GDP ",
 StyleBox["vs.",
  FontSlant->"Italic"],
 " life expectancy for countries in Asia. Diameter of bubbles is proportional \
to population size."
}], "Text",
 CellChangeTimes->{{3.479225293910315*^9, 3.479225308636464*^9}, {
  3.4792253543514967`*^9, 3.479225377574892*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"CountryData", "[", 
            RowBox[{"c", ",", "#1"}], "]"}], "&"}], ")"}], "/@", 
         RowBox[{"{", 
          RowBox[{
          "\"\<LifeExpectancy\>\"", ",", "\"\<GDPPerCapita\>\"", ",", 
           "\"\<Population\>\""}], "}"}]}], "}"}], ",", 
       RowBox[{"Column", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CountryData", "[", 
           RowBox[{"c", ",", "\"\<Name\>\""}], "]"}], ",", 
          RowBox[{"CountryData", "[", 
           RowBox[{"c", ",", "\"\<Population\>\""}], "]"}]}], "}"}], "]"}]}], 
      "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"CountryData", "[", "\"\<Asia\>\"", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"BubbleChart", "[", 
  RowBox[{"data", ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Life expectancy\>\"", ",", "\"\<GDP/capita\>\""}], 
     "}"}]}]}], "]"}]}], "Input",
 CellID->653064214]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot ozone density", "MoreExamplesSection"],

Cell["\<\
Show ozone density around the world (total ozone values in Dobson Units): \
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<ExampleData/ozonemap.hdf\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Datasets\>\"", ",", "\"\<TOTAL_OZONE\>\""}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellID->611876539],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{
   RowBox[{"Reverse", "[", "data", "]"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "180"}], ",", "180"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "}"}]}]}], "]"}]], "Input",\

 CellID->206798417],

Cell[TextData[{
 "Use ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 " to add country outlines: "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"outlines", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"CountryData", "[", 
        RowBox[{"r", ",", "\"\<SchematicPolygon\>\""}], "]"}], ",", 
       RowBox[{"Polygon", "[", "_Missing", "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SouthAmerica\>\"", ",", "\"\<NorthAmerica\>\"", ",", 
         "\"\<Africa\>\"", ",", "\"\<Europe\>\"", ",", "\"\<Asia\>\"", ",", 
         "\"\<Australia\>\""}], "}"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellID->421547818],

Cell["Put everything together adding a legend.", "MathCaption"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListDensityPlot", "[", 
      RowBox[{
       RowBox[{"Reverse", "@", "data"}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", "\"\<DeepSeaColors\>\""}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"DataRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "180"}], ",", "180"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FaceForm", "[", "]"}], ",", 
          RowBox[{"EdgeForm", "[", 
           RowBox[{"Opacity", "[", "0.5", "]"}], "]"}], ",", "outlines"}], 
         "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "180"}], ",", "220"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", "None", ",", "None", ",", "True"}], "}"}]}], 
       ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", "None", ",", "None", ",", 
          RowBox[{"Thread", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"-", "80"}], ",", "80", ",", "20"}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{"100", ",", "600", ",", "60"}], "]"}]}], "}"}], "]"}]}],
          "}"}]}]}], "]"}], ",", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"ColorData", "[", "\"\<DeepSeaColors\>\"", "]"}], "[", 
            RowBox[{"Rescale", "[", 
             RowBox[{"i", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "88"}], ",", "88"}], "}"}]}], "]"}], "]"}], ",", 
           
           RowBox[{"Rectangle", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"200", ",", "i"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"220", ",", 
               RowBox[{"i", "+", "16"}]}], "}"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"-", "88"}], ",", "88", ",", 
           RowBox[{"176", "/", "11"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"None", ",", "None", ",", "None", ",", "True"}], "}"}]}]}], 
      "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic reports", "MoreExamplesSection"],

Cell["\<\
Create a button that automatically grabs some country data and creates a \
report.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Country data notebook\>\"", ",", 
   RowBox[{"CreateDocument", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"CellGroup", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TextCell", "[", 
            RowBox[{
             RowBox[{"CountryData", "[", 
              RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], ",", 
             "\"\<Section\>\""}], "]"}], ",", 
           RowBox[{"ExpressionCell", "[", 
            RowBox[{
             RowBox[{"GraphicsRow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"CountryData", "[", 
                  RowBox[{"#", ",", "\"\<Shape\>\""}], "]"}], ",", 
                 RowBox[{"Quiet", "[", 
                  RowBox[{"DateListPlot", "[", 
                   RowBox[{
                    RowBox[{"CountryData", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"\"\<Population\>\"", ",", 
                    RowBox[{"{", 
                    RowBox[{"1970", ",", "2008"}], "}"}]}], "}"}]}], "]"}], 
                    ",", 
                    RowBox[{"PlotLabel", "\[Rule]", 
                    RowBox[{"Style", "[", 
                    RowBox[{
                    "\"\<Population growth\>\"", ",", "\"\<Text\>\""}], 
                    "]"}]}]}], "]"}], "]"}]}], "}"}], ",", 
               RowBox[{"Frame", "\[Rule]", "All"}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}], ",", 
             "\"\<Output\>\""}], "]"}]}], "}"}], ",", "Closed"}], "]"}], 
       "&"}], "/@", 
      RowBox[{"CountryData", "[", "\"\<Europe\>\"", "]"}]}], ",", 
     RowBox[{
     "StyleDefinitions", "\[Rule]", "\"\<Creative/PastelColor.nb\>\""}]}], 
    "]"}], ",", 
   RowBox[{"Method", "\[Rule]", "\"\<Queued\>\""}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: CityData", "Section"],

Cell["\<\
Properties of cities worldwide.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CityDataTable", "[", "fun_Symbol", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "data", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"fun", ",", "\"\<Section\>\"", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Lucida Grande\>\""}], ",", 
            RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], ",", 
          "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\>\"", ",", 
          "\"\<\!\(\*\n\
StyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\)\>\"", ",", 
          "\"\<\!\(\*\n\
StyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\)\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<Entities\>\"", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"fun", "[", "]"}], "]"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{"fun", "[", "]"}], ",", "2"}], "]"}], ",", 
            "\"\<\[Ellipsis]\>\""}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<Properties\>\"", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"fun", "[", "\"\<Properties\>\"", "]"}], "]"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{"fun", "[", "\"\<Properties\>\"", "]"}], ",", "2"}], 
             "]"}], ",", "\"\<\[Ellipsis]\>\""}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CellPrint", "[", 
      RowBox[{"TextCell", "[", 
       RowBox[{
        RowBox[{"Grid", "[", 
         RowBox[{"data", ",", 
          RowBox[{"Frame", "\[Rule]", "All"}], ",", 
          RowBox[{"BaseStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<Menu\>\"", ",", 
             RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
          RowBox[{"Spacings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1.25"}], "}"}]}], ",", 
          RowBox[{"Alignment", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Center", ",", "Automatic", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "Left"}], ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", "Left"}]}], 
              "}"}]}], "}"}]}], ",", 
          RowBox[{"Background", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Lighter", "[", 
                RowBox[{"Black", ",", ".9"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"White", ",", 
                 RowBox[{"Lighter", "[", 
                  RowBox[{
                   RowBox[{"Blend", "[", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue"}], "}"}], "]"}], ",", ".9"}], 
                  "]"}]}], "}"}]}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Dividers", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"Lighter", "[", 
                 RowBox[{"Gray", ",", ".5"}], "]"}], "}"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"{", "False", "}"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}]}], "}"}]}], "}"}]}]}], 
         "]"}], ",", "\"\<DisplayDataTable\>\""}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"CityDataTable", "[", "CityData", "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["CityData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "163893", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\<\"JelczLaskowice\"\>", ",", "\<\"Dolnoslaskie\"\>", 
         ",", "\<\"Poland\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\<\"Raholt\"\>", ",", "\<\"Akershus\"\>", 
         ",", "\<\"Norway\"\>"}], "}"}], ",", "\<\"\[Ellipsis]\"\>"}], 
      "}"}]},
    {"\<\"Properties\"\>", "14", 
     RowBox[{"{", 
      RowBox[{"\<\"RegionName\"\>", ",", "\<\"AlternateNames\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Automatic}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of CityData", "PictureCaption"],

Cell["Create a link to a city map.", "MathCaption",
 CellChangeTimes->{{3.479225614791469*^9, 3.479225620310238*^9}}],

Cell[BoxData[
 RowBox[{"Hyperlink", "[", 
  RowBox[{"CityData", "[", 
   RowBox[{"\"\<Marseille\>\"", ",", "\"\<LocationLink\>\""}], "]"}], 
  "]"}]], "Input"],

Cell["\<\
Find city names that occur most frequently in India.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Tally", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CityData", "[", 
       RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], "&"}], ",", 
     RowBox[{"CityData", "[", 
      RowBox[{"{", 
       RowBox[{"All", ",", "\"\<India\>\""}], "}"}], "]"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell["Sort on the second element in each list and take the top 10.", \
"MathCaption"],

Cell[BoxData[
 RowBox[{"top10", "=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"SortBy", "[", 
     RowBox[{"data", ",", "Last"}], "]"}], ",", 
    RowBox[{"-", "10"}]}], "]"}]}]], "Input"],

Cell["Put the data in a formatted grid.", "MathCaption"],

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{"top10", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<City Name\>\"", ",", "\"\<Frequency of Occurrence\>\""}], 
      "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}]}], ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Left", ",", "Center"}], "}"}], ",", "Automatic"}], "}"}]}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "All"}], ",", 
   RowBox[{"Background", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"LightBlue", ",", "LightGray"}], "}"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", "\[Rule]", "LightYellow"}], "}"}]}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"BaseStyle", "\[Rule]", "\"\<Text\>\""}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Map of Japan", "MoreExamplesSection"],

Cell[TextData[{
 "In this extended example, we will create an outline map of Japan, showing \
many of the cities and use a ",
 ButtonBox["Tooltip",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Tooltip"],
 " to give the name of the cities."
}], "Text"],

Cell["This gets a list of all the cities in Japan.", "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"japanCities", "=", 
   RowBox[{"CityData", "[", 
    RowBox[{"{", 
     RowBox[{"All", ",", "\"\<Japan\>\""}], "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Length", "[", "japanCities", "]"}]}], "Input"],

Cell["\<\
There are cities on the list for which information may be missing. Here we \
select only those cities that have latitude and longitude information \
available.\
\>", "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"japanCities2", "=", 
   RowBox[{"Cases", "[", 
    RowBox[{"japanCities", ",", 
     RowBox[{"city_", "/;", 
      RowBox[{"VectorQ", "[", 
       RowBox[{
        RowBox[{"CityData", "[", 
         RowBox[{"city", ",", "\"\<Coordinates\>\""}], "]"}], ",", 
        "NumericQ"}], "]"}]}], ",", "Infinity"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Length", "[", "japanCities2", "]"}]}], "Input"],

Cell["\<\
The data set is constructed to give the name of the city and the political \
district in which it is located. We use rules to reduce those cities given as \
a list to the name of the city.\
\>", "MathCaption",
 CellChangeTimes->{{3.425401441489957*^9, 3.425401460004442*^9}, {
  3.425401558217993*^9, 3.425401609337412*^9}}],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"japanCities2", ",", 
   RowBox[{"-", "10"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"Union", "@", " ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"Point", "[", 
          RowBox[{"Reverse", "[", 
           RowBox[{"CityData", "[", 
            RowBox[{"#", ",", "\"\<Coordinates\>\""}], "]"}], "]"}], "]"}], 
         ",", 
         RowBox[{"#", "/.", 
          RowBox[{
           RowBox[{"List", "[", 
            RowBox[{"a_", ",", "b__"}], "]"}], "\[RuleDelayed]", " ", 
           "a"}]}]}], "]"}], "&"}], ",", "japanCities2"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.42539997726432*^9, 3.425400095074589*^9}, {
  3.425400199809424*^9, 3.425400201408485*^9}, {3.425400604862131*^9, 
  3.425400606179325*^9}, {3.425401071725254*^9, 3.425401104395802*^9}, {
  3.4312610653303013`*^9, 3.431261069757873*^9}}],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"points", ",", 
   RowBox[{"-", "10"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Or make the tooltip label of the form ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    StyleBox["cityname", "TI"], ",", 
    StyleBox["population", "TI"]}], "}"}]]],
 "."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"points", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"Point", "[", 
         RowBox[{"Reverse", "[", 
          RowBox[{"CityData", "[", 
           RowBox[{"#", ",", "\"\<Coordinates\>\""}], "]"}], "]"}], "]"}], 
        ",", 
        RowBox[{"#", "/.", 
         RowBox[{
          RowBox[{"List", "[", 
           RowBox[{"a_", ",", "b__"}], "]"}], "\[RuleDelayed]", " ", 
          RowBox[{"{", 
           RowBox[{"a", ",", 
            RowBox[{"CityData", "[", 
             RowBox[{"a", ",", "\"\<Population\>\""}], "]"}]}], "}"}]}]}]}], 
       "]"}], "&"}], ",", "japanCities2"}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Here is a plot of the cites. Because several of the cites lie in the Pacific \
Ocean our plot is quite large.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AbsolutePointSize", "[", "1", "]"}], ",", "Red", ",", 
     "points"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.42540010604321*^9, 3.425400112849779*^9}, {
  3.42540025102512*^9, 3.425400274887536*^9}, {3.4254003133314743`*^9, 
  3.425400318105217*^9}}],

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"points", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.4254003744960012`*^9, 3.425400416412046*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s select out the cities on the main islands of Japan; \
i.e., those that have latitude greater than 130\[Degree].\
\>", "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"newPoints", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"points", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1", ",", "1"}], "]"}], "]"}], ">", "130"}], 
      "&"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Graphics", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"AbsolutePointSize", "[", "1", "]"}], ",", "Purple", ",", 
    "newPoints"}], "}"}], "]"}]}], "Input"],

Cell[TextData[{
 "Finally, get the outline of Japan from ",
 ButtonBox["CountryData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/CountryData"],
 " and show that together with the cities."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"JapanPoints", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"Reverse", ",", 
     RowBox[{"CountryData", "[", 
      RowBox[{"\"\<Japan\>\"", ",", "\"\<FullCoordinates\>\""}], "]"}], ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"DarkOliveGreen", ",", 
     RowBox[{"EdgeForm", "[", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thin"}], "}"}], "]"}], ",", 
     RowBox[{"Polygon", "[", "JapanPoints", "]"}], ",", "\[IndentingNewLine]",
      "LightPink", ",", 
     RowBox[{"PointSize", "[", ".002", "]"}], ",", "newPoints"}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"Background", "\[Rule]", "Cerulean"}]}], "]"}]}], "Input"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.333293, 0.419599, 0.184301], EdgeForm[{GrayLevel[0], Thickness[
   Tiny]}], PolygonBox[{CompressedData["
1:eJxdfHecT8f3viiJlg8huli99y6IuUWJ3js7Vw1WiN47qxNWt1ZfotfovQuR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     "], CompressedData["
1:eJxdWGdUVUcXRWIv2MUSVCxYsICxYOWoby4GY8EWo0ada49dY0NFUBFFDYIV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     "], CompressedData["
1:eJxdWXlcz1kXbiwzBmFimLHFa8swRrYWzD2ktCihUolu2RNJRSUtEpOQLYwl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     "], CompressedData["
1:eJxNVwlYiNkajttky3CbGFtKmLLMkNGYxtD7ZywzuB7uXJJljlQMUhgzpHK1
RyFJWVKptNraZDTJ0kKWRJYxGIxrXLJ0yYRx73v+/zy6//P09Lyd/z/nO9/3
fu/71cvdZ4pnSxMTk3L+yN+lSd0GXY8SyP/3ssJOhwFnx9k/fkmc2vvQ6/AS
wEXcrbFdJ+D3Sc7IaVzfNbroP39GCBwujjZ7UgS8znpaOzFM4E769hM2+4GV
9z9waB0iYPtn4/JfcwF+fa0pSGDQ9T5ma/YALQeEd75KbB6bFTT5QPP7p2eN
r2pVCBRUfV+axP0qvIf+82AxsPNxRsX4cIGZG449t2c8Fya6d3SNFBjeYmJI
+yNAcc/QB5MZ76bq1eOOlAO99i+dHxMtkMxr9Tmr9lsvMGF32zF964DqFF4g
RiDp84EXt90AxvA6FzcLHHXq/dWqO0Bw2amU0VuEEfe/AJkOc2ILuVAPuDpx
R2KbuY/cXBqBbF7fPUFghsvI36++BtYtuvcqK1HA7lhYxrS2mnEe8e8LBjTG
t9eM/O0QyHqv5osrHZux99SAvUUWmnHeTgFL54pfCi01JCzmycRmFvwLsZ6P
JIFJ+zZ7RrynYeq7H+YlEkcdWtimiftdawpcUJIs0Cf+vxsD22mYMCxSEykC
X7ysf1DWQsNLLn+XKox9XwJnTvNJE2jTfefsfq8AnQ+ZAgfPm9xoyfePP7ef
uSFb4MHtT7qV/UXFm8v4GP4TUw15iQxoX/P+ki7XDgi88Xzx25wW6v0CgZ+7
+88Z8o6GAEmwQoFFbZqS5zE+VtOpgOu378flmXfV8MffySRi52kzDhzpoWHZ
/Jh6/3yBxaktSt6x1UD2nH1BHDF31i9jemvoasoMFCn+Eqf5jmh7+aAw8tBH
wxRJkEO8j/vqqyP6afAYfnNS9GF+H+p2oWSAZtS/ROC7wk6vqj/SUG5DAv1E
/vM4i6EaWM2ntcS2i1b4pRPvljQvFVjIcl7/WIPl3rG3/MoEMh3PDP+bg4Zt
W/kcFYi2r29fOljDx/I5LhBQkz/9Ode3jCJDiFt9kzChE/czWxM3at0JgZR5
vIGjZvC7XOCHD3tZP+M6o41fXCHQg+n7B/eT6aoiPsT260zcV25QKfDIn4kd
okHS4TGx/t0QFV+VwOOTx132OKh6VDXf186hdW6PUwIXSu5YWjE/8vMM4o6y
4e00SLqXVrPf7Tq0K/xAQ2bF+GGRZwRGrnTNdOyrGX1yVsDnSejJr3tpqFvB
hq4RMPFZY1purSG2Cwt0XmDcLT/LvdaKrxeEoRusp96/F1W8xKtJz1ji7KDJ
XybaKD4Qm96Lsq+30vCDJGidwKw3o17Wd1f5Jj7hsufbG12bcdKZ7HN1nTVD
X/g92ZhyyVyDlRsZwPOzxddT7FprkNd347pF+k9H3zfTIOWjntim1uebVmbN
+5E9K135vq4rl5rxeV4/kPjkXee0m2aqXsSD+7PD2R+SbvHETR3uH9zH/tF1
8ooA0m6Wvku90Ot1WSBQb2CA0XgMJ3YaPXZp0wu8PW9qUs6eK8S6jjIevU6N
Sm+IjwRYfTrvGd7Gk7Gyst9nDYC8fi7PmysDfgKj34h1Hj0CTORzRen1Q8Ca
5Sjm90Uh/jX595V+1wp0m8wOvqXiO6fwVRj8Yf3dnh/6eS31Ve8X8kPv8/NA
PyncpwVY1S6mZ5V+kl96XU8A5tIQTlIP2F4D6S872F5LyU897gIVHzFXR/XI
UX5Afut9nAF4yYf9oP89Q+k/++cO5WpGJrCEcpDK/tLjov/oeTsm8NHG5D8c
6F+9daEQiKy98Wu74yp+6sXStet/a6hU+SoWKH+Tt6qhCm/1Rdd9Yr3e1J+Y
wFef+Vao++Up/TsKg1/Uy3NedfcW8H563DkCUm6r6W96nrKov5TD/DxVX2It
6HZlQiogy9GTeD3bfVwCwNMsgqnPXpLQW1R9dgtMf5+KTSzb3ZI44tm1y2ti
ASmPeekCyy5bNGgblF9R76U9nVoLQ3+IvaSghin/J7Zdv3xJ91AYekW/0N8L
AVZJQdkl8P2knp0XhCp/JH5A+X0VDDxhGYbRb7xlwoJg9BP9qJE2cixA1ZeY
7hbi7wvIbRfRv16YURC9Yeh9kqr3QqCScqPxfXvZIN8qvnN//b15MHSP58d5
8gIegLcsILEMv71QfGX8NtrTuadnAWSD7wiuc3qYtG8mDL1PUX5BrOsPz6P6
WzrPVvVKUvo9B4bf0I95urOjFyDtYwX9fXrYp5fKPWHoy3aB4x5UGHcVzzbq
BenBNjH0ZKsw4nBX88xWdb6Hmq84T7hKQ+H+uv7Gq/i5v+7HnD/KHu78fCDf
1/Map/yJWPd7YqdL5d5D56t5h1ifaxYDUobHxql6LQMekl6hsYoPfmo+26Tq
56f6i9hEEnyFmo82KX4shzEXxaj5aZnSm430Y/MlueuIdb/eICDTvXm56meu
b+3fJe7iShVPjOrHQMUXrhdMp6CQP7pf8PuvVgUPmhCm8s95jtNW7ssQpS9R
ii/Bil/Eet+FqPmOOPGvFPhwQKa9LffbHM4BIAqGfxInR+6/dT9O8Zv702z7
Z20H5Ng5U77fSILuUPMS49N9cCsg5cU3phnr80aM6t/tqr9jVL8kqvptUvqe
BMMfiCU9Inap+xFLGnZJU/zk952spMMofvJ8SX/ndBh+S3y3wbrWh/qnz2OM
N+rafBOfLOUfvI/eR5kqv8yHPL5DltI34rIZZFiO4mO08ov9Si+4PlgO0IXN
uPJH/gNQrObF//v/4X9wJ6fv
     "], CompressedData["
1:eJxNVA1MlWUYBcKrIRpTfnSo/GhAQ0ZZpj6FHPCn5Y2YcEPGbr4fKEm3e8Eb
tIqpRYgI/hI43JhOhwyczpClkrKGoqjMtCC7C9Sk0qv8eUEQEdGeF771+W13
3z17vp33PM85zxuQkhGX6uLk5KTnn3y/Ztx1bsAh8Na3p/BdIOGDBQVRSrfA
QJstJ9ObYLEPH+7tEDDdshbu9CRc8K/+PO2+wM9nfYLivQj/VJSd978nkOKR
uOjHaYQ7vwa2Dd0VMGTNKX3ur2FLwsZjJ6MJwW9MODqD+ZaXPNKJRA0XdW+I
nL+a0J7teew95i/0W9OTlELITOOKXWBu6vS/E9cRWG2IkTGz7970GWFyWM2+
B4wTm+adP55OGO2H9WTapvRFZRBmtw1tMnUJdOypcbeatf4CuI0iC8Evr3Nl
bY8As/ucshIclY36Bb0C+d5/Xh3MJTB7ZeNDgb3pU3LrCwkG2fBjgaeHe5tj
vidsZNWnhwQG/00++EcJIa52Vl4n45ygc1sqS7V6V/iZ4FfKVL2DAk2Gs1WH
9qv4gQCmJje0HCHs5+P0jNPLnevG1Wj1M7U7dI6ThAZuf1cf67lZnJ93mpC0
9p2/Ygc07O4Smu/N5/H0ohfXEny4jfhhjY+n2579VGDS7bDdB6oI0t7mEYGp
fVHXPqkghMrGnwvoL42PKKtQ5+ek/P+9HNcsZwWGuOADBdWEpdvM9mHGAz+1
Fo6cIEg7k1wV9HTWL5rNerj79911ChauW/ppRj3hi+JprgmMt675+MbyBg3n
1jcdXNZIkPI8GV+3m0IfXSRIm7qZr+zuzMp7lwiP49kAxm628vURTYT7QXwi
46vTV7b6XlH9HafAOWbzpNhrNOYb83ltX9Hh+juB1biEjleQs2fJNrON8KqO
/zGObLxxYnMXoa85JsVjggKrL3fsoLFcv4BHc+qmoPol+/aQbsKh9RFutokK
RsfRruaTccut2xOLL2v8I/n9bbbjhARpKM83LMCv37xFzRf7Mzn2h5LUrwhV
HL8C9s9r5uU7kVkEK9OXc95WyQBxnn3Db87Rcf23IuOzJSYay+ETgXBpcCpB
jn8t83EqdpSuVveX6x7Zbx9ZvErdD+YzxTzcGW8gfCgb7Od8yAsgjvCNqS6r
mO+DUd16GpsT52/YaLnwLFrdR8Zyffe+S7jIcqMcat4Wqvnn/Wk9+sRomU/4
5Qo/zL81L6ml7k2ClJ/DeZ2xIXneR69r+Es5kLmEr6Wh/P31l9MCzSGq3hfu
p/8AVIYe0Q==
     "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvWnu++XHvBMdJiz4Yfjsn5PD1YqXaoY+iQ7TnLtz
njM7O8DkI9ssrh1ldXZ4ekHp9k+vRIcz9R77a4H8579XfrzkmejAYTs7dD5Q
PVA3xxqPRAeV6f8n1AH5lSABID8qxfq+P1A92Fz3RIeCcx2X7nE4O6SBANC8
B7pAF0g6O2TtKZksAbT/J//L7euVnR1E1rk/rApIdPjQejLkoIGzQ629adyu
wESHRxHi2y8C+Quk9O+qBCU6lIAs1HN2WHHM27wTKB8SpL6gU8PZwZbr+uIC
IP9Flva36bLODr3T84Sagea5uhf95Afax6cL9KE/1H2izg4g4z2B8tUgi4Wc
Hf4AvecLNP/x0tlHFAScHSy3nCjbF5zo8L30wRxBXmeHg6cWum4D8jX4ubcu
43R2kG99HbgDqH4D8/MeDaB/VwG1JwHNy7pX2NX3x8mBAQR8oP7/4OQwDxS8
wPC1vHY01wTIBxk/HxgeM+5Obm/95ORw+KtGTD+Qv2btjfiy704O6PEFAPGI
ycA=
     "], CompressedData["
1:eJxTTMoPSmViYGCQA2IQffDUQtdt+gkOr6Zu4imMcXT4Efx46WyDBIdae9O4
XZGODiFA7hEgv8xfTiwrFCEva5Hukunv6CCtf1eFTTfB4ekn+Uv59o4Oyrd/
1mXpJDg4nU+7+twKqh7I/9v+5fZ1QwTfvegn/0t9R4eY/kNfNYB8gZfb1zMD
+bs8eZi0tRMcdK7MeiYL5OcLNR84pZngsGbtjfgyIH/Vx0u+SRoJDhPrflsV
6Dk6pFjf9+9VB+qPsNxyAshfIxOVYg3kPz4+Y/c0A4T85upPGwKMHR1Ywvh0
NwHNKzjXcemehaPDNw2gC4D8e5PbW6OsHR1A3mkE8qcAuZdtHB38koAmA+3z
Ajqr3c7R4RPQegEgv8Fjf62sg6PDcW/zTkcg38xmb9A0R4T+rcsqj2s6OTr8
WQl0sFaCQwfQuD3Ojg4gZ5YB+VorhS+4eCDUg4JtTwjCPVsiv+68FeXokAYC
QPUtvP7rp8Q6OrwJ3CHXCgyfsNp125LiHR0mS4B8hOCjxycAdO7JUg==
     
     "], CompressedData["
1:eJxTTMoPSmViYGBQB2IQvadksgSLWYLDUYUNRRmFNg6KQGqiaYKD5lvefQaZ
Ng5pIGCU4OC8NvNeYZSNg/jNc9+D9RMcTh12WpvpZ+NwUen2zzq9BIdPjufT
rroj+P2HvmrE2Ns4uHTnPP+tm+DAHj/DR9TGxuHflYqXakD+uygnuxeWNg5n
zwCBToJD41Tn7hxzG4cfwY+Xzgbyl9zfxzfH2MaBT3fT3PfaCQ4PdCcs+GFo
AzEXyM8zadjuYGTjADJ+pWaCQ/1vq4JzFjYOuzx5mLTVExym/59Q99vKxoHr
+uICW7UEB+uCcx2X7BD8708SF15zsXGYkSfUfADI5/NfPyXVw8bhV13WnhKg
/iuznskuB/L9kgQiLDUSHLS/Tb872R3qXiA/aeE1k/dAeWDohfEB7X/FYiJo
5mPj0Po6cIcckB+kvqBzQ6CNQ629adwuIF//rgpbY6iNQ0Dv9Dwhbah7I2wc
RNa5P6wC+hcUvF1xNg65QO98BIZf1VIdZ5lsG4eDpxa6bgOGd+w/519vgfyr
wOAzNEhwWLctqf5mro3Dqo+XfJOAfHOpA9EKwPjTjAGGEJD/+/S7k4eLbBy2
ff57pcIQ6h6gfNAOudbXQP60TTyFa4Dm3fcHOsgIYR84fo0R5oPDH8jfXytr
kV4CjR+TBIfPfcElKuU2Dj7mnY4JwPQy30bnyqwyqH9Nof4ttXFAT18A1oEO
RQ==
     "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQvUYmKsX6doJDoS3X9cUOjg4p1vf9e4F8YxBwdnQw
jdvlyXMvwSFoh1zra09Hh97peULNDxIcGO8xcXb5Ozpc9k0SiHiY4PDYTOpA
dICjwzr3h1UijxIcjmtaTToNlJdkCePTBfINdqvzc/s6OhRnTHxbcz/B4Wi/
Ybmuo6ODfOvrwB1A8126c57/tnR0eFdjbxoH5J9bdf5qmImjQ6djwtMLIPs9
5zaoaTk6zABafwDI37j/zTwbFUeHg6cWum4DujfrXmFXn4yjw7LZRxQ23Epw
6EiOveMm7eiwoQho4Y0Eh3JdRfkvQPnbP+uy9gD5TxMXXjORd3Sw3HKibN/1
BIcLLjc+fFFydCidLMESdi3BQT9vMeMeVUeH5gNAC4D8+Bk+oj1A+922ff57
5QZUvRHU/UD7uv+mfn8CdD96eAIArQWeRw==
     "], CompressedData["
1:eJxTTMoPSmViYGBQAmIQ3Z3z/PdKxwSHOlmLdBdJB4f6rD0lkx0SHGrXbUuq
B/L5dDfNfW+f4KCiUdezU9rBYUmBLdd1IH9t5r3CLjkHBwYQAKoPZl08yUrR
weGlmiHHGiDf/tidrS0qDg7r3B9WiTglOKR1JMfeUXNwiLDccqIMyNeM6T/0
VcPB4b5/7/Q8IP9djb1pnJaDQ8LTC0q3ge4B2rr8mLaDg1+SQIQl0LzdO3rZ
Pug5OBw8tdB1G9D+w5e1UyWNHBzaxW6e+w7k+yzjclM1dXD4pgE0GKi/tebC
5khbBwcXkAeB/NXnr4a9sXdwAPpOggVo303byogVrgj37Jk2gb/KzcHhy98r
FS+B/PlnV52/CuSf/x78eKlzgoON38WJMUC+8u2fdVkuCHmwP4B8hvxGlqPu
Dg76d1XYGl0TIOHiAfUPkA8K3kygPNf1xQW2bgkOUSnW9/2B9guAHADkL7xm
8t4C6F5QcC8H8h+9nLqJx9DBYR4wGLzdge49B3SIroODMQgA+VNTgQGq4+Ag
3/o6cAdQvVGogdZKYHi5bfv89wrQPVpWk07Xa0DDxxkRH6psjVOdgXz2D2Ie
ATIODl48TNrtQP+C3QmMb/T0AADo2uHT
     "], {{131.092, 30.8438}, {131.099, 
     30.8041}, {130.971, 30.5591}, {130.922, 30.465}, {130.903, 30.4038}, {
     130.888, 30.3902}, {130.871, 30.3913}, {130.864, 30.3981}, {130.859, 
     30.4333}, {130.837, 30.4707}, {130.838, 30.5058}, {130.864, 30.5591}, {
     130.883, 30.6816}, {130.913, 30.7247}, {131.036, 30.8427}, {131.061, 
     30.8529}, {131.08, 30.8495}, {131.092, 30.8438}}, CompressedData["
1:eJxTTMoPSmViYGBQBmIQrRnTf+irRIJDrb1p3K5EBweWMD7dTZIJDokhQeoL
gPwIyy0nyqQSHArXdN/OSHBwCOidnickneAg7hHwRyLawcHjYZXIOiBf6kC0
gmOkg0Pr68AdcrIJDjpXZj2TDXdwsOW6vrgAyP9e+mCOYKiDw1GFDUUZQP5m
HqCJwQ4OIY+Xzj4ik+DA7aZayhTk4ACybh/QvA9iQAsCHBxA2m2B9m9rqbmw
ORDhvlkzgSAQah6Q7zblG1s8UP2KY97mnUB+7B035gpvBweQ89yBfKDvPHm8
HBzYGqc6dwP9m/+h9WSIp4PDNOfunOfiCP5Fpds/68QSHKZtAjoQqP/0Qtdt
n0URfGWgdJZIgkOQ59wGNaB5m+a+X35MOMGhSz75XRSQv2z2EYUNQgkOGx++
nLrJBxp+QD7L8x6Nt74Ivk6q5KMIfweH3Oe/V34E8uuz9pRMBrp/SQEwxIDm
XdEGKgDy5wCNKxJB+B9k/R4g35BjjUxUiIMDKNo8gfxjuSYN24Hx81INKAPk
b4n8uvNWkoMDD5N2uxjM/ckODiDrLgH5nNLz4jSB/E7HhKcXgP5d1RToOTcB
Gp/A8Ag9uGKJH5CPnj4AU4rlYw==
     "], CompressedData["
1:eJxTTMoPSmViYGCQBWIQXTpZgiWML97hyqxnsss7LBw+XfJNEhCId7jRWOw2
pczCYd775ce8+eMd5sVpnhZIt3BQ3FCUMZE33sFnGZebaqqFA8camagUbgT/
6QWl2z/Z4h3eW7i6F2VaODz/vfLjJdZ4hxK3Kd/Y8i0cgJbpbgLygaYd31Vh
4fAj+PHS2SzxDio7/7R/qbZwMI3b5cnDFO9w5t3Jw061Fg6zZgIBY7yDrEW6
S2a9hUN3DtBEIF9CLZh1cZOFw+GvGjH9QPUpsXfcmIHuP3sGCIDm8Uxe2RTY
aeFgy3V9cQHQvre8+wxmdlk4+Jh3OiYA+WB39Vo4CDUfOLUQyAebM8nCgUm7
Xewm0P0tvP7rp0y1cFhxzNu8kzPeQXfT3PfLp0Ht44p3mHF3cnvrLAsHkPG2
XNDwWga1nyfe4Wniwmsm6y0cGqc6d+cAw2/5Cw+9/xstHBJAASSI4E8DSj8X
Rqj3SxKIsBSJd9hc/WlDwGoLhyVA068D5f0uToz5t9jCIcJyy4kyYHxNWPDD
8FmfhQN6/AEAMPbIIQ==
     "], CompressedData["
1:eJxTTMoPSmViYGBQAGIQnWJ9379XOcGhdt22pPqJDg58upvmvgfy/34rfTAH
yJ9zRGFDkUqCQ3L9TdvKCQ4OL9UMOdYA+SBly/scHH4EP146G8hfxuWmWtrl
4AASPgbU/2rqJp7CFgcHj4dVIuuA/Bk+oj1eTQ4O05y7c54D+Y9eAhU0OjiI
rHN/WKWC4G/7/PdKhWqCw+bqTxsCmh0cnv9e+fESkO93cWLMPyD/XY29aZwa
UP5V8VZRID/CcsuJMiD/UYT49osNDg7NB04tdFWDuq/OwaF833wpfaD+ZbOB
HqlycHADWQC0b+ef9i+3yx0cNhRlTHwL5LsX/eR/me/gkCQANBHIL3swR3Bp
roNDJcjDQL7jx+QzsdkODvOA3vNWRvCrQR5QSnC4/bMua0+Og0MuyMFAvsTU
K5wZRQ4OnY4JTy8A+UBbauxLHRwUQRYqJjiU6yrKf6lxcHgTuEOuVR6oXi2Y
dTEwfMDulEP4F+i7ffOB/Jceev8VWx0cvgCD5yWQL/8lJ6y2zcHBluv64gKg
eWHzV6+90e7gsKdksgQL0L73Fq7uRZ0ODl48TNrtQP6a7tsZDP0ODujxDQCR
POgV
     "], {{130.49, 30.2905}, {130.453, 30.2947}, {130.404, 30.3171}, {
     130.369, 30.3667}, {130.376, 30.4026}, {130.43, 30.4488}, {130.493, 
     30.459}, {130.569, 30.4577}, {130.629, 30.4391}, {130.67, 30.4116}, {
     130.683, 30.3699}, {130.674, 30.3276}, {130.634, 30.2988}, {130.575, 
     30.2905}, {130.49, 30.2905}}, CompressedData["
1:eJxTTMoPSmViYGCQA2IQ/SP48dLZX+IcHkWIb78YYOHg0p3z/PfHOIcvOWG1
68IsHML4dDfNfR/noHNl1jPZcAsH/bsqbI1vEXzLLSfK9j2Pc5AKvCVdE2jh
0Hzg1ELXZ3EOAb3T84SCLRxunvse/PhpnMPXnbe6/oZaOJxe6LrtM5DPHj/D
RzTGwgFo+xGFF3EOtiADcy0c/l2peKn2Ms5hzdob8WX5Fg7qhhxrZF7FOZRs
Ff19Os/C4SDQ+G2v4xwuuNz48CXLwgHs/jcIfsbEtzX2bxHmwfiSxdeFPhUi
9Cc8vaB0uxLBt+W6vrig1sJhEdB5f4HmlbhN+cZWb+GwQAro43dQ++ssHIpB
BgLDw3Z26PzVQPXTnIEB9jnOwV9OLMu3GOr/b3EOq+3CozfmQ9V/j3NgExKx
P5YD9e+POAetlcIXXDIQ/HYxYEglWzgwaQNZ36D+ibJwkG99HbgDyA/MnlU+
J8jCYU/JZAkWIF8aFBGBUP99RcQfenwCALwi6/E=
     "], CompressedData["
1:eJxTTMoPSmViYGAQA2IQrRnTf+hrRLyDw5L7+/juWDgE7ZBrfR0Z77C5+tOG
gNsWDr/qsvaURMc7NHjsr5W9YeHQLnbz3Hcg/8E+vjnGlywcVNkapzoD+ZOt
GH1bzlo4/LtS8VINqP/yvQfck09aOKyRiUqxDkfwF7lu+/w3BKFeHGhccHC8
Q2SbxbWjQD6I+9gXKL+yKdATyF9SYMt13Tveofi60CfH8xYOnY4JTy94xTv8
5H+5ff1lBP+z/KX8+OsWDiDvaPjEO8zikJ4X99LC4fBXjZh+oLx7EVDHdwuH
i0q3f9YB+ezxM3xE/1g4OAG1KwHNf96j8Zb3n4XDeaD1S4H8kq2iv08D+eX7
5kvpA92juKEoY+JfCwdweAXEOyzo3PDw5VMLh2WzjyhsCIp3OHZna0vNA6g8
UngCAPcMqqI=
     "], {{129.318, 34.3292}, {129.332, 34.3194}, {129.341, 
     34.2815}, {129.333, 34.2436}, {129.249, 34.1625}, {129.198, 34.1364}, {
     129.152, 34.1364}, {129.125, 34.1573}, {129.121, 34.1861}, {129.164, 
     34.2972}, {129.184, 34.3162}, {129.221, 34.3279}, {129.318, 
     34.3292}}, CompressedData["
1:eJxTTMoPSmViYGCQAWIQXS2yzv3hsQQHa0bfFl53R4fe6XlCzScSHBo89tfK
ejg6RKVY3/c/meCwjMtNtdTL0eHPyo+XfE8lOBjO1JKY6uPoMOeIwoaiMwkO
L7evZ34O5D+sAhp4FqEerB/Ib30duEPO1dEhSSDCcgtQfbb2t+l3nRH6JVnC
+HSdHB1+BD9eOhvInywBFLB1dLha8VLNEMiP/ef86621o8MboDGtpxHya2SA
NgD5j15O3cTj6OgAMv4E0H3LX3jo/QfyF0jp31UB8rlVNOp6gPyMiW9r7IH+
2a3Oz73VztGh0Jbr+mKgf5fuPSiuBjSfT3fT3PfHge55FCG+3dLRof/QV40Y
IL9rw8OXU60cHYxBAMj3/dwXXGLj6GDIAXQBUP/cBrVDbfZQ/wD5YH86ODp8
uuSbJADkJx6+rJ0KtD/h6QWl20cTHIC+n9wOdP9loHQEkO8d2WZxDcjfUAR0
4ZEEhzVrb8SXAc37sPyYtzlQvnbdtqR6oH70+AIAR2PAGQ==
     "], {{133.227, 
     36.2818}, {133.222, 36.3299}, {133.261, 36.3963}, {133.296, 36.409}, {
     133.342, 36.3848}, {133.388, 36.3253}, {133.387, 36.296}, {133.363, 
     36.2525}, {133.325, 36.2217}, {133.287, 36.2227}, {133.255, 36.2344}, {
     133.227, 36.2818}}, {{139.556, 42.3318}, {139.569, 42.3362}, {139.586, 
     42.3308}, {139.583, 42.2844}, {139.518, 42.2356}, {139.51, 42.1892}, {
     139.478, 42.1472}, {139.447, 42.1096}, {139.43, 42.1086}, {139.414, 
     42.1179}, {139.396, 42.1411}, {139.423, 42.2011}, {139.413, 42.2446}, {
     139.427, 42.2622}, {139.461, 42.2654}, {139.495, 42.281}, {139.556, 
     42.3318}}, CompressedData["
1:eJxTTMoPSmViYGAQA2IQHWG55USZXoLDBZcbH77McnA4vdB122fdBAeeySub
Amc6OBhyrJGJ0klwcFMtZZo1w8EBxE3RTnDQqOvZmQ2U73RMeHpBK8HB8WPy
mdjZDg5M2u1iN4F81sWTrBjnOjgUZ0x8WwNUfyrk4Iol8xwc5hxR2FAENO9J
87yzq+Y7OLht+/z3CpAfUqIy/f8CBF+pr7RQeqmDQ1SK9X1/oHvWrL0RX7bc
wWGd+8MqEaB7zUEWr3BwADnHWj/BIeCPRPH1VQ4Om+a+X34MyG+Lurzn8RoH
B6Brzn0H8t9FOdm92OjgIAIywCDBwSjUQGvlZgcHkPPsDRMc9O+qsDVudXAI
2iHX+hrI/+oV2WaxzcHhotLtn3VGCQ4LOjc8fAmUz33+e+VHID9b+9v0u0D9
y2YDPQTk84A8DjQfPTwBXx2f9g==
     "], {{129.904, 31.7982}, {129.908, 
     31.7935}, {129.907, 31.7854}, {129.896, 31.7705}, {129.83, 31.7265}, {
     129.8, 31.6933}, {129.795, 31.6331}, {129.78, 31.6162}, {129.761, 
     31.606}, {129.739, 31.606}, {129.712, 31.6236}, {129.705, 31.6798}, {
     129.715, 31.6994}, {129.843, 31.7915}, {129.873, 31.7976}, {129.904, 
     31.7982}}, {{141.176, 45.2817}, {141.252, 45.2793}, {141.313, 45.2539}, {
     141.339, 45.2189}, {141.32, 45.1735}, {141.273, 45.1511}, {141.201, 
     45.164}, {141.145, 45.1943}, {141.126, 45.2488}, {141.151, 45.2761}, {
     141.176, 45.2817}}, CompressedData["
1:eJxTTMoPSmViYGCQAGIQ3X/oq0ZMe4KDFw+Tdvs3BwdVtsapzkD+J8fzaVe/
Ozj8qsvaUwLkx95xY6747eDw6ZJvkkBHgoNSTkXV0j8ODq2vA3fIdSY4sH8Q
8wgA8rmuLy6w7UpwuLu1peYCUP2898uPeXcnOOQ3shzt/+ngsGkuUADIr123
LakeyJ9zRGFDUU+Cwz0mzi55oPqTZfvmS/UnOJSoTP8/4Z+DQ4r1ff9eIH9v
0DTFvr8ODuI3z30PBvLf6O9W5weqB3Ef9yY4eDysElkHdO+KY97mnUB+9Mb9
b+Z9cXDwMe90TADy39XYm8Z9cnAAmq5/twfqno8ODoYca2SikPhg/wLdZ2YD
tBHIf3pB6fZPoH/OrTp/NQxo3sS3QIOA/GnO3TnPPzs4LHLd9vkvMDzUD7Ut
Dweav0MOGCJAfnWzvs+yT1D/AsPvFYuJoBlQP3p4AwCmirnB
     "], {{129.815, 
     33.7699}, {129.813, 33.7584}, {129.793, 33.7412}, {129.765, 33.7251}, {
     129.724, 33.7274}, {129.694, 33.7492}, {129.672, 33.8154}, {129.672, 
     33.8487}, {129.688, 33.8717}, {129.726, 33.8861}, {129.752, 33.8849}, {
     129.785, 33.8717}, {129.803, 33.8527}, {129.8, 33.7998}, {129.815, 
     33.7699}}, {{128.623, 27.3307}, {128.602, 27.3252}, {128.572, 27.326}, {
     128.538, 27.3354}, {128.502, 27.3628}, {128.491, 27.3808}, {128.505, 
     27.3988}, {128.538, 27.4129}, {128.578, 27.4184}, {128.715, 27.4192}, {
     128.731, 27.4122}, {128.733, 27.3996}, {128.726, 27.3902}, {128.699, 
     27.3808}, {128.623, 27.3307}}, {{130.449, 32.5478}, {130.458, 32.5497}, {
     130.467, 32.5453}, {130.471, 32.5314}, {130.465, 32.4995}, {130.436, 
     32.4542}, {130.415, 32.4436}, {130.384, 32.4383}, {130.292, 32.445}, {
     130.269, 32.4561}, {130.269, 32.4826}, {130.279, 32.501}, {130.317, 
     32.5154}, {130.361, 32.5227}, {130.405, 32.5232}, {130.449, 32.5478}}, {{
     128.859, 27.8543}, {128.917, 27.8536}, {128.951, 27.8341}, {128.952, 
     27.8202}, {128.941, 27.7931}, {128.942, 27.7771}, {128.956, 27.7431}, {
     128.955, 27.7118}, {128.939, 27.6972}, {128.912, 27.6944}, {128.88, 
     27.6993}, {128.861, 27.7146}, {128.86, 27.7285}, {128.859, 27.7549}, {
     128.831, 27.807}, {128.835, 27.8362}, {128.846, 27.8466}, {128.859, 
     27.8543}}, {{141.07, 45.3101}, {141.07, 45.3027}, {141.047, 45.2954}, {
     141.025, 45.3032}, {141.014, 45.3167}, {140.998, 45.4163}, {140.972, 
     45.4578}, {140.99, 45.4866}, {141.029, 45.4998}, {141.069, 45.4817}, {
     141.087, 45.4346}, {141.078, 45.3608}, {141.07, 45.3101}}, {{126.791, 
     26.4063}, {126.785, 26.3995}, {126.77, 26.3932}, {126.74, 26.3881}, {
     126.679, 26.387}, {126.639, 26.3921}, {126.618, 26.4068}, {126.612, 
     26.4329}, {126.629, 26.4607}, {126.679, 26.4822}, {126.725, 26.4874}, {
     126.763, 26.4862}, {126.782, 26.476}, {126.791, 26.4063}}, {{123.052, 
     24.5484}, {123.069, 24.5395}, {123.07, 24.5261}, {123.066, 24.5077}, {
     123.021, 24.4803}, {122.959, 24.4697}, {122.92, 24.4714}, {122.858, 
     24.506}, {122.852, 24.5222}, {122.854, 24.5345}, {122.889, 24.5445}, {
     122.921, 24.5451}, {122.968, 24.5417}, {122.978, 24.5423}, {123.022, 
     24.5518}, {123.052, 24.5484}}, {{129.141, 28.1358}, {129.129, 28.1455}, {
     129.128, 28.1551}, {129.142, 28.1782}, {129.141, 28.1879}, {129.121, 
     28.2052}, {129.112, 28.2158}, {129.112, 28.2341}, {129.124, 28.2466}, {
     129.152, 28.2447}, {129.196, 28.2148}, {129.2, 28.1965}, {129.287, 
     28.1503}, {129.288, 28.1435}, {129.28, 28.133}, {129.244, 28.1272}, {
     129.141, 28.1358}}, {{130.292, 30.5113}, {130.309, 30.5072}, {130.328, 
     30.4946}, {130.33, 30.4734}, {130.318, 30.4549}, {130.282, 30.4377}, {
     130.235, 30.4341}, {130.183, 30.4386}, {130.151, 30.4558}, {130.14, 
     30.4752}, {130.146, 30.4937}, {130.178, 30.5104}, {130.292, 30.5113}}, {{
     139.779, 33.1936}, {139.766, 33.2056}, {139.767, 33.2105}, {139.772, 
     33.2139}, {139.782, 33.2129}, {139.79, 33.208}, {139.81, 33.1997}, {
     139.883, 33.1939}, {139.941, 33.1734}, {139.949, 33.148}, {139.932, 
     33.124}, {139.915, 33.1138}, {139.887, 33.1153}, {139.838, 33.1226}, {
     139.806, 33.1394}, {139.798, 33.1707}, {139.779, 33.1936}}, {{132.545, 
     34.1777}, {132.55, 34.1855}, {132.563, 34.185}, {132.578, 34.1733}, {
     132.614, 34.1518}, {132.633, 34.1401}, {132.628, 34.1186}, {132.623, 
     34.0859}, {132.598, 34.0678}, {132.581, 34.0698}, {132.559, 34.0874}, {
     132.539, 34.0957}, {132.498, 34.1001}, {132.487, 34.1059}, {132.495, 
     34.1225}, {132.53, 34.1523}, {132.545, 34.1777}}, {{123.823, 24.0777}, {
     123.687, 24.0817}, {123.651, 24.0968}, {123.649, 24.1078}, {123.652, 
     24.1223}, {123.674, 24.131}, {123.81, 24.1316}, {123.831, 24.1252}, {
     123.842, 24.1136}, {123.843, 24.0962}, {123.837, 24.0875}, {123.823, 
     24.0777}}, {{139.397, 34.8449}, {139.415, 34.8581}, {139.454, 34.8461}, {
     139.477, 34.7973}, {139.489, 34.7475}, {139.475, 34.7372}, {139.463, 
     34.7367}, {139.446, 34.7485}, {139.424, 34.7489}, {139.405, 34.7458}, {
     139.388, 34.7624}, {139.397, 34.7941}, {139.394, 34.8254}, {139.397, 
     34.8449}}, {{129.888, 29.9179}, {129.886, 29.8819}, {129.855, 29.8676}, {
     129.829, 29.8676}, {129.795, 29.8762}, {129.768, 29.9008}, {129.758, 
     29.9255}, {129.765, 29.9493}, {129.791, 29.9569}, {129.808, 29.954}, {
     129.842, 29.9331}, {129.866, 29.9274}, {129.878, 29.9274}, {129.888, 
     29.9179}}, {{127.999, 27.1201}, {127.978, 27.0817}, {127.876, 26.9829}, {
     127.866, 26.9817}, {127.859, 26.9875}, {127.859, 26.998}, {127.882, 
     27.041}, {127.875, 27.0608}, {127.883, 27.0748}, {127.948, 27.1236}, {
     127.969, 27.1283}, {127.985, 27.1259}, {127.999, 27.1201}}, {{128.314, 
     27.1399}, {128.325, 27.1422}, {128.344, 27.1434}, {128.367, 27.1376}, {
     128.375, 27.1236}, {128.37, 27.0934}, {128.356, 27.0783}, {128.285, 
     27.0538}, {128.257, 27.0538}, {128.239, 27.0608}, {128.236, 27.0736}, {
     128.252, 27.098}, {128.314, 27.1399}}, {{124.679, 24.6815}, {124.657, 
     24.6938}, {124.634, 24.7099}, {124.634, 24.7349}, {124.639, 24.7454}, {
     124.664, 24.7516}, {124.693, 24.7532}, {124.714, 24.7532}, {124.749, 
     24.7416}, {124.757, 24.726}, {124.76, 24.7071}, {124.75, 24.6876}, {
     124.714, 24.6804}, {124.679, 24.6815}}, {{125.096, 24.8635}, {125.06, 
     24.8673}, {125.029, 24.8731}, {125.019, 24.8837}, {125.015, 24.9404}, {
     125.021, 24.9578}, {125.037, 24.9635}, {125.064, 24.9616}, {125.093, 
     24.9424}, {125.107, 24.8875}, {125.107, 24.8721}, {125.096, 24.8635}}, {{
     139.226, 34.5087}, {139.247, 34.5101}, {139.262, 34.4964}, {139.256, 
     34.4525}, {139.237, 34.3953}, {139.222, 34.3934}, {139.208, 34.3978}, {
     139.172, 34.4222}, {139.17, 34.4432}, {139.188, 34.4759}, {139.226, 
     34.5087}}, {{132.398, 34.2468}, {132.398, 34.2561}, {132.417, 34.2693}, {
     132.437, 34.2829}, {132.461, 34.2888}, {132.475, 34.2785}, {132.476, 
     34.257}, {132.462, 34.2165}, {132.456, 34.1555}, {132.447, 34.1496}, {
     132.434, 34.1526}, {132.426, 34.1623}, {132.407, 34.2097}, {132.398, 
     34.2468}}, {{132.997, 34.2439}, {132.996, 34.2509}, {132.989, 34.2734}, {
     132.994, 34.288}, {133.022, 34.2968}, {133.064, 34.2905}, {133.08, 
     34.249}, {133.045, 34.2167}, {133.016, 34.2036}, {132.992, 34.2006}, {
     132.972, 34.2109}, {132.974, 34.2292}, {132.997, 34.2439}}, {{129.967, 
     31.8415}, {129.936, 31.8422}, {129.855, 31.8849}, {129.841, 31.9011}, {
     129.847, 31.9099}, {129.866, 31.9146}, {129.905, 31.9099}, {129.928, 
     31.9011}, {129.955, 31.9004}, {129.982, 31.8937}, {129.993, 31.8794}, {
     129.99, 31.8598}, {129.982, 31.8483}, {129.967, 31.8415}}, {{130.015, 
     28.3877}, {130.036, 28.3739}, {130.039, 28.3515}, {130.03, 28.3237}, {
     129.989, 28.2966}, {129.956, 28.2966}, {129.937, 28.3153}, {129.938, 
     28.3316}, {129.97, 28.3751}, {129.994, 28.3865}, {130.015, 28.3877}}, {{
     130.171, 32.2194}, {130.209, 32.1754}, {130.203, 32.1315}, {130.18, 
     32.1233}, {130.158, 32.1288}, {130.131, 32.1498}, {130.116, 32.1947}, {
     130.122, 32.212}, {130.138, 32.2212}, {130.15, 32.2212}, {130.171, 
     32.2194}}, {{131.207, 25.9505}, {131.218, 25.945}, {131.229, 25.9346}, {
     131.235, 25.9169}, {131.228, 25.8946}, {131.216, 25.8833}, {131.19, 
     25.8764}, {131.163, 25.8754}, {131.135, 25.8877}, {131.126, 25.907}, {
     131.135, 25.9307}, {131.178, 25.95}, {131.207, 25.9505}}, {{146.053, 
     43.5457}, {146.089, 43.554}, {146.127, 43.5521}, {146.135, 43.536}, {
     146.124, 43.5154}, {146.101, 43.4832}, {146.081, 43.4783}, {146.064, 
     43.4808}, {146.049, 43.4935}, {146.019, 43.5159}, {146.023, 43.5345}, {
     146.053, 43.5457}}, {{128.904, 32.959}, {128.911, 32.9694}, {128.932, 
     32.9789}, {128.96, 32.9797}, {129.004, 32.9606}, {129.019, 32.9279}, {
     129.019, 32.9159}, {129.001, 32.9063}, {128.956, 32.9103}, {128.92, 
     32.9303}, {128.904, 32.959}}, {{127.667, 26.7916}, {127.688, 26.7882}, {
     127.706, 26.7779}, {127.719, 26.7631}, {127.716, 26.7517}, {127.694, 
     26.7375}, {127.656, 26.7369}, {127.607, 26.75}, {127.581, 26.7643}, {
     127.579, 26.7745}, {127.588, 26.7842}, {127.607, 26.7916}, {127.667, 
     26.7916}}, {{139.518, 34.145}, {139.541, 34.1519}, {139.593, 34.1299}, {
     139.602, 34.103}, {139.58, 34.0806}, {139.536, 34.0645}, {139.525, 
     34.0664}, {139.51, 34.0938}, {139.506, 34.1245}, {139.518, 34.145}}, {{
     139.572, 33.9616}, {139.602, 33.9739}, {139.638, 33.9572}, {139.646, 
     33.9289}, {139.634, 33.8982}, {139.608, 33.883}, {139.584, 33.8859}, {
     139.569, 33.8962}, {139.564, 33.9294}, {139.572, 33.9616}}, {{141.264, 
     24.8951}, {141.282, 24.9009}, {141.313, 24.9043}, {141.33, 24.8951}, {
     141.335, 24.8828}, {141.321, 24.8657}, {141.297, 24.8501}, {141.264, 
     24.8364}, {141.242, 24.833}, {141.228, 24.8394}, {141.218, 24.8511}, {
     141.218, 24.8677}, {141.236, 24.8843}, {141.264, 24.8951}}, {{133.048, 
     36.1873}, {133.083, 36.1931}, {133.1, 36.1863}, {133.1, 36.1731}, {
     133.087, 36.1575}, {133.076, 36.1331}, {133.072, 36.1077}, {133.055, 
     36.0945}, {133.034, 36.0989}, {133.018, 36.1233}, {133.023, 36.1604}, {
     133.048, 36.1873}}, {{123.486, 25.9534}, {123.498, 25.9113}, {123.483, 
     25.8922}, {123.453, 25.8892}, {123.405, 25.9002}, {123.399, 25.9113}, {
     123.405, 25.9293}, {123.436, 25.9544}, {123.465, 25.9604}, {123.486, 
     25.9534}}, {{129.268, 29.2142}, {129.276, 29.2055}, {129.277, 29.1943}, {
     129.269, 29.1796}, {129.243, 29.167}, {129.21, 29.1677}, {129.173, 
     29.1836}, {129.161, 29.2069}, {129.166, 29.2228}, {129.195, 29.2248}, {
     129.268, 29.2142}}, {{129.6, 29.9816}, {129.601, 29.9426}, {129.569, 
     29.9236}, {129.534, 29.9236}, {129.51, 29.9331}, {129.503, 29.9493}, {
     129.522, 29.9721}, {129.546, 29.9863}, {129.57, 29.991}, {129.589, 
     29.9863}, {129.6, 29.9816}}, {{127.32, 26.2759}, {127.334, 26.281}, {
     127.338, 26.2818}, {127.353, 26.2784}, {127.365, 26.2633}, {127.365, 
     26.2271}, {127.326, 26.1867}, {127.309, 26.1817}, {127.295, 26.1834}, {
     127.288, 26.1993}, {127.32, 26.2759}}, {{140.45, 29.998}, {140.46, 
     30.0091}, {140.479, 30.018}, {140.502, 30.0194}, {140.526, 30.0069}, {
     140.535, 29.9811}, {140.528, 29.9574}, {140.505, 29.9449}, {140.485, 
     29.9471}, {140.459, 29.9626}, {140.45, 29.9774}, {140.45, 29.998}}, {{
     145.833, 43.4581}, {145.878, 43.4649}, {145.925, 43.4566}, {145.931, 
     43.4346}, {145.921, 43.4146}, {145.9, 43.4126}, {145.831, 43.42}, {
     145.816, 43.4283}, {145.815, 43.4468}, {145.833, 43.4581}}, {{133.164, 
     36.1726}, {133.189, 36.1746}, {133.211, 36.1629}, {133.209, 36.1477}, {
     133.192, 36.1233}, {133.176, 36.0872}, {133.166, 36.0833}, {133.155, 
     36.0867}, {133.148, 36.0945}, {133.138, 36.1165}, {133.136, 36.1546}, {
     133.164, 36.1726}}, {{129.295, 33.0808}, {129.313, 33.0888}, {129.329, 
     33.0924}, {129.356, 33.0853}, {129.368, 33.0622}, {129.352, 33.0374}, {
     129.319, 33.0197}, {129.287, 33.0268}, {129.277, 33.0489}, {129.295, 
     33.0808}}, {{136.122, 20.4704}, {136.105, 20.469}, {136.084, 20.4775}, {
     136.071, 20.4975}, {136.084, 20.5161}, {136.135, 20.529}, {136.174, 
     20.5276}, {136.186, 20.5118}, {136.167, 20.4947}, {136.122, 20.4704}}, {{
     142.309, 27.8201}, {142.344, 27.8225}, {142.366, 27.8088}, {142.372, 
     27.7869}, {142.363, 27.7624}, {142.337, 27.7517}, {142.312, 27.758}, {
     142.291, 27.7732}, {142.289, 27.7986}, {142.309, 27.8201}}, {{124.659, 
     24.826}, {124.631, 24.8366}, {124.607, 24.8694}, {124.609, 24.8844}, {
     124.635, 24.8905}, {124.671, 24.8861}, {124.694, 24.8694}, {124.699, 
     24.8427}, {124.695, 24.8338}, {124.677, 24.8249}, {124.659, 24.826}}, {{
     128.125, 26.5298}, {128.111, 26.4812}, {128.086, 26.4714}, {128.061, 
     26.4752}, {128.041, 26.4905}, {128.04, 26.5112}, {128.056, 26.5293}, {
     128.084, 26.5391}, {128.106, 26.5391}, {128.121, 26.5325}, {128.125, 
     26.5298}}, {{139.923, 32.5333}, {139.951, 32.5299}, {139.964, 32.507}, {
     139.959, 32.4757}, {139.931, 32.464}, {139.908, 32.4698}, {139.885, 
     32.4899}, {139.884, 32.5133}, {139.9, 32.5294}, {139.923, 32.5333}}, {{
     139.242, 33.7602}, {139.256, 33.7831}, {139.281, 33.7919}, {139.302, 
     33.7773}, {139.315, 33.7529}, {139.308, 33.7333}, {139.284, 33.7152}, {
     139.261, 33.7148}, {139.246, 33.7231}, {139.237, 33.7406}, {139.242, 
     33.7602}}, {{142.139, 26.8325}, {142.148, 26.8394}, {142.165, 26.8374}, {
     142.189, 26.8242}, {142.206, 26.8071}, {142.2, 26.7895}, {142.181, 
     26.7685}, {142.167, 26.7617}, {142.146, 26.7739}, {142.135, 26.7915}, {
     142.129, 26.8149}, {142.139, 26.8325}}, {{132.191, 33.8239}, {132.196, 
     33.8349}, {132.219, 33.8447}, {132.245, 33.8325}, {132.274, 33.7988}, {
     132.288, 33.7715}, {132.277, 33.7602}, {132.262, 33.7632}, {132.242, 
     33.78}, {132.214, 33.8015}, {132.19, 33.8112}, {132.191, 33.8239}}, {{
     139.258, 34.6496}, {139.3, 34.6496}, {139.32, 34.6364}, {139.316, 
     34.6159}, {139.284, 34.5988}, {139.255, 34.5997}, {139.232, 34.609}, {
     139.218, 34.6222}, {139.229, 34.6398}, {139.258, 34.6496}}, {{129.385, 
     31.3053}, {129.393, 31.3053}, {129.405, 31.2989}, {129.409, 31.2875}, {
     129.405, 31.2743}, {129.383, 31.2497}, {129.367, 31.2419}, {129.348, 
     31.2412}, {129.334, 31.2444}, {129.324, 31.259}, {129.327, 31.2811}, {
     129.349, 31.296}, {129.385, 31.3053}}, {{123.686, 26.0216}, {123.662, 
     26.0216}, {123.65, 26.0276}, {123.641, 26.0346}, {123.647, 26.0677}, {
     123.674, 26.0838}, {123.703, 26.0848}, {123.721, 26.0708}, {123.722, 
     26.0507}, {123.686, 26.0216}}, {{142.17, 27.1634}, {142.177, 27.1717}, {
     142.197, 27.1756}, {142.221, 27.1756}, {142.243, 27.1698}, {142.252, 
     27.1576}, {142.247, 27.1429}, {142.23, 27.1312}, {142.214, 27.1141}, {
     142.199, 27.1116}, {142.182, 27.1204}, {142.172, 27.1429}, {142.17, 
     27.1634}}, {{127.213, 26.2768}, {127.221, 26.2717}, {127.229, 26.2675}, {
     127.223, 26.2498}, {127.183, 26.2397}, {127.123, 26.2456}, {127.105, 
     26.2566}, {127.105, 26.2675}, {127.118, 26.2768}, {127.213, 26.2768}}, {{
     129.135, 28.8146}, {129.138, 28.8033}, {129.134, 28.7929}, {129.118, 
     28.7885}, {129.094, 28.7949}, {129.059, 28.8166}, {129.052, 28.829}, {
     129.05, 28.8413}, {129.053, 28.8477}, {129.065, 28.8546}, {129.083, 
     28.8546}, {129.107, 28.8462}, {129.135, 28.8146}}, {{139.266, 38.5311}, {
     139.273, 38.5374}, {139.291, 38.5399}, {139.309, 38.5243}, {139.31, 
     38.5116}, {139.291, 38.494}, {139.27, 38.4681}, {139.237, 38.4671}, {
     139.225, 38.4783}, {139.229, 38.491}, {139.247, 38.5047}, {139.266, 
     38.5311}}, {{131.662, 33.7319}, {131.644, 33.7391}, {131.638, 33.7443}, {
     131.637, 33.7547}, {131.646, 33.763}, {131.668, 33.7724}, {131.705, 
     33.7713}, {131.73, 33.7584}, {131.738, 33.7412}, {131.727, 33.7272}, {
     131.703, 33.722}, {131.662, 33.7319}}, {{123.967, 24.2523}, {123.962, 
     24.2611}, {123.961, 24.2663}, {123.966, 24.2813}, {123.992, 24.2901}, {
     124.02, 24.2892}, {124.045, 24.2725}, {124.056, 24.2593}, {124.049, 
     24.2434}, {124.029, 24.2355}, {123.967, 24.2523}}, {{129.703, 29.5734}, {
     129.679, 29.5826}, {129.672, 29.5942}, {129.674, 29.6058}, {129.706, 
     29.6375}, {129.727, 29.6414}, {129.746, 29.6383}, {129.749, 29.6275}, {
     129.74, 29.5942}, {129.723, 29.5772}, {129.703, 29.5734}}, {{127.11, 
     26.4611}, {127.11, 26.4299}, {127.094, 26.4173}, {127.058, 26.4165}, {
     127.042, 26.4249}, {127.042, 26.4459}, {127.048, 26.4678}, {127.082, 
     26.4796}, {127.099, 26.477}, {127.11, 26.4611}}, {{127.214, 26.6043}, {
     127.206, 26.6007}, {127.185, 26.6007}, {127.17, 26.6038}, {127.168, 
     26.621}, {127.171, 26.6403}, {127.203, 26.6626}, {127.222, 26.6637}, {
     127.239, 26.6595}, {127.246, 26.6486}, {127.244, 26.634}, {127.214, 
     26.6043}}, {{134.481, 34.714}, {134.5, 34.7171}, {134.517, 34.7035}, {
     134.514, 34.6859}, {134.491, 34.6708}, {134.446, 34.6634}, {134.424, 
     34.6683}, {134.414, 34.6827}, {134.436, 34.6998}, {134.481, 34.714}}, {{
     130.267, 30.8033}, {130.299, 30.8134}, {130.322, 30.8095}, {130.34, 
     30.7935}, {130.338, 30.7802}, {130.313, 30.7645}, {130.269, 30.7629}, {
     130.248, 30.7731}, {130.243, 30.7849}, {130.251, 30.7943}, {130.267, 
     30.8033}}, {{129.932, 30.8284}, {129.94, 30.8088}, {129.926, 30.7861}, {
     129.886, 30.7634}, {129.864, 30.7692}, {129.859, 30.7825}, {129.871, 
     30.8076}, {129.902, 30.8288}, {129.919, 30.8295}, {129.932, 30.8284}}, {{
     140.801, 27.3283}, {140.824, 27.3366}, {140.844, 27.3243}, {140.847, 
     27.3048}, {140.841, 27.2833}, {140.821, 27.2657}, {140.802, 27.2638}, {
     140.789, 27.2687}, {140.783, 27.2828}, {140.786, 27.3048}, {140.801, 
     27.3283}}, {{132.927, 34.2839}, {132.919, 34.2605}, {132.893, 34.2453}, {
     132.866, 34.2375}, {132.845, 34.2385}, {132.833, 34.2463}, {132.835, 
     34.2644}, {132.874, 34.2854}, {132.907, 34.2922}, {132.923, 34.2922}, {
     132.927, 34.2839}}, {{123.543, 24.188}, {123.52, 24.1818}, {123.507, 
     24.1827}, {123.495, 24.1853}, {123.493, 24.1977}, {123.499, 24.217}, {
     123.544, 24.2399}, {123.564, 24.2417}, {123.575, 24.2373}, {123.576, 
     24.2241}, {123.576, 24.2117}, {123.543, 24.188}}, {{140.778, 21.8084}, {
     140.785, 21.8181}, {140.796, 21.8177}, {140.805, 21.8045}, {140.807, 
     21.7757}, {140.8, 21.7551}, {140.781, 21.7346}, {140.762, 21.7346}, {
     140.749, 21.7478}, {140.752, 21.7654}, {140.769, 21.783}, {140.778, 
     21.8084}}, {{128.719, 32.8545}, {128.709, 32.8401}, {128.683, 32.8306}, {
     128.656, 32.8353}, {128.643, 32.8529}, {128.644, 32.8728}, {128.661, 
     32.8856}, {128.681, 32.8904}, {128.709, 32.876}, {128.719, 32.8545}}, {{
     129.557, 29.6962}, {129.545, 29.6615}, {129.517, 29.6445}, {129.495, 
     29.6445}, {129.483, 29.6545}, {129.483, 29.6777}, {129.506, 29.6978}, {
     129.524, 29.7063}, {129.536, 29.7055}, {129.546, 29.704}, {129.557, 
     29.6962}}, {{124.531, 26.0116}, {124.541, 26.006}, {124.542, 26.0004}, {
     124.539, 25.9823}, {124.527, 25.9634}, {124.5, 25.9529}, {124.484, 
     25.9529}, {124.471, 25.9613}, {124.473, 25.9906}, {124.487, 26.0067}, {
     124.51, 26.0116}, {124.531, 26.0116}}, {{130.603, 30.8066}, {130.623, 
     30.803}, {130.631, 30.7957}, {130.631, 30.7824}, {130.62, 30.7695}, {
     130.584, 30.7626}, {130.554, 30.7679}, {130.543, 30.7763}, {130.541, 
     30.7868}, {130.546, 30.7985}, {130.566, 30.8066}, {130.603, 30.8066}}, {{
     131.18, 24.5783}, {131.186, 24.5629}, {131.177, 24.5385}, {131.155, 
     24.5242}, {131.138, 24.5242}, {131.118, 24.5362}, {131.116, 24.5517}, {
     131.126, 24.5738}, {131.148, 24.5826}, {131.169, 24.5815}, {131.18, 
     24.5783}}, {{131.25, 34.4645}, {131.222, 34.4664}, {131.199, 34.4751}, {
     131.19, 34.4877}, {131.195, 34.5045}, {131.224, 34.5113}, {131.244, 
     34.5113}, {131.271, 34.4978}, {131.279, 34.4862}, {131.274, 34.4771}, {
     131.25, 34.4645}}, {{129.436, 33.4484}, {129.434, 33.4108}, {129.406, 
     33.394}, {129.387, 33.3932}, {129.369, 33.402}, {129.367, 33.4188}, {
     129.378, 33.4316}, {129.413, 33.4548}, {129.426, 33.454}, {129.436, 
     33.4484}}, {{131.156, 34.7617}, {131.152, 34.7564}, {131.143, 34.7523}, {
     131.117, 34.7535}, {131.082, 34.776}, {131.07, 34.7886}, {131.074, 
     34.8005}, {131.09, 34.807}, {131.111, 34.8049}, {131.149, 34.7833}, {
     131.156, 34.7617}}, {{129.199, 33.2271}, {129.204, 33.2094}, {129.192, 
     33.1854}, {129.168, 33.1792}, {129.144, 33.1854}, {129.135, 33.2058}, {
     129.14, 33.2218}, {129.162, 33.2333}, {129.183, 33.2315}, {129.199, 
     33.2271}}, {{129.656, 29.4559}, {129.646, 29.4644}, {129.646, 29.4714}, {
     129.658, 29.4814}, {129.684, 29.4853}, {129.728, 29.4791}, {129.743, 
     29.4675}, {129.743, 29.4559}, {129.731, 29.4474}, {129.716, 29.4466}, {
     129.656, 29.4559}}, {{128.886, 32.5673}, {128.871, 32.5753}, {128.865, 
     32.5848}, {128.871, 32.5984}, {128.9, 32.612}, {128.917, 32.6144}, {
     128.943, 32.6048}, {128.943, 32.592}, {128.93, 32.5745}, {128.908, 
     32.5673}, {128.886, 32.5673}}, {{131.304, 25.9875}, {131.317, 25.9959}, {
     131.329, 25.9989}, {131.346, 25.9974}, {131.354, 25.9875}, {131.352, 
     25.9697}, {131.336, 25.9475}, {131.313, 25.9421}, {131.294, 25.9475}, {
     131.287, 25.9623}, {131.304, 25.9875}}, {{133.065, 34.1953}, {133.073, 
     34.2024}, {133.101, 34.2077}, {133.114, 34.2024}, {133.101, 34.1733}, {
     133.082, 34.1577}, {133.049, 34.1562}, {133.037, 34.1672}, {133.041, 
     34.1816}, {133.065, 34.1953}}, {{129.707, 33.5277}, {129.696, 33.502}, {
     129.672, 33.4844}, {129.657, 33.4828}, {129.642, 33.4908}, {129.642, 
     33.5052}, {129.658, 33.5317}, {129.676, 33.5389}, {129.691, 33.5381}, {
     129.702, 33.5349}, {129.707, 33.5277}}, {{131.8, 34.8356}, {131.79, 
     34.8239}, {131.768, 34.82}, {131.743, 34.8251}, {131.735, 34.8372}, {
     131.735, 34.8496}, {131.743, 34.8629}, {131.758, 34.8687}, {131.776, 
     34.8675}, {131.797, 34.8559}, {131.8, 34.8356}}, {{129.087, 28.0957}, {
     129.111, 28.0941}, {129.15, 28.0784}, {129.155, 28.0644}, {129.15, 
     28.0577}, {129.129, 28.0554}, {129.083, 28.0655}, {129.07, 28.0756}, {
     129.066, 28.084}, {129.073, 28.0929}, {129.087, 28.0957}}, {{145.514, 
     27.8022}, {145.533, 27.7983}, {145.534, 27.7822}, {145.521, 27.7637}, {
     145.5, 27.748}, {145.482, 27.7446}, {145.467, 27.7558}, {145.47, 
     27.771}, {145.489, 27.7905}, {145.514, 27.8022}}, {{145.178, 27.5239}, {
     145.197, 27.52}, {145.199, 27.5039}, {145.185, 27.4854}, {145.164, 
     27.4697}, {145.147, 27.4663}, {145.131, 27.4775}, {145.135, 27.4927}, {
     145.153, 27.5122}, {145.178, 27.5239}}, {{145.266, 27.8964}, {145.285, 
     27.8925}, {145.286, 27.8764}, {145.273, 27.8578}, {145.252, 27.8422}, {
     145.234, 27.8388}, {145.219, 27.85}, {145.223, 27.8652}, {145.241, 
     27.8847}, {145.266, 27.8964}}, {{127.47, 26.249}, {127.489, 26.2532}, {
     127.508, 26.2456}, {127.509, 26.2322}, {127.482, 26.2086}, {127.459, 
     26.2002}, {127.442, 26.2019}, {127.439, 26.2069}, {127.442, 26.228}, {
     127.47, 26.249}}, {{141.319, 25.6169}, {141.347, 25.6267}, {141.366, 
     25.6194}, {141.366, 25.6037}, {141.351, 25.5866}, {141.326, 25.5774}, {
     141.31, 25.5774}, {141.297, 25.5881}, {141.298, 25.6018}, {141.319, 
     25.6169}}, {{129.425, 30.8362}, {129.388, 30.8123}, {129.373, 30.8123}, {
     129.361, 30.8203}, {129.361, 30.8335}, {129.373, 30.8528}, {129.395, 
     30.8628}, {129.411, 30.8608}, {129.425, 30.8528}, {129.427, 30.8468}, {
     129.425, 30.8362}}, {{127.048, 26.2305}, {127.048, 26.1968}, {127.026, 
     26.1842}, {127.005, 26.1892}, {126.99, 26.201}, {126.992, 26.2162}, {
     127.014, 26.233}, {127.031, 26.2372}, {127.038, 26.2364}, {127.048, 
     26.2305}}, {{128.838, 32.7899}, {128.827, 32.8002}, {128.831, 32.817}, {
     128.855, 32.833}, {128.876, 32.8322}, {128.892, 32.8154}, {128.887, 
     32.7963}, {128.865, 32.7851}, {128.838, 32.7899}}, {{128.592, 32.7715}, {
     128.59, 32.7348}, {128.573, 32.7229}, {128.561, 32.7205}, {128.546, 
     32.7253}, {128.539, 32.7388}, {128.548, 32.7659}, {128.565, 32.7755}, {
     128.578, 32.7755}, {128.592, 32.7715}}, {{142.222, 26.719}, {142.244, 
     26.7185}, {142.247, 26.7019}, {142.241, 26.6872}, {142.22, 26.674}, {
     142.201, 26.6692}, {142.185, 26.675}, {142.179, 26.6892}, {142.2, 
     26.7077}, {142.222, 26.719}}, {{140.389, 30.5489}, {140.389, 30.5611}, {
     140.403, 30.5684}, {140.444, 30.5518}, {140.455, 30.5245}, {140.446, 
     30.5162}, {140.429, 30.5152}, {140.406, 30.5279}, {140.389, 30.5489}}, {{
     139.819, 31.9546}, {139.818, 31.9668}, {139.833, 31.9741}, {139.873, 
     31.9575}, {139.885, 31.9302}, {139.876, 31.9219}, {139.859, 31.9209}, {
     139.836, 31.9336}, {139.819, 31.9546}}, {{130.095, 30.8045}, {130.121, 
     30.7931}, {130.121, 30.7782}, {130.099, 30.7673}, {130.065, 30.7688}, {
     130.046, 30.7829}, {130.048, 30.7939}, {130.066, 30.8033}, {130.095, 
     30.8045}}, {{131.876, 33.9765}, {131.884, 33.9765}, {131.891, 33.9701}, {
     131.883, 33.9511}, {131.867, 33.9363}, {131.851, 33.9315}, {131.832, 
     33.9336}, {131.822, 33.9426}, {131.826, 33.9564}, {131.849, 33.9738}, {
     131.876, 33.9765}}, {{125.122, 25.0126}, {125.089, 25.0145}, {125.071, 
     25.0203}, {125.071, 25.0319}, {125.086, 25.0492}, {125.103, 25.0492}, {
     125.129, 25.0473}, {125.142, 25.0309}, {125.139, 25.0184}, {125.122, 
     25.0126}}, {{139.755, 32.4787}, {139.765, 32.4992}, {139.787, 32.5078}, {
     139.809, 32.5001}, {139.816, 32.4855}, {139.807, 32.4667}, {139.785, 
     32.459}, {139.764, 32.465}, {139.755, 32.4787}}, {{141.389, 24.3647}, {
     141.389, 24.3754}, {141.41, 24.3788}, {141.439, 24.3744}, {141.461, 
     24.3544}, {141.456, 24.3432}, {141.438, 24.3378}, {141.418, 24.3407}, {
     141.397, 24.351}, {141.389, 24.3647}}, {{142.109, 26.7014}, {142.136, 
     26.699}, {142.147, 26.6877}, {142.149, 26.6667}, {142.139, 26.656}, {
     142.126, 26.6526}, {142.107, 26.6594}, {142.096, 26.6736}, {142.093, 
     26.6887}, {142.109, 26.7014}}, {{142.203, 26.6399}, {142.214, 26.6359}, {
     142.217, 26.6247}, {142.217, 26.6091}, {142.211, 26.5949}, {142.198, 
     26.5866}, {142.182, 26.5866}, {142.17, 26.5954}, {142.164, 26.6101}, {
     142.181, 26.6296}, {142.203, 26.6399}}, {{131.654, 34.0278}, {131.684, 
     34.0093}, {131.684, 33.9939}, {131.664, 33.9844}, {131.654, 33.9844}, {
     131.632, 33.9923}, {131.623, 34.0087}, {131.626, 34.0209}, {131.64, 
     34.0299}, {131.654, 34.0278}}, {{139.392, 41.5679}, {139.413, 41.5684}, {
     139.435, 41.5679}, {139.453, 41.5567}, {139.445, 41.544}, {139.417, 
     41.5362}, {139.392, 41.5372}, {139.378, 41.543}, {139.377, 41.5557}, {
     139.392, 41.5679}}, {{129.895, 30.0898}, {129.906, 30.0575}, {129.893, 
     30.0442}, {129.876, 30.0423}, {129.859, 30.048}, {129.854, 30.0651}, {
     129.866, 30.0869}, {129.883, 30.0926}, {129.895, 30.0898}}, {{133.165, 
     34.3349}, {133.18, 34.3437}, {133.213, 34.3325}, {133.215, 34.311}, {
     133.209, 34.2983}, {133.191, 34.2924}, {133.17, 34.311}, {133.165, 
     34.3349}}, {{139.723, 32.5266}, {139.732, 32.5378}, {139.751, 32.5463}, {
     139.767, 32.5395}, {139.771, 32.5258}, {139.756, 32.5095}, {139.734, 
     32.5018}, {139.723, 32.5052}, {139.717, 32.5164}, {139.723, 32.5266}}, {{
     142.227, 27.2279}, {142.254, 27.2269}, {142.271, 27.2167}, {142.274, 
     27.2015}, {142.266, 27.1932}, {142.243, 27.1937}, {142.224, 27.204}, {
     142.214, 27.2191}, {142.227, 27.2279}}, {{142.284, 26.6583}, {142.31, 
     26.6573}, {142.327, 26.647}, {142.33, 26.6319}, {142.322, 26.6236}, {
     142.299, 26.6241}, {142.28, 26.6343}, {142.27, 26.6495}, {142.284, 
     26.6583}}, {{142.203, 27.6829}, {142.229, 27.6819}, {142.246, 27.6716}, {
     142.25, 27.6565}, {142.241, 27.6482}, {142.218, 27.6487}, {142.199, 
     27.6589}, {142.19, 27.6741}, {142.203, 27.6829}}, {{142.203, 27.8118}, {
     142.23, 27.8108}, {142.247, 27.8006}, {142.25, 27.7854}, {142.241, 
     27.7771}, {142.219, 27.7776}, {142.2, 27.7879}, {142.19, 27.803}, {
     142.203, 27.8118}}, {{142.164, 27.2773}, {142.19, 27.2763}, {142.207, 
     27.266}, {142.211, 27.2509}, {142.202, 27.2426}, {142.18, 27.2431}, {
     142.16, 27.2533}, {142.151, 27.2685}, {142.164, 27.2773}}, {{142.208, 
     27.7489}, {142.234, 27.748}, {142.251, 27.7377}, {142.255, 27.7226}, {
     142.246, 27.7143}, {142.224, 27.7147}, {142.204, 27.725}, {142.195, 
     27.7401}, {142.208, 27.7489}}, {{142.249, 27.6114}, {142.276, 27.6105}, {
     142.292, 27.6002}, {142.296, 27.5851}, {142.287, 27.5768}, {142.265, 
     27.5772}, {142.246, 27.5875}, {142.236, 27.6026}, {142.249, 27.6114}}, {{
     141.475, 38.3223}, {141.484, 38.3287}, {141.501, 38.3272}, {141.53, 
     38.314}, {141.536, 38.2964}, {141.522, 38.2891}, {141.506, 38.2925}, {
     141.487, 38.3062}, {141.475, 38.3223}}, {{141.629, 38.3433}, {141.641, 
     38.3457}, {141.653, 38.336}, {141.66, 38.3213}, {141.652, 38.3091}, {
     141.64, 38.3077}, {141.625, 38.3179}, {141.62, 38.3311}, {141.629, 
     38.3433}}, CompressedData["
1:eJxTTMoPSmViYGAQB2IQ7dKd8/x3a6KDadwuT54iewd1Q441Mm2JDg+5J69s
KrR3+LPy4yVfID/UQGulcIG9w7sae9M4IP+Z/ZL7+/IQ/HXbkupv5to7lE6W
YAkD8jc+fDl1U469w8S3QAVAvoNw4uHL2fYQe4D8KrPVduFAftAOudbXQPun
T+CvMgPyWcL4dDe1IuT176qwNbYi9F/2TRKIaEWYX75vvpQ+kH9a4PiuHUD7
eZi028WAfOuCcx2XgO6TBhkA5DPkN7IczUfwC225ri8uQKgPUl/QuaEQYd7h
lFUJIcDwiEqxvu8P5JsImtnsBfLB2oD8pTrOMq+B/FkzgQDI/x2Te/QfkP9N
I6b/EJJ69PAFABbvl8M=
     "], CompressedData["
1:eJxTTMoPSmViYGAQB2IQfdzbvNOxJdEhocxfTizL3sGQY41MFJDvkpn/oTXT
3oGtcapzN5Df4LG/VjbD3qHQluv6YiBfIMJyy4k0BP/mue/Bj1PtHeqz9pRM
BvJv/6zL2pNi7zDniMKGIiB/SQFQYbK9ww651teBQP5SPwfhRCA/pv/QVw0g
/9fb1wcsgXw+3U1z3zcj5IG2lO1rRui/qwJ0UTPC/F9AqgTI/6YBNAlovzjI
IUD+/LOrzl8Fum/e++XHvIF87Xaxm+fSEfzZofNXr81AqK+1N43blYkwT/1Q
2/LwLIR9M/KEmg8A+QdPLXTdBuRfcLnx4QuQD3YXkB+3y5OHKdveofKlmiEH
0D/xmqcFjgPl0cMXAE6bpHs=
     "]}], 
   {RGBColor[1, 0.925, 0.925], PointSize[0.002], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      RowBox[{"{", 
        RowBox[{"\"Tokyo\"", ",", "8336599"}], "}"}]],
     Annotation[#, {"Tokyo", 8336599}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.62, 35.47}],
      "\"Yokohama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokohama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.62, 35.47}],
      RowBox[{"{", 
        RowBox[{"\"Yokohama\"", ",", "3574443"}], "}"}]],
     Annotation[#, {"Yokohama", 3574443}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Osaka\"", ",", "2592413"}], "}"}]],
     Annotation[#, {"Osaka", 2592413}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 35.15}],
      "\"Nagoya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagoya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 35.15}],
      RowBox[{"{", 
        RowBox[{"\"Nagoya\"", ",", "2191279"}], "}"}]],
     Annotation[#, {"Nagoya", 2191279}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.34, 43.06}],
      "\"Sapporo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sapporo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.34, 43.06}],
      RowBox[{"{", 
        RowBox[{"\"Sapporo\"", ",", "1883027"}], "}"}]],
     Annotation[#, {"Sapporo", 1883027}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.68}],
      "\"Kobe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kobe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Kobe\"", ",", "1528478"}], "}"}]],
     Annotation[#, {"Kobe", 1528478}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Kyoto\"", ",", "1459640"}], "}"}]],
     Annotation[#, {"Kyoto", 1459640}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      RowBox[{"{", 
        RowBox[{"\"Fukuoka\"", ",", "1392289"}], "}"}]],
     Annotation[#, {"Fukuoka", 1392289}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.70000000000002`, 35.53}],
      "\"Kawasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.70000000000002`, 35.53}],
      RowBox[{"{", 
        RowBox[{"\"Kawasaki\"", ",", "1306785"}], "}"}]],
     Annotation[#, {"Kawasaki", 1306785}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      RowBox[{"{", 
        RowBox[{"\"Hiroshima\"", ",", "1143841"}], "}"}]],
     Annotation[#, {"Hiroshima", 1143841}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      RowBox[{"{", 
        RowBox[{"\"Saitama\"", ",", "1077730"}], "}"}]],
     Annotation[#, {"Saitama", 1077730}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.89000000000001`, 38.26}],
      "\"Sendai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sendai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.89000000000001`, 38.26}],
      RowBox[{"{", 
        RowBox[{"\"Sendai\"", ",", "1037562"}], "}"}]],
     Annotation[#, {"Sendai", 1037562}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.86, 33.88}],
      "\"Kitakyushu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitakyushu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.86, 33.88}],
      RowBox[{"{", 
        RowBox[{"\"Kitakyushu\"", ",", "997536"}], "}"}]],
     Annotation[#, {"Kitakyushu", 997536}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      RowBox[{"{", 
        RowBox[{"\"Chiba\"", ",", "919729"}], "}"}]],
     Annotation[#, {"Chiba", 919729}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.57}],
      "\"Sakai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.57}],
      RowBox[{"{", 
        RowBox[{"\"Sakai\"", ",", "782339"}], "}"}]],
     Annotation[#, {"Sakai", 782339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shizuoka\"", ",", "701561"}], "}"}]],
     Annotation[#, {"Shizuoka", 701561}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      RowBox[{"{", 
        RowBox[{"\"Kumamoto\"", ",", "680423"}], "}"}]],
     Annotation[#, {"Kumamoto", 680423}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 35.58}],
      "\"Sagamihara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sagamihara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 35.58}],
      RowBox[{"{", 
        RowBox[{"\"Sagamihara\"", ",", "648801"}], "}"}]],
     Annotation[#, {"Sagamihara", 648801}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Okayama\"", ",", "639652"}], "}"}]],
     Annotation[#, {"Okayama", 639652}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.73, 34.72}],
      "\"Hamamatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hamamatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.73, 34.72}],
      RowBox[{"{", 
        RowBox[{"\"Hamamatsu\"", ",", "605098"}], "}"}]],
     Annotation[#, {"Hamamatsu", 605098}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.660000000000004`}],
      "\"Hachioji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hachioji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Hachioji\"", ",", "579399"}], "}"}]],
     Annotation[#, {"Hachioji", 579399}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 35.7}],
      "\"Funabashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Funabashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 35.7}],
      RowBox[{"{", 
        RowBox[{"\"Funabashi\"", ",", "560743"}], "}"}]],
     Annotation[#, {"Funabashi", 560743}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      RowBox[{"{", 
        RowBox[{"\"Kagoshima\"", ",", "555352"}], "}"}]],
     Annotation[#, {"Kagoshima", 555352}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.59, 34.67}],
      "\"Higashiosaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashiosaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.59, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Higashiosaka\"", ",", "513125"}], "}"}]],
     Annotation[#, {"Higashiosaka", 513125}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      RowBox[{"{", 
        RowBox[{"\"Niigata\"", ",", "505272"}], "}"}]],
     Annotation[#, {"Niigata", 505272}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.77, 33.84}],
      "\"Matsuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.77, 33.84}],
      RowBox[{"{", 
        RowBox[{"\"Matsuyama\"", ",", "485431"}], "}"}]],
     Annotation[#, {"Matsuyama", 485431}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.69, 34.83}],
      "\"Himeji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Himeji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.69, 34.83}],
      RowBox[{"{", 
        RowBox[{"\"Himeji\"", ",", "481493"}], "}"}]],
     Annotation[#, {"Himeji", 481493}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.9, 35.78}],
      "\"Matsudo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsudo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.9, 35.78}],
      RowBox[{"{", 
        RowBox[{"\"Matsudo\"", ",", "470277"}], "}"}]],
     Annotation[#, {"Matsudo", 470277}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.34, 34.730000000000004`}],
      "\"Nishinomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishinomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.34, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nishinomiya\"", ",", "468925"}], "}"}]],
     Annotation[#, {"Nishinomiya", 468925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 35.81}],
      "\"Kawaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 35.81}],
      RowBox[{"{", 
        RowBox[{"\"Kawaguchi\"", ",", "468565"}], "}"}]],
     Annotation[#, {"Kawaguchi", 468565}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 36.56}],
      "\"Kanazawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanazawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 36.56}],
      RowBox[{"{", 
        RowBox[{"\"Kanazawa\"", ",", "458937"}], "}"}]],
     Annotation[#, {"Kanazawa", 458937}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 35.72}],
      "\"Ichikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ichikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Ichikawa\"", ",", "458240"}], "}"}]],
     Annotation[#, {"Ichikawa", 458240}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 36.56}],
      "\"Utsunomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Utsunomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 36.56}],
      RowBox[{"{", 
        RowBox[{"\"Utsunomiya\"", ",", "449865"}], "}"}]],
     Annotation[#, {"Utsunomiya", 449865}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      RowBox[{"{", 
        RowBox[{"\"Oita\"", ",", "448907"}], "}"}]],
     Annotation[#, {"Oita", 448907}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.41, 34.71}],
      "\"Amagasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Amagasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.41, 34.71}],
      RowBox[{"{", 
        RowBox[{"\"Amagasaki\"", ",", "442173"}], "}"}]],
     Annotation[#, {"Amagasaki", 442173}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.77, 34.61}],
      "\"Kurashiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurashiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.77, 34.61}],
      RowBox[{"{", 
        RowBox[{"\"Kurashiki\"", ",", "437581"}], "}"}]],
     Annotation[#, {"Kurashiki", 437581}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 35.27}],
      "\"Yokosuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokosuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 35.27}],
      RowBox[{"{", 
        RowBox[{"\"Yokosuka\"", ",", "428992"}], "}"}]],
     Annotation[#, {"Yokosuka", 428992}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.66, 34.81}],
      "\"Hirakata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hirakata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.66, 34.81}],
      RowBox[{"{", 
        RowBox[{"\"Hirakata\"", ",", "406331"}], "}"}]],
     Annotation[#, {"Hirakata", 406331}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.56}],
      "\"Machida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Machida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.56}],
      RowBox[{"{", 
        RowBox[{"\"Machida\"", ",", "399969"}], "}"}]],
     Annotation[#, {"Machida", 399969}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      RowBox[{"{", 
        RowBox[{"\"Gifu\"", ",", "397714"}], "}"}]],
     Annotation[#, {"Gifu", 397714}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.33}],
      "\"Fujisawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujisawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.33}],
      RowBox[{"{", 
        RowBox[{"\"Fujisawa\"", ",", "394624"}], "}"}]],
     Annotation[#, {"Fujisawa", 394624}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.78}],
      "\"Toyonaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyonaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.78}],
      RowBox[{"{", 
        RowBox[{"\"Toyonaka\"", ",", "384459"}], "}"}]],
     Annotation[#, {"Toyonaka", 384459}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.37, 34.5}],
      "\"Fukuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.37, 34.5}],
      RowBox[{"{", 
        RowBox[{"\"Fukuyama\"", ",", "383298"}], "}"}]],
     Annotation[#, {"Fukuyama", 383298}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 34.76}],
      "\"Toyohashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyohashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 34.76}],
      RowBox[{"{", 
        RowBox[{"\"Toyohashi\"", ",", "378374"}], "}"}]],
     Annotation[#, {"Toyohashi", 378374}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      RowBox[{"{", 
        RowBox[{"\"Wakayama\"", ",", "375339"}], "}"}]],
     Annotation[#, {"Wakayama", 375339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      RowBox[{"{", 
        RowBox[{"\"Nara\"", ",", "367353"}], "}"}]],
     Annotation[#, {"Nara", 367353}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.16, 35.09}],
      "\"Toyota\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyota", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.16, 35.09}],
      RowBox[{"{", 
        RowBox[{"\"Toyota\"", ",", "362383"}], "}"}]],
     Annotation[#, {"Toyota", 362383}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      RowBox[{"{", 
        RowBox[{"\"Nagano\"", ",", "360176"}], "}"}]],
     Annotation[#, {"Nagano", 360176}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 37.050000000000004`}],
      "\"Iwaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 37.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Iwaki\"", ",", "357309"}], "}"}]],
     Annotation[#, {"Iwaki", 357309}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.36, 43.77}],
      "\"Asahikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Asahikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.36, 43.77}],
      RowBox[{"{", 
        RowBox[{"\"Asahikawa\"", ",", "356612"}], "}"}]],
     Annotation[#, {"Asahikawa", 356612}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.85}],
      "\"Takatsuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takatsuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.85}],
      RowBox[{"{", 
        RowBox[{"\"Takatsuki\"", ",", "354468"}], "}"}]],
     Annotation[#, {"Takatsuki", 354468}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.16, 34.96}],
      "\"Okazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.16, 34.96}],
      RowBox[{"{", 
        RowBox[{"\"Okazaki\"", ",", "352361"}], "}"}]],
     Annotation[#, {"Okazaki", 352361}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.52, 34.75}],
      "\"Suita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.52, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Suita\"", ",", "351630"}], "}"}]],
     Annotation[#, {"Suita", 351630}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 37.410000000000004`}],
      "\"Koriyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koriyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 37.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Koriyama\"", ",", "340560"}], "}"}]],
     Annotation[#, {"Koriyama", 340560}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 35.87}],
      "\"Kashiwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashiwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 35.87}],
      RowBox[{"{", 
        RowBox[{"\"Kashiwa\"", ",", "340221"}], "}"}]],
     Annotation[#, {"Kashiwa", 340221}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.800000000000004`}],
      "\"Tokorozawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokorozawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tokorozawa\"", ",", "339435"}], "}"}]],
     Annotation[#, {"Tokorozawa", 339435}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.92}],
      "\"Kawagoe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawagoe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.92}],
      RowBox[{"{", 
        RowBox[{"\"Kawagoe\"", ",", "337931"}], "}"}]],
     Annotation[#, {"Kawagoe", 337931}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.54, 33.56}],
      RowBox[{"{", 
        RowBox[{"\"Kochi\"", ",", "604696"}], "}"}]],
     Annotation[#, {"Kochi", 604696}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.04, 34.34}],
      "\"Takamatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takamatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.04, 34.34}],
      RowBox[{"{", 
        RowBox[{"\"Takamatsu\"", ",", "334223"}], "}"}]],
     Annotation[#, {"Takamatsu", 334223}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      RowBox[{"{", 
        RowBox[{"\"Toyama\"", ",", "325532"}], "}"}]],
     Annotation[#, {"Toyama", 325532}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      RowBox[{"{", 
        RowBox[{"\"Akita\"", ",", "320069"}], "}"}]],
     Annotation[#, {"Akita", 320069}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.79, 35.89}],
      "\"Koshigaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koshigaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.79, 35.89}],
      RowBox[{"{", 
        RowBox[{"\"Koshigaya\"", ",", "317437"}], "}"}]],
     Annotation[#, {"Koshigaya", 317437}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      RowBox[{"{", 
        RowBox[{"\"Miyazaki\"", ",", "311203"}], "}"}]],
     Annotation[#, {"Miyazaki", 311203}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 35.24}],
      "\"Kasugai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasugai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 35.24}],
      RowBox[{"{", 
        RowBox[{"\"Kasugai\"", ",", "298589"}], "}"}]],
     Annotation[#, {"Kasugai", 298589}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      RowBox[{"{", 
        RowBox[{"\"Aomori\"", ",", "298394"}], "}"}]],
     Annotation[#, {"Aomori", 298394}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.87, 35.01}],
      "\"Otsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.87, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Otsu\"", ",", "298164"}], "}"}]],
     Annotation[#, {"Otsu", 298164}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.98, 34.660000000000004`}],
      "\"Akashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.98, 34.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Akashi\"", ",", "297279"}], "}"}]],
     Annotation[#, {"Akashi", 297279}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 34.97}],
      "\"Yokkaichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokkaichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 34.97}],
      RowBox[{"{", 
        RowBox[{"\"Yokkaichi\"", ",", "295841"}], "}"}]],
     Annotation[#, {"Yokkaichi", 295841}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.15, 39.7}],
      "\"Morioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Morioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.15, 39.7}],
      RowBox[{"{", 
        RowBox[{"\"Morioka\"", ",", "295172"}], "}"}]],
     Annotation[#, {"Morioka", 295172}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      RowBox[{"{", 
        RowBox[{"\"Fukushima\"", ",", "294237"}], "}"}]],
     Annotation[#, {"Fukushima", 294237}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 35.53}],
      "\"Ichihara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ichihara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 35.53}],
      RowBox[{"{", 
        RowBox[{"\"Ichihara\"", ",", "283531"}], "}"}]],
     Annotation[#, {"Ichihara", 283531}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.06, 36.39}],
      "\"Maebashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maebashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.06, 36.39}],
      RowBox[{"{", 
        RowBox[{"\"Maebashi\"", ",", "282711"}], "}"}]],
     Annotation[#, {"Maebashi", 282711}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.8, 35.300000000000004`}],
      "\"Ichinomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ichinomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.8, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ichinomiya\"", ",", "280331"}], "}"}]],
     Annotation[#, {"Ichinomiya", 280331}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 41.800000000000004`}],
      "\"Hakodate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hakodate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 41.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Hakodate\"", ",", "275730"}], "}"}]],
     Annotation[#, {"Hakodate", 275730}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.58, 34.63}],
      "\"Yao\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yao", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.58, 34.63}],
      RowBox[{"{", 
        RowBox[{"\"Yao\"", ",", "273213"}], "}"}]],
     Annotation[#, {"Yao", 273213}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.84, 34.77}],
      "\"Kakogawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kakogawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.84, 34.77}],
      RowBox[{"{", 
        RowBox[{"\"Kakogawa\"", ",", "271634"}], "}"}]],
     Annotation[#, {"Kakogawa", 271634}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      RowBox[{"{", 
        RowBox[{"\"Tokushima\"", ",", "267345"}], "}"}]],
     Annotation[#, {"Tokushima", 267345}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      RowBox[{"{", 
        RowBox[{"\"Ibaraki\"", ",", "263405"}], "}"}]],
     Annotation[#, {"Ibaraki", 263405}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.35, 35.33}],
      "\"Hiratsuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiratsuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.35, 35.33}],
      RowBox[{"{", 
        RowBox[{"\"Hiratsuka\"", ",", "259052"}], "}"}]],
     Annotation[#, {"Hiratsuka", 259052}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      RowBox[{"{", 
        RowBox[{"\"Yamagata\"", ",", "254538"}], "}"}]],
     Annotation[#, {"Yamagata", 254538}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      RowBox[{"{", 
        RowBox[{"\"Fukui\"", ",", "248707"}], "}"}]],
     Annotation[#, {"Fukui", 248707}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 36.38}],
      "\"Mito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 36.38}],
      RowBox[{"{", 
        RowBox[{"\"Mito\"", ",", "246538"}], "}"}]],
     Annotation[#, {"Mito", 246538}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.94, 33.96}],
      "\"Shimonoseki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimonoseki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.94, 33.96}],
      RowBox[{"{", 
        RowBox[{"\"Shimonoseki\"", ",", "245786"}], "}"}]],
     Annotation[#, {"Shimonoseki", 245786}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.79}],
      "\"Neyagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Neyagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.79}],
      RowBox[{"{", 
        RowBox[{"\"Neyagawa\"", ",", "245110"}], "}"}]],
     Annotation[#, {"Neyagawa", 245110}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.02, 36.33}],
      "\"Takasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.02, 36.33}],
      RowBox[{"{", 
        RowBox[{"\"Takasaki\"", ",", "240857"}], "}"}]],
     Annotation[#, {"Takasaki", 240857}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.67}],
      "\"Fuchu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuchu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.67}],
      RowBox[{"{", 
        RowBox[{"\"Fuchu\"", ",", "240081"}], "}"}]],
     Annotation[#, {"Fuchu", 240081}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.69, 35.17}],
      "\"Fuji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.69, 35.17}],
      RowBox[{"{", 
        RowBox[{"\"Fuji\"", ",", "240014"}], "}"}]],
     Annotation[#, {"Fuji", 240014}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.53, 40.52}],
      "\"Hachinohe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hachinohe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.53, 40.52}],
      RowBox[{"{", 
        RowBox[{"\"Hachinohe\"", ",", "239046"}], "}"}]],
     Annotation[#, {"Hachinohe", 239046}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.51, 33.31}],
      "\"Kurume\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurume", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.51, 33.31}],
      RowBox[{"{", 
        RowBox[{"\"Kurume\"", ",", "238197"}], "}"}]],
     Annotation[#, {"Kurume", 238197}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.33}],
      "\"Chigasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chigasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.33}],
      RowBox[{"{", 
        RowBox[{"\"Chigasaki\"", ",", "231657"}], "}"}]],
     Annotation[#, {"Chigasaki", 231657}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.79, 35.82}],
      "\"Soka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Soka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.79, 35.82}],
      RowBox[{"{", 
        RowBox[{"\"Soka\"", ",", "231445"}], "}"}]],
     Annotation[#, {"Soka", 231445}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.45}],
      "\"Atsugi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Atsugi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.45}],
      RowBox[{"{", 
        RowBox[{"\"Atsugi\"", ",", "229199"}], "}"}]],
     Annotation[#, {"Atsugi", 229199}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.52}],
      "\"Yamato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.52}],
      RowBox[{"{", 
        RowBox[{"\"Yamato\"", ",", "224015"}], "}"}]],
     Annotation[#, {"Yamato", 224015}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.35, 34.800000000000004`}],
      "\"Takarazuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takarazuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.35, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Takarazuka\"", ",", "219789"}], "}"}]],
     Annotation[#, {"Takarazuka", 219789}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 35.95}],
      "\"Ageo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ageo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Ageo\"", ",", "219401"}], "}"}]],
     Annotation[#, {"Ageo", 219401}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.65}],
      "\"Chofu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chofu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.65}],
      RowBox[{"{", 
        RowBox[{"\"Chofu\"", ",", "212977"}], "}"}]],
     Annotation[#, {"Chofu", 212977}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.97, 36.24}],
      "\"Matsumoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsumoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.97, 36.24}],
      RowBox[{"{", 
        RowBox[{"\"Matsumoto\"", ",", "210667"}], "}"}]],
     Annotation[#, {"Matsumoto", 210667}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.980000000000004`}],
      "\"Kasukabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasukabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kasukabe\"", ",", "206915"}], "}"}]],
     Annotation[#, {"Kasukabe", 206915}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.39000000000001`, 34.47}],
      "\"Kishiwada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kishiwada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.39000000000001`, 34.47}],
      RowBox[{"{", 
        RowBox[{"\"Kishiwada\"", ",", "205561"}], "}"}]],
     Annotation[#, {"Kishiwada", 205561}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.86, 35.1}],
      "\"Numazu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Numazu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.86, 35.1}],
      RowBox[{"{", 
        RowBox[{"\"Numazu\"", ",", "204318"}], "}"}]],
     Annotation[#, {"Numazu", 204318}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.16, 35.25}],
      "\"Odawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Odawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.16, 35.25}],
      RowBox[{"{", 
        RowBox[{"\"Odawara\"", ",", "203035"}], "}"}]],
     Annotation[#, {"Odawara", 203035}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.56, 34.25}],
      "\"Kure\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kure", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.56, 34.25}],
      RowBox[{"{", 
        RowBox[{"\"Kure\"", ",", "196624"}], "}"}]],
     Annotation[#, {"Kure", 196624}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 37.46}],
      "\"Nagaoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagaoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 37.46}],
      RowBox[{"{", 
        RowBox[{"\"Nagaoka\"", ",", "195318"}], "}"}]],
     Annotation[#, {"Nagaoka", 195318}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.78}],
      "\"Itami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Itami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.78}],
      RowBox[{"{", 
        RowBox[{"\"Itami\"", ",", "193524"}], "}"}]],
     Annotation[#, {"Itami", 193524}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.9}],
      "\"Uji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.9}],
      RowBox[{"{", 
        RowBox[{"\"Uji\"", ",", "192925"}], "}"}]],
     Annotation[#, {"Uji", 192925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 34.88}],
      "\"Suzuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suzuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 34.88}],
      RowBox[{"{", 
        RowBox[{"\"Suzuka\"", ",", "191477"}], "}"}]],
     Annotation[#, {"Suzuka", 191477}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.57, 35.660000000000004`}],
      "\"Kofu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kofu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.57, 35.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kofu\"", ",", "190000"}], "}"}]],
     Annotation[#, {"Kofu", 190000}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.480000000000004`}],
      "\"Izumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Izumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Izumi\"", ",", "189085"}], "}"}]],
     Annotation[#, {"Izumi", 189085}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.74}],
      "\"Kodaira\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kodaira", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Kodaira\"", ",", "187368"}], "}"}]],
     Annotation[#, {"Kodaira", 187368}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.66, 36.59}],
      "\"Hitachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hitachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.66, 36.59}],
      RowBox[{"{", 
        RowBox[{"\"Hitachi\"", ",", "186307"}], "}"}]],
     Annotation[#, {"Hitachi", 186307}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.38, 42.980000000000004`}],
      "\"Kushiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kushiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.38, 42.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kushiro\"", ",", "183612"}], "}"}]],
     Annotation[#, {"Kushiro", 183612}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 35.74}],
      "\"Yachiyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yachiyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Yachiyo\"", ",", "182890"}], "}"}]],
     Annotation[#, {"Yachiyo", 182890}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.23, 35.72}],
      "\"Sakura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.23, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Sakura\"", ",", "182549"}], "}"}]],
     Annotation[#, {"Sakura", 182549}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.57, 35.68}],
      "\"Mitaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mitaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.57, 35.68}],
      RowBox[{"{", 
        RowBox[{"\"Mitaka\"", ",", "178739"}], "}"}]],
     Annotation[#, {"Mitaka", 178739}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 36.21}],
      "\"Tsukuba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsukuba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 36.21}],
      RowBox[{"{", 
        RowBox[{"\"Tsukuba\"", ",", "175589"}], "}"}]],
     Annotation[#, {"Tsukuba", 175589}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 40.6}],
      "\"Hirosaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hirosaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 40.6}],
      RowBox[{"{", 
        RowBox[{"\"Hirosaki\"", ",", "174972"}], "}"}]],
     Annotation[#, {"Hirosaki", 174972}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.59, 42.63}],
      "\"Tomakomai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tomakomai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.59, 42.63}],
      RowBox[{"{", 
        RowBox[{"\"Tomakomai\"", ",", "174806"}], "}"}]],
     Annotation[#, {"Tomakomai", 174806}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.37}],
      "\"Hadano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hadano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.37}],
      RowBox[{"{", 
        RowBox[{"\"Hadano\"", ",", "174281"}], "}"}]],
     Annotation[#, {"Hadano", 174281}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.19, 42.92}],
      "\"Obihiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Obihiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.19, 42.92}],
      RowBox[{"{", 
        RowBox[{"\"Obihiro\"", ",", "173890"}], "}"}]],
     Annotation[#, {"Obihiro", 173890}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.24, 33.94}],
      "\"Ube\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ube", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.24, 33.94}],
      RowBox[{"{", 
        RowBox[{"\"Ube\"", ",", "173733"}], "}"}]],
     Annotation[#, {"Ube", 173733}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.7}],
      "\"Tachikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tachikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.7}],
      RowBox[{"{", 
        RowBox[{"\"Tachikawa\"", ",", "173695"}], "}"}]],
     Annotation[#, {"Tachikawa", 173695}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.68}],
      "\"Hino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.68}],
      RowBox[{"{", 
        RowBox[{"\"Hino\"", ",", "171777"}], "}"}]],
     Annotation[#, {"Hino", 171777}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.02, 36.75}],
      "\"Takaoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takaoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.02, 36.75}],
      RowBox[{"{", 
        RowBox[{"\"Takaoka\"", ",", "170077"}], "}"}]],
     Annotation[#, {"Takaoka", 170077}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.1, 34.96}],
      "\"Anjo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Anjo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.1, 34.96}],
      RowBox[{"{", 
        RowBox[{"\"Anjo\"", ",", "168663"}], "}"}]],
     Annotation[#, {"Anjo", 168663}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.32}],
      "\"Kamakura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamakura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.32}],
      RowBox[{"{", 
        RowBox[{"\"Kamakura\"", ",", "166016"}], "}"}]],
     Annotation[#, {"Kamakura", 166016}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      RowBox[{"{", 
        RowBox[{"\"Saga\"", ",", "165236"}], "}"}]],
     Annotation[#, {"Saga", 165236}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.51, 34.72}],
      "\"Tsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.51, 34.72}],
      RowBox[{"{", 
        RowBox[{"\"Tsu\"", ",", "163461"}], "}"}]],
     Annotation[#, {"Tsu", 163461}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.87}],
      "\"Sayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.87}],
      RowBox[{"{", 
        RowBox[{"\"Sayama\"", ",", "160843"}], "}"}]],
     Annotation[#, {"Sayama", 160843}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.82}],
      "\"Kawanishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawanishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Kawanishi\"", ",", "160520"}], "}"}]],
     Annotation[#, {"Kawanishi", 160520}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.8, 36.32}],
      "\"Oyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.8, 36.32}],
      RowBox[{"{", 
        RowBox[{"\"Oyama\"", ",", "159936"}], "}"}]],
     Annotation[#, {"Oyama", 159936}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.35}],
      "\"Ashikaga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ashikaga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.35}],
      RowBox[{"{", 
        RowBox[{"\"Ashikaga\"", ",", "159671"}], "}"}]],
     Annotation[#, {"Ashikaga", 159671}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.04, 35.480000000000004`}],
      "\"Matsue\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsue", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.04, 35.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Matsue\"", ",", "156811"}], "}"}]],
     Annotation[#, {"Matsue", 156811}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.04, 35.69}],
      "\"Narashino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Narashino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.04, 35.69}],
      RowBox[{"{", 
        RowBox[{"\"Narashino\"", ",", "156082"}], "}"}]],
     Annotation[#, {"Narashino", 156082}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 35.86}],
      "\"Nagareyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagareyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 35.86}],
      RowBox[{"{", 
        RowBox[{"\"Nagareyama\"", ",", "156000"}], "}"}]],
     Annotation[#, {"Nagareyama", 156000}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.52, 36.4}],
      "\"Hitachinaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hitachinaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.52, 36.4}],
      RowBox[{"{", 
        RowBox[{"\"Hitachinaka\"", ",", "155968"}], "}"}]],
     Annotation[#, {"Hitachinaka", 155968}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 36.15}],
      "\"Kumagaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumagaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 36.15}],
      RowBox[{"{", 
        RowBox[{"\"Kumagaya\"", ",", "155813"}], "}"}]],
     Annotation[#, {"Kumagaya", 155813}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      "\"Tottori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tottori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      "\"Tottori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tottori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      RowBox[{"{", 
        RowBox[{"\"Tottori\"", ",", "154098"}], "}"}]],
     Annotation[#, {"Tottori", 154098}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.81}],
      "\"Niiza\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niiza", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.81}],
      RowBox[{"{", 
        RowBox[{"\"Niiza\"", ",", "153588"}], "}"}]],
     Annotation[#, {"Niiza", 153588}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 36.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ota\"", ",", "173881"}], "}"}]],
     Annotation[#, {"Ota", 173881}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 35.83}],
      "\"Iruma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iruma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 35.83}],
      RowBox[{"{", 
        RowBox[{"\"Iruma\"", ",", "151545"}], "}"}]],
     Annotation[#, {"Iruma", 151545}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 35.300000000000004`}],
      "\"Komaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Komaki\"", ",", "151025"}], "}"}]],
     Annotation[#, {"Komaki", 151025}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.75}],
      "\"Higashimurayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashimurayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.75}],
      RowBox[{"{", 
        RowBox[{"\"Higashimurayama\"", ",", "150868"}], "}"}]],
     Annotation[#, {"Higashimurayama", 150868}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 35.37}],
      "\"Ogaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ogaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 35.37}],
      RowBox[{"{", 
        RowBox[{"\"Ogaki\"", ",", "150570"}], "}"}]],
     Annotation[#, {"Ogaki", 150570}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.26, 35.79}],
      "\"Ome\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ome", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.26, 35.79}],
      RowBox[{"{", 
        RowBox[{"\"Ome\"", ",", "149323"}], "}"}]],
     Annotation[#, {"Ome", 149323}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.730000000000004`}],
      "\"Moriguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Moriguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Moriguchi\"", ",", "148350"}], "}"}]],
     Annotation[#, {"Moriguchi", 148350}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.46, 35.61}],
      "\"Tama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.46, 35.61}],
      RowBox[{"{", 
        RowBox[{"\"Tama\"", ",", "147477"}], "}"}]],
     Annotation[#, {"Tama", 147477}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      RowBox[{"{", 
        RowBox[{"\"Yamaguchi\"", ",", "145515"}], "}"}]],
     Annotation[#, {"Yamaguchi", 145515}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141., 43.2}],
      "\"Otaru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otaru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141., 43.2}],
      RowBox[{"{", 
        RowBox[{"\"Otaru\"", ",", "143792"}], "}"}]],
     Annotation[#, {"Otaru", 143792}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.9, 35.67}],
      "\"Urayasu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Urayasu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.9, 35.67}],
      RowBox[{"{", 
        RowBox[{"\"Urayasu\"", ",", "143758"}], "}"}]],
     Annotation[#, {"Urayasu", 143758}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.34, 35.44}],
      "\"Yonago\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yonago", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      "\"Tottori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tottori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.34, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Yonago\"", ",", "141368"}], "}"}]],
     Annotation[#, {"Yonago", 141368}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137., 34.99}],
      "\"Kariya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kariya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137., 34.99}],
      RowBox[{"{", 
        RowBox[{"\"Kariya\"", ",", "139159"}], "}"}]],
     Annotation[#, {"Kariya", 139159}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.71}],
      "\"Musashino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Musashino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.71}],
      RowBox[{"{", 
        RowBox[{"\"Musashino\"", ",", "137479"}], "}"}]],
     Annotation[#, {"Musashino", 137479}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.09}],
      "\"Tsuchiura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsuchiura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.09}],
      RowBox[{"{", 
        RowBox[{"\"Tsuchiura\"", ",", "136383"}], "}"}]],
     Annotation[#, {"Tsuchiura", 136383}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 37.12}],
      "\"Joetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Joetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 37.12}],
      RowBox[{"{", 
        RowBox[{"\"Joetsu\"", ",", "136233"}], "}"}]],
     Annotation[#, {"Joetsu", 136233}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.72, 34.44}],
      "\"Higashihiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashihiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.72, 34.44}],
      RowBox[{"{", 
        RowBox[{"\"Higashihiroshima\"", ",", "135639"}], "}"}]],
     Annotation[#, {"Higashihiroshima", 135639}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.5}],
      "\"Zama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Zama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.5}],
      RowBox[{"{", 
        RowBox[{"\"Zama\"", ",", "134671"}], "}"}]],
     Annotation[#, {"Zama", 134671}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.08, 35.22}],
      "\"Seto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Seto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.08, 35.22}],
      RowBox[{"{", 
        RowBox[{"\"Seto\"", ",", "134246"}], "}"}]],
     Annotation[#, {"Seto", 134246}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.55, 43.12}],
      "\"Ebetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ebetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.55, 43.12}],
      RowBox[{"{", 
        RowBox[{"\"Ebetsu\"", ",", "133953"}], "}"}]],
     Annotation[#, {"Ebetsu", 133953}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.6, 34.52}],
      "\"Tondabayashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tondabayashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.6, 34.52}],
      RowBox[{"{", 
        RowBox[{"\"Tondabayashi\"", ",", "132873"}], "}"}]],
     Annotation[#, {"Tondabayashi", 132873}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 34.88}],
      "\"Fujieda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujieda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 34.88}],
      RowBox[{"{", 
        RowBox[{"\"Fujieda\"", ",", "132859"}], "}"}]],
     Annotation[#, {"Fujieda", 132859}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.22, 34.89}],
      "\"Sanda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sanda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.22, 34.89}],
      RowBox[{"{", 
        RowBox[{"\"Sanda\"", ",", "132858"}], "}"}]],
     Annotation[#, {"Sanda", 132858}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.89000000000001`, 35.410000000000004`}],
      "\"Kakamigahara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kakamigahara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.89000000000001`, 35.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kakamigahara\"", ",", "132241"}], "}"}]],
     Annotation[#, {"Kakamigahara", 132241}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.44, 33.02}],
      "\"Omuta\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omuta", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.44, 33.02}],
      RowBox[{"{", 
        RowBox[{"\"Omuta\"", ",", "131974"}], "}"}]],
     Annotation[#, {"Omuta", 131974}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 35.88}],
      "\"Abiko\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Abiko", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 35.88}],
      RowBox[{"{", 
        RowBox[{"\"Abiko\"", ",", "131771"}], "}"}]],
     Annotation[#, {"Abiko", 131771}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.59, 34.730000000000004`}],
      "\"Kadoma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kadoma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.59, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kadoma\"", ",", "131727"}], "}"}]],
     Annotation[#, {"Kadoma", 131727}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.06, 31.720000000000002`}],
      "\"Miyakonojo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyakonojo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.06, 31.720000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Miyakonojo\"", ",", "130994"}], "}"}]],
     Annotation[#, {"Miyakonojo", 130994}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.55, 34.57}],
      "\"Matsubara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsubara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.55, 34.57}],
      RowBox[{"{", 
        RowBox[{"\"Matsubara\"", ",", "130855"}], "}"}]],
     Annotation[#, {"Matsubara", 130855}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.20000000000002`, 36.32}],
      "\"Isesaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Isesaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.20000000000002`, 36.32}],
      RowBox[{"{", 
        RowBox[{"\"Isesaki\"", ",", "130692"}], "}"}]],
     Annotation[#, {"Isesaki", 130692}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 35.83}],
      "\"Misato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Misato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 35.83}],
      RowBox[{"{", 
        RowBox[{"\"Misato\"", ",", "129692"}], "}"}]],
     Annotation[#, {"Misato", 129692}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.71}],
      "\"Daito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Daito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.71}],
      RowBox[{"{", 
        RowBox[{"\"Daito\"", ",", "129521"}], "}"}]],
     Annotation[#, {"Daito", 129521}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.83}],
      "\"Asaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Asaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.83}],
      RowBox[{"{", 
        RowBox[{"\"Asaka\"", ",", "128058"}], "}"}]],
     Annotation[#, {"Asaka", 128058}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.95, 35.02}],
      "\"Kusatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kusatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.95, 35.02}],
      RowBox[{"{", 
        RowBox[{"\"Kusatsu\"", ",", "127680"}], "}"}]],
     Annotation[#, {"Kusatsu", 127680}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 36.4}],
      "\"Ueda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ueda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 36.4}],
      RowBox[{"{", 
        RowBox[{"\"Ueda\"", ",", "126606"}], "}"}]],
     Annotation[#, {"Ueda", 126606}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.480000000000004`}],
      "\"Kawachinagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawachinagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kawachinagano\"", ",", "126498"}], "}"}]],
     Annotation[#, {"Kawachinagano", 126498}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.5}],
      "\"Kashihara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashihara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.5}],
      RowBox[{"{", 
        RowBox[{"\"Kashihara\"", ",", "126221"}], "}"}]],
     Annotation[#, {"Kashihara", 126221}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.5, 33.28}],
      "\"Beppu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Beppu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.5, 33.28}],
      RowBox[{"{", 
        RowBox[{"\"Beppu\"", ",", "125065"}], "}"}]],
     Annotation[#, {"Beppu", 125065}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 34.58}],
      "\"Matsusaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsusaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 34.58}],
      RowBox[{"{", 
        RowBox[{"\"Matsusaka\"", ",", "124613"}], "}"}]],
     Annotation[#, {"Matsusaka", 124613}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.47, 34.83}],
      "\"Mino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.47, 34.83}],
      RowBox[{"{", 
        RowBox[{"\"Mino\"", ",", "123948"}], "}"}]],
     Annotation[#, {"Mino", 123948}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.42000000000002`, 35.47}],
      "\"Ebina\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ebina", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.42000000000002`, 35.47}],
      RowBox[{"{", 
        RowBox[{"\"Ebina\"", ",", "123665"}], "}"}]],
     Annotation[#, {"Ebina", 123665}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.27, 33.96}],
      "\"Niihama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niihama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.27, 33.96}],
      RowBox[{"{", 
        RowBox[{"\"Niihama\"", ",", "123059"}], "}"}]],
     Annotation[#, {"Niihama", 123059}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 35.38}],
      "\"Kisarazu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kisarazu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 35.38}],
      RowBox[{"{", 
        RowBox[{"\"Kisarazu\"", ",", "122524"}], "}"}]],
     Annotation[#, {"Kisarazu", 122524}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.68, 32.58}],
      "\"Nobeoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nobeoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.68, 32.58}],
      RowBox[{"{", 
        RowBox[{"\"Nobeoka\"", ",", "121949"}], "}"}]],
     Annotation[#, {"Nobeoka", 121949}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.61, 35.22}],
      "\"Fujinomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujinomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.61, 35.22}],
      RowBox[{"{", 
        RowBox[{"\"Fujinomiya\"", ",", "121515"}], "}"}]],
     Annotation[#, {"Fujinomiya", 121515}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.87, 35.95}],
      "\"Noda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Noda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.87, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Noda\"", ",", "121411"}], "}"}]],
     Annotation[#, {"Noda", 121411}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 34.87}],
      "\"Yaizu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yaizu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 34.87}],
      RowBox[{"{", 
        RowBox[{"\"Yaizu\"", ",", "121057"}], "}"}]],
     Annotation[#, {"Yaizu", 121057}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.61, 34.56}],
      "\"Habikino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Habikino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.61, 34.56}],
      RowBox[{"{", 
        RowBox[{"\"Habikino\"", ",", "121051"}], "}"}]],
     Annotation[#, {"Habikino", 121051}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 34.82}],
      "\"Toyokawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyokawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Toyokawa\"", ",", "120537"}], "}"}]],
     Annotation[#, {"Toyokawa", 120537}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.68, 35.82}],
      "\"Toda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.68, 35.82}],
      RowBox[{"{", 
        RowBox[{"\"Toda\"", ",", "118731"}], "}"}]],
     Annotation[#, {"Toda", 118731}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.7}],
      "\"Kokubunji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kokubunji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.7}],
      RowBox[{"{", 
        RowBox[{"\"Kokubunji\"", ",", "118682"}], "}"}]],
     Annotation[#, {"Kokubunji", 118682}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.72, 34.7}],
      "\"Ikoma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ikoma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.72, 34.7}],
      RowBox[{"{", 
        RowBox[{"\"Ikoma\"", ",", "117601"}], "}"}]],
     Annotation[#, {"Ikoma", 117601}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.29, 38.43}],
      "\"Ishinomaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ishinomaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.29, 38.43}],
      RowBox[{"{", 
        RowBox[{"\"Ishinomaki\"", ",", "117233"}], "}"}]],
     Annotation[#, {"Ishinomaki", 117233}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.57, 34.05}],
      "\"Hofu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hofu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.57, 34.05}],
      RowBox[{"{", 
        RowBox[{"\"Hofu\"", ",", "116925"}], "}"}]],
     Annotation[#, {"Hofu", 116925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 35.76}],
      "\"Higashikurume\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashikurume", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 35.76}],
      RowBox[{"{", 
        RowBox[{"\"Higashikurume\"", ",", "116323"}], "}"}]],
     Annotation[#, {"Higashikurume", 116323}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.94, 34.9}],
      "\"Handa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Handa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.94, 34.9}],
      RowBox[{"{", 
        RowBox[{"\"Handa\"", ",", "116119"}], "}"}]],
     Annotation[#, {"Handa", 116119}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.52, 35.72}],
      "\"Koganei\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koganei", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.52, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Koganei\"", ",", "115967"}], "}"}]],
     Annotation[#, {"Koganei", 115967}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 37.49}],
      "\"Aizuwakamatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aizuwakamatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 37.49}],
      RowBox[{"{", 
        RowBox[{"\"Aizuwakamatsu\"", ",", "115937"}], "}"}]],
     Annotation[#, {"Aizuwakamatsu", 115937}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133., 34.06}],
      "\"Imabari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Imabari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133., 34.06}],
      RowBox[{"{", 
        RowBox[{"\"Imabari\"", ",", "115355"}], "}"}]],
     Annotation[#, {"Imabari", 115355}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.92000000000002`, 35.12}],
      "\"Mishima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mishima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.92000000000002`, 35.12}],
      RowBox[{"{", 
        RowBox[{"\"Mishima\"", ",", "113479"}], "}"}]],
     Annotation[#, {"Mishima", 113479}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.89000000000001`, 43.81}],
      "\"Kitami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.89000000000001`, 43.81}],
      RowBox[{"{", 
        RowBox[{"\"Kitami\"", ",", "113137"}], "}"}]],
     Annotation[#, {"Kitami", 113137}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.08}],
      "\"Kuwana\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kuwana", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.08}],
      RowBox[{"{", 
        RowBox[{"\"Kuwana\"", ",", "113107"}], "}"}]],
     Annotation[#, {"Kuwana", 113107}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.54}],
      "\"Kasuga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasuga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.54}],
      RowBox[{"{", 
        RowBox[{"\"Kasuga\"", ",", "112299"}], "}"}]],
     Annotation[#, {"Kasuga", 112299}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.24, 35.27}],
      "\"Hikone\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hikone", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.24, 35.27}],
      RowBox[{"{", 
        RowBox[{"\"Hikone\"", ",", "110925"}], "}"}]],
     Annotation[#, {"Hikone", 110925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 36.43}],
      "\"Kiryu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kiryu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 36.43}],
      RowBox[{"{", 
        RowBox[{"\"Kiryu\"", ",", "110219"}], "}"}]],
     Annotation[#, {"Kiryu", 110219}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.44, 36.410000000000004`}],
      "\"Komatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.44, 36.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Komatsu\"", ",", "109045"}], "}"}]],
     Annotation[#, {"Komatsu", 109045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.70000000000002`, 35.96}],
      "\"Iwatsuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwatsuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.70000000000002`, 35.96}],
      RowBox[{"{", 
        RowBox[{"\"Iwatsuki\"", ",", "108833"}], "}"}]],
     Annotation[#, {"Iwatsuki", 108833}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 35.87}],
      "\"Fujimi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujimi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 35.87}],
      RowBox[{"{", 
        RowBox[{"\"Fujimi\"", ",", "108460"}], "}"}]],
     Annotation[#, {"Fujimi", 108460}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.7}],
      "\"Akishima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akishima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.7}],
      RowBox[{"{", 
        RowBox[{"\"Akishima\"", ",", "107926"}], "}"}]],
     Annotation[#, {"Akishima", 107926}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.13, 35.33}],
      "\"Tajimi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tajimi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.13, 35.33}],
      RowBox[{"{", 
        RowBox[{"\"Tajimi\"", ",", "107818"}], "}"}]],
     Annotation[#, {"Tajimi", 107818}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.83, 35.52}],
      "\"Iida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.83, 35.52}],
      RowBox[{"{", 
        RowBox[{"\"Iida\"", ",", "107111"}], "}"}]],
     Annotation[#, {"Iida", 107111}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.74}],
      "\"Hoya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hoya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Hoya\"", ",", "107072"}], "}"}]],
     Annotation[#, {"Hoya", 107072}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.21}],
      "\"Fukaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.21}],
      RowBox[{"{", 
        RowBox[{"\"Fukaya\"", ",", "106595"}], "}"}]],
     Annotation[#, {"Fukaya", 106595}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.01, 35.77}],
      "\"Kamagaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamagaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.01, 35.77}],
      RowBox[{"{", 
        RowBox[{"\"Kamagaya\"", ",", "106286"}], "}"}]],
     Annotation[#, {"Kamagaya", 106286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.52, 33.480000000000004`}],
      "\"Chikushino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chikushino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.52, 33.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Chikushino\"", ",", "105420"}], "}"}]],
     Annotation[#, {"Chikushino", 105420}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.6, 32.51}],
      "\"Yatsushiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yatsushiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.6, 32.51}],
      RowBox[{"{", 
        RowBox[{"\"Yatsushiro\"", ",", "104341"}], "}"}]],
     Annotation[#, {"Yatsushiro", 104341}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.23, 34.17}],
      "\"Iwakuni\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwakuni", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.23, 34.17}],
      RowBox[{"{", 
        RowBox[{"\"Iwakuni\"", ",", "104004"}], "}"}]],
     Annotation[#, {"Iwakuni", 104004}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.410000000000004`}],
      "\"Isehara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Isehara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Isehara\"", ",", "103401"}], "}"}]],
     Annotation[#, {"Isehara", 103401}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.06, 34.87}],
      "\"Nishio\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishio", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.06, 34.87}],
      RowBox[{"{", 
        RowBox[{"\"Nishio\"", ",", "103337"}], "}"}]],
     Annotation[#, {"Nishio", 103337}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.25}],
      "\"Inazawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inazawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.25}],
      RowBox[{"{", 
        RowBox[{"\"Inazawa\"", ",", "102130"}], "}"}]],
     Annotation[#, {"Inazawa", 102130}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.8, 34.05}],
      "\"Tokuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.8, 34.05}],
      RowBox[{"{", 
        RowBox[{"\"Tokuyama\"", ",", "101133"}], "}"}]],
     Annotation[#, {"Tokuyama", 101133}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.89000000000001`, 35.03}],
      "\"Tokai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.89000000000001`, 35.03}],
      RowBox[{"{", 
        RowBox[{"\"Tokai\"", ",", "100679"}], "}"}]],
     Annotation[#, {"Tokai", 100679}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.79}],
      "\"Narita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Narita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.79}],
      RowBox[{"{", 
        RowBox[{"\"Narita\"", ",", "100641"}], "}"}]],
     Annotation[#, {"Narita", 100641}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.83, 38.910000000000004`}],
      "\"Sakata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.83, 38.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Sakata\"", ",", "100446"}], "}"}]],
     Annotation[#, {"Sakata", 100446}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.34}],
      "\"Konan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Konan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.34}],
      RowBox[{"{", 
        RowBox[{"\"Konan\"", ",", "100389"}], "}"}]],
     Annotation[#, {"Konan", 100389}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 38.730000000000004`}],
      "\"Tsuruoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsuruoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 38.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tsuruoka\"", ",", "99820"}], "}"}]],
     Annotation[#, {"Tsuruoka", 99820}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.43, 34.82}],
      "\"Ikeda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ikeda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.43, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Ikeda\"", ",", "99476"}], "}"}]],
     Annotation[#, {"Ikeda", 99476}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 34.42}],
      "\"Izumisano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Izumisano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 34.42}],
      RowBox[{"{", 
        RowBox[{"\"Izumisano\"", ",", "99428"}], "}"}]],
     Annotation[#, {"Izumisano", 99428}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.43}],
      "\"Kani\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kani", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.43}],
      RowBox[{"{", 
        RowBox[{"\"Kani\"", ",", "97469"}], "}"}]],
     Annotation[#, {"Kani", 97469}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.05, 32.84}],
      "\"Isahaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Isahaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.05, 32.84}],
      RowBox[{"{", 
        RowBox[{"\"Isahaya\"", ",", "97371"}], "}"}]],
     Annotation[#, {"Isahaya", 97371}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.29, 35.43}],
      "\"Mobara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mobara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.29, 35.43}],
      RowBox[{"{", 
        RowBox[{"\"Mobara\"", ",", "97315"}], "}"}]],
     Annotation[#, {"Mobara", 97315}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.71, 34.49}],
      RowBox[{"{", 
        RowBox[{"\"Ise\"", ",", "190063"}], "}"}]],
     Annotation[#, {"Ise", 190063}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 35.02}],
      "\"Kameoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kameoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 35.02}],
      RowBox[{"{", 
        RowBox[{"\"Kameoka\"", ",", "97181"}], "}"}]],
     Annotation[#, {"Kameoka", 97181}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.95}],
      "\"Sakado\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakado", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Sakado\"", ",", "96656"}], "}"}]],
     Annotation[#, {"Sakado", 96656}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.01, 42.34}],
      "\"Muroran\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Muroran", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.01, 42.34}],
      RowBox[{"{", 
        RowBox[{"\"Muroran\"", ",", "96197"}], "}"}]],
     Annotation[#, {"Muroran", 96197}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.48, 33.54}],
      "\"Onojo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Onojo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.48, 33.54}],
      RowBox[{"{", 
        RowBox[{"\"Onojo\"", ",", "96166"}], "}"}]],
     Annotation[#, {"Onojo", 96166}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.75, 36.57}],
      "\"Kanuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.75, 36.57}],
      RowBox[{"{", 
        RowBox[{"\"Kanuma\"", ",", "94903"}], "}"}]],
     Annotation[#, {"Kanuma", 94903}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 37.910000000000004`}],
      "\"Yonezawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yonezawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 37.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Yonezawa\"", ",", "94486"}], "}"}]],
     Annotation[#, {"Yonezawa", 94486}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.65, 34.800000000000004`}],
      "\"Takasago\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takasago", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.65, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Takasago\"", ",", "94422"}], "}"}]],
     Annotation[#, {"Takasago", 94422}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 36.050000000000004`}],
      "\"Higashimatsuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashimatsuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 36.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Higashimatsuyama\"", ",", "93932"}], "}"}]],
     Annotation[#, {"Higashimatsuyama", 93932}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.12, 39.29}],
      "\"Kitakami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitakami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.12, 39.29}],
      RowBox[{"{", 
        RowBox[{"\"Kitakami\"", ",", "93854"}], "}"}]],
     Annotation[#, {"Kitakami", 93854}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.64000000000001`, 42.83}],
      "\"Chitose\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chitose", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.64000000000001`, 42.83}],
      RowBox[{"{", 
        RowBox[{"\"Chitose\"", ",", "92942"}], "}"}]],
     Annotation[#, {"Chitose", 92942}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.36, 34.45}],
      "\"Kaizuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaizuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.36, 34.45}],
      RowBox[{"{", 
        RowBox[{"\"Kaizuka\"", ",", "92632"}], "}"}]],
     Annotation[#, {"Kaizuka", 92632}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 35.45}],
      "\"Maizuru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maizuru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 35.45}],
      RowBox[{"{", 
        RowBox[{"\"Maizuru\"", ",", "92465"}], "}"}]],
     Annotation[#, {"Maizuru", 92465}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.79, 34.64}],
      "\"Yamatokoriyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamatokoriyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.79, 34.64}],
      RowBox[{"{", 
        RowBox[{"\"Yamatokoriyama\"", ",", "92137"}], "}"}]],
     Annotation[#, {"Yamatokoriyama", 92137}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 35.33}],
      "\"Kimitsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kimitsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 35.33}],
      RowBox[{"{", 
        RowBox[{"\"Kimitsu\"", ",", "92126"}], "}"}]],
     Annotation[#, {"Kimitsu", 92126}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.19, 34.410000000000004`}],
      "\"Onomichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Onomichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.19, 34.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Onomichi\"", ",", "90936"}], "}"}]],
     Annotation[#, {"Onomichi", 90936}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.01, 35.07}],
      "\"Tsuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.01, 35.07}],
      RowBox[{"{", 
        RowBox[{"\"Tsuyama\"", ",", "89717"}], "}"}]],
     Annotation[#, {"Tsuyama", 89717}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.75, 35.36}],
      "\"Izumo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Izumo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.75, 35.36}],
      RowBox[{"{", 
        RowBox[{"\"Izumo\"", ",", "89286"}], "}"}]],
     Annotation[#, {"Izumo", 89286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.31, 34.730000000000004`}],
      "\"Ashiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ashiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.31, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ashiya\"", ",", "88573"}], "}"}]],
     Annotation[#, {"Ashiya", 88573}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.85, 34.72}],
      "\"Iwata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.85, 34.72}],
      RowBox[{"{", 
        RowBox[{"\"Iwata\"", ",", "88509"}], "}"}]],
     Annotation[#, {"Iwata", 88509}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 36.050000000000004`}],
      "\"Konosu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Konosu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 36.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Konosu\"", ",", "88493"}], "}"}]],
     Annotation[#, {"Konosu", 88493}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.09, 34.63}],
      "\"Nabari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nabari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.09, 34.63}],
      RowBox[{"{", 
        RowBox[{"\"Nabari\"", ",", "88128"}], "}"}]],
     Annotation[#, {"Nabari", 88128}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.55, 33.81}],
      "\"Munakata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Munakata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.55, 33.81}],
      RowBox[{"{", 
        RowBox[{"\"Munakata\"", ",", "86979"}], "}"}]],
     Annotation[#, {"Munakata", 86979}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.17000000000002`, 35.68}],
      "\"Yotsukaido\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yotsukaido", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.17000000000002`, 35.68}],
      RowBox[{"{", 
        RowBox[{"\"Yotsukaido\"", ",", "86701"}], "}"}]],
     Annotation[#, {"Yotsukaido", 86701}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.78, 34.800000000000004`}],
      "\"Hamakita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hamakita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.78, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Hamakita\"", ",", "86502"}], "}"}]],
     Annotation[#, {"Hamakita", 86502}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 36.14}],
      "\"Gyoda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gyoda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 36.14}],
      RowBox[{"{", 
        RowBox[{"\"Gyoda\"", ",", "86343"}], "}"}]],
     Annotation[#, {"Gyoda", 86343}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.86}],
      "\"Hanno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hanno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.86}],
      RowBox[{"{", 
        RowBox[{"\"Hanno\"", ",", "86262"}], "}"}]],
     Annotation[#, {"Hanno", 86262}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.57, 37.38}],
      "\"Kashiwazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashiwazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.57, 37.38}],
      RowBox[{"{", 
        RowBox[{"\"Kashiwazaki\"", ",", "86183"}], "}"}]],
     Annotation[#, {"Kashiwazaki", 86183}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 35.910000000000004`}],
      "\"Ryugasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ryugasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 35.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ryugasaki\"", ",", "85761"}], "}"}]],
     Annotation[#, {"Ryugasaki", 85761}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.76, 43.2}],
      "\"Iwamizawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwamizawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.76, 43.2}],
      RowBox[{"{", 
        RowBox[{"\"Iwamizawa\"", ",", "85107"}], "}"}]],
     Annotation[#, {"Iwamizawa", 85107}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.03, 34.77}],
      "\"Kakegawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kakegawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.03, 34.77}],
      RowBox[{"{", 
        RowBox[{"\"Kakegawa\"", ",", "84004"}], "}"}]],
     Annotation[#, {"Kakegawa", 84004}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 35.31}],
      "\"Gotemba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gotemba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 35.31}],
      RowBox[{"{", 
        RowBox[{"\"Gotemba\"", ",", "83794"}], "}"}]],
     Annotation[#, {"Gotemba", 83794}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.55, 34.78}],
      "\"Settsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Settsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.55, 34.78}],
      RowBox[{"{", 
        RowBox[{"\"Settsu\"", ",", "83336"}], "}"}]],
     Annotation[#, {"Settsu", 83336}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.31, 35.660000000000004`}],
      "\"Yachimata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yachimata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.31, 35.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Yachimata\"", ",", "83322"}], "}"}]],
     Annotation[#, {"Yachimata", 83322}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.}],
      RowBox[{"{", 
        RowBox[{"\"Chita\"", ",", "308291"}], "}"}]],
     Annotation[#, {"Chita", 308291}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.77, 34.86}],
      "\"Joyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Joyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.77, 34.86}],
      RowBox[{"{", 
        RowBox[{"\"Joyo\"", ",", "83110"}], "}"}]],
     Annotation[#, {"Joyo", 83110}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.96, 37.62}],
      "\"Sanjo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sanjo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.96, 37.62}],
      RowBox[{"{", 
        RowBox[{"\"Sanjo\"", ",", "82893"}], "}"}]],
     Annotation[#, {"Sanjo", 82893}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.44}],
      "\"Ayase\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ayase", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Ayase\"", ",", "82612"}], "}"}]],
     Annotation[#, {"Ayase", 82612}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 36.32}],
      "\"Sano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 36.32}],
      RowBox[{"{", 
        RowBox[{"\"Sano\"", ",", "82535"}], "}"}]],
     Annotation[#, {"Sano", 82535}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.85, 31.38}],
      "\"Kanoya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanoya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.85, 31.38}],
      RowBox[{"{", 
        RowBox[{"\"Kanoya\"", ",", "82335"}], "}"}]],
     Annotation[#, {"Kanoya", 82335}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      RowBox[{"{", 
        RowBox[{"\"Tochigi\"", ",", "82133"}], "}"}]],
     Annotation[#, {"Tochigi", 82133}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.74}],
      "\"Tanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Tanashi\"", ",", "82112"}], "}"}]],
     Annotation[#, {"Tanashi", 82112}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.79, 34.29}],
      "\"Marugame\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Marugame", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.79, 34.29}],
      RowBox[{"{", 
        RowBox[{"\"Marugame\"", ",", "82090"}], "}"}]],
     Annotation[#, {"Marugame", 82090}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.68, 34.78}],
      "\"Katano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Katano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.68, 34.78}],
      RowBox[{"{", 
        RowBox[{"\"Katano\"", ",", "82026"}], "}"}]],
     Annotation[#, {"Katano", 82026}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.29, 35.72}],
      "\"Akiruno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akiruno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.29, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Akiruno\"", ",", "82021"}], "}"}]],
     Annotation[#, {"Akiruno", 82021}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.14}],
      "\"Nisshin\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nisshin", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.14}],
      RowBox[{"{", 
        RowBox[{"\"Nisshin\"", ",", "81865"}], "}"}]],
     Annotation[#, {"Nisshin", 81865}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 36.25}],
      "\"Tatebayashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tatebayashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 36.25}],
      RowBox[{"{", 
        RowBox[{"\"Tatebayashi\"", ",", "81274"}], "}"}]],
     Annotation[#, {"Tatebayashi", 81274}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 37.94}],
      "\"Shibata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shibata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 37.94}],
      RowBox[{"{", 
        RowBox[{"\"Shibata\"", ",", "80793"}], "}"}]],
     Annotation[#, {"Shibata", 80793}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.23, 34.84}],
      "\"Gamagori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gamagori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.23, 34.84}],
      RowBox[{"{", 
        RowBox[{"\"Gamagori\"", ",", "80786"}], "}"}]],
     Annotation[#, {"Gamagori", 80786}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.41, 34.5}],
      "\"Izumiotsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Izumiotsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.41, 34.5}],
      RowBox[{"{", 
        RowBox[{"\"Izumiotsu\"", ",", "80772"}], "}"}]],
     Annotation[#, {"Izumiotsu", 80772}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.07, 35.9}],
      "\"Toride\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toride", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.07, 35.9}],
      RowBox[{"{", 
        RowBox[{"\"Toride\"", ",", "80716"}], "}"}]],
     Annotation[#, {"Toride", 80716}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 35.22}],
      "\"Owariashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Owariashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 35.22}],
      RowBox[{"{", 
        RowBox[{"\"Owariashi\"", ",", "80633"}], "}"}]],
     Annotation[#, {"Owariashi", 80633}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.08, 34.4}],
      "\"Mihara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mihara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.08, 34.4}],
      RowBox[{"{", 
        RowBox[{"\"Mihara\"", ",", "80387"}], "}"}]],
     Annotation[#, {"Mihara", 80387}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.14000000000001`, 36.}],
      "\"Ushiku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ushiku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.14000000000001`, 36.}],
      RowBox[{"{", 
        RowBox[{"\"Ushiku\"", ",", "80020"}], "}"}]],
     Annotation[#, {"Ushiku", 80020}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.74}],
      "\"Higashiyamato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashiyamato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.41, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Higashiyamato\"", ",", "79333"}], "}"}]],
     Annotation[#, {"Higashiyamato", 79333}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.59}],
      "\"Kashiwara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashiwara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.59}],
      RowBox[{"{", 
        RowBox[{"\"Kashiwara\"", ",", "79058"}], "}"}]],
     Annotation[#, {"Kashiwara", 79058}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.64}],
      "\"Iizuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iizuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.64}],
      RowBox[{"{", 
        RowBox[{"\"Iizuka\"", ",", "78206"}], "}"}]],
     Annotation[#, {"Iizuka", 78206}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.69}],
      "\"Kunitachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kunitachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.43, 35.69}],
      RowBox[{"{", 
        RowBox[{"\"Kunitachi\"", ",", "78062"}], "}"}]],
     Annotation[#, {"Kunitachi", 78062}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 35.01}],
      "\"Obu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Obu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Obu\"", ",", "77864"}], "}"}]],
     Annotation[#, {"Obu", 77864}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.63}],
      "\"Komae\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komae", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.63}],
      RowBox[{"{", 
        RowBox[{"\"Komae\"", ",", "77642"}], "}"}]],
     Annotation[#, {"Komae", 77642}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 35.78}],
      "\"Wako\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wako", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 35.78}],
      RowBox[{"{", 
        RowBox[{"\"Wako\"", ",", "77435"}], "}"}]],
     Annotation[#, {"Wako", 77435}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.33, 34.36}],
      "\"Hatsukaichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hatsukaichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.33, 34.36}],
      RowBox[{"{", 
        RowBox[{"\"Hatsukaichi\"", ",", "77341"}], "}"}]],
     Annotation[#, {"Hatsukaichi", 77341}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.39000000000001`, 34.86}],
      "\"Seki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Seki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.39000000000001`, 34.86}],
      RowBox[{"{", 
        RowBox[{"\"Seki\"", ",", "77084"}], "}"}]],
     Annotation[#, {"Seki", 77084}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.63}],
      "\"Inagi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inagi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.49, 35.63}],
      RowBox[{"{", 
        RowBox[{"\"Inagi\"", ",", "77023"}], "}"}]],
     Annotation[#, {"Inagi", 77023}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.93}],
      "\"Nagaokakyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagaokakyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.93}],
      RowBox[{"{", 
        RowBox[{"\"Nagaokakyo\"", ",", "76895"}], "}"}]],
     Annotation[#, {"Nagaokakyo", 76895}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.96, 38.57}],
      "\"Furukawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Furukawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.96, 38.57}],
      RowBox[{"{", 
        RowBox[{"\"Furukawa\"", ",", "76312"}], "}"}]],
     Annotation[#, {"Furukawa", 76312}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.13, 34.83}],
      "\"Shimada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.13, 34.83}],
      RowBox[{"{", 
        RowBox[{"\"Shimada\"", ",", "75781"}], "}"}]],
     Annotation[#, {"Shimada", 75781}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.16, 35.910000000000004`}],
      "\"Takefu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takefu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.16, 35.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Takefu\"", ",", "75753"}], "}"}]],
     Annotation[#, {"Takefu", 75753}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.81, 35.75}],
      "\"Choshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Choshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.81, 35.75}],
      RowBox[{"{", 
        RowBox[{"\"Choshi\"", ",", "75650"}], "}"}]],
     Annotation[#, {"Choshi", 75650}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 38.160000000000004`}],
      "\"Natori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Natori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 38.160000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Natori\"", ",", "75561"}], "}"}]],
     Annotation[#, {"Natori", 75561}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.56, 36.}],
      "\"Okegawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okegawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.56, 36.}],
      RowBox[{"{", 
        RowBox[{"\"Okegawa\"", ",", "75062"}], "}"}]],
     Annotation[#, {"Okegawa", 75062}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.98, 34.81}],
      "\"Miki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.98, 34.81}],
      RowBox[{"{", 
        RowBox[{"\"Miki\"", ",", "74701"}], "}"}]],
     Annotation[#, {"Miki", 74701}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.84, 35.83}],
      "\"Yashio\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yashio", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.84, 35.83}],
      RowBox[{"{", 
        RowBox[{"\"Yashio\"", ",", "74699"}], "}"}]],
     Annotation[#, {"Yashio", 74699}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.93, 35.38}],
      "\"Inuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.93, 35.38}],
      RowBox[{"{", 
        RowBox[{"\"Inuyama\"", ",", "73995"}], "}"}]],
     Annotation[#, {"Inuyama", 73995}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.07}],
      "\"Kuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.07}],
      RowBox[{"{", 
        RowBox[{"\"Kuki\"", ",", "73373"}], "}"}]],
     Annotation[#, {"Kuki", 73373}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 34.51}],
      "\"Yamatotakada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamatotakada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 34.51}],
      RowBox[{"{", 
        RowBox[{"\"Yamatotakada\"", ",", "73171"}], "}"}]],
     Annotation[#, {"Yamatotakada", 73171}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.89000000000001`, 38.26}],
      "\"Sendai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sendai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.29, 31.82}],
      RowBox[{"{", 
        RowBox[{"\"Sendai\"", ",", "1037562"}], "}"}]],
     Annotation[#, {"Sendai", 1037562}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.12, 39.39}],
      "\"Hanamaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hanamaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.12, 39.39}],
      RowBox[{"{", 
        RowBox[{"\"Hanamaki\"", ",", "73115"}], "}"}]],
     Annotation[#, {"Hanamaki", 73115}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.71, 34.87}],
      "\"Yawata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yawata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.71, 34.87}],
      RowBox[{"{", 
        RowBox[{"\"Yawata\"", ",", "71656"}], "}"}]],
     Annotation[#, {"Yawata", 71656}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.1, 34.97}],
      "\"Ito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.1, 34.97}],
      RowBox[{"{", 
        RowBox[{"\"Ito\"", ",", "71578"}], "}"}]],
     Annotation[#, {"Ito", 71578}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.6, 36.13}],
      "\"Kazo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kazo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.6, 36.13}],
      RowBox[{"{", 
        RowBox[{"\"Kazo\"", ",", "71291"}], "}"}]],
     Annotation[#, {"Kazo", 71291}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.97, 33.730000000000004`}],
      "\"Yukuhashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yukuhashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.97, 33.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Yukuhashi\"", ",", "71277"}], "}"}]],
     Annotation[#, {"Yukuhashi", 71277}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.84, 34.6}],
      "\"Tenri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tenri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.84, 34.6}],
      RowBox[{"{", 
        RowBox[{"\"Tenri\"", ",", "71052"}], "}"}]],
     Annotation[#, {"Tenri", 71052}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.2, 33.56}],
      "\"Maebaru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maebaru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.2, 33.56}],
      RowBox[{"{", 
        RowBox[{"\"Maebaru\"", ",", "70339"}], "}"}]],
     Annotation[#, {"Maebaru", 70339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 36.03}],
      "\"Kitamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 36.03}],
      RowBox[{"{", 
        RowBox[{"\"Kitamoto\"", ",", "69839"}], "}"}]],
     Annotation[#, {"Kitamoto", 69839}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.68, 35.85}],
      "\"Warabi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Warabi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.68, 35.85}],
      RowBox[{"{", 
        RowBox[{"\"Warabi\"", ",", "69646"}], "}"}]],
     Annotation[#, {"Warabi", 69646}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.39000000000001`, 33.730000000000004`}],
      "\"Tanabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tanabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.39000000000001`, 33.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tanabe\"", ",", "69563"}], "}"}]],
     Annotation[#, {"Tanabe", 69563}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 35.78}],
      "\"Kiyose\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kiyose", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.53, 35.78}],
      RowBox[{"{", 
        RowBox[{"\"Kiyose\"", ",", "69529"}], "}"}]],
     Annotation[#, {"Kiyose", 69529}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 35.95}],
      "\"Tsurugashima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsurugashima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Tsurugashima\"", ",", "69429"}], "}"}]],
     Annotation[#, {"Tsurugashima", 69429}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.550000000000004`}],
      "\"Kashiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kashiba\"", ",", "69390"}], "}"}]],
     Annotation[#, {"Kashiba", 69390}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.47, 36.230000000000004`}],
      "\"Saku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.47, 36.230000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Saku\"", ",", "68885"}], "}"}]],
     Annotation[#, {"Saku", 68885}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 34.89}],
      "\"Hekinan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hekinan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 34.89}],
      RowBox[{"{", 
        RowBox[{"\"Hekinan\"", ",", "68872"}], "}"}]],
     Annotation[#, {"Hekinan", 68872}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 37.29}],
      "\"Sukagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sukagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 37.29}],
      RowBox[{"{", 
        RowBox[{"\"Sukagawa\"", ",", "68790"}], "}"}]],
     Annotation[#, {"Sukagawa", 68790}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.57, 42.89}],
      "\"Eniwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Eniwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.57, 42.89}],
      RowBox[{"{", 
        RowBox[{"\"Eniwa\"", ",", "68770"}], "}"}]],
     Annotation[#, {"Eniwa", 68770}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.12, 35.300000000000004`}],
      "\"Fukuchiyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuchiyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.12, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Fukuchiyama\"", ",", "68735"}], "}"}]],
     Annotation[#, {"Fukuchiyama", 68735}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.08, 35.14}],
      "\"Omihachiman\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omihachiman", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.08, 35.14}],
      RowBox[{"{", 
        RowBox[{"\"Omihachiman\"", ",", "68696"}], "}"}]],
     Annotation[#, {"Omihachiman", 68696}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.02, 35.07}],
      "\"Moriyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Moriyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.02, 35.07}],
      RowBox[{"{", 
        RowBox[{"\"Moriyama\"", ",", "68584"}], "}"}]],
     Annotation[#, {"Moriyama", 68584}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.01, 35.06}],
      "\"Toyoake\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyoake", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.01, 35.06}],
      RowBox[{"{", 
        RowBox[{"\"Toyoake\"", ",", "68557"}], "}"}]],
     Annotation[#, {"Toyoake", 68557}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.07, 35.65}],
      "\"Tsuruga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsuruga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.07, 35.65}],
      RowBox[{"{", 
        RowBox[{"\"Tsuruga\"", ",", "68482"}], "}"}]],
     Annotation[#, {"Tsuruga", 68482}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.57, 36.52}],
      "\"Matto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.57, 36.52}],
      RowBox[{"{", 
        RowBox[{"\"Matto\"", ",", "68159"}], "}"}]],
     Annotation[#, {"Matto", 68159}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.94, 34.51}],
      "\"Tamano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tamano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.94, 34.51}],
      RowBox[{"{", 
        RowBox[{"\"Tamano\"", ",", "67786"}], "}"}]],
     Annotation[#, {"Tamano", 67786}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 35.18}],
      "\"Tsushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 35.18}],
      RowBox[{"{", 
        RowBox[{"\"Tsushima\"", ",", "67658"}], "}"}]],
     Annotation[#, {"Tsushima", 67658}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 35.84}],
      "\"Inzai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inzai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 35.84}],
      RowBox[{"{", 
        RowBox[{"\"Inzai\"", ",", "67396"}], "}"}]],
     Annotation[#, {"Inzai", 67396}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.19, 33.6}],
      "\"Nakatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.19, 33.6}],
      RowBox[{"{", 
        RowBox[{"\"Nakatsu\"", ",", "67372"}], "}"}]],
     Annotation[#, {"Nakatsu", 67372}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.31, 36.31}],
      "\"Kaga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.31, 36.31}],
      RowBox[{"{", 
        RowBox[{"\"Kaga\"", ",", "67369"}], "}"}]],
     Annotation[#, {"Kaga", 67369}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.52, 33.51}],
      "\"Dazaifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Dazaifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.52, 33.51}],
      RowBox[{"{", 
        RowBox[{"\"Dazaifu\"", ",", "67324"}], "}"}]],
     Annotation[#, {"Dazaifu", 67324}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 36.12}],
      "\"Shiojiri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiojiri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 36.12}],
      RowBox[{"{", 
        RowBox[{"\"Shiojiri\"", ",", "67159"}], "}"}]],
     Annotation[#, {"Shiojiri", 67159}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 35.01}],
      "\"Chiryu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiryu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Chiryu\"", ",", "67062"}], "}"}]],
     Annotation[#, {"Chiryu", 67062}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.6, 34.57}],
      "\"Fujiidera\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujiidera", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.6, 34.57}],
      RowBox[{"{", 
        RowBox[{"\"Fujiidera\"", ",", "66856"}], "}"}]],
     Annotation[#, {"Fujiidera", 66856}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.24, 36.15}],
      "\"Takayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.24, 36.15}],
      RowBox[{"{", 
        RowBox[{"\"Takayama\"", ",", "66636"}], "}"}]],
     Annotation[#, {"Takayama", 66636}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.76}],
      "\"Musashimurayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Musashimurayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.76}],
      RowBox[{"{", 
        RowBox[{"\"Musashimurayama\"", ",", "66553"}], "}"}]],
     Annotation[#, {"Musashimurayama", 66553}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.28, 34.37}],
      "\"Sennan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sennan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.28, 34.37}],
      RowBox[{"{", 
        RowBox[{"\"Sennan\"", ",", "66459"}], "}"}]],
     Annotation[#, {"Sennan", 66459}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.57}],
      "\"Togane\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Togane", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.57}],
      RowBox[{"{", 
        RowBox[{"\"Togane\"", ",", "66332"}], "}"}]],
     Annotation[#, {"Togane", 66332}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.19, 35.95}],
      "\"Sabae\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sabae", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.19, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Sabae\"", ",", "66291"}], "}"}]],
     Annotation[#, {"Sabae", 66291}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.63, 35.97}],
      "\"Kashima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.63, 35.97}],
      RowBox[{"{", 
        RowBox[{"\"Kashima\"", ",", "65935"}], "}"}]],
     Annotation[#, {"Kashima", 65935}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.12, 37.800000000000004`}],
      "\"Niitsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niitsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.12, 37.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Niitsu\"", ",", "65910"}], "}"}]],
     Annotation[#, {"Niitsu", 65910}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.77, 34.82}],
      "\"Kyotanabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyotanabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.77, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Kyotanabe\"", ",", "65903"}], "}"}]],
     Annotation[#, {"Kyotanabe", 65903}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.01, 36.44}],
      "\"Moka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Moka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.01, 36.44}],
      RowBox[{"{", 
        RowBox[{"\"Moka\"", ",", "65717"}], "}"}]],
     Annotation[#, {"Moka", 65717}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.32}],
      "\"Hashima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hashima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.32}],
      RowBox[{"{", 
        RowBox[{"\"Hashima\"", ",", "65612"}], "}"}]],
     Annotation[#, {"Hashima", 65612}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.85}],
      "\"Shiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.55, 35.85}],
      RowBox[{"{", 
        RowBox[{"\"Shiki\"", ",", "65411"}], "}"}]],
     Annotation[#, {"Shiki", 65411}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 38.35}],
      "\"Tendo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tendo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 38.35}],
      RowBox[{"{", 
        RowBox[{"\"Tendo\"", ",", "65393"}], "}"}]],
     Annotation[#, {"Tendo", 65393}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 35.99}],
      "\"Hasuda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hasuda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 35.99}],
      RowBox[{"{", 
        RowBox[{"\"Hasuda\"", ",", "65161"}], "}"}]],
     Annotation[#, {"Hasuda", 65161}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.56, 40.27}],
      "\"Odate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Odate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.56, 40.27}],
      RowBox[{"{", 
        RowBox[{"\"Odate\"", ",", "64543"}], "}"}]],
     Annotation[#, {"Odate", 64543}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.69, 36.730000000000004`}],
      "\"Imaichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Imaichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.69, 36.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Imaichi\"", ",", "64323"}], "}"}]],
     Annotation[#, {"Imaichi", 64323}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.6, 34.19}],
      "\"Naruto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Naruto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.6, 34.19}],
      RowBox[{"{", 
        RowBox[{"\"Naruto\"", ",", "64082"}], "}"}]],
     Annotation[#, {"Naruto", 64082}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.21, 40.62}],
      "\"Towada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Towada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.21, 40.62}],
      RowBox[{"{", 
        RowBox[{"\"Towada\"", ",", "63672"}], "}"}]],
     Annotation[#, {"Towada", 63672}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 36.31}],
      "\"Shimodate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimodate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 36.31}],
      RowBox[{"{", 
        RowBox[{"\"Shimodate\"", ",", "63666"}], "}"}]],
     Annotation[#, {"Shimodate", 63666}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.51, 33.36}],
      "\"Tosu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tosu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.51, 33.36}],
      RowBox[{"{", 
        RowBox[{"\"Tosu\"", ",", "63595"}], "}"}]],
     Annotation[#, {"Tosu", 63595}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.25}],
      "\"Fujioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.25}],
      RowBox[{"{", 
        RowBox[{"\"Fujioka\"", ",", "63358"}], "}"}]],
     Annotation[#, {"Fujioka", 63358}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.93, 34.75}],
      "\"Fukuroi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuroi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.93, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Fukuroi\"", ",", "63045"}], "}"}]],
     Annotation[#, {"Fukuroi", 63045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.13, 38.92}],
      "\"Ichinoseki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ichinoseki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.13, 38.92}],
      RowBox[{"{", 
        RowBox[{"\"Ichinoseki\"", ",", "62970"}], "}"}]],
     Annotation[#, {"Ichinoseki", 62970}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.85, 34.51}],
      "\"Sakurai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakurai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.85, 34.51}],
      RowBox[{"{", 
        RowBox[{"\"Sakurai\"", ",", "62964"}], "}"}]],
     Annotation[#, {"Sakurai", 62964}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.56, 42.99}],
      "\"Kitahiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitahiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.56, 42.99}],
      RowBox[{"{", 
        RowBox[{"\"Kitahiroshima\"", ",", "62370"}], "}"}]],
     Annotation[#, {"Kitahiroshima", 62370}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.74}],
      "\"Fussa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fussa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Fussa\"", ",", "62296"}], "}"}]],
     Annotation[#, {"Fussa", 62296}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 35.84}],
      "\"Ina\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ina", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 35.84}],
      RowBox[{"{", 
        RowBox[{"\"Ina\"", ",", "62104"}], "}"}]],
     Annotation[#, {"Ina", 62104}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.27, 35.38}],
      "\"Nagahama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagahama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.27, 35.38}],
      RowBox[{"{", 
        RowBox[{"\"Nagahama\"", ",", "62089"}], "}"}]],
     Annotation[#, {"Nagahama", 62089}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.95000000000002`, 38.29}],
      "\"Tagajo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tagajo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.95000000000002`, 38.29}],
      RowBox[{"{", 
        RowBox[{"\"Tagajo\"", ",", "61936"}], "}"}]],
     Annotation[#, {"Tagajo", 61936}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.18, 36.24}],
      "\"Honjo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Honjo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.18, 36.24}],
      RowBox[{"{", 
        RowBox[{"\"Honjo\"", ",", "61868"}], "}"}]],
     Annotation[#, {"Honjo", 61868}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.13, 34.77}],
      "\"Ueno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ueno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.13, 34.77}],
      RowBox[{"{", 
        RowBox[{"\"Ueno\"", ",", "61598"}], "}"}]],
     Annotation[#, {"Ueno", 61598}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.94, 33.31}],
      "\"Hita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.94, 33.31}],
      RowBox[{"{", 
        RowBox[{"\"Hita\"", ",", "61481"}], "}"}]],
     Annotation[#, {"Hita", 61481}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.18, 35.35}],
      "\"Toki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.18, 35.35}],
      RowBox[{"{", 
        RowBox[{"\"Toki\"", ",", "61394"}], "}"}]],
     Annotation[#, {"Toki", 61394}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.14000000000001`, 39.14}],
      "\"Mizusawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mizusawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.14000000000001`, 39.14}],
      RowBox[{"{", 
        RowBox[{"\"Mizusawa\"", ",", "61281"}], "}"}]],
     Annotation[#, {"Mizusawa", 61281}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.05, 36.980000000000004`}],
      "\"Kuroiso\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kuroiso", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.05, 36.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kuroiso\"", ",", "61230"}], "}"}]],
     Annotation[#, {"Kuroiso", 61230}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.25, 34.36}],
      "\"Hannan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hannan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.25, 34.36}],
      RowBox[{"{", 
        RowBox[{"\"Hannan\"", ",", "60795"}], "}"}]],
     Annotation[#, {"Hannan", 60795}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.94, 35.42}],
      "\"Sodegaura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sodegaura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.94, 35.42}],
      RowBox[{"{", 
        RowBox[{"\"Sodegaura\"", ",", "60592"}], "}"}]],
     Annotation[#, {"Sodegaura", 60592}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.44, 34.53}],
      "\"Takaishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takaishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.44, 34.53}],
      RowBox[{"{", 
        RowBox[{"\"Takaishi\"", ",", "60511"}], "}"}]],
     Annotation[#, {"Takaishi", 60511}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.85, 35.89}],
      "\"Yoshikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoshikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.85, 35.89}],
      RowBox[{"{", 
        RowBox[{"\"Yoshikawa\"", ",", "60510"}], "}"}]],
     Annotation[#, {"Yoshikawa", 60510}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.96, 34.99}],
      "\"Ritto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ritto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.96, 34.99}],
      RowBox[{"{", 
        RowBox[{"\"Ritto\"", ",", "60362"}], "}"}]],
     Annotation[#, {"Ritto", 60362}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.300000000000004`}],
      "\"Zushi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Zushi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Zushi\"", ",", "60055"}], "}"}]],
     Annotation[#, {"Zushi", 60055}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.730000000000004`}],
      "\"Koga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Koga\"", ",", "60045"}], "}"}]],
     Annotation[#, {"Koga", 60045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.01, 38.31}],
      "\"Shiogama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiogama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.01, 38.31}],
      RowBox[{"{", 
        RowBox[{"\"Shiogama\"", ",", "59526"}], "}"}]],
     Annotation[#, {"Shiogama", 59526}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.57, 38.81}],
      "\"Kesennuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kesennuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.57, 38.81}],
      RowBox[{"{", 
        RowBox[{"\"Kesennuma\"", ",", "59116"}], "}"}]],
     Annotation[#, {"Kesennuma", 59116}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.56, 33.22}],
      "\"Uwajima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uwajima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.56, 33.22}],
      RowBox[{"{", 
        RowBox[{"\"Uwajima\"", ",", "58971"}], "}"}]],
     Annotation[#, {"Uwajima", 58971}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.65, 32.44}],
      "\"Hyuga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hyuga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.65, 32.44}],
      RowBox[{"{", 
        RowBox[{"\"Hyuga\"", ",", "58905"}], "}"}]],
     Annotation[#, {"Hyuga", 58905}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.74, 35.31}],
      "\"Bisai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Bisai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.74, 35.31}],
      RowBox[{"{", 
        RowBox[{"\"Bisai\"", ",", "58902"}], "}"}]],
     Annotation[#, {"Bisai", 58902}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 36.87}],
      "\"Otawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 36.87}],
      RowBox[{"{", 
        RowBox[{"\"Otawara\"", ",", "58888"}], "}"}]],
     Annotation[#, {"Otawara", 58888}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.17000000000002`, 33.92}],
      "\"Saijo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saijo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.17000000000002`, 33.92}],
      RowBox[{"{", 
        RowBox[{"\"Saijo\"", ",", "58823"}], "}"}]],
     Annotation[#, {"Saijo", 58823}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 36.18}],
      "\"Hanyu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hanyu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 36.18}],
      RowBox[{"{", 
        RowBox[{"\"Hanyu\"", ",", "58686"}], "}"}]],
     Annotation[#, {"Hanyu", 58686}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.}],
      "\"Chichibu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chichibu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.}],
      RowBox[{"{", 
        RowBox[{"\"Chichibu\"", ",", "58507"}], "}"}]],
     Annotation[#, {"Chichibu", 58507}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.52, 34.52}],
      "\"Kasaoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasaoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.52, 34.52}],
      RowBox[{"{", 
        RowBox[{"\"Kasaoka\"", ",", "58461"}], "}"}]],
     Annotation[#, {"Kasaoka", 58461}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.07, 39.75}],
      "\"Takizawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takizawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.07, 39.75}],
      RowBox[{"{", 
        RowBox[{"\"Takizawa\"", ",", "58414"}], "}"}]],
     Annotation[#, {"Takizawa", 58414}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 33.39}],
      "\"Ogori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ogori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 33.39}],
      RowBox[{"{", 
        RowBox[{"\"Ogori\"", ",", "58258"}], "}"}]],
     Annotation[#, {"Ogori", 58258}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.76}],
      "\"Hamura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hamura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.76}],
      RowBox[{"{", 
        RowBox[{"\"Hamura\"", ",", "58201"}], "}"}]],
     Annotation[#, {"Hamura", 58201}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.730000000000004`}],
      "\"Koga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.71, 36.2}],
      RowBox[{"{", 
        RowBox[{"\"Koga\"", ",", "60045"}], "}"}]],
     Annotation[#, {"Koga", 60045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.77, 31.73}],
      "\"Kokubu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kokubu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.77, 31.73}],
      RowBox[{"{", 
        RowBox[{"\"Kokubu\"", ",", "57896"}], "}"}]],
     Annotation[#, {"Kokubu", 57896}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.74, 34.68}],
      "\"Soja\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Soja", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.74, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Soja\"", ",", "57469"}], "}"}]],
     Annotation[#, {"Soja", 57469}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.36, 43.25}],
      "\"Ishikari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ishikari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.36, 43.25}],
      RowBox[{"{", 
        RowBox[{"\"Ishikari\"", ",", "57301"}], "}"}]],
     Annotation[#, {"Ishikari", 57301}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.56, 34.5}],
      "\"Osakasayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osakasayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.56, 34.5}],
      RowBox[{"{", 
        RowBox[{"\"Osakasayama\"", ",", "57169"}], "}"}]],
     Annotation[#, {"Osakasayama", 57169}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.31}],
      "\"Hashimoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hashimoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.31}],
      RowBox[{"{", 
        RowBox[{"\"Hashimoto\"", ",", "57115"}], "}"}]],
     Annotation[#, {"Hashimoto", 57115}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.85, 34.31}],
      "\"Sakaide\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakaide", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.85, 34.31}],
      RowBox[{"{", 
        RowBox[{"\"Sakaide\"", ",", "57090"}], "}"}]],
     Annotation[#, {"Sakaide", 57090}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.08}],
      "\"Miyoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.08}],
      RowBox[{"{", 
        RowBox[{"\"Miyoshi\"", ",", "56957"}], "}"}]],
     Annotation[#, {"Miyoshi", 56957}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.75}],
      "\"Shijonawate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shijonawate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.64000000000001`, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Shijonawate\"", ",", "56850"}], "}"}]],
     Annotation[#, {"Shijonawate", 56850}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.73, 33.74}],
      "\"Nogata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nogata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.73, 33.74}],
      RowBox[{"{", 
        RowBox[{"\"Nogata\"", ",", "56821"}], "}"}]],
     Annotation[#, {"Nogata", 56821}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.15, 36.}],
      RowBox[{"{", 
        RowBox[{"\"Chino\"", ",", "77578"}], "}"}]],
     Annotation[#, {"Chino", 77578}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 35.97}],
      "\"Moriya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Moriya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 35.97}],
      RowBox[{"{", 
        RowBox[{"\"Moriya\"", ",", "56566"}], "}"}]],
     Annotation[#, {"Moriya", 56566}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.46, 32.96}],
      "\"Arao\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Arao", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.46, 32.96}],
      RowBox[{"{", 
        RowBox[{"\"Arao\"", ",", "55850"}], "}"}]],
     Annotation[#, {"Arao", 55850}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 34.25}],
      "\"Iwade\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwade", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.32, 34.25}],
      RowBox[{"{", 
        RowBox[{"\"Iwade\"", ",", "55633"}], "}"}]],
     Annotation[#, {"Iwade", 55633}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.91, 35.160000000000004`}],
      "\"Susono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Susono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.91, 35.160000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Susono\"", ",", "55545"}], "}"}]],
     Annotation[#, {"Susono", 55545}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.66, 33.92}],
      "\"Anan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Anan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.66, 33.92}],
      RowBox[{"{", 
        RowBox[{"\"Anan\"", ",", "55421"}], "}"}]],
     Annotation[#, {"Anan", 55421}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.05, 35.800000000000004`}],
      "\"Shiroi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiroi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.05, 35.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shiroi\"", ",", "55314"}], "}"}]],
     Annotation[#, {"Shiroi", 55314}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.76, 36.08}],
      "\"Satte\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Satte", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.76, 36.08}],
      RowBox[{"{", 
        RowBox[{"\"Satte\"", ",", "55286"}], "}"}]],
     Annotation[#, {"Satte", 55286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 35.49}],
      "\"Nakatsugawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakatsugawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 35.49}],
      RowBox[{"{", 
        RowBox[{"\"Nakatsugawa\"", ",", "55011"}], "}"}]],
     Annotation[#, {"Nakatsugawa", 55011}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.12, 36.050000000000004`}],
      "\"Suwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.12, 36.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Suwa\"", ",", "54735"}], "}"}]],
     Annotation[#, {"Suwa", 54735}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.99, 36.86}],
      "\"Himi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Himi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.99, 36.86}],
      RowBox[{"{", 
        RowBox[{"\"Himi\"", ",", "54510"}], "}"}]],
     Annotation[#, {"Himi", 54510}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.06, 36.06}],
      "\"Okaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.06, 36.06}],
      RowBox[{"{", 
        RowBox[{"\"Okaya\"", ",", "54286"}], "}"}]],
     Annotation[#, {"Okaya", 54286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 36.65}],
      "\"Suzaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suzaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 36.65}],
      RowBox[{"{", 
        RowBox[{"\"Suzaka\"", ",", "54022"}], "}"}]],
     Annotation[#, {"Suzaka", 54022}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.01, 35.44}],
      "\"Minokamo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minokamo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.01, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Minokamo\"", ",", "53968"}], "}"}]],
     Annotation[#, {"Minokamo", 53968}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.31, 35.52}],
      "\"Oamishirasato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oamishirasato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.31, 35.52}],
      RowBox[{"{", 
        RowBox[{"\"Oamishirasato\"", ",", "53239"}], "}"}]],
     Annotation[#, {"Oamishirasato", 53239}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.72, 34.96}],
      "\"Muko\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Muko", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.72, 34.96}],
      RowBox[{"{", 
        RowBox[{"\"Muko\"", ",", "53222"}], "}"}]],
     Annotation[#, {"Muko", 53222}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 35.84}],
      "\"Hatogaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hatogaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 35.84}],
      RowBox[{"{", 
        RowBox[{"\"Hatogaya\"", ",", "53062"}], "}"}]],
     Annotation[#, {"Hatogaya", 53062}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.730000000000004`}],
      "\"Tomisato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tomisato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tomisato\"", ",", "53016"}], "}"}]],
     Annotation[#, {"Tomisato", 53016}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.8, 35.5}],
      "\"Fujiyoshida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujiyoshida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.8, 35.5}],
      RowBox[{"{", 
        RowBox[{"\"Fujiyoshida\"", ",", "52983"}], "}"}]],
     Annotation[#, {"Fujiyoshida", 52983}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.35, 35.9}],
      "\"Hidaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hidaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.35, 35.9}],
      RowBox[{"{", 
        RowBox[{"\"Hidaka\"", ",", "52911"}], "}"}]],
     Annotation[#, {"Hidaka", 52911}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.1, 42.410000000000004`}],
      "\"Noboribetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Noboribetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.1, 42.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Noboribetsu\"", ",", "52881"}], "}"}]],
     Annotation[#, {"Noboribetsu", 52881}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 34.}],
      "\"Kudamatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kudamatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 34.}],
      RowBox[{"{", 
        RowBox[{"\"Kudamatsu\"", ",", "52772"}], "}"}]],
     Annotation[#, {"Kudamatsu", 52772}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.68, 35.88}],
      "\"Kamisu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamisu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.68, 35.88}],
      RowBox[{"{", 
        RowBox[{"\"Kamisu\"", ",", "52553"}], "}"}]],
     Annotation[#, {"Kamisu", 52553}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.51, 35.88}],
      "\"Kamifukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamifukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.51, 35.88}],
      RowBox[{"{", 
        RowBox[{"\"Kamifukuoka\"", ",", "52323"}], "}"}]],
     Annotation[#, {"Kamifukuoka", 52323}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.28, 36.19}],
      "\"Ishioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ishioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.28, 36.19}],
      RowBox[{"{", 
        RowBox[{"\"Ishioka\"", ",", "52304"}], "}"}]],
     Annotation[#, {"Ishioka", 52304}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.39000000000001`, 34.75}],
      "\"Ako\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ako", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.39000000000001`, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Ako\"", ",", "52015"}], "}"}]],
     Annotation[#, {"Ako", 52015}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.95000000000002`, 39.65}],
      "\"Miyako\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyako", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.95000000000002`, 39.65}],
      RowBox[{"{", 
        RowBox[{"\"Miyako\"", ",", "51721"}], "}"}]],
     Annotation[#, {"Miyako", 51721}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.83, 35.31}],
      "\"Futtsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Futtsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.83, 35.31}],
      RowBox[{"{", 
        RowBox[{"\"Futtsu\"", ",", "51650"}], "}"}]],
     Annotation[#, {"Futtsu", 51650}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 33.64}],
      "\"Tagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 33.64}],
      RowBox[{"{", 
        RowBox[{"\"Tagawa\"", ",", "51608"}], "}"}]],
     Annotation[#, {"Tagawa", 51608}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 36.300000000000004`}],
      "\"Yuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 36.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Yuki\"", ",", "51574"}], "}"}]],
     Annotation[#, {"Yuki", 51574}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.63, 35.15}],
      "\"Miura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.63, 35.15}],
      RowBox[{"{", 
        RowBox[{"\"Miura\"", ",", "51483"}], "}"}]],
     Annotation[#, {"Miura", 51483}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.64000000000001`, 33.58}],
      "\"Nankoku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nankoku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.64000000000001`, 33.58}],
      RowBox[{"{", 
        RowBox[{"\"Nankoku\"", ",", "51128"}], "}"}]],
     Annotation[#, {"Nankoku", 51128}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 40.2}],
      "\"Noshiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Noshiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.03, 40.2}],
      RowBox[{"{", 
        RowBox[{"\"Noshiro\"", ",", "51079"}], "}"}]],
     Annotation[#, {"Noshiro", 51079}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.01}],
      "\"Shiraoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiraoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.01}],
      RowBox[{"{", 
        RowBox[{"\"Shiraoka\"", ",", "50974"}], "}"}]],
     Annotation[#, {"Shiraoka", 50974}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.73, 36.79}],
      "\"Kitaibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitaibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.73, 36.79}],
      RowBox[{"{", 
        RowBox[{"\"Kitaibaraki\"", ",", "50843"}], "}"}]],
     Annotation[#, {"Kitaibaraki", 50843}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.67}],
      "\"Fuchu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuchu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.23, 34.58}],
      RowBox[{"{", 
        RowBox[{"\"Fuchu\"", ",", "240081"}], "}"}]],
     Annotation[#, {"Fuchu", 240081}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.51, 35.85}],
      "\"Oi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.51, 35.85}],
      RowBox[{"{", 
        RowBox[{"\"Oi\"", ",", "50593"}], "}"}]],
     Annotation[#, {"Oi", 50593}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.84}],
      "\"Ono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.84}],
      RowBox[{"{", 
        RowBox[{"\"Ono\"", ",", "50230"}], "}"}]],
     Annotation[#, {"Ono", 50230}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 35.}],
      "\"Tateyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tateyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 35.}],
      RowBox[{"{", 
        RowBox[{"\"Tateyama\"", ",", "50064"}], "}"}]],
     Annotation[#, {"Tateyama", 50064}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.84, 34.95}],
      "\"Kasai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.84, 34.95}],
      RowBox[{"{", 
        RowBox[{"\"Kasai\"", ",", "50046"}], "}"}]],
     Annotation[#, {"Kasai", 50046}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.19, 37.93}],
      "\"Toyosaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyosaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.19, 37.93}],
      RowBox[{"{", 
        RowBox[{"\"Toyosaka\"", ",", "49824"}], "}"}]],
     Annotation[#, {"Toyosaka", 49824}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.03}],
      "\"Sugito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sugito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.03}],
      RowBox[{"{", 
        RowBox[{"\"Sugito\"", ",", "49817"}], "}"}]],
     Annotation[#, {"Sugito", 49817}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.84, 34.9}],
      "\"Tokoname\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokoname", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.84, 34.9}],
      RowBox[{"{", 
        RowBox[{"\"Tokoname\"", ",", "49554"}], "}"}]],
     Annotation[#, {"Tokoname", 49554}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.42000000000002`, 33.5}],
      "\"Nakagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.42000000000002`, 33.5}],
      RowBox[{"{", 
        RowBox[{"\"Nakagawa\"", ",", "49420"}], "}"}]],
     Annotation[#, {"Nakagawa", 49420}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.9, 36.26}],
      "\"Tomioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tomioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.9, 36.26}],
      RowBox[{"{", 
        RowBox[{"\"Tomioka\"", ",", "49281"}], "}"}]],
     Annotation[#, {"Tomioka", 49281}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.21, 41.29}],
      "\"Mutsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mutsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.21, 41.29}],
      RowBox[{"{", 
        RowBox[{"\"Mutsu\"", ",", "49220"}], "}"}]],
     Annotation[#, {"Mutsu", 49220}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.18}],
      "\"Nagakute\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagakute", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.18}],
      RowBox[{"{", 
        RowBox[{"\"Nagakute\"", ",", "49145"}], "}"}]],
     Annotation[#, {"Nagakute", 49145}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.44, 40.81}],
      "\"Goshogawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Goshogawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.44, 40.81}],
      RowBox[{"{", 
        RowBox[{"\"Goshogawara\"", ",", "49110"}], "}"}]],
     Annotation[#, {"Goshogawara", 49110}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.2}],
      "\"Chikugo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chikugo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.2}],
      RowBox[{"{", 
        RowBox[{"\"Chikugo\"", ",", "49068"}], "}"}]],
     Annotation[#, {"Chikugo", 49068}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.91, 32.96}],
      "\"Saiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.91, 32.96}],
      RowBox[{"{", 
        RowBox[{"\"Saiki\"", ",", "49065"}], "}"}]],
     Annotation[#, {"Saiki", 49065}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.75, 36.17}],
      "\"Sowa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sowa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.75, 36.17}],
      RowBox[{"{", 
        RowBox[{"\"Sowa\"", ",", "48800"}], "}"}]],
     Annotation[#, {"Sowa", 48800}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.36, 33.53}],
      "\"Usa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Usa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.36, 33.53}],
      RowBox[{"{", 
        RowBox[{"\"Usa\"", ",", "48724"}], "}"}]],
     Annotation[#, {"Usa", 48724}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 34.68}],
      "\"Masuda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Masuda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Masuda\"", ",", "48576"}], "}"}]],
     Annotation[#, {"Masuda", 48576}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 36.54}],
      "\"Nonoichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nonoichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 36.54}],
      RowBox[{"{", 
        RowBox[{"\"Nonoichi\"", ",", "48354"}], "}"}]],
     Annotation[#, {"Nonoichi", 48354}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.82, 35.44}],
      "\"Kurayoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurayoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      "\"Tottori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tottori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.82, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Kurayoshi\"", ",", "48347"}], "}"}]],
     Annotation[#, {"Kurayoshi", 48347}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.21, 37.13}],
      "\"Shirakawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shirakawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.21, 37.13}],
      RowBox[{"{", 
        RowBox[{"\"Shirakawa\"", ",", "48339"}], "}"}]],
     Annotation[#, {"Shirakawa", 48339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.01, 36.5}],
      "\"Shibukawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shibukawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.01, 36.5}],
      RowBox[{"{", 
        RowBox[{"\"Shibukawa\"", ",", "48322"}], "}"}]],
     Annotation[#, {"Shibukawa", 48322}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.24, 36.04}],
      "\"Ami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.24, 36.04}],
      RowBox[{"{", 
        RowBox[{"\"Ami\"", ",", "48256"}], "}"}]],
     Annotation[#, {"Ami", 48256}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.89000000000001`, 36.33}],
      "\"Annaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Annaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.89000000000001`, 36.33}],
      RowBox[{"{", 
        RowBox[{"\"Annaka\"", ",", "48235"}], "}"}]],
     Annotation[#, {"Annaka", 48235}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.28}],
      "\"Iwakura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwakura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.28}],
      RowBox[{"{", 
        RowBox[{"\"Iwakura\"", ",", "48007"}], "}"}]],
     Annotation[#, {"Iwakura", 48007}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 34.97}],
      "\"Higashiura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashiura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 34.97}],
      RowBox[{"{", 
        RowBox[{"\"Higashiura\"", ",", "48001"}], "}"}]],
     Annotation[#, {"Higashiura", 48001}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.96, 37.64}],
      "\"Haramachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Haramachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.96, 37.64}],
      RowBox[{"{", 
        RowBox[{"\"Haramachi\"", ",", "47433"}], "}"}]],
     Annotation[#, {"Haramachi", 47433}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.22, 35.07}],
      "\"Sasayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sasayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.22, 35.07}],
      RowBox[{"{", 
        RowBox[{"\"Sasayama\"", ",", "47204"}], "}"}]],
     Annotation[#, {"Sasayama", 47204}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.5, 35.9}],
      "\"Sawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.5, 35.9}],
      RowBox[{"{", 
        RowBox[{"\"Sawara\"", ",", "47199"}], "}"}]],
     Annotation[#, {"Sawara", 47199}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140., 35.84}],
      "\"Shonan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shonan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140., 35.84}],
      RowBox[{"{", 
        RowBox[{"\"Shonan\"", ",", "47071"}], "}"}]],
     Annotation[#, {"Shonan", 47071}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 36.89}],
      "\"Nishinasuno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishinasuno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.98, 36.89}],
      RowBox[{"{", 
        RowBox[{"\"Nishinasuno\"", ",", "46865"}], "}"}]],
     Annotation[#, {"Nishinasuno", 46865}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.17000000000002`, 36.050000000000004`}],
      "\"Naka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Naka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.17000000000002`, 36.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Naka\"", ",", "46760"}], "}"}]],
     Annotation[#, {"Naka", 46760}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.72, 33.82}],
      "\"Nakama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.72, 33.82}],
      RowBox[{"{", 
        RowBox[{"\"Nakama\"", ",", "46745"}], "}"}]],
     Annotation[#, {"Nakama", 46745}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.18, 36.24}],
      "\"Honjo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Honjo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 39.44}],
      RowBox[{"{", 
        RowBox[{"\"Honjo\"", ",", "61868"}], "}"}]],
     Annotation[#, {"Honjo", 61868}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.82, 35.54}],
      "\"Toyooka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyooka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.82, 35.54}],
      RowBox[{"{", 
        RowBox[{"\"Toyooka\"", ",", "46500"}], "}"}]],
     Annotation[#, {"Toyooka", 46500}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 35.38}],
      "\"Samukawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Samukawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 35.38}],
      RowBox[{"{", 
        RowBox[{"\"Samukawa\"", ",", "46495"}], "}"}]],
     Annotation[#, {"Samukawa", 46495}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.43, 36.33}],
      "\"Komoro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komoro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.43, 36.33}],
      RowBox[{"{", 
        RowBox[{"\"Komoro\"", ",", "46272"}], "}"}]],
     Annotation[#, {"Komoro", 46272}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.93, 33.96}],
      "\"Hikari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hikari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.93, 33.96}],
      RowBox[{"{", 
        RowBox[{"\"Hikari\"", ",", "45885"}], "}"}]],
     Annotation[#, {"Hikari", 45885}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 36.82}],
      "\"Uozu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uozu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.39000000000001`, 36.82}],
      RowBox[{"{", 
        RowBox[{"\"Uozu\"", ",", "45848"}], "}"}]],
     Annotation[#, {"Uozu", 45848}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 38.44}],
      "\"Higashine\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Higashine", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.38, 38.44}],
      RowBox[{"{", 
        RowBox[{"\"Higashine\"", ",", "45779"}], "}"}]],
     Annotation[#, {"Higashine", 45779}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.07, 34.9}],
      "\"Hamada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hamada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.07, 34.9}],
      RowBox[{"{", 
        RowBox[{"\"Hamada\"", ",", "45750"}], "}"}]],
     Annotation[#, {"Hamada", 45750}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 32.92}],
      "\"Tamana\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tamana", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 32.92}],
      RowBox[{"{", 
        RowBox[{"\"Tamana\"", ",", "45661"}], "}"}]],
     Annotation[#, {"Tamana", 45661}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.05, 36.65}],
      "\"Numata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Numata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.05, 36.65}],
      RowBox[{"{", 
        RowBox[{"\"Numata\"", ",", "45526"}], "}"}]],
     Annotation[#, {"Numata", 45526}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 31.73}],
      "\"Aira\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aira", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 31.73}],
      RowBox[{"{", 
        RowBox[{"\"Aira\"", ",", "45352"}], "}"}]],
     Annotation[#, {"Aira", 45352}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.2, 35.11}],
      "\"Yokaichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokaichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.2, 35.11}],
      RowBox[{"{", 
        RowBox[{"\"Yokaichi\"", ",", "45338"}], "}"}]],
     Annotation[#, {"Yokaichi", 45338}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 37.050000000000004`}],
      "\"Nanao\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nanao", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 37.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nanao\"", ",", "45309"}], "}"}]],
     Annotation[#, {"Nanao", 45309}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.37, 34.410000000000004`}],
      "\"Kumatori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumatori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.37, 34.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kumatori\"", ",", "45233"}], "}"}]],
     Annotation[#, {"Kumatori", 45233}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.9, 43.57}],
      "\"Takikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.9, 43.57}],
      RowBox[{"{", 
        RowBox[{"\"Takikawa\"", ",", "45131"}], "}"}]],
     Annotation[#, {"Takikawa", 45131}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.1, 35.32}],
      "\"Minamiashigara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minamiashigara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.1, 35.32}],
      RowBox[{"{", 
        RowBox[{"\"Minamiashigara\"", ",", "45128"}], "}"}]],
     Annotation[#, {"Minamiashigara", 45128}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.65, 34.13}],
      "\"Kanonji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanonji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.65, 34.13}],
      RowBox[{"{", 
        RowBox[{"\"Kanonji\"", ",", "44363"}], "}"}]],
     Annotation[#, {"Kanonji", 44363}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.18, 33.980000000000004`}],
      "\"Onoda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Onoda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.18, 33.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Onoda\"", ",", "44295"}], "}"}]],
     Annotation[#, {"Onoda", 44295}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 37.65}],
      "\"Tsubame\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsubame", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 37.65}],
      RowBox[{"{", 
        RowBox[{"\"Tsubame\"", ",", "44284"}], "}"}]],
     Annotation[#, {"Tsubame", 44284}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 31.580000000000002`}],
      "\"Nichinan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nichinan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 31.580000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Nichinan\"", ",", "44243"}], "}"}]],
     Annotation[#, {"Nichinan", 44243}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.88, 35.25}],
      "\"Shikatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shikatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.88, 35.25}],
      RowBox[{"{", 
        RowBox[{"\"Shikatsu\"", ",", "44131"}], "}"}]],
     Annotation[#, {"Shikatsu", 44131}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.55, 34.72}],
      "\"Kosai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kosai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.55, 34.72}],
      RowBox[{"{", 
        RowBox[{"\"Kosai\"", ",", "43913"}], "}"}]],
     Annotation[#, {"Kosai", 43913}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 34.42}],
      "\"Hagi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hagi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 34.42}],
      RowBox[{"{", 
        RowBox[{"\"Hagi\"", ",", "43826"}], "}"}]],
     Annotation[#, {"Hagi", 43826}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 38.37}],
      "\"Sagae\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sagae", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 38.37}],
      RowBox[{"{", 
        RowBox[{"\"Sagae\"", ",", "43544"}], "}"}]],
     Annotation[#, {"Sagae", 43544}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.29, 35.550000000000004`}],
      "\"Aikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.29, 35.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Aikawa\"", ",", "43457"}], "}"}]],
     Annotation[#, {"Aikawa", 43457}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.21, 34.15}],
      "\"Kainan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kainan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.21, 34.15}],
      RowBox[{"{", 
        RowBox[{"\"Kainan\"", ",", "43369"}], "}"}]],
     Annotation[#, {"Kainan", 43369}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.07, 35.01}],
      "\"Kosei\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kosei", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.07, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Kosei\"", ",", "43336"}], "}"}]],
     Annotation[#, {"Kosei", 43336}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.51, 35.67}],
      "\"Ryuo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ryuo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.51, 35.67}],
      RowBox[{"{", 
        RowBox[{"\"Ryuo\"", ",", "43180"}], "}"}]],
     Annotation[#, {"Ryuo", 43180}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 37.52}],
      "\"Mitsuke\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mitsuke", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 37.52}],
      RowBox[{"{", 
        RowBox[{"\"Mitsuke\"", ",", "43180"}], "}"}]],
     Annotation[#, {"Mitsuke", 43180}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 33.77}],
      "\"Fukuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 33.77}],
      RowBox[{"{", 
        RowBox[{"\"Fukuma\"", ",", "43154"}], "}"}]],
     Annotation[#, {"Fukuma", 43154}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.89000000000001`, 39.27}],
      "\"Kamaishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamaishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.89000000000001`, 39.27}],
      RowBox[{"{", 
        RowBox[{"\"Kamaishi\"", ",", "43107"}], "}"}]],
     Annotation[#, {"Kamaishi", 43107}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.34, 40.68}],
      "\"Misawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Misawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.34, 40.68}],
      RowBox[{"{", 
        RowBox[{"\"Misawa\"", ",", "42805"}], "}"}]],
     Annotation[#, {"Misawa", 42805}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.37, 36.75}],
      "\"Nakano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.37, 36.75}],
      RowBox[{"{", 
        RowBox[{"\"Nakano\"", ",", "42708"}], "}"}]],
     Annotation[#, {"Nakano", 42708}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 36.64}],
      "\"Tonami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tonami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.96, 36.64}],
      RowBox[{"{", 
        RowBox[{"\"Tonami\"", ",", "42691"}], "}"}]],
     Annotation[#, {"Tonami", 42691}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.25, 35.37}],
      "\"Mizunami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mizunami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.25, 35.37}],
      RowBox[{"{", 
        RowBox[{"\"Mizunami\"", ",", "42617"}], "}"}]],
     Annotation[#, {"Mizunami", 42617}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.59, 34.01}],
      "\"Komatsushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komatsushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.59, 34.01}],
      RowBox[{"{", 
        RowBox[{"\"Komatsushima\"", ",", "42598"}], "}"}]],
     Annotation[#, {"Komatsushima", 42598}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.300000000000004`}],
      "\"Tamamura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tamamura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tamamura\"", ",", "42566"}], "}"}]],
     Annotation[#, {"Tamamura", 42566}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 38.4}],
      "\"Tomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.88, 38.4}],
      RowBox[{"{", 
        RowBox[{"\"Tomiya\"", ",", "42500"}], "}"}]],
     Annotation[#, {"Tomiya", 42500}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.27, 44.02}],
      "\"Abashiri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Abashiri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.27, 44.02}],
      RowBox[{"{", 
        RowBox[{"\"Abashiri\"", ",", "42498"}], "}"}]],
     Annotation[#, {"Abashiri", 42498}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 36.04}],
      "\"Iwai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 36.04}],
      RowBox[{"{", 
        RowBox[{"\"Iwai\"", ",", "42497"}], "}"}]],
     Annotation[#, {"Iwai", 42497}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.87, 38.11}],
      "\"Iwanuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwanuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.87, 38.11}],
      RowBox[{"{", 
        RowBox[{"\"Iwanuma\"", ",", "42411"}], "}"}]],
     Annotation[#, {"Iwanuma", 42411}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 33.42}],
      "\"Amagi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Amagi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 33.42}],
      RowBox[{"{", 
        RowBox[{"\"Amagi\"", ",", "42312"}], "}"}]],
     Annotation[#, {"Amagi", 42312}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 36.24}],
      "\"Oizumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oizumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.39000000000001`, 36.24}],
      RowBox[{"{", 
        RowBox[{"\"Oizumi\"", ",", "41925"}], "}"}]],
     Annotation[#, {"Oizumi", 41925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.81, 34.730000000000004`}],
      "\"Kizu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kizu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.81, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kizu\"", ",", "41760"}], "}"}]],
     Annotation[#, {"Kizu", 41760}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.65, 35.72}],
      "\"Asahi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Asahi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.65, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Asahi\"", ",", "41720"}], "}"}]],
     Annotation[#, {"Asahi", 41720}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.92000000000002`, 34.85}],
      "\"Taketoyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Taketoyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.92000000000002`, 34.85}],
      RowBox[{"{", 
        RowBox[{"\"Taketoyo\"", ",", "41679"}], "}"}]],
     Annotation[#, {"Taketoyo", 41679}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.47, 34.67}],
      "\"Hisai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hisai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.47, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Hisai\"", ",", "41642"}], "}"}]],
     Annotation[#, {"Hisai", 41642}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.1}],
      "\"Togo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Togo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.04, 35.1}],
      RowBox[{"{", 
        RowBox[{"\"Togo\"", ",", "41638"}], "}"}]],
     Annotation[#, {"Togo", 41638}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.67000000000002`, 45.410000000000004`}],
      "\"Wakkanai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakkanai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.67000000000002`, 45.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Wakkanai\"", ",", "41556"}], "}"}]],
     Annotation[#, {"Wakkanai", 41556}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139., 37.76}],
      "\"Shirone\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shirone", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139., 37.76}],
      RowBox[{"{", 
        RowBox[{"\"Shirone\"", ",", "41406"}], "}"}]],
     Annotation[#, {"Shirone", 41406}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 36.02}],
      "\"Mitsukaido\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mitsukaido", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 36.02}],
      RowBox[{"{", 
        RowBox[{"\"Mitsukaido\"", ",", "41147"}], "}"}]],
     Annotation[#, {"Mitsukaido", 41147}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.3, 38.77}],
      "\"Shinjo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shinjo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.3, 38.77}],
      RowBox[{"{", 
        RowBox[{"\"Shinjo\"", ",", "41140"}], "}"}]],
     Annotation[#, {"Shinjo", 41140}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.75, 37.14}],
      "\"Tokamachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokamachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.75, 37.14}],
      RowBox[{"{", 
        RowBox[{"\"Tokamachi\"", ",", "41136"}], "}"}]],
     Annotation[#, {"Tokamachi", 41136}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.20000000000002`, 43.}],
      "\"Otofuke\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otofuke", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.20000000000002`, 43.}],
      RowBox[{"{", 
        RowBox[{"\"Otofuke\"", ",", "40944"}], "}"}]],
     Annotation[#, {"Otofuke", 40944}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.19, 32.46}],
      "\"Hondo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hondo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.19, 32.46}],
      RowBox[{"{", 
        RowBox[{"\"Hondo\"", ",", "40787"}], "}"}]],
     Annotation[#, {"Hondo", 40787}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.38, 34.54}],
      "\"Kannabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kannabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.38, 34.54}],
      RowBox[{"{", 
        RowBox[{"\"Kannabe\"", ",", "40766"}], "}"}]],
     Annotation[#, {"Kannabe", 40766}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 35.02}],
      "\"Komono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 35.02}],
      RowBox[{"{", 
        RowBox[{"\"Komono\"", ",", "40740"}], "}"}]],
     Annotation[#, {"Komono", 40740}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.07, 35.1}],
      "\"Atami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Atami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.07, 35.1}],
      RowBox[{"{", 
        RowBox[{"\"Atami\"", ",", "40687"}], "}"}]],
     Annotation[#, {"Atami", 40687}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.79, 37.31}],
      "\"Ojiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ojiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.79, 37.31}],
      RowBox[{"{", 
        RowBox[{"\"Ojiya\"", ",", "40549"}], "}"}]],
     Annotation[#, {"Ojiya", 40549}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 34.92}],
      "\"Takahama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takahama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.98, 34.92}],
      RowBox[{"{", 
        RowBox[{"\"Takahama\"", ",", "40501"}], "}"}]],
     Annotation[#, {"Takahama", 40501}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.17}],
      "\"Yanagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yanagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.17}],
      RowBox[{"{", 
        RowBox[{"\"Yanagawa\"", ",", "40386"}], "}"}]],
     Annotation[#, {"Yanagawa", 40386}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.94, 35.1}],
      "\"Kannami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kannami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.94, 35.1}],
      RowBox[{"{", 
        RowBox[{"\"Kannami\"", ",", "40199"}], "}"}]],
     Annotation[#, {"Kannami", 40199}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.13, 36.54}],
      "\"Koshoku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koshoku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.13, 36.54}],
      RowBox[{"{", 
        RowBox[{"\"Koshoku\"", ",", "40153"}], "}"}]],
     Annotation[#, {"Koshoku", 40153}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 36.2}],
      "\"Sanwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sanwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 36.2}],
      RowBox[{"{", 
        RowBox[{"\"Sanwa\"", ",", "40021"}], "}"}]],
     Annotation[#, {"Sanwa", 40021}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.87}],
      "\"Tatsuno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tatsuno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.87}],
      RowBox[{"{", 
        RowBox[{"\"Tatsuno\"", ",", "40011"}], "}"}]],
     Annotation[#, {"Tatsuno", 40011}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 37.94}],
      "\"Shibata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shibata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.75, 38.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shibata\"", ",", "80793"}], "}"}]],
     Annotation[#, {"Shibata", 80793}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.45, 34.86}],
      "\"Kameyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kameyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.45, 34.86}],
      RowBox[{"{", 
        RowBox[{"\"Kameyama\"", ",", "39899"}], "}"}]],
     Annotation[#, {"Kameyama", 39899}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.57}],
      "\"Umi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Umi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.57}],
      RowBox[{"{", 
        RowBox[{"\"Umi\"", ",", "39772"}], "}"}]],
     Annotation[#, {"Umi", 39772}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.96, 31.990000000000002`}],
      "\"Kobayashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kobayashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.96, 31.990000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Kobayashi\"", ",", "39747"}], "}"}]],
     Annotation[#, {"Kobayashi", 39747}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.81, 36.42}],
      "\"Mibu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mibu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.81, 36.42}],
      RowBox[{"{", 
        RowBox[{"\"Mibu\"", ",", "39728"}], "}"}]],
     Annotation[#, {"Mibu", 39728}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.52, 36.54}],
      "\"Hitachiota\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hitachiota", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.52, 36.54}],
      RowBox[{"{", 
        RowBox[{"\"Hitachiota\"", ",", "39723"}], "}"}]],
     Annotation[#, {"Hitachiota", 39723}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.94}],
      "\"Moroyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Moroyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.94}],
      RowBox[{"{", 
        RowBox[{"\"Moroyama\"", ",", "39693"}], "}"}]],
     Annotation[#, {"Moroyama", 39693}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.89000000000001`, 34.34}],
      "\"Sumoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sumoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.89000000000001`, 34.34}],
      RowBox[{"{", 
        RowBox[{"\"Sumoto\"", ",", "39546"}], "}"}]],
     Annotation[#, {"Sumoto", 39546}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 38.01}],
      "\"Shiroishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiroishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 38.01}],
      RowBox[{"{", 
        RowBox[{"\"Shiroishi\"", ",", "39481"}], "}"}]],
     Annotation[#, {"Shiroishi", 39481}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.74, 31.76}],
      "\"Hayato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hayato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.74, 31.76}],
      RowBox[{"{", 
        RowBox[{"\"Hayato\"", ",", "39475"}], "}"}]],
     Annotation[#, {"Hayato", 39475}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.08}],
      "\"Miyoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.83, 34.81}],
      RowBox[{"{", 
        RowBox[{"\"Miyoshi\"", ",", "56957"}], "}"}]],
     Annotation[#, {"Miyoshi", 56957}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 32.68}],
      "\"Uto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 32.68}],
      RowBox[{"{", 
        RowBox[{"\"Uto\"", ",", "39234"}], "}"}]],
     Annotation[#, {"Uto", 39234}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 33.21}],
      "\"Yame\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yame", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 33.21}],
      RowBox[{"{", 
        RowBox[{"\"Yame\"", ",", "39228"}], "}"}]],
     Annotation[#, {"Yame", 39228}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 33.2}],
      "\"Okawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 33.2}],
      RowBox[{"{", 
        RowBox[{"\"Okawa\"", ",", "39223"}], "}"}]],
     Annotation[#, {"Okawa", 39223}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.480000000000004`}],
      "\"Izumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Izumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.35, 32.08}],
      RowBox[{"{", 
        RowBox[{"\"Izumi\"", ",", "189085"}], "}"}]],
     Annotation[#, {"Izumi", 189085}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.6}],
      "\"Shime\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shime", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.47, 33.6}],
      RowBox[{"{", 
        RowBox[{"\"Shime\"", ",", "39216"}], "}"}]],
     Annotation[#, {"Shime", 39216}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.81, 35.77}],
      "\"Hasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.81, 35.77}],
      RowBox[{"{", 
        RowBox[{"\"Hasaki\"", ",", "39209"}], "}"}]],
     Annotation[#, {"Hasaki", 39209}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.56, 39.31}],
      "\"Yokote\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokote", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.56, 39.31}],
      RowBox[{"{", 
        RowBox[{"\"Yokote\"", ",", "39178"}], "}"}]],
     Annotation[#, {"Yokote", 39178}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.5, 34.39}],
      "\"Fuchu2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuchu2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.5, 34.39}],
      RowBox[{"{", 
        RowBox[{"\"Fuchu2\"", ",", "39049"}], "}"}]],
     Annotation[#, {"Fuchu2", 39049}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.17000000000002`, 34.97}],
      "\"Minakuchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minakuchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.17000000000002`, 34.97}],
      RowBox[{"{", 
        RowBox[{"\"Minakuchi\"", ",", "38986"}], "}"}]],
     Annotation[#, {"Minakuchi", 38986}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.82, 35.2}],
      "\"Jimokuji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Jimokuji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.82, 35.2}],
      RowBox[{"{", 
        RowBox[{"\"Jimokuji\"", ",", "38908"}], "}"}]],
     Annotation[#, {"Jimokuji", 38908}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.55, 33.51}],
      "\"Ozu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ozu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.55, 33.51}],
      RowBox[{"{", 
        RowBox[{"\"Ozu\"", ",", "38833"}], "}"}]],
     Annotation[#, {"Ozu", 38833}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.46, 39.46}],
      "\"Omagari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omagari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.46, 39.46}],
      RowBox[{"{", 
        RowBox[{"\"Omagari\"", ",", "38805"}], "}"}]],
     Annotation[#, {"Omagari", 38805}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.20000000000002`, 36.12}],
      "\"Yorii\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yorii", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.20000000000002`, 36.12}],
      RowBox[{"{", 
        RowBox[{"\"Yorii\"", ",", "38717"}], "}"}]],
     Annotation[#, {"Yorii", 38717}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 36.67}],
      "\"Tsubata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsubata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 36.67}],
      RowBox[{"{", 
        RowBox[{"\"Tsubata\"", ",", "38644"}], "}"}]],
     Annotation[#, {"Tsubata", 38644}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.59, 40.64}],
      "\"Kuroishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kuroishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.59, 40.64}],
      RowBox[{"{", 
        RowBox[{"\"Kuroishi\"", ",", "38615"}], "}"}]],
     Annotation[#, {"Kuroishi", 38615}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.26, 34.67}],
      "\"Tahara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tahara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.26, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Tahara\"", ",", "38177"}], "}"}]],
     Annotation[#, {"Tahara", 38177}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 32.79}],
      "\"Shimabara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimabara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 32.79}],
      RowBox[{"{", 
        RowBox[{"\"Shimabara\"", ",", "38113"}], "}"}]],
     Annotation[#, {"Shimabara", 38113}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.67000000000002`, 41.83}],
      "\"Kamiiso\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamiiso", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.67000000000002`, 41.83}],
      RowBox[{"{", 
        RowBox[{"\"Kamiiso\"", ",", "38098"}], "}"}]],
     Annotation[#, {"Kamiiso", 38098}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.9, 35.14}],
      "\"Nagaizumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagaizumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.9, 35.14}],
      RowBox[{"{", 
        RowBox[{"\"Nagaizumi\"", ",", "38092"}], "}"}]],
     Annotation[#, {"Nagaizumi", 38092}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.92000000000002`, 37.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Soma\"", ",", "65934"}], "}"}]],
     Annotation[#, {"Soma", 65934}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.77, 32.21}],
      "\"Hitoyoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hitoyoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.77, 32.21}],
      RowBox[{"{", 
        RowBox[{"\"Hitoyoshi\"", ",", "38006"}], "}"}]],
     Annotation[#, {"Hitoyoshi", 38006}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.08, 34.4}],
      "\"Mihara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mihara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.58, 34.54}],
      RowBox[{"{", 
        RowBox[{"\"Mihara\"", ",", "80387"}], "}"}]],
     Annotation[#, {"Mihara", 80387}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 33.61}],
      "\"Kasuya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasuya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 33.61}],
      RowBox[{"{", 
        RowBox[{"\"Kasuya\"", ",", "37870"}], "}"}]],
     Annotation[#, {"Kasuya", 37870}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 35.11}],
      "\"Yatomi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yatomi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.73, 35.11}],
      RowBox[{"{", 
        RowBox[{"\"Yatomi\"", ",", "37825"}], "}"}]],
     Annotation[#, {"Yatomi", 37825}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.96, 36.2}],
      "\"Shimotsuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimotsuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.96, 36.2}],
      RowBox[{"{", 
        RowBox[{"\"Shimotsuma\"", ",", "37787"}], "}"}]],
     Annotation[#, {"Shimotsuma", 37787}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.57, 34.01}],
      "\"Kawanoe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawanoe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.57, 34.01}],
      RowBox[{"{", 
        RowBox[{"\"Kawanoe\"", ",", "37641"}], "}"}]],
     Annotation[#, {"Kawanoe", 37641}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.25, 35.300000000000004`}],
      "\"Ayabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ayabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.25, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ayabe\"", ",", "37612"}], "}"}]],
     Annotation[#, {"Ayabe", 37612}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.05, 35.08}],
      "\"Yasu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yasu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.05, 35.08}],
      RowBox[{"{", 
        RowBox[{"\"Yasu\"", ",", "37587"}], "}"}]],
     Annotation[#, {"Yasu", 37587}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.84}],
      "\"Ono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.49, 35.99}],
      RowBox[{"{", 
        RowBox[{"\"Ono\"", ",", "50230"}], "}"}]],
     Annotation[#, {"Ono", 50230}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.27, 36.06}],
      "\"Ogawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ogawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.27, 36.06}],
      RowBox[{"{", 
        RowBox[{"\"Ogawa\"", ",", "37443"}], "}"}]],
     Annotation[#, {"Ogawa", 37443}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.18, 37.7}],
      "\"Gosen\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gosen", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.18, 37.7}],
      RowBox[{"{", 
        RowBox[{"\"Gosen\"", ",", "37360"}], "}"}]],
     Annotation[#, {"Gosen", 37360}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.4}],
      "\"Hozumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hozumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.70000000000002`, 35.4}],
      RowBox[{"{", 
        RowBox[{"\"Hozumi\"", ",", "37229"}], "}"}]],
     Annotation[#, {"Hozumi", 37229}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.3, 36.35}],
      "\"Tomobe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tomobe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.3, 36.35}],
      RowBox[{"{", 
        RowBox[{"\"Tomobe\"", ",", "37146"}], "}"}]],
     Annotation[#, {"Tomobe", 37146}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 37.660000000000004`}],
      "\"Kitakata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitakata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.88, 37.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kitakata\"", ",", "37140"}], "}"}]],
     Annotation[#, {"Kitakata", 37140}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      RowBox[{"{", 
        RowBox[{"\"Gumma\"", ",", "37107"}], "}"}]],
     Annotation[#, {"Gumma", 37107}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.97, 34.980000000000004`}],
      "\"Nishiwaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishiwaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.97, 34.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nishiwaki\"", ",", "36953"}], "}"}]],
     Annotation[#, {"Nishiwaki", 36953}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.78, 40.18}],
      "\"Kazuno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kazuno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.78, 40.18}],
      RowBox[{"{", 
        RowBox[{"\"Kazuno\"", ",", "36925"}], "}"}]],
     Annotation[#, {"Kazuno", 36925}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.8, 35.99}],
      "\"Showa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Showa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.8, 35.99}],
      RowBox[{"{", 
        RowBox[{"\"Showa\"", ",", "36755"}], "}"}]],
     Annotation[#, {"Showa", 36755}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.67}],
      "\"Fuchu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuchu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.8, 35.12}],
      "\"Kanie\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanie", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.8, 35.12}],
      RowBox[{"{", 
        RowBox[{"\"Kanie\"", ",", "36592"}], "}"}]],
     Annotation[#, {"Kanie", 36592}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.45000000000002`, 36.88}],
      "\"Kurobe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurobe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.45000000000002`, 36.88}],
      RowBox[{"{", 
        RowBox[{"\"Kurobe\"", ",", "36478"}], "}"}]],
     Annotation[#, {"Kurobe", 36478}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.24, 35.53}],
      "\"Sakaiminato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakaiminato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.23, 35.5}],
      "\"Tottori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tottori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.24, 35.53}],
      RowBox[{"{", 
        RowBox[{"\"Sakaiminato\"", ",", "36324"}], "}"}]],
     Annotation[#, {"Sakaiminato", 36324}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.85, 38.04}],
      "\"Watari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Watari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.85, 38.04}],
      RowBox[{"{", 
        RowBox[{"\"Watari\"", ",", "36321"}], "}"}]],
     Annotation[#, {"Watari", 36321}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.43, 37.6}],
      "\"Nihommatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nihommatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.43, 37.6}],
      RowBox[{"{", 
        RowBox[{"\"Nihommatsu\"", ",", "36287"}], "}"}]],
     Annotation[#, {"Nihommatsu", 36287}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 36.800000000000004`}],
      "\"Yaita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yaita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.93, 36.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Yaita\"", ",", "36275"}], "}"}]],
     Annotation[#, {"Yaita", 36275}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.98, 33.78}],
      "\"Kanda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.98, 33.78}],
      RowBox[{"{", 
        RowBox[{"\"Kanda\"", ",", "36122"}], "}"}]],
     Annotation[#, {"Kanda", 36122}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.95000000000002`, 36.63}],
      "\"Kawachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.95000000000002`, 36.63}],
      RowBox[{"{", 
        RowBox[{"\"Kawachi\"", ",", "36107"}], "}"}]],
     Annotation[#, {"Kawachi", 36107}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 34.9}],
      "\"Shinshiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shinshiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 34.9}],
      RowBox[{"{", 
        RowBox[{"\"Shinshiro\"", ",", "36069"}], "}"}]],
     Annotation[#, {"Shinshiro", 36069}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.55, 33.99}],
      "\"Iyomishima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iyomishima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.55, 33.99}],
      RowBox[{"{", 
        RowBox[{"\"Iyomishima\"", ",", "36030"}], "}"}]],
     Annotation[#, {"Iyomishima", 36030}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.09, 36.78}],
      "\"Shimminato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimminato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.09, 36.78}],
      RowBox[{"{", 
        RowBox[{"\"Shimminato\"", ",", "35994"}], "}"}]],
     Annotation[#, {"Shimminato", 35994}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 35.08}],
      "\"Miyoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.52, 35.84}],
      RowBox[{"{", 
        RowBox[{"\"Miyoshi\"", ",", "56957"}], "}"}]],
     Annotation[#, {"Miyoshi", 56957}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.42000000000002`, 35.45}],
      "\"Ena\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ena", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.42000000000002`, 35.45}],
      RowBox[{"{", 
        RowBox[{"\"Ena\"", ",", "35688"}], "}"}]],
     Annotation[#, {"Ena", 35688}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 38.160000000000004`}],
      "\"Kaminoyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaminoyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 38.160000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kaminoyama\"", ",", "35593"}], "}"}]],
     Annotation[#, {"Kaminoyama", 35593}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 36.5}],
      "\"Kuji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kuji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 36.5}],
      RowBox[{"{", 
        RowBox[{"\"Kuji\"", ",", "35567"}], "}"}]],
     Annotation[#, {"Kuji", 35567}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.79, 34.230000000000004`}],
      "\"Zentsuji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Zentsuji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.79, 34.230000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Zentsuji\"", ",", "35473"}], "}"}]],
     Annotation[#, {"Zentsuji", 35473}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.91, 35.57}],
      "\"Tsuru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsuru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.91, 35.57}],
      RowBox[{"{", 
        RowBox[{"\"Tsuru\"", ",", "35454"}], "}"}]],
     Annotation[#, {"Tsuru", 35454}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.71, 39.08}],
      "\"Ofunato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ofunato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.71, 39.08}],
      RowBox[{"{", 
        RowBox[{"\"Ofunato\"", ",", "35418"}], "}"}]],
     Annotation[#, {"Ofunato", 35418}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 38.050000000000004`}],
      "\"Nanyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nanyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 38.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nanyo\"", ",", "35334"}], "}"}]],
     Annotation[#, {"Nanyo", 35334}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.89000000000001`, 35.03}],
      "\"Tokai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.59, 36.47}],
      RowBox[{"{", 
        RowBox[{"\"Tokai\"", ",", "100679"}], "}"}]],
     Annotation[#, {"Tokai", 100679}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.86, 42.47}],
      "\"Date\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Date", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.86, 42.47}],
      RowBox[{"{", 
        RowBox[{"\"Date\"", ",", "35301"}], "}"}]],
     Annotation[#, {"Date", 35301}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.97, 38.33}],
      "\"Rifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Rifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.97, 38.33}],
      RowBox[{"{", 
        RowBox[{"\"Rifu\"", ",", "35037"}], "}"}]],
     Annotation[#, {"Rifu", 35037}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.81, 33.12}],
      "\"Usuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Usuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.81, 33.12}],
      RowBox[{"{", 
        RowBox[{"\"Usuki\"", ",", "35001"}], "}"}]],
     Annotation[#, {"Usuki", 35001}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.02}],
      "\"Miyashiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyashiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.02}],
      RowBox[{"{", 
        RowBox[{"\"Miyashiro\"", ",", "34894"}], "}"}]],
     Annotation[#, {"Miyashiro", 34894}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.94, 35.74}],
      "\"Komagane\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Komagane", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.94, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Komagane\"", ",", "34757"}], "}"}]],
     Annotation[#, {"Komagane", 34757}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 35.84}],
      "\"Ina\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ina", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.65, 35.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ina\"", ",", "62104"}], "}"}]],
     Annotation[#, {"Ina", 62104}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.34, 36.77}],
      "\"Namerikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Namerikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.34, 36.77}],
      RowBox[{"{", 
        RowBox[{"\"Namerikawa\"", ",", "34638"}], "}"}]],
     Annotation[#, {"Namerikawa", 34638}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.42000000000002`, 36.28}],
      RowBox[{"{", 
        RowBox[{"\"Ibaraki\"", ",", "263405"}], "}"}]],
     Annotation[#, {"Ibaraki", 263405}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.94, 32.99}],
      "\"Nakamura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakamura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.94, 32.99}],
      RowBox[{"{", 
        RowBox[{"\"Nakamura\"", ",", "34559"}], "}"}]],
     Annotation[#, {"Nakamura", 34559}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.47, 34.6}],
      "\"Ibara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.47, 34.6}],
      RowBox[{"{", 
        RowBox[{"\"Ibara\"", ",", "34424"}], "}"}]],
     Annotation[#, {"Ibara", 34424}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.17000000000002`, 34.87}],
      RowBox[{"{", 
        RowBox[{"\"Kota\"", ",", "763088"}], "}"}]],
     Annotation[#, {"Kota", 763088}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.08}],
      "\"Washimiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Washimiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.08}],
      RowBox[{"{", 
        RowBox[{"\"Washimiya\"", ",", "34365"}], "}"}]],
     Annotation[#, {"Washimiya", 34365}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.36}],
      "\"Gojo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gojo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.36}],
      RowBox[{"{", 
        RowBox[{"\"Gojo\"", ",", "34342"}], "}"}]],
     Annotation[#, {"Gojo", 34342}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.41, 32.11}],
      "\"Saito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.41, 32.11}],
      RowBox[{"{", 
        RowBox[{"\"Saito\"", ",", "34318"}], "}"}]],
     Annotation[#, {"Saito", 34318}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.17000000000002`, 39.56}],
      "\"Shiwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.17000000000002`, 39.56}],
      RowBox[{"{", 
        RowBox[{"\"Shiwa\"", ",", "34315"}], "}"}]],
     Annotation[#, {"Shiwa", 34315}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.02, 33.19}],
      RowBox[{"{", 
        RowBox[{"\"Takeo\"", ",", "44270"}], "}"}]],
     Annotation[#, {"Takeo", 44270}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.85, 34.730000000000004`}],
      "\"Harima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Harima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.85, 34.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Harima\"", ",", "34018"}], "}"}]],
     Annotation[#, {"Harima", 34018}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.77}],
      "\"Mizuho\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mizuho", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.36, 35.77}],
      RowBox[{"{", 
        RowBox[{"\"Mizuho\"", ",", "33922"}], "}"}]],
     Annotation[#, {"Mizuho", 33922}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 34.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Koryo\"", ",", "180611"}], "}"}]],
     Annotation[#, {"Koryo", 180611}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.8, 32.79}],
      "\"Mashiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mashiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.8, 32.79}],
      RowBox[{"{", 
        RowBox[{"\"Mashiki\"", ",", "33633"}], "}"}]],
     Annotation[#, {"Mashiki", 33633}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.71, 36.71}],
      "\"Takahagi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takahagi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.71, 36.71}],
      RowBox[{"{", 
        RowBox[{"\"Takahagi\"", ",", "33576"}], "}"}]],
     Annotation[#, {"Takahagi", 33576}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.26, 36.15}],
      "\"Maruoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maruoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.26, 36.15}],
      RowBox[{"{", 
        RowBox[{"\"Maruoka\"", ",", "33563"}], "}"}]],
     Annotation[#, {"Maruoka", 33563}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.85, 35.24}],
      "\"Nishiharu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishiharu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.85, 35.24}],
      RowBox[{"{", 
        RowBox[{"\"Nishiharu\"", ",", "33545"}], "}"}]],
     Annotation[#, {"Nishiharu", 33545}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.48, 39.17}],
      "\"Yuzawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yuzawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.48, 39.17}],
      RowBox[{"{", 
        RowBox[{"\"Yuzawa\"", ",", "33536"}], "}"}]],
     Annotation[#, {"Yuzawa", 33536}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.88, 36.67}],
      "\"Oyabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oyabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.88, 36.67}],
      RowBox[{"{", 
        RowBox[{"\"Oyabe\"", ",", "33495"}], "}"}]],
     Annotation[#, {"Oyabe", 33495}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.47, 35.71}],
      "\"Nirasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nirasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.47, 35.71}],
      RowBox[{"{", 
        RowBox[{"\"Nirasaki\"", ",", "33263"}], "}"}]],
     Annotation[#, {"Nirasaki", 33263}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.92000000000002`, 35.31}],
      "\"Fuso\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fuso", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.92000000000002`, 35.31}],
      RowBox[{"{", 
        RowBox[{"\"Fuso\"", ",", "33247"}], "}"}]],
     Annotation[#, {"Fuso", 33247}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.78, 37.97}],
      "\"Kakuda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kakuda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.78, 37.97}],
      RowBox[{"{", 
        RowBox[{"\"Kakuda\"", ",", "33221"}], "}"}]],
     Annotation[#, {"Kakuda", 33221}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.09, 36.71}],
      "\"Kosugi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kosugi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.09, 36.71}],
      RowBox[{"{", 
        RowBox[{"\"Kosugi\"", ",", "33200"}], "}"}]],
     Annotation[#, {"Kosugi", 33200}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.87, 36.35}],
      "\"Hotaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hotaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.87, 36.35}],
      RowBox[{"{", 
        RowBox[{"\"Hotaka\"", ",", "33195"}], "}"}]],
     Annotation[#, {"Hotaka", 33195}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.12, 35.92}],
      "\"Fujishiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujishiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.12, 35.92}],
      RowBox[{"{", 
        RowBox[{"\"Fujishiro\"", ",", "33148"}], "}"}]],
     Annotation[#, {"Fujishiro", 33148}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.29, 32.04}],
      "\"Sadowara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sadowara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.29, 32.04}],
      RowBox[{"{", 
        RowBox[{"\"Sadowara\"", ",", "33111"}], "}"}]],
     Annotation[#, {"Sadowara", 33111}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.56, 35.31}],
      "\"Yoro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.56, 35.31}],
      RowBox[{"{", 
        RowBox[{"\"Yoro\"", ",", "32921"}], "}"}]],
     Annotation[#, {"Yoro", 32921}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.74, 35.5}],
      "\"Obama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Obama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.74, 35.5}],
      RowBox[{"{", 
        RowBox[{"\"Obama\"", ",", "32896"}], "}"}]],
     Annotation[#, {"Obama", 32896}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 34.46}],
      "\"Gose\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gose", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 34.46}],
      RowBox[{"{", 
        RowBox[{"\"Gose\"", ",", "32870"}], "}"}]],
     Annotation[#, {"Gose", 32870}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.18, 39.2}],
      "\"Esashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Esashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.18, 39.2}],
      RowBox[{"{", 
        RowBox[{"\"Esashi\"", ",", "32844"}], "}"}]],
     Annotation[#, {"Esashi", 32844}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      RowBox[{"{", 
        RowBox[{"\"Yamanashi\"", ",", "32791"}], "}"}]],
     Annotation[#, {"Yamanashi", 32791}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 37.87}],
      "\"Kameda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kameda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 37.87}],
      RowBox[{"{", 
        RowBox[{"\"Kameda\"", ",", "32765"}], "}"}]],
     Annotation[#, {"Kameda", 32765}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.56}],
      "\"Tawaramoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tawaramoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.56}],
      RowBox[{"{", 
        RowBox[{"\"Tawaramoto\"", ",", "32659"}], "}"}]],
     Annotation[#, {"Tawaramoto", 32659}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.12, 34.09}],
      "\"Arida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Arida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.12, 34.09}],
      RowBox[{"{", 
        RowBox[{"\"Arida\"", ",", "32651"}], "}"}]],
     Annotation[#, {"Arida", 32651}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 35.71}],
      "\"Yokaichiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yokaichiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 35.71}],
      RowBox[{"{", 
        RowBox[{"\"Yokaichiba\"", ",", "32651"}], "}"}]],
     Annotation[#, {"Yokaichiba", 32651}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.300000000000004`}],
      "\"Oiso\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oiso", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.32, 35.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Oiso\"", ",", "32595"}], "}"}]],
     Annotation[#, {"Oiso", 32595}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.53, 33.62}],
      "\"Sasaguri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sasaguri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.53, 33.62}],
      RowBox[{"{", 
        RowBox[{"\"Sasaguri\"", ",", "32588"}], "}"}]],
     Annotation[#, {"Sasaguri", 32588}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.78, 35.35}],
      "\"Kisogawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kisogawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.78, 35.35}],
      RowBox[{"{", 
        RowBox[{"\"Kisogawa\"", ",", "32586"}], "}"}]],
     Annotation[#, {"Kisogawa", 32586}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.08, 34.75}],
      "\"Kikugawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kikugawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.08, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Kikugawa\"", ",", "32500"}], "}"}]],
     Annotation[#, {"Kikugawa", 32500}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.48, 34.12}],
      "\"Aizumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aizumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.48, 34.12}],
      RowBox[{"{", 
        RowBox[{"\"Aizumi\"", ",", "32485"}], "}"}]],
     Annotation[#, {"Aizumi", 32485}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.05, 33.97}],
      "\"Toyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.05, 33.97}],
      RowBox[{"{", 
        RowBox[{"\"Toyo\"", ",", "32475"}], "}"}]],
     Annotation[#, {"Toyo", 32475}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.63, 35.97}],
      "\"Kashima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kashima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.09, 33.11}],
      RowBox[{"{", 
        RowBox[{"\"Kashima\"", ",", "65935"}], "}"}]],
     Annotation[#, {"Kashima", 65935}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.74}],
      "\"Inami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.74}],
      RowBox[{"{", 
        RowBox[{"\"Inami\"", ",", "32408"}], "}"}]],
     Annotation[#, {"Inami", 32408}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.45, 34.800000000000004`}],
      "\"Aioi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aioi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.45, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Aioi\"", ",", "32394"}], "}"}]],
     Annotation[#, {"Aioi", 32394}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.89000000000001`, 35.09}],
      "\"Shimizu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimizu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.89000000000001`, 35.09}],
      RowBox[{"{", 
        RowBox[{"\"Shimizu\"", ",", "32380"}], "}"}]],
     Annotation[#, {"Shimizu", 32380}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.01}],
      "\"Yamaga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.01}],
      RowBox[{"{", 
        RowBox[{"\"Yamaga\"", ",", "32298"}], "}"}]],
     Annotation[#, {"Yamaga", 32298}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.11, 33.97}],
      "\"Yanai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yanai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.11, 33.97}],
      RowBox[{"{", 
        RowBox[{"\"Yanai\"", ",", "32229"}], "}"}]],
     Annotation[#, {"Yanai", 32229}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.05, 37.65}],
      "\"Kamo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.05, 37.65}],
      RowBox[{"{", 
        RowBox[{"\"Kamo\"", ",", "32129"}], "}"}]],
     Annotation[#, {"Kamo", 32129}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.58, 34.83}],
      "\"Taishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Taishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.58, 34.83}],
      RowBox[{"{", 
        RowBox[{"\"Taishi\"", ",", "32078"}], "}"}]],
     Annotation[#, {"Taishi", 32078}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.14000000000001`, 36.25}],
      "\"Kamisato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamisato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.14000000000001`, 36.25}],
      RowBox[{"{", 
        RowBox[{"\"Kamisato\"", ",", "32055"}], "}"}]],
     Annotation[#, {"Kamisato", 32055}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.22, 38.42}],
      "\"Yamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.22, 38.42}],
      RowBox[{"{", 
        RowBox[{"\"Yamoto\"", ",", "32028"}], "}"}]],
     Annotation[#, {"Yamoto", 32028}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.37, 34.89}],
      "\"Inagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.37, 34.89}],
      RowBox[{"{", 
        RowBox[{"\"Inagawa\"", ",", "31999"}], "}"}]],
     Annotation[#, {"Inagawa", 31999}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.85}],
      "\"Mizumaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mizumaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.69, 33.85}],
      RowBox[{"{", 
        RowBox[{"\"Mizumaki\"", ",", "31955"}], "}"}]],
     Annotation[#, {"Mizumaki", 31955}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.51, 35.19}],
      RowBox[{"{", 
        RowBox[{"\"Oda\"", ",", "43399"}], "}"}]],
     Annotation[#, {"Oda", 43399}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.73, 34.08}],
      "\"Shinnanyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shinnanyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.73, 34.08}],
      RowBox[{"{", 
        RowBox[{"\"Shinnanyo\"", ",", "31850"}], "}"}]],
     Annotation[#, {"Shinnanyo", 31850}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 33.86}],
      "\"Okagaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okagaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 33.86}],
      RowBox[{"{", 
        RowBox[{"\"Okagaki\"", ",", "31757"}], "}"}]],
     Annotation[#, {"Okagaki", 31757}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 32.9}],
      "\"Ueki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ueki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 32.9}],
      RowBox[{"{", 
        RowBox[{"\"Ueki\"", ",", "31688"}], "}"}]],
     Annotation[#, {"Ueki", 31688}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 36.62}],
      "\"Takanezawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takanezawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.99, 36.62}],
      RowBox[{"{", 
        RowBox[{"\"Takanezawa\"", ",", "31642"}], "}"}]],
     Annotation[#, {"Takanezawa", 31642}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136., 33.72}],
      "\"Shingu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shingu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136., 33.72}],
      RowBox[{"{", 
        RowBox[{"\"Shingu\"", ",", "31619"}], "}"}]],
     Annotation[#, {"Shingu", 31619}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.29}],
      "\"Ninomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ninomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.29}],
      RowBox[{"{", 
        RowBox[{"\"Ninomiya\"", ",", "31412"}], "}"}]],
     Annotation[#, {"Ninomiya", 31412}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 38.230000000000004`}],
      "\"Murakami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Murakami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 38.230000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Murakami\"", ",", "31334"}], "}"}]],
     Annotation[#, {"Murakami", 31334}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.57}],
      "\"Sakai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.27, 36.26}],
      RowBox[{"{", 
        RowBox[{"\"Sakai\"", ",", "782339"}], "}"}]],
     Annotation[#, {"Sakai", 782339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 35.62}],
      "\"Otsuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otsuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 35.62}],
      RowBox[{"{", 
        RowBox[{"\"Otsuki\"", ",", "31226"}], "}"}]],
     Annotation[#, {"Otsuki", 31226}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{145.57, 43.33}],
      "\"Nemuro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nemuro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{145.57, 43.33}],
      RowBox[{"{", 
        RowBox[{"\"Nemuro\"", ",", "31223"}], "}"}]],
     Annotation[#, {"Nemuro", 31223}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.38, 31.85}],
      "\"Kiyotake\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kiyotake", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.38, 31.85}],
      RowBox[{"{", 
        RowBox[{"\"Kiyotake\"", ",", "31200"}], "}"}]],
     Annotation[#, {"Kiyotake", 31200}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.59, 35.26}],
      "\"Hayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.59, 35.26}],
      RowBox[{"{", 
        RowBox[{"\"Hayama\"", ",", "31136"}], "}"}]],
     Annotation[#, {"Hayama", 31136}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.26, 35.59}],
      "\"Tsukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.26, 35.59}],
      RowBox[{"{", 
        RowBox[{"\"Tsukui\"", ",", "31032"}], "}"}]],
     Annotation[#, {"Tsukui", 31032}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.04, 38.1}],
      "\"Nagai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.04, 38.1}],
      RowBox[{"{", 
        RowBox[{"\"Nagai\"", ",", "31026"}], "}"}]],
     Annotation[#, {"Nagai", 31026}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.72, 35.160000000000004`}],
      "\"Saya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.72, 35.160000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Saya\"", ",", "31006"}], "}"}]],
     Annotation[#, {"Saya", 31006}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 36.03}],
      "\"Sekiyado\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sekiyado", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 36.03}],
      RowBox[{"{", 
        RowBox[{"\"Sekiyado\"", ",", "30923"}], "}"}]],
     Annotation[#, {"Sekiyado", 30923}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.85, 37.04}],
      "\"Itoigawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Itoigawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.85, 37.04}],
      RowBox[{"{", 
        RowBox[{"\"Itoigawa\"", ",", "30865"}], "}"}]],
     Annotation[#, {"Itoigawa", 30865}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.42000000000002`, 33.46}],
      "\"Yawatahama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yawatahama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.42000000000002`, 33.46}],
      RowBox[{"{", 
        RowBox[{"\"Yawatahama\"", ",", "30834"}], "}"}]],
     Annotation[#, {"Yawatahama", 30834}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.92000000000002`, 36.44}],
      "\"Kaminokawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaminokawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.92000000000002`, 36.44}],
      RowBox[{"{", 
        RowBox[{"\"Kaminokawa\"", ",", "30827"}], "}"}]],
     Annotation[#, {"Kaminokawa", 30827}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.69, 33.76}],
      "\"Iyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.69, 33.76}],
      RowBox[{"{", 
        RowBox[{"\"Iyo\"", ",", "30760"}], "}"}]],
     Annotation[#, {"Iyo", 30760}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 35.93}],
      "\"Matsubushi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsubushi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 35.93}],
      RowBox[{"{", 
        RowBox[{"\"Matsubushi\"", ",", "30646"}], "}"}]],
     Annotation[#, {"Matsubushi", 30646}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.84, 36.51}],
      "\"Omachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.84, 36.51}],
      RowBox[{"{", 
        RowBox[{"\"Omachi\"", ",", "30599"}], "}"}]],
     Annotation[#, {"Omachi", 30599}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.91, 34.35}],
      "\"Takehara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takehara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.91, 34.35}],
      RowBox[{"{", 
        RowBox[{"\"Takehara\"", ",", "30506"}], "}"}]],
     Annotation[#, {"Takehara", 30506}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.69, 33.79}],
      "\"Masaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Masaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.69, 33.79}],
      RowBox[{"{", 
        RowBox[{"\"Masaki\"", ",", "30471"}], "}"}]],
     Annotation[#, {"Masaki", 30471}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 32.87}],
      "\"Kikuyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kikuyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 32.87}],
      RowBox[{"{", 
        RowBox[{"\"Kikuyo\"", ",", "30460"}], "}"}]],
     Annotation[#, {"Kikuyo", 30460}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.82, 34.72}],
      "\"Toyoda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyoda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.82, 34.72}],
      RowBox[{"{", 
        RowBox[{"\"Toyoda\"", ",", "30435"}], "}"}]],
     Annotation[#, {"Toyoda", 30435}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.31, 36.300000000000004`}],
      "\"Nitta\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nitta", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.31, 36.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nitta\"", ",", "30394"}], "}"}]],
     Annotation[#, {"Nitta", 30394}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.96, 36.68}],
      "\"Ujiie\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ujiie", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.96, 36.68}],
      RowBox[{"{", 
        RowBox[{"\"Ujiie\"", ",", "30366"}], "}"}]],
     Annotation[#, {"Ujiie", 30366}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.25}],
      "\"Yasato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yasato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.25}],
      RowBox[{"{", 
        RowBox[{"\"Yasato\"", ",", "30339"}], "}"}]],
     Annotation[#, {"Yasato", 30339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.78, 34.77}],
      "\"Seika\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Seika", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.78, 34.77}],
      RowBox[{"{", 
        RowBox[{"\"Seika\"", ",", "30311"}], "}"}]],
     Annotation[#, {"Seika", 30311}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.22, 34.21}],
      "\"Otake\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otake", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.22, 34.21}],
      RowBox[{"{", 
        RowBox[{"\"Otake\"", ",", "30151"}], "}"}]],
     Annotation[#, {"Otake", 30151}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.65, 34.86}],
      "\"Shimamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.65, 34.86}],
      RowBox[{"{", 
        RowBox[{"\"Shimamoto\"", ",", "30031"}], "}"}]],
     Annotation[#, {"Shimamoto", 30031}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.68, 41.9}],
      "\"Nanae\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nanae", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.68, 41.9}],
      RowBox[{"{", 
        RowBox[{"\"Nanae\"", ",", "30008"}], "}"}]],
     Annotation[#, {"Nanae", 30008}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.53, 34.37}],
      "\"Kaita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.53, 34.37}],
      RowBox[{"{", 
        RowBox[{"\"Kaita\"", ",", "29901"}], "}"}]],
     Annotation[#, {"Kaita", 29901}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.55, 33.51}],
      "\"Ozu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ozu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.87, 32.88}],
      RowBox[{"{", 
        RowBox[{"\"Ozu\"", ",", "38833"}], "}"}]],
     Annotation[#, {"Ozu", 38833}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.98, 34.81}],
      "\"Miki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.14000000000001`, 34.27}],
      RowBox[{"{", 
        RowBox[{"\"Miki\"", ",", "74701"}], "}"}]],
     Annotation[#, {"Miki", 74701}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 31.26}],
      "\"Ibusuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibusuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 31.26}],
      RowBox[{"{", 
        RowBox[{"\"Ibusuki\"", ",", "29710"}], "}"}]],
     Annotation[#, {"Ibusuki", 29710}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.44, 33.5}],
      "\"Tosa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tosa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.44, 33.5}],
      RowBox[{"{", 
        RowBox[{"\"Tosa\"", ",", "29635"}], "}"}]],
     Annotation[#, {"Tosa", 29635}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.81, 35.17}],
      "\"Oharu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oharu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.81, 35.17}],
      RowBox[{"{", 
        RowBox[{"\"Oharu\"", ",", "29623"}], "}"}]],
     Annotation[#, {"Oharu", 29623}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.63, 35.65}],
      "\"Isawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Isawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.63, 35.65}],
      RowBox[{"{", 
        RowBox[{"\"Isawa\"", ",", "29616"}], "}"}]],
     Annotation[#, {"Isawa", 29616}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.73, 32.88}],
      "\"Nishigoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishigoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.73, 32.88}],
      RowBox[{"{", 
        RowBox[{"\"Nishigoshi\"", ",", "29485"}], "}"}]],
     Annotation[#, {"Nishigoshi", 29485}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.25, 36.38}],
      RowBox[{"{", 
        RowBox[{"\"Kasama\"", ",", "91056"}], "}"}]],
     Annotation[#, {"Kasama", 91056}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 32.21}],
      "\"Minamata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minamata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 32.21}],
      RowBox[{"{", 
        RowBox[{"\"Minamata\"", ",", "29428"}], "}"}]],
     Annotation[#, {"Minamata", 29428}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.25, 35.43}],
      "\"Yasugi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yasugi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.25, 35.43}],
      RowBox[{"{", 
        RowBox[{"\"Yasugi\"", ",", "29368"}], "}"}]],
     Annotation[#, {"Yasugi", 29368}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.88, 37.08}],
      "\"Muika\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Muika", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.88, 37.08}],
      RowBox[{"{", 
        RowBox[{"\"Muika\"", ",", "29123"}], "}"}]],
     Annotation[#, {"Muika", 29123}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.12, 35.11}],
      "\"Kamogawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamogawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.12, 35.11}],
      RowBox[{"{", 
        RowBox[{"\"Kamogawa\"", ",", "29119"}], "}"}]],
     Annotation[#, {"Kamogawa", 29119}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 35.37}],
      "\"Tarui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tarui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.53, 35.37}],
      RowBox[{"{", 
        RowBox[{"\"Tarui\"", ",", "29070"}], "}"}]],
     Annotation[#, {"Tarui", 29070}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.88, 37.76}],
      "\"Maki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.88, 37.76}],
      RowBox[{"{", 
        RowBox[{"\"Maki\"", ",", "29041"}], "}"}]],
     Annotation[#, {"Maki", 29041}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.86, 43.33}],
      "\"Bibai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Bibai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.86, 43.33}],
      RowBox[{"{", 
        RowBox[{"\"Bibai\"", ",", "29028"}], "}"}]],
     Annotation[#, {"Bibai", 29028}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.57, 36.37}],
      "\"Tanuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tanuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.57, 36.37}],
      RowBox[{"{", 
        RowBox[{"\"Tanuma\"", ",", "28723"}], "}"}]],
     Annotation[#, {"Tanuma", 28723}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 34.79}],
      "\"Yoshida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoshida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 34.79}],
      RowBox[{"{", 
        RowBox[{"\"Yoshida\"", ",", "28687"}], "}"}]],
     Annotation[#, {"Yoshida", 28687}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.15, 39.61}],
      "\"Yahaba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yahaba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.15, 39.61}],
      RowBox[{"{", 
        RowBox[{"\"Yahaba\"", ",", "28653"}], "}"}]],
     Annotation[#, {"Yahaba", 28653}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.34}],
      "\"Ohira\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ohira", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.72, 36.34}],
      RowBox[{"{", 
        RowBox[{"\"Ohira\"", ",", "28472"}], "}"}]],
     Annotation[#, {"Ohira", 28472}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.39000000000001`, 38.480000000000004`}],
      "\"Murayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Murayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.39000000000001`, 38.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Murayama\"", ",", "28427"}], "}"}]],
     Annotation[#, {"Murayama", 28427}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.1}],
      "\"Fukiage\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukiage", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.1}],
      RowBox[{"{", 
        RowBox[{"\"Fukiage\"", ",", "28334"}], "}"}]],
     Annotation[#, {"Fukiage", 28334}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.73, 34.62}],
      "\"Ikagura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ikagura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.73, 34.62}],
      RowBox[{"{", 
        RowBox[{"\"Ikagura\"", ",", "28329"}], "}"}]],
     Annotation[#, {"Ikagura", 28329}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 35.}],
      "\"Tateyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tateyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.32, 36.67}],
      RowBox[{"{", 
        RowBox[{"\"Tateyama\"", ",", "50064"}], "}"}]],
     Annotation[#, {"Tateyama", 50064}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.11, 33.62}],
      "\"Buzen\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Buzen", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.11, 33.62}],
      RowBox[{"{", 
        RowBox[{"\"Buzen\"", ",", "28309"}], "}"}]],
     Annotation[#, {"Buzen", 28309}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 39.910000000000004`}],
      "\"Oga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 39.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Oga\"", ",", "28304"}], "}"}]],
     Annotation[#, {"Oga", 28304}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.82, 35.44}],
      "\"Hirata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hirata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.82, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Hirata\"", ",", "28154"}], "}"}]],
     Annotation[#, {"Hirata", 28154}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.77, 33.97}],
      "\"Hojo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hojo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.77, 33.97}],
      RowBox[{"{", 
        RowBox[{"\"Hojo\"", ",", "27992"}], "}"}]],
     Annotation[#, {"Hojo", 27992}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.53, 33.36}],
      "\"Hiji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.53, 33.36}],
      RowBox[{"{", 
        RowBox[{"\"Hiji\"", ",", "27864"}], "}"}]],
     Annotation[#, {"Hiji", 27864}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.01, 37.85}],
      "\"Kurosaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurosaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.01, 37.85}],
      RowBox[{"{", 
        RowBox[{"\"Kurosaki\"", ",", "27848"}], "}"}]],
     Annotation[#, {"Kurosaki", 27848}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 35.62}],
      "\"Uenohara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uenohara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 35.62}],
      RowBox[{"{", 
        RowBox[{"\"Uenohara\"", ",", "27840"}], "}"}]],
     Annotation[#, {"Uenohara", 27840}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.89000000000001`, 36.300000000000004`}],
      "\"Toyoshina\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyoshina", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.89000000000001`, 36.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Toyoshina\"", ",", "27834"}], "}"}]],
     Annotation[#, {"Toyoshina", 27834}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.69, 36.15}],
      "\"Kurihashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurihashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.69, 36.15}],
      RowBox[{"{", 
        RowBox[{"\"Kurihashi\"", ",", "27813"}], "}"}]],
     Annotation[#, {"Kurihashi", 27813}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.44, 36.26}],
      "\"Ora\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ora", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.44, 36.26}],
      RowBox[{"{", 
        RowBox[{"\"Ora\"", ",", "27735"}], "}"}]],
     Annotation[#, {"Ora", 27735}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 36.19}],
      "\"Hokota\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hokota", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 36.19}],
      RowBox[{"{", 
        RowBox[{"\"Hokota\"", ",", "27691"}], "}"}]],
     Annotation[#, {"Hokota", 27691}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.37, 36.22}],
      "\"Menuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Menuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.37, 36.22}],
      RowBox[{"{", 
        RowBox[{"\"Menuma\"", ",", "27684"}], "}"}]],
     Annotation[#, {"Menuma", 27684}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.39}],
      "\"Kasakake\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasakake", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.39}],
      RowBox[{"{", 
        RowBox[{"\"Kasakake\"", ",", "27641"}], "}"}]],
     Annotation[#, {"Kasakake", 27641}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.84, 35.4}],
      "\"Hikawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hikawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.84, 35.4}],
      RowBox[{"{", 
        RowBox[{"\"Hikawa\"", ",", "27635"}], "}"}]],
     Annotation[#, {"Hikawa", 27635}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Omiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.42000000000002`, 36.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Omiya\"", ",", "1077730"}], "}"}]],
     Annotation[#, {"Omiya", 1077730}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 36.94}],
      "\"Nyuzen\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nyuzen", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.5, 36.94}],
      RowBox[{"{", 
        RowBox[{"\"Nyuzen\"", ",", "27585"}], "}"}]],
     Annotation[#, {"Nyuzen", 27585}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.07, 35.15}],
      "\"Yugawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yugawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.07, 35.15}],
      RowBox[{"{", 
        RowBox[{"\"Yugawara\"", ",", "27567"}], "}"}]],
     Annotation[#, {"Yugawara", 27567}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 37.04}],
      "\"Arai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Arai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.25, 37.04}],
      RowBox[{"{", 
        RowBox[{"\"Arai\"", ",", "27481"}], "}"}]],
     Annotation[#, {"Arai", 27481}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.24}],
      "\"Nogi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nogi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.24}],
      RowBox[{"{", 
        RowBox[{"\"Nogi\"", ",", "27334"}], "}"}]],
     Annotation[#, {"Nogi", 27334}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.26, 34.74}],
      "\"Bizen\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Bizen", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.26, 34.74}],
      RowBox[{"{", 
        RowBox[{"\"Bizen\"", ",", "27251"}], "}"}]],
     Annotation[#, {"Bizen", 27251}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.14000000000001`, 33.9}],
      "\"Gobo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gobo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.14000000000001`, 33.9}],
      RowBox[{"{", 
        RowBox[{"\"Gobo\"", ",", "27169"}], "}"}]],
     Annotation[#, {"Gobo", 27169}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.67000000000002`, 34.32}],
      "\"Kurose\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurose", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.67000000000002`, 34.32}],
      RowBox[{"{", 
        RowBox[{"\"Kurose\"", ",", "27157"}], "}"}]],
     Annotation[#, {"Kurose", 27157}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.49, 36.06}],
      "\"Katsuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Katsuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.49, 36.06}],
      RowBox[{"{", 
        RowBox[{"\"Katsuyama\"", ",", "27088"}], "}"}]],
     Annotation[#, {"Katsuyama", 27088}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.13, 37.02}],
      "\"Nasu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nasu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.13, 37.02}],
      RowBox[{"{", 
        RowBox[{"\"Nasu\"", ",", "27076"}], "}"}]],
     Annotation[#, {"Nasu", 27076}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.98, 35.910000000000004`}],
      "\"Minowa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minowa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.98, 35.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Minowa\"", ",", "27070"}], "}"}]],
     Annotation[#, {"Minowa", 27070}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.23, 36.15}],
      "\"Chiyoda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiyoda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.23, 36.15}],
      RowBox[{"{", 
        RowBox[{"\"Chiyoda\"", ",", "26981"}], "}"}]],
     Annotation[#, {"Chiyoda", 26981}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 36.65}],
      "\"Uchinada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Uchinada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.64000000000001`, 36.65}],
      RowBox[{"{", 
        RowBox[{"\"Uchinada\"", ",", "26956"}], "}"}]],
     Annotation[#, {"Uchinada", 26956}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.48, 34.57}],
      "\"Sakai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.79, 36.12}],
      RowBox[{"{", 
        RowBox[{"\"Sakai\"", ",", "782339"}], "}"}]],
     Annotation[#, {"Sakai", 782339}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.35, 44.35}],
      "\"Mombetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mombetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{143.35, 44.35}],
      RowBox[{"{", 
        RowBox[{"\"Mombetsu\"", ",", "26895"}], "}"}]],
     Annotation[#, {"Mombetsu", 26895}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.31, 40.28}],
      "\"Ninohe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ninohe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.31, 40.28}],
      RowBox[{"{", 
        RowBox[{"\"Ninohe\"", ",", "26872"}], "}"}]],
     Annotation[#, {"Ninohe", 26872}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.53, 39.34}],
      "\"Tono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.53, 39.34}],
      RowBox[{"{", 
        RowBox[{"\"Tono\"", ",", "26781"}], "}"}]],
     Annotation[#, {"Tono", 26781}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 34.68}],
      "\"Shimoda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimoda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.93, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Shimoda\"", ",", "26704"}], "}"}]],
     Annotation[#, {"Shimoda", 26704}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 32.980000000000004`}],
      "\"Kikuchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kikuchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.81, 32.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kikuchi\"", ",", "26677"}], "}"}]],
     Annotation[#, {"Kikuchi", 26677}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 38.01}],
      "\"Nakajo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakajo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.38, 38.01}],
      RowBox[{"{", 
        RowBox[{"\"Nakajo\"", ",", "26670"}], "}"}]],
     Annotation[#, {"Nakajo", 26670}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 35.1}],
      "\"Toin\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toin", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 35.1}],
      RowBox[{"{", 
        RowBox[{"\"Toin\"", ",", "26630"}], "}"}]],
     Annotation[#, {"Toin", 26630}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.46, 44.35}],
      "\"Nayoro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nayoro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.46, 44.35}],
      RowBox[{"{", 
        RowBox[{"\"Nayoro\"", ",", "26457"}], "}"}]],
     Annotation[#, {"Nayoro", 26457}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.65, 43.94}],
      "\"Rumoi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Rumoi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.65, 43.94}],
      RowBox[{"{", 
        RowBox[{"\"Rumoi\"", ",", "26454"}], "}"}]],
     Annotation[#, {"Rumoi", 26454}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.9, 34.77}],
      "\"Mihama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mihama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.9, 34.77}],
      RowBox[{"{", 
        RowBox[{"\"Mihama\"", ",", "26402"}], "}"}]],
     Annotation[#, {"Mihama", 26402}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.43, 34.07}],
      "\"Ishii\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ishii", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.43, 34.07}],
      RowBox[{"{", 
        RowBox[{"\"Ishii\"", ",", "26394"}], "}"}]],
     Annotation[#, {"Ishii", 26394}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.24, 35.85}],
      "\"Sakae\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sakae", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.24, 35.85}],
      RowBox[{"{", 
        RowBox[{"\"Sakae\"", ",", "26391"}], "}"}]],
     Annotation[#, {"Sakae", 26391}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.21, 38.}],
      "\"Takahata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takahata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.21, 38.}],
      RowBox[{"{", 
        RowBox[{"\"Takahata\"", ",", "26347"}], "}"}]],
     Annotation[#, {"Takahata", 26347}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.28, 33.39}],
      "\"Susaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Susaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.28, 33.39}],
      RowBox[{"{", 
        RowBox[{"\"Susaki\"", ",", "26195"}], "}"}]],
     Annotation[#, {"Susaki", 26195}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.84}],
      "\"Ono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.28, 34.28}],
      RowBox[{"{", 
        RowBox[{"\"Ono\"", ",", "50230"}], "}"}]],
     Annotation[#, {"Ono", 50230}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.34, 36.24}],
      "\"Minori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.34, 36.24}],
      RowBox[{"{", 
        RowBox[{"\"Minori\"", ",", "26186"}], "}"}]],
     Annotation[#, {"Minori", 26186}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.58}],
      "\"Sue\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sue", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.5, 33.58}],
      RowBox[{"{", 
        RowBox[{"\"Sue\"", ",", "26173"}], "}"}]],
     Annotation[#, {"Sue", 26173}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 32.65}],
      "\"Matsubase\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Matsubase", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 32.65}],
      RowBox[{"{", 
        RowBox[{"\"Matsubase\"", ",", "26163"}], "}"}]],
     Annotation[#, {"Matsubase", 26163}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.04, 43.72}],
      "\"Fukagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.04, 43.72}],
      RowBox[{"{", 
        RowBox[{"\"Fukagawa\"", ",", "26152"}], "}"}]],
     Annotation[#, {"Fukagawa", 26152}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.18, 34.29}],
      "\"Innoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Innoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.18, 34.29}],
      RowBox[{"{", 
        RowBox[{"\"Innoshima\"", ",", "26141"}], "}"}]],
     Annotation[#, {"Innoshima", 26141}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 33.61}],
      "\"Honami\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Honami", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 33.61}],
      RowBox[{"{", 
        RowBox[{"\"Honami\"", ",", "26118"}], "}"}]],
     Annotation[#, {"Honami", 26118}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 36.47}],
      "\"Mashiko\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mashiko", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 36.47}],
      RowBox[{"{", 
        RowBox[{"\"Mashiko\"", ",", "26045"}], "}"}]],
     Annotation[#, {"Mashiko", 26045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 36.37}],
      "\"Tobu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tobu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.32, 36.37}],
      RowBox[{"{", 
        RowBox[{"\"Tobu\"", ",", "26008"}], "}"}]],
     Annotation[#, {"Tobu", 26008}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136., 33.72}],
      "\"Shingu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shingu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.46, 33.730000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shingu\"", ",", "31619"}], "}"}]],
     Annotation[#, {"Shingu", 31619}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.81, 45.37}],
      "\"Makubetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Makubetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.81, 45.37}],
      RowBox[{"{", 
        RowBox[{"\"Makubetsu\"", ",", "25935"}], "}"}]],
     Annotation[#, {"Makubetsu", 25935}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.20000000000002`, 34.68}],
      "\"Sagara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sagara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.20000000000002`, 34.68}],
      RowBox[{"{", 
        RowBox[{"\"Sagara\"", ",", "25922"}], "}"}]],
     Annotation[#, {"Sagara", 25922}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.38, 43.35}],
      "\"Furano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Furano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.38, 43.35}],
      RowBox[{"{", 
        RowBox[{"\"Furano\"", ",", "25872"}], "}"}]],
     Annotation[#, {"Furano", 25872}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.46, 34.910000000000004`}],
      "\"Toyono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.46, 34.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Toyono\"", ",", "25866"}], "}"}]],
     Annotation[#, {"Toyono", 25866}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.89000000000001`, 38.44}],
      "\"Taiwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Taiwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.89000000000001`, 38.44}],
      RowBox[{"{", 
        RowBox[{"\"Taiwa\"", ",", "25837"}], "}"}]],
     Annotation[#, {"Taiwa", 25837}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 35.93}],
      "\"Itako\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Itako", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 35.93}],
      RowBox[{"{", 
        RowBox[{"\"Itako\"", ",", "25791"}], "}"}]],
     Annotation[#, {"Itako", 25791}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.72, 32.93}],
      "\"Sukumo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sukumo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.72, 32.93}],
      RowBox[{"{", 
        RowBox[{"\"Sukumo\"", ",", "25784"}], "}"}]],
     Annotation[#, {"Sukumo", 25784}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 35.85}],
      "\"Omigawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omigawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.61, 35.85}],
      RowBox[{"{", 
        RowBox[{"\"Omigawa\"", ",", "25763"}], "}"}]],
     Annotation[#, {"Omigawa", 25763}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.26, 31.7}],
      "\"Kushikino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kushikino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.26, 31.7}],
      RowBox[{"{", 
        RowBox[{"\"Kushikino\"", ",", "25744"}], "}"}]],
     Annotation[#, {"Kushikino", 25744}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.6, 34.19}],
      "\"Naruto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Naruto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.4, 35.61}],
      RowBox[{"{", 
        RowBox[{"\"Naruto\"", ",", "64082"}], "}"}]],
     Annotation[#, {"Naruto", 64082}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.23, 34.74}],
      "\"Haibara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Haibara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.23, 34.74}],
      RowBox[{"{", 
        RowBox[{"\"Haibara\"", ",", "25670"}], "}"}]],
     Annotation[#, {"Haibara", 25670}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.58, 34.34}],
      "\"Kumano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.58, 34.34}],
      RowBox[{"{", 
        RowBox[{"\"Kumano\"", ",", "25663"}], "}"}]],
     Annotation[#, {"Kumano", 25663}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.98, 36.25}],
      "\"Yoshii\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoshii", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.98, 36.25}],
      RowBox[{"{", 
        RowBox[{"\"Yoshii\"", ",", "25655"}], "}"}]],
     Annotation[#, {"Yoshii", 25655}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 34.79}],
      "\"Yoshida\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoshida", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.88, 37.68}],
      RowBox[{"{", 
        RowBox[{"\"Yoshida\"", ",", "28687"}], "}"}]],
     Annotation[#, {"Yoshida", 28687}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.99}],
      "\"Kukizaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kukizaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.99}],
      RowBox[{"{", 
        RowBox[{"\"Kukizaki\"", ",", "25494"}], "}"}]],
     Annotation[#, {"Kukizaki", 25494}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.02, 34.75}],
      "\"Sanyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sanyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.02, 34.75}],
      RowBox[{"{", 
        RowBox[{"\"Sanyo\"", ",", "25467"}], "}"}]],
     Annotation[#, {"Sanyo", 25467}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.12, 34.65}],
      "\"Hamaoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hamaoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.12, 34.65}],
      RowBox[{"{", 
        RowBox[{"\"Hamaoka\"", ",", "25447"}], "}"}]],
     Annotation[#, {"Hamaoka", 25447}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 36.32}],
      "\"Maruko\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Maruko", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.26, 36.32}],
      RowBox[{"{", 
        RowBox[{"\"Maruko\"", ",", "25403"}], "}"}]],
     Annotation[#, {"Maruko", 25403}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.11, 31.740000000000002`}],
      "\"Mimata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mimata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.11, 31.740000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Mimata\"", ",", "25305"}], "}"}]],
     Annotation[#, {"Mimata", 25305}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.36, 36.85}],
      "\"Iiyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iiyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.36, 36.85}],
      RowBox[{"{", 
        RowBox[{"\"Iiyama\"", ",", "25281"}], "}"}]],
     Annotation[#, {"Iiyama", 25281}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.38, 31.61}],
      "\"Ijuin\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ijuin", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.38, 31.61}],
      RowBox[{"{", 
        RowBox[{"\"Ijuin\"", ",", "25217"}], "}"}]],
     Annotation[#, {"Ijuin", 25217}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.73, 35.72}],
      "\"Enzan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Enzan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.65, 35.68}],
      "\"Yamanashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamanashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.73, 35.72}],
      RowBox[{"{", 
        RowBox[{"\"Enzan\"", ",", "25142"}], "}"}]],
     Annotation[#, {"Enzan", 25142}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.53, 35.02}],
      "\"Yamasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.53, 35.02}],
      RowBox[{"{", 
        RowBox[{"\"Yamasaki\"", ",", "25115"}], "}"}]],
     Annotation[#, {"Yamasaki", 25115}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.2, 32.01}],
      "\"Akune\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akune", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.2, 32.01}],
      RowBox[{"{", 
        RowBox[{"\"Akune\"", ",", "25089"}], "}"}]],
     Annotation[#, {"Akune", 25089}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.28, 31.26}],
      "\"Makurazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Makurazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.28, 31.26}],
      RowBox[{"{", 
        RowBox[{"\"Makurazaki\"", ",", "24971"}], "}"}]],
     Annotation[#, {"Makurazaki", 24971}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kagawa\"", ",", "24957"}], "}"}]],
     Annotation[#, {"Kagawa", 24957}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.74}],
      "\"Itsukaichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Itsukaichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.77, 35.67}],
      "\"Tokyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.23, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Itsukaichi\"", ",", "24954"}], "}"}]],
     Annotation[#, {"Itsukaichi", 24954}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 36.12}],
      "\"Ishige\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ishige", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 36.12}],
      RowBox[{"{", 
        RowBox[{"\"Ishige\"", ",", "24948"}], "}"}]],
     Annotation[#, {"Ishige", 24948}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 35.7}],
      "\"Kokubunji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kokubunji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.97, 34.28}],
      RowBox[{"{", 
        RowBox[{"\"Kokubunji\"", ",", "118682"}], "}"}]],
     Annotation[#, {"Kokubunji", 118682}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.62, 34.800000000000004`}],
      "\"Takahashi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takahashi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.62, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Takahashi\"", ",", "24819"}], "}"}]],
     Annotation[#, {"Takahashi", 24819}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.63, 39.02}],
      "\"Rikuzentakata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Rikuzentakata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.63, 39.02}],
      RowBox[{"{", 
        RowBox[{"\"Rikuzentakata\"", ",", "24793"}], "}"}]],
     Annotation[#, {"Rikuzentakata", 24793}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.96, 35.84}],
      "\"Ina\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ina", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.02, 35.96}],
      RowBox[{"{", 
        RowBox[{"\"Ina\"", ",", "62104"}], "}"}]],
     Annotation[#, {"Ina", 62104}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.88, 33.8}],
      "\"Shigenobu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shigenobu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.88, 33.8}],
      RowBox[{"{", 
        RowBox[{"\"Shigenobu\"", ",", "24693"}], "}"}]],
     Annotation[#, {"Shigenobu", 24693}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.78, 37.37}],
      "\"Wajima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wajima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.78, 37.37}],
      RowBox[{"{", 
        RowBox[{"\"Wajima\"", ",", "24605"}], "}"}]],
     Annotation[#, {"Wajima", 24605}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.22, 35.02}],
      "\"Gotsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gotsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.22, 35.02}],
      RowBox[{"{", 
        RowBox[{"\"Gotsu\"", ",", "24597"}], "}"}]],
     Annotation[#, {"Gotsu", 24597}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.2}],
      "\"Miwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.2}],
      RowBox[{"{", 
        RowBox[{"\"Miwa\"", ",", "24593"}], "}"}]],
     Annotation[#, {"Miwa", 24593}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 36.9}],
      "\"Hakui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hakui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 36.9}],
      RowBox[{"{", 
        RowBox[{"\"Hakui\"", ",", "24529"}], "}"}]],
     Annotation[#, {"Hakui", 24529}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 37.82}],
      "\"Hobara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hobara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 37.82}],
      RowBox[{"{", 
        RowBox[{"\"Hobara\"", ",", "24515"}], "}"}]],
     Annotation[#, {"Hobara", 24515}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.43, 34.82}],
      "\"Ikeda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ikeda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.57, 35.44}],
      RowBox[{"{", 
        RowBox[{"\"Ikeda\"", ",", "99476"}], "}"}]],
     Annotation[#, {"Ikeda", 99476}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.35, 34.07}],
      "\"Kamojima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamojima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.35, 34.07}],
      RowBox[{"{", 
        RowBox[{"\"Kamojima\"", ",", "24374"}], "}"}]],
     Annotation[#, {"Kamojima", 24374}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.21, 36.14}],
      "\"Harue\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Harue", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.21, 36.14}],
      RowBox[{"{", 
        RowBox[{"\"Harue\"", ",", "24332"}], "}"}]],
     Annotation[#, {"Harue", 24332}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.56}],
      "\"Kammaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kammaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.7, 34.56}],
      RowBox[{"{", 
        RowBox[{"\"Kammaki\"", ",", "24224"}], "}"}]],
     Annotation[#, {"Kammaki", 24224}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 34.95}],
      "\"Agui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Agui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 34.95}],
      RowBox[{"{", 
        RowBox[{"\"Agui\"", ",", "24198"}], "}"}]],
     Annotation[#, {"Agui", 24198}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.43, 33.55}],
      "\"Ino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.43, 33.55}],
      RowBox[{"{", 
        RowBox[{"\"Ino\"", ",", "24123"}], "}"}]],
     Annotation[#, {"Ino", 24123}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.93, 34.84}],
      "\"Ono\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ono", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.68, 35.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ono\"", ",", "50230"}], "}"}]],
     Annotation[#, {"Ono", 50230}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.46, 33.15}],
      "\"Setaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Setaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.46, 33.15}],
      RowBox[{"{", 
        RowBox[{"\"Setaka\"", ",", "23985"}], "}"}]],
     Annotation[#, {"Setaka", 23985}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 34.82}],
      "\"Isshiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Isshiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.03, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Isshiki\"", ",", "23966"}], "}"}]],
     Annotation[#, {"Isshiki", 23966}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.84, 32.05}],
      "\"Ebino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ebino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.84, 32.05}],
      RowBox[{"{", 
        RowBox[{"\"Ebino\"", ",", "23880"}], "}"}]],
     Annotation[#, {"Ebino", 23880}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      RowBox[{"{", 
        RowBox[{"\"Shiga\"", ",", "23836"}], "}"}]],
     Annotation[#, {"Shiga", 23836}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.97, 43.550000000000004`}],
      "\"Nakashibetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakashibetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.97, 43.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Nakashibetsu\"", ",", "23818"}], "}"}]],
     Annotation[#, {"Nakashibetsu", 23818}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.46, 34.99}],
      "\"Niimi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niimi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.46, 34.99}],
      RowBox[{"{", 
        RowBox[{"\"Niimi\"", ",", "23787"}], "}"}]],
     Annotation[#, {"Niimi", 23787}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.31, 35.6}],
      "\"Shiroyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiroyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.31, 35.6}],
      RowBox[{"{", 
        RowBox[{"\"Shiroyama\"", ",", "23748"}], "}"}]],
     Annotation[#, {"Shiroyama", 23748}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.82, 34.33}],
      "\"Ago\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ago", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.82, 34.33}],
      RowBox[{"{", 
        RowBox[{"\"Ago\"", ",", "23722"}], "}"}]],
     Annotation[#, {"Ago", 23722}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 31.41}],
      "\"Kaseda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kaseda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 31.41}],
      RowBox[{"{", 
        RowBox[{"\"Kaseda\"", ",", "23710"}], "}"}]],
     Annotation[#, {"Kaseda", 23710}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 35.74}],
      "\"Yachiyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yachiyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.89000000000001`, 36.2}],
      RowBox[{"{", 
        RowBox[{"\"Yachiyo\"", ",", "182890"}], "}"}]],
     Annotation[#, {"Yachiyo", 182890}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.69, 34.6}],
      "\"Sango\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sango", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.69, 34.6}],
      RowBox[{"{", 
        RowBox[{"\"Sango\"", ",", "23607"}], "}"}]],
     Annotation[#, {"Sango", 23607}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.47, 34.83}],
      "\"Mino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.91, 35.54}],
      RowBox[{"{", 
        RowBox[{"\"Mino\"", ",", "123948"}], "}"}]],
     Annotation[#, {"Mino", 123948}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 36.01}],
      "\"Kawajima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawajima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.48, 36.01}],
      RowBox[{"{", 
        RowBox[{"\"Kawajima\"", ",", "23563"}], "}"}]],
     Annotation[#, {"Kawajima", 23563}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.58, 37.44}],
      "\"Funehiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Funehiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.58, 37.44}],
      RowBox[{"{", 
        RowBox[{"\"Funehiki\"", ",", "23524"}], "}"}]],
     Annotation[#, {"Funehiki", 23524}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 33.39}],
      "\"Ogori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ogori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.4, 34.09}],
      RowBox[{"{", 
        RowBox[{"\"Ogori\"", ",", "58258"}], "}"}]],
     Annotation[#, {"Ogori", 58258}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.75, 34.26}],
      "\"Tadotsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tadotsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.75, 34.26}],
      RowBox[{"{", 
        RowBox[{"\"Tadotsu\"", ",", "23514"}], "}"}]],
     Annotation[#, {"Tadotsu", 23514}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.14000000000001`, 36.22}],
      "\"Mikuni\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mikuni", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.22, 36.08}],
      "\"Fukui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.14000000000001`, 36.22}],
      RowBox[{"{", 
        RowBox[{"\"Mikuni\"", ",", "23480"}], "}"}]],
     Annotation[#, {"Mikuni", 23480}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.27, 34.800000000000004`}],
      "\"Oigawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oigawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.27, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Oigawa\"", ",", "23475"}], "}"}]],
     Annotation[#, {"Oigawa", 23475}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.21, 36.58}],
      "\"Osawano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osawano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.21, 36.58}],
      RowBox[{"{", 
        RowBox[{"\"Osawano\"", ",", "23420"}], "}"}]],
     Annotation[#, {"Osawano", 23420}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.83, 34.88}],
      "\"Tenryu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tenryu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.83, 34.88}],
      RowBox[{"{", 
        RowBox[{"\"Tenryu\"", ",", "23418"}], "}"}]],
     Annotation[#, {"Tenryu", 23418}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.71, 35.25}],
      "\"Sobue\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sobue", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.71, 35.25}],
      RowBox[{"{", 
        RowBox[{"\"Sobue\"", ",", "23372"}], "}"}]],
     Annotation[#, {"Sobue", 23372}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.62, 33.410000000000004`}],
      "\"Kitsuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitsuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.62, 33.410000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kitsuki\"", ",", "23353"}], "}"}]],
     Annotation[#, {"Kitsuki", 23353}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.08, 33.31}],
      "\"Taku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Taku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.08, 33.31}],
      RowBox[{"{", 
        RowBox[{"\"Taku\"", ",", "23340"}], "}"}]],
     Annotation[#, {"Taku", 23340}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.72, 38.050000000000004`}],
      "\"Ogawara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ogawara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.72, 38.050000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Ogawara\"", ",", "23340"}], "}"}]],
     Annotation[#, {"Ogawara", 23340}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.84, 34.49}],
      "\"Toba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.84, 34.49}],
      RowBox[{"{", 
        RowBox[{"\"Toba\"", ",", "23303"}], "}"}]],
     Annotation[#, {"Toba", 23303}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.54, 35.87}],
      "\"Fujimi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujimi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.07, 36.45}],
      RowBox[{"{", 
        RowBox[{"\"Fujimi\"", ",", "108460"}], "}"}]],
     Annotation[#, {"Fujimi", 108460}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.04}],
      "\"Yoshimi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoshimi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.45000000000002`, 36.04}],
      RowBox[{"{", 
        RowBox[{"\"Yoshimi\"", ",", "23119"}], "}"}]],
     Annotation[#, {"Yoshimi", 23119}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.18, 34.37}],
      "\"Nagato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.18, 34.37}],
      RowBox[{"{", 
        RowBox[{"\"Nagato\"", ",", "23101"}], "}"}]],
     Annotation[#, {"Nagato", 23101}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.08, 36.07}],
      "\"Shimosuwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shimosuwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.08, 36.07}],
      RowBox[{"{", 
        RowBox[{"\"Shimosuwa\"", ",", "23067"}], "}"}]],
     Annotation[#, {"Shimosuwa", 23067}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139., 37.480000000000004`}],
      "\"Tochio\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochio", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139., 37.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tochio\"", ",", "23045"}], "}"}]],
     Annotation[#, {"Tochio", 23045}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.71, 34.59}],
      "\"Oji\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oji", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.71, 34.59}],
      RowBox[{"{", 
        RowBox[{"\"Oji\"", ",", "23015"}], "}"}]],
     Annotation[#, {"Oji", 23015}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.37, 36.7}],
      "\"Kamiichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamiichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.37, 36.7}],
      RowBox[{"{", 
        RowBox[{"\"Kamiichi\"", ",", "23004"}], "}"}]],
     Annotation[#, {"Kamiichi", 23004}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 31.740000000000002`}],
      "\"Kajiki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kajiki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.66, 31.740000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Kajiki\"", ",", "22997"}], "}"}]],
     Annotation[#, {"Kajiki", 22997}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.1, 43.83}],
      "\"Bihoro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Bihoro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.1, 43.83}],
      RowBox[{"{", 
        RowBox[{"\"Bihoro\"", ",", "22972"}], "}"}]],
     Annotation[#, {"Bihoro", 22972}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.38}],
      "\"Ginan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ginan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.38}],
      RowBox[{"{", 
        RowBox[{"\"Ginan\"", ",", "22962"}], "}"}]],
     Annotation[#, {"Ginan", 22962}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.24, 36.34}],
      "\"Azuma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Azuma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.24, 36.34}],
      RowBox[{"{", 
        RowBox[{"\"Azuma\"", ",", "22883"}], "}"}]],
     Annotation[#, {"Azuma", 22883}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.48, 43.}],
      "\"Kushiro2\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kushiro2", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{144.48, 43.}],
      RowBox[{"{", 
        RowBox[{"\"Kushiro2\"", ",", "22863"}], "}"}]],
     Annotation[#, {"Kushiro2", 22863}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.17000000000002`, 34.32}],
      "\"Shido\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shido", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.17000000000002`, 34.32}],
      RowBox[{"{", 
        RowBox[{"\"Shido\"", ",", "22859"}], "}"}]],
     Annotation[#, {"Shido", 22859}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.79, 43.19}],
      "\"Yoichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yoichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.79, 43.19}],
      RowBox[{"{", 
        RowBox[{"\"Yoichi\"", ",", "22788"}], "}"}]],
     Annotation[#, {"Yoichi", 22788}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.7, 34.62}],
      "\"Mabi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mabi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.7, 34.62}],
      RowBox[{"{", 
        RowBox[{"\"Mabi\"", ",", "22771"}], "}"}]],
     Annotation[#, {"Mabi", 22771}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.4, 35.68}],
      "\"Hino\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hino", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.25, 35.01}],
      RowBox[{"{", 
        RowBox[{"\"Hino\"", ",", "171777"}], "}"}]],
     Annotation[#, {"Hino", 171777}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 39.9}],
      "\"Tenno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tenno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.97, 39.9}],
      RowBox[{"{", 
        RowBox[{"\"Tenno\"", ",", "22740"}], "}"}]],
     Annotation[#, {"Tenno", 22740}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.20000000000002`, 38.68}],
      "\"Hasama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hasama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.20000000000002`, 38.68}],
      RowBox[{"{", 
        RowBox[{"\"Hasama\"", ",", "22739"}], "}"}]],
     Annotation[#, {"Hasama", 22739}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.4, 37.52}],
      "\"Motomiya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Motomiya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.4, 37.52}],
      RowBox[{"{", 
        RowBox[{"\"Motomiya\"", ",", "22705"}], "}"}]],
     Annotation[#, {"Motomiya", 22705}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.74, 35.2}],
      "\"Saori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.74, 35.2}],
      RowBox[{"{", 
        RowBox[{"\"Saori\"", ",", "22695"}], "}"}]],
     Annotation[#, {"Saori", 22695}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.37}],
      "\"Kasamatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasamatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.77, 35.37}],
      RowBox[{"{", 
        RowBox[{"\"Kasamatsu\"", ",", "22671"}], "}"}]],
     Annotation[#, {"Kasamatsu", 22671}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.71}],
      "\"Daito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Daito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.05, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Daito\"", ",", "129521"}], "}"}]],
     Annotation[#, {"Daito", 129521}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.87, 36.38}],
      "\"Minamikawachi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minamikawachi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.87, 36.38}],
      RowBox[{"{", 
        RowBox[{"\"Minamikawachi\"", ",", "22617"}], "}"}]],
     Annotation[#, {"Minamikawachi", 22617}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 34.54}],
      "\"Meiwa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Meiwa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.61, 34.54}],
      RowBox[{"{", 
        RowBox[{"\"Meiwa\"", ",", "22610"}], "}"}]],
     Annotation[#, {"Meiwa", 22610}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.79, 35.17}],
      "\"Shippo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shippo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.79, 35.17}],
      RowBox[{"{", 
        RowBox[{"\"Shippo\"", ",", "22588"}], "}"}]],
     Annotation[#, {"Shippo", 22588}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.31, 31.98}],
      "\"Kunitomi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kunitomi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.31, 31.98}],
      RowBox[{"{", 
        RowBox[{"\"Kunitomi\"", ",", "22584"}], "}"}]],
     Annotation[#, {"Kunitomi", 22584}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.16, 35.18}],
      "\"Notogawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Notogawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.16, 35.18}],
      RowBox[{"{", 
        RowBox[{"\"Notogawa\"", ",", "22551"}], "}"}]],
     Annotation[#, {"Notogawa", 22551}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.47, 35.52}],
      "\"Yamato\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamato", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.26, 33.32}],
      RowBox[{"{", 
        RowBox[{"\"Yamato\"", ",", "224015"}], "}"}]],
     Annotation[#, {"Yamato", 224015}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.78, 32.88}],
      "\"Koshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Koshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.78, 32.88}],
      RowBox[{"{", 
        RowBox[{"\"Koshi\"", ",", "22514"}], "}"}]],
     Annotation[#, {"Koshi", 22514}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.52, 32.12}],
      "\"Takanabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takanabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.52, 32.12}],
      RowBox[{"{", 
        RowBox[{"\"Takanabe\"", ",", "22513"}], "}"}]],
     Annotation[#, {"Takanabe", 22513}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.69, 33.61}],
      "\"Tosayamada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tosayamada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.69, 33.61}],
      RowBox[{"{", 
        RowBox[{"\"Tosayamada\"", ",", "22496"}], "}"}]],
     Annotation[#, {"Tosayamada", 22496}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.37, 42.33}],
      "\"Shizunai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizunai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.37, 42.33}],
      RowBox[{"{", 
        RowBox[{"\"Shizunai\"", ",", "22436"}], "}"}]],
     Annotation[#, {"Shizunai", 22436}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 32.05}],
      "\"Okuchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okuchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.62, 32.05}],
      RowBox[{"{", 
        RowBox[{"\"Okuchi\"", ",", "22425"}], "}"}]],
     Annotation[#, {"Okuchi", 22425}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.86, 36.38}],
      "\"Haruna\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Haruna", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.86, 36.38}],
      RowBox[{"{", 
        RowBox[{"\"Haruna\"", ",", "22375"}], "}"}]],
     Annotation[#, {"Haruna", 22375}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.65, 34.800000000000004`}],
      "\"Hosoe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hosoe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.65, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Hosoe\"", ",", "22345"}], "}"}]],
     Annotation[#, {"Hosoe", 22345}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.35, 36.77}],
      "\"Daigo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Daigo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.35, 36.77}],
      RowBox[{"{", 
        RowBox[{"\"Daigo\"", ",", "22310"}], "}"}]],
     Annotation[#, {"Daigo", 22310}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.15}],
      "\"Katsuura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Katsuura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.15}],
      RowBox[{"{", 
        RowBox[{"\"Katsuura\"", ",", "22307"}], "}"}]],
     Annotation[#, {"Katsuura", 22307}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 40.59}],
      "\"Hiraka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiraka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.55, 40.59}],
      RowBox[{"{", 
        RowBox[{"\"Hiraka\"", ",", "22290"}], "}"}]],
     Annotation[#, {"Hiraka", 22290}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.14000000000001`, 36.57}],
      "\"Yatsuo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yatsuo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.14000000000001`, 36.57}],
      RowBox[{"{", 
        RowBox[{"\"Yatsuo\"", ",", "22205"}], "}"}]],
     Annotation[#, {"Yatsuo", 22205}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.6, 36.07}],
      "\"Shobu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shobu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.6, 36.07}],
      RowBox[{"{", 
        RowBox[{"\"Shobu\"", ",", "22156"}], "}"}]],
     Annotation[#, {"Shobu", 22156}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.23, 31.45}],
      "\"Kushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.23, 31.45}],
      RowBox[{"{", 
        RowBox[{"\"Kushima\"", ",", "22102"}], "}"}]],
     Annotation[#, {"Kushima", 22102}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.36, 34.800000000000004`}],
      "\"Kozakai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kozakai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.36, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kozakai\"", ",", "22064"}], "}"}]],
     Annotation[#, {"Kozakai", 22064}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.63, 36.45}],
      "\"Tsurugi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsurugi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.63, 36.45}],
      RowBox[{"{", 
        RowBox[{"\"Tsurugi\"", ",", "22042"}], "}"}]],
     Annotation[#, {"Tsurugi", 22042}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.21, 34.08}],
      "\"Owase\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Owase", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.21, 34.08}],
      RowBox[{"{", 
        RowBox[{"\"Owase\"", ",", "22038"}], "}"}]],
     Annotation[#, {"Owase", 22038}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 36.36}],
      "\"Iwase\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwase", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 36.36}],
      RowBox[{"{", 
        RowBox[{"\"Iwase\"", ",", "21980"}], "}"}]],
     Annotation[#, {"Iwase", 21980}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.31, 34.2}],
      "\"Kishigawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kishigawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.31, 34.2}],
      RowBox[{"{", 
        RowBox[{"\"Kishigawa\"", ",", "21926"}], "}"}]],
     Annotation[#, {"Kishigawa", 21926}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.94, 34.71}],
      "\"Minamichita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Minamichita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.94, 34.71}],
      RowBox[{"{", 
        RowBox[{"\"Minamichita\"", ",", "21917"}], "}"}]],
     Annotation[#, {"Minamichita", 21917}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.72, 34.92}],
      "\"Yumesaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yumesaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.72, 34.92}],
      RowBox[{"{", 
        RowBox[{"\"Yumesaki\"", ",", "21917"}], "}"}]],
     Annotation[#, {"Yumesaki", 21917}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.02, 34.75}],
      "\"Sanyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sanyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.17000000000002`, 34.05}],
      RowBox[{"{", 
        RowBox[{"\"Sanyo\"", ",", "25467"}], "}"}]],
     Annotation[#, {"Sanyo", 25467}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141., 37.5}],
      "\"Namie\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Namie", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141., 37.5}],
      RowBox[{"{", 
        RowBox[{"\"Namie\"", ",", "21866"}], "}"}]],
     Annotation[#, {"Namie", 21866}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.52, 43.21}],
      "\"Tobetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tobetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.52, 43.21}],
      RowBox[{"{", 
        RowBox[{"\"Tobetsu\"", ",", "21818"}], "}"}]],
     Annotation[#, {"Tobetsu", 21818}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.8, 36.32}],
      "\"Oyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.22, 34.6}],
      RowBox[{"{", 
        RowBox[{"\"Oyama\"", ",", "159936"}], "}"}]],
     Annotation[#, {"Oyama", 159936}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{145.12, 43.65}],
      "\"Shibetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shibetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{145.12, 43.65}],
      RowBox[{"{", 
        RowBox[{"\"Shibetsu\"", ",", "21744"}], "}"}]],
     Annotation[#, {"Shibetsu", 21744}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.11, 34.63}],
      "\"Atsumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Atsumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.11, 34.63}],
      RowBox[{"{", 
        RowBox[{"\"Atsumi\"", ",", "21712"}], "}"}]],
     Annotation[#, {"Atsumi", 21712}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 33.07}],
      "\"Tsukumi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tsukumi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.86, 33.07}],
      RowBox[{"{", 
        RowBox[{"\"Tsukumi\"", ",", "21658"}], "}"}]],
     Annotation[#, {"Tsukumi", 21658}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.19, 35.53}],
      "\"Miyazu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.19, 35.53}],
      RowBox[{"{", 
        RowBox[{"\"Miyazu\"", ",", "21632"}], "}"}]],
     Annotation[#, {"Miyazu", 21632}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 34.800000000000004`}],
      "\"Kira\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kira", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.07, 34.800000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kira\"", ",", "21585"}], "}"}]],
     Annotation[#, {"Kira", 21585}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.96, 34.92}],
      "\"Yashiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yashiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.96, 34.92}],
      RowBox[{"{", 
        RowBox[{"\"Yashiro\"", ",", "21554"}], "}"}]],
     Annotation[#, {"Yashiro", 21554}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.14000000000001`, 36.2}],
      "\"Kodama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kodama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.14000000000001`, 36.2}],
      RowBox[{"{", 
        RowBox[{"\"Kodama\"", ",", "21544"}], "}"}]],
     Annotation[#, {"Kodama", 21544}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.87}],
      "\"Tatsuno\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tatsuno", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.18, 36.65}],
      "\"Nagano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nagano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138., 35.99}],
      RowBox[{"{", 
        RowBox[{"\"Tatsuno\"", ",", "40011"}], "}"}]],
     Annotation[#, {"Tatsuno", 40011}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.64}],
      "\"Sambu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sambu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.36, 35.64}],
      RowBox[{"{", 
        RowBox[{"\"Sambu\"", ",", "21480"}], "}"}]],
     Annotation[#, {"Sambu", 21480}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.05, 38.300000000000004`}],
      "\"Shichigahama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shichigahama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.05, 38.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shichigahama\"", ",", "21433"}], "}"}]],
     Annotation[#, {"Shichigahama", 21433}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.79, 33.74}],
      "\"Tobe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tobe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.79, 33.74}],
      RowBox[{"{", 
        RowBox[{"\"Tobe\"", ",", "21382"}], "}"}]],
     Annotation[#, {"Tobe", 21382}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.44}],
      "\"Omama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Omama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.28, 36.44}],
      RowBox[{"{", 
        RowBox[{"\"Omama\"", ",", "21286"}], "}"}]],
     Annotation[#, {"Omama", 21286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 33.35}],
      "\"Tanushimaru\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tanushimaru", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.68, 33.35}],
      RowBox[{"{", 
        RowBox[{"\"Tanushimaru\"", ",", "21156"}], "}"}]],
     Annotation[#, {"Tanushimaru", 21156}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.25}],
      "\"Fujioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.20000000000002`, 35.19}],
      RowBox[{"{", 
        RowBox[{"\"Fujioka\"", ",", "63358"}], "}"}]],
     Annotation[#, {"Fujioka", 63358}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.27, 34.56}],
      "\"Shinichi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shinichi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.27, 34.56}],
      RowBox[{"{", 
        RowBox[{"\"Shinichi\"", ",", "21030"}], "}"}]],
     Annotation[#, {"Shinichi", 21030}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.28, 38.42}],
      "\"Kahoku\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kahoku", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.28, 38.42}],
      RowBox[{"{", 
        RowBox[{"\"Kahoku\"", ",", "20868"}], "}"}]],
     Annotation[#, {"Kahoku", 20868}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 36.1}],
      "\"Kisai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kisai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.58, 36.1}],
      RowBox[{"{", 
        RowBox[{"\"Kisai\"", ",", "20850"}], "}"}]],
     Annotation[#, {"Kisai", 20850}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.4, 38.6}],
      "\"Obanazawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Obanazawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.4, 38.6}],
      RowBox[{"{", 
        RowBox[{"\"Obanazawa\"", ",", "20821"}], "}"}]],
     Annotation[#, {"Obanazawa", 20821}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.17}],
      "\"Yanagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yanagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.6, 37.86}],
      RowBox[{"{", 
        RowBox[{"\"Yanagawa\"", ",", "40386"}], "}"}]],
     Annotation[#, {"Yanagawa", 40386}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.35, 42.550000000000004`}],
      "\"Shiraoi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiraoi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.35, 42.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Shiraoi\"", ",", "20804"}], "}"}]],
     Annotation[#, {"Shiraoi", 20804}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.95}],
      "\"Edosaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Edosaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 35.95}],
      RowBox[{"{", 
        RowBox[{"\"Edosaki\"", ",", "20800"}], "}"}]],
     Annotation[#, {"Edosaki", 20800}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.6, 35.42}],
      "\"Godo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Godo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.6, 35.42}],
      RowBox[{"{", 
        RowBox[{"\"Godo\"", ",", "20758"}], "}"}]],
     Annotation[#, {"Godo", 20758}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.59, 40.71}],
      "\"Namioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Namioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.59, 40.71}],
      RowBox[{"{", 
        RowBox[{"\"Namioka\"", ",", "20681"}], "}"}]],
     Annotation[#, {"Namioka", 20681}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.86, 35.34}],
      "\"Konan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Konan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.92000000000002`, 35.19}],
      "\"Shiga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.17000000000002`, 34.93}],
      RowBox[{"{", 
        RowBox[{"\"Konan\"", ",", "100389"}], "}"}]],
     Annotation[#, {"Konan", 100389}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 40.230000000000004`}],
      "\"Takanosu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Takanosu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 40.230000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Takanosu\"", ",", "20542"}], "}"}]],
     Annotation[#, {"Takanosu", 20542}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.72, 32.7}],
      "\"Jonan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Jonan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.72, 32.7}],
      RowBox[{"{", 
        RowBox[{"\"Jonan\"", ",", "20536"}], "}"}]],
     Annotation[#, {"Jonan", 20536}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.02, 34.86}],
      "\"Shobara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shobara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.44, 34.39}],
      "\"Hiroshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hiroshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.02, 34.86}],
      RowBox[{"{", 
        RowBox[{"\"Shobara\"", ",", "20527"}], "}"}]],
     Annotation[#, {"Shobara", 20527}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.4}],
      "\"Oyodo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oyodo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.8, 34.4}],
      RowBox[{"{", 
        RowBox[{"\"Oyodo\"", ",", "20489"}], "}"}]],
     Annotation[#, {"Oyodo", 20489}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.45000000000002`, 35.53}],
      "\"Kujukuri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kujukuri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.45000000000002`, 35.53}],
      RowBox[{"{", 
        RowBox[{"\"Kujukuri\"", ",", "20488"}], "}"}]],
     Annotation[#, {"Kujukuri", 20488}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.67000000000002`, 33.72}],
      "\"Miyata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.67000000000002`, 33.72}],
      RowBox[{"{", 
        RowBox[{"\"Miyata\"", ",", "20421"}], "}"}]],
     Annotation[#, {"Miyata", 20421}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.22, 37.84}],
      "\"Suibara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suibara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.22, 37.84}],
      RowBox[{"{", 
        RowBox[{"\"Suibara\"", ",", "20392"}], "}"}]],
     Annotation[#, {"Suibara", 20392}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.69, 34.63}],
      "\"Heguri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Heguri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.69, 34.63}],
      RowBox[{"{", 
        RowBox[{"\"Heguri\"", ",", "20303"}], "}"}]],
     Annotation[#, {"Heguri", 20303}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.14000000000001`, 34.82}],
      "\"Kanaya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanaya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.14000000000001`, 34.82}],
      RowBox[{"{", 
        RowBox[{"\"Kanaya\"", ",", "20286"}], "}"}]],
     Annotation[#, {"Kanaya", 20286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.93, 34.83}],
      "\"Mori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.93, 34.83}],
      RowBox[{"{", 
        RowBox[{"\"Mori\"", ",", "20280"}], "}"}]],
     Annotation[#, {"Mori", 20280}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.81, 34.67}],
      "\"Ryuyo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ryuyo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.81, 34.67}],
      RowBox[{"{", 
        RowBox[{"\"Ryuyo\"", ",", "20263"}], "}"}]],
     Annotation[#, {"Ryuyo", 20263}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.24}],
      "\"Ryonan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ryonan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.24}],
      RowBox[{"{", 
        RowBox[{"\"Ryonan\"", ",", "20246"}], "}"}]],
     Annotation[#, {"Ryonan", 20246}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.39000000000001`, 35.24}],
      "\"Ohara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ohara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.39000000000001`, 35.24}],
      RowBox[{"{", 
        RowBox[{"\"Ohara\"", ",", "20226"}], "}"}]],
     Annotation[#, {"Ohara", 20226}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.39000000000001`, 34.980000000000004`}],
      "\"Shizuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.93, 34.7}],
      RowBox[{"{", 
        RowBox[{"\"Asaba\"", ",", "73374"}], "}"}]],
     Annotation[#, {"Asaba", 73374}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 37.03}],
      "\"Shiozawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shiozawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 37.03}],
      RowBox[{"{", 
        RowBox[{"\"Shiozawa\"", ",", "20178"}], "}"}]],
     Annotation[#, {"Shiozawa", 20178}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 33.3}],
      "\"Kanzaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kanzaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.37, 33.3}],
      RowBox[{"{", 
        RowBox[{"\"Kanzaki\"", ",", "20172"}], "}"}]],
     Annotation[#, {"Kanzaki", 20172}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.94, 39.47}],
      "\"Yamada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.94, 39.47}],
      RowBox[{"{", 
        RowBox[{"\"Yamada\"", ",", "20144"}], "}"}]],
     Annotation[#, {"Yamada", 20144}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.91, 33.5}],
      "\"Aki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.91, 33.5}],
      RowBox[{"{", 
        RowBox[{"\"Aki\"", ",", "20117"}], "}"}]],
     Annotation[#, {"Aki", 20117}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.73, 34.57}],
      "\"Kawai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.73, 34.57}],
      RowBox[{"{", 
        RowBox[{"\"Kawai\"", ",", "20105"}], "}"}]],
     Annotation[#, {"Kawai", 20105}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.91, 43.49}],
      "\"Sunagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sunagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.91, 43.49}],
      RowBox[{"{", 
        RowBox[{"\"Sunagawa\"", ",", "20102"}], "}"}]],
     Annotation[#, {"Sunagawa", 20102}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.55, 33.24}],
      "\"Hirokawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hirokawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.55, 33.24}],
      RowBox[{"{", 
        RowBox[{"\"Hirokawa\"", ",", "20052"}], "}"}]],
     Annotation[#, {"Hirokawa", 20052}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.54, 34.12}],
      "\"Kitajima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kitajima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.54, 34.12}],
      RowBox[{"{", 
        RowBox[{"\"Kitajima\"", ",", "20052"}], "}"}]],
     Annotation[#, {"Kitajima", 20052}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 32.06}],
      "\"Shintomi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shintomi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.42000000000002`, 31.91}],
      "\"Miyazaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miyazaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 32.06}],
      RowBox[{"{", 
        RowBox[{"\"Shintomi\"", ",", "20050"}], "}"}]],
     Annotation[#, {"Shintomi", 20050}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.02, 31.64}],
      "\"Sueyoshi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Sueyoshi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.02, 31.64}],
      RowBox[{"{", 
        RowBox[{"\"Sueyoshi\"", ",", "19986"}], "}"}]],
     Annotation[#, {"Sueyoshi", 19986}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 35.74}],
      "\"Shisui\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shisui", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 35.61}],
      "\"Chiba\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Chiba", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.27, 35.74}],
      RowBox[{"{", 
        RowBox[{"\"Shisui\"", ",", "19903"}], "}"}]],
     Annotation[#, {"Shisui", 19903}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.98, 39.69}],
      "\"Shizukuishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shizukuishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.98, 39.69}],
      RowBox[{"{", 
        RowBox[{"\"Shizukuishi\"", ",", "19866"}], "}"}]],
     Annotation[#, {"Shizukuishi", 19866}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.91, 34.13}],
      "\"Toyoura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyoura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.91, 34.13}],
      RowBox[{"{", 
        RowBox[{"\"Toyoura\"", ",", "19802"}], "}"}]],
     Annotation[#, {"Toyoura", 19802}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.05, 38.550000000000004`}],
      "\"Kogota\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kogota", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.05, 38.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kogota\"", ",", "19760"}], "}"}]],
     Annotation[#, {"Kogota", 19760}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.16, 37.660000000000004`}],
      "\"Muramatsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Muramatsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.16, 37.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Muramatsu\"", ",", "19712"}], "}"}]],
     Annotation[#, {"Muramatsu", 19712}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.48, 37.43}],
      "\"Miharu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Miharu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.48, 37.43}],
      RowBox[{"{", 
        RowBox[{"\"Miharu\"", ",", "19708"}], "}"}]],
     Annotation[#, {"Miharu", 19708}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.53}],
      "\"Motegi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Motegi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.19, 36.53}],
      RowBox[{"{", 
        RowBox[{"\"Motegi\"", ",", "19575"}], "}"}]],
     Annotation[#, {"Motegi", 19575}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.87, 36.550000000000004`}],
      "\"Fukumitsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukumitsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.22, 36.7}],
      "\"Toyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Toyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.87, 36.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Fukumitsu\"", ",", "19535"}], "}"}]],
     Annotation[#, {"Fukumitsu", 19535}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.58, 34.34}],
      "\"Kumano\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumano", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.14000000000001`, 33.93}],
      RowBox[{"{", 
        RowBox[{"\"Kumano\"", ",", "25663"}], "}"}]],
     Annotation[#, {"Kumano", 25663}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.13, 35.43}],
      "\"Mitake\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mitake", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.13, 35.43}],
      RowBox[{"{", 
        RowBox[{"\"Mitake\"", ",", "19340"}], "}"}]],
     Annotation[#, {"Mitake", 19340}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.57, 36.32}],
      "\"Oarai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oarai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.57, 36.32}],
      RowBox[{"{", 
        RowBox[{"\"Oarai\"", ",", "19326"}], "}"}]],
     Annotation[#, {"Oarai", 19326}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 36.27}],
      "\"Makabe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Makabe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.09, 36.27}],
      RowBox[{"{", 
        RowBox[{"\"Makabe\"", ",", "19293"}], "}"}]],
     Annotation[#, {"Makabe", 19293}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.73, 34.910000000000004`}],
      "\"Kodera\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kodera", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.73, 34.910000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kodera\"", ",", "19271"}], "}"}]],
     Annotation[#, {"Kodera", 19271}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.31}],
      "\"Iwafune\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwafune", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.67000000000002`, 36.31}],
      RowBox[{"{", 
        RowBox[{"\"Iwafune\"", ",", "19248"}], "}"}]],
     Annotation[#, {"Iwafune", 19248}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.7, 31.490000000000002`}],
      "\"Tarumizu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tarumizu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.7, 31.490000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Tarumizu\"", ",", "19146"}], "}"}]],
     Annotation[#, {"Tarumizu", 19146}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.70000000000002`, 35.53}],
      "\"Kawasaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawasaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.83, 33.58}],
      RowBox[{"{", 
        RowBox[{"\"Kawasaki\"", ",", "1306785"}], "}"}]],
     Annotation[#, {"Kawasaki", 1306785}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 33.59}],
      "\"Inatsuki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inatsuki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 33.59}],
      RowBox[{"{", 
        RowBox[{"\"Inatsuki\"", ",", "19140"}], "}"}]],
     Annotation[#, {"Inatsuki", 19140}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.300000000000004`}],
      "\"Katsuragi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Katsuragi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.300000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Katsuragi\"", ",", "19138"}], "}"}]],
     Annotation[#, {"Katsuragi", 19138}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.19, 43.52}],
      "\"Ashibetsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ashibetsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.19, 43.52}],
      RowBox[{"{", 
        RowBox[{"\"Ashibetsu\"", ",", "19108"}], "}"}]],
     Annotation[#, {"Ashibetsu", 19108}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.76, 34.95}],
      "\"Fukusaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukusaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.76, 34.95}],
      RowBox[{"{", 
        RowBox[{"\"Fukusaki\"", ",", "19033"}], "}"}]],
     Annotation[#, {"Fukusaki", 19033}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 40.79}],
      "\"Kizukuri\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kizukuri", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.74, 40.83}],
      "\"Aomori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aomori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.37, 40.79}],
      RowBox[{"{", 
        RowBox[{"\"Kizukuri\"", ",", "18907"}], "}"}]],
     Annotation[#, {"Kizukuri", 18907}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.13, 34.31}],
      "\"Misaki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Misaki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.5, 34.68}],
      "\"Osaka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Osaka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.13, 34.31}],
      RowBox[{"{", 
        RowBox[{"\"Misaki\"", ",", "18886"}], "}"}]],
     Annotation[#, {"Misaki", 18886}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.45000000000002`, 37.14}],
      RowBox[{"{", 
        RowBox[{"\"Ishikawa\"", ",", "22412"}], "}"}]],
     Annotation[#, {"Ishikawa", 22412}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.71, 34.26}],
      "\"Nandan\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nandan", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.71, 34.26}],
      RowBox[{"{", 
        RowBox[{"\"Nandan\"", ",", "18721"}], "}"}]],
     Annotation[#, {"Nandan", 18721}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.94, 33.62}],
      "\"Nachikatsuura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nachikatsuura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.17000000000002`, 34.22}],
      "\"Wakayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.94, 33.62}],
      RowBox[{"{", 
        RowBox[{"\"Nachikatsuura\"", ",", "18712"}], "}"}]],
     Annotation[#, {"Nachikatsuura", 18712}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 37.56}],
      "\"Aizubange\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aizubange", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.82, 37.56}],
      RowBox[{"{", 
        RowBox[{"\"Aizubange\"", ",", "18702"}], "}"}]],
     Annotation[#, {"Aizubange", 18702}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.42000000000002`, 34.82}],
      "\"Kawanishi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawanishi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.05, 38.}],
      RowBox[{"{", 
        RowBox[{"\"Kawanishi\"", ",", "160520"}], "}"}]],
     Annotation[#, {"Kawanishi", 160520}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 35.49}],
      "\"Ibigawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibigawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.76, 35.42}],
      "\"Gifu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gifu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{136.58, 35.49}],
      RowBox[{"{", 
        RowBox[{"\"Ibigawa\"", ",", "18562"}], "}"}]],
     Annotation[#, {"Ibigawa", 18562}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.41, 39.2}],
      "\"Ugo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ugo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.11, 39.71}],
      "\"Akita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.41, 39.2}],
      RowBox[{"{", 
        RowBox[{"\"Ugo\"", ",", "18545"}], "}"}]],
     Annotation[#, {"Ugo", 18545}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 36.65}],
      "\"Karasuyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Karasuyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.15, 36.65}],
      RowBox[{"{", 
        RowBox[{"\"Karasuyama\"", ",", "18488"}], "}"}]],
     Annotation[#, {"Karasuyama", 18488}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.23, 34.74}],
      "\"Haibara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Haibara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.83, 34.69}],
      "\"Nara\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nara", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.95, 34.53}],
      RowBox[{"{", 
        RowBox[{"\"Haibara\"", ",", "25670"}], "}"}]],
     Annotation[#, {"Haibara", 25670}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.58, 34.52}],
      "\"Kamogata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kamogata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.92000000000002`, 34.67}],
      "\"Okayama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Okayama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.58, 34.52}],
      RowBox[{"{", 
        RowBox[{"\"Kamogata\"", ",", "18412"}], "}"}]],
     Annotation[#, {"Kamogata", 18412}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.67000000000002`, 33.79}],
      "\"Kurate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kurate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.67000000000002`, 33.79}],
      RowBox[{"{", 
        RowBox[{"\"Kurate\"", ",", "18405"}], "}"}]],
     Annotation[#, {"Kurate", 18405}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.32, 33.19}],
      "\"Kawasoe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawasoe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.3, 33.25}],
      "\"Saga\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saga", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.32, 33.19}],
      RowBox[{"{", 
        RowBox[{"\"Kawasoe\"", ",", "18399"}], "}"}]],
     Annotation[#, {"Kawasoe", 18399}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.15, 33.27}],
      "\"Kusu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kusu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.15, 33.27}],
      RowBox[{"{", 
        RowBox[{"\"Kusu\"", ",", "18371"}], "}"}]],
     Annotation[#, {"Kusu", 18371}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.1, 31.470000000000002`}],
      "\"Shibushi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Shibushi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.1, 31.470000000000002`}],
      RowBox[{"{", 
        RowBox[{"\"Shibushi\"", ",", "18349"}], "}"}]],
     Annotation[#, {"Shibushi", 18349}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.09, 36.25}],
      "\"Fujioka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fujioka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.65, 36.26}],
      RowBox[{"{", 
        RowBox[{"\"Fujioka\"", ",", "63358"}], "}"}]],
     Annotation[#, {"Fujioka", 63358}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.14000000000001`, 38.54}],
      "\"Wakuya\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Wakuya", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.14000000000001`, 38.54}],
      RowBox[{"{", 
        RowBox[{"\"Wakuya\"", ",", "18334"}], "}"}]],
     Annotation[#, {"Wakuya", 18334}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.2, 34.17}],
      "\"Mine\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mine", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.48, 34.18}],
      "\"Yamaguchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamaguchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.2, 34.17}],
      RowBox[{"{", 
        RowBox[{"\"Mine\"", ",", "18247"}], "}"}]],
     Annotation[#, {"Mine", 18247}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.26, 37.44}],
      "\"Suzu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Suzu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{137.26, 37.44}],
      RowBox[{"{", 
        RowBox[{"\"Suzu\"", ",", "18205"}], "}"}]],
     Annotation[#, {"Suzu", 18205}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.04, 32.97}],
      "\"Aso\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Aso", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.04, 32.97}],
      RowBox[{"{", 
        RowBox[{"\"Aso\"", ",", "18118"}], "}"}]],
     Annotation[#, {"Aso", 18118}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 36.08}],
      "\"Kasumigaura\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kasumigaura", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.32, 36.08}],
      RowBox[{"{", 
        RowBox[{"\"Kasumigaura\"", ",", "18017"}], "}"}]],
     Annotation[#, {"Kasumigaura", 18017}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.16, 35.86}],
      "\"Tone\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tone", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.57, 34.81}],
      "\"Ibaraki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ibaraki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.16, 35.86}],
      RowBox[{"{", 
        RowBox[{"\"Tone\"", ",", "17954"}], "}"}]],
     Annotation[#, {"Tone", 17954}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.45, 33.56}],
      "\"Bungotakada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Bungotakada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.45, 33.56}],
      RowBox[{"{", 
        RowBox[{"\"Bungotakada\"", ",", "17931"}], "}"}]],
     Annotation[#, {"Bungotakada", 17931}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131., 30.73}],
      "\"Nishinoomote\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nishinoomote", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.56, 31.59}],
      "\"Kagoshima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagoshima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131., 30.73}],
      RowBox[{"{", 
        RowBox[{"\"Nishinoomote\"", ",", "17832"}], "}"}]],
     Annotation[#, {"Nishinoomote", 17832}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 36.59}],
      "\"Nakanojo\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nakanojo", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.99, 36.39}],
      "\"Gumma\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Gumma", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.85, 36.59}],
      RowBox[{"{", 
        RowBox[{"\"Nakanojo\"", ",", "17741"}], "}"}]],
     Annotation[#, {"Nakanojo", 17741}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.15, 34.08}],
      "\"Waki\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Waki", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.15, 34.08}],
      RowBox[{"{", 
        RowBox[{"\"Waki\"", ",", "17659"}], "}"}]],
     Annotation[#, {"Waki", 17659}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.15, 33.3}],
      "\"Muroto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Muroto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.15, 33.3}],
      RowBox[{"{", 
        RowBox[{"\"Muroto\"", ",", "17601"}], "}"}]],
     Annotation[#, {"Muroto", 17601}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 37.56}],
      "\"Inawashiro\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Inawashiro", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.1, 37.56}],
      RowBox[{"{", 
        RowBox[{"\"Inawashiro\"", ",", "17413"}], "}"}]],
     Annotation[#, {"Inawashiro", 17413}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.95, 32.79}],
      "\"Tosashimizu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tosashimizu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{132.95, 32.79}],
      RowBox[{"{", 
        RowBox[{"\"Tosashimizu\"", ",", "17286"}], "}"}]],
     Annotation[#, {"Tosashimizu", 17286}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 39.02}],
      "\"Yuza\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yuza", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.33, 38.25}],
      "\"Yamagata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamagata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.91, 39.02}],
      RowBox[{"{", 
        RowBox[{"\"Yuza\"", ",", "17082"}], "}"}]],
     Annotation[#, {"Yuza", 17082}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.77, 37.92}],
      "\"Marumori\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Marumori", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.77, 37.92}],
      RowBox[{"{", 
        RowBox[{"\"Marumori\"", ",", "16752"}], "}"}]],
     Annotation[#, {"Marumori", 16752}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.62, 34.71}],
      "\"Daito\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Daito", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.4, 39.01}],
      RowBox[{"{", 
        RowBox[{"\"Daito\"", ",", "129521"}], "}"}]],
     Annotation[#, {"Daito", 129521}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.02, 32.2}],
      "\"Ushibuka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ushibuka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.02, 32.2}],
      RowBox[{"{", 
        RowBox[{"\"Ushibuka\"", ",", "16667"}], "}"}]],
     Annotation[#, {"Ushibuka", 16667}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.18, 34.480000000000004`}],
      "\"Tonosho\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tonosho", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.03, 34.230000000000004`}],
      "\"Kagawa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kagawa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.18, 34.480000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Tonosho\"", ",", "16514"}], "}"}]],
     Annotation[#, {"Tonosho", 16514}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.91, 39.36}],
      "\"Otsuchi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Otsuchi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.91, 39.36}],
      RowBox[{"{", 
        RowBox[{"\"Otsuchi\"", ",", "16497"}], "}"}]],
     Annotation[#, {"Otsuchi", 16497}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.6, 37.660000000000004`}],
      "\"Kawamata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kawamata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.47, 37.75}],
      "\"Fukushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.6, 37.660000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Kawamata\"", ",", "16477"}], "}"}]],
     Annotation[#, {"Kawamata", 16477}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 32.95}],
      "\"Taketa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Taketa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.6, 33.24}],
      "\"Oita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Oita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{131.39000000000001`, 32.95}],
      RowBox[{"{", 
        RowBox[{"\"Taketa\"", ",", "16361"}], "}"}]],
     Annotation[#, {"Taketa", 16361}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.43, 38.08}],
      "\"Ryotsu\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ryotsu", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.04, 37.92}],
      "\"Niigata\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Niigata", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{138.43, 38.08}],
      RowBox[{"{", 
        RowBox[{"\"Ryotsu\"", ",", "16359"}], "}"}]],
     Annotation[#, {"Ryotsu", 16359}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Iwate\"", ",", "16328"}], "}"}]],
     Annotation[#, {"Iwate", 16328}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.980000000000004`}],
      "\"Hatoyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hatoyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.64000000000001`, 35.87}],
      "\"Saitama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Saitama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.33, 35.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Hatoyama\"", ",", "16103"}], "}"}]],
     Annotation[#, {"Hatoyama", 16103}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 32.28}],
      "\"Ashikita\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ashikita", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.71, 32.8}],
      "\"Kumamoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumamoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.49, 32.28}],
      RowBox[{"{", 
        RowBox[{"\"Ashikita\"", ",", "16082"}], "}"}]],
     Annotation[#, {"Ashikita", 16082}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 36.75}],
      "\"Nikko\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Nikko", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.73, 36.38}],
      "\"Tochigi\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tochigi", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.61, 36.75}],
      RowBox[{"{", 
        RowBox[{"\"Nikko\"", ",", "16041"}], "}"}]],
     Annotation[#, {"Nikko", 16041}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.74, 34.88}],
      "\"Kumiyama\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kumiyama", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.75, 35.01}],
      "\"Kyoto\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Kyoto", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.74, 34.88}],
      RowBox[{"{", 
        RowBox[{"\"Kumiyama\"", ",", "16005"}], "}"}]],
     Annotation[#, {"Kumiyama", 16005}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{135.43, 34.82}],
      "\"Ikeda\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ikeda", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{134.55, 34.07}],
      "\"Tokushima\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Tokushima", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{133.79, 34.01}],
      RowBox[{"{", 
        RowBox[{"\"Ikeda\"", ",", "99476"}], "}"}]],
     Annotation[#, {"Ikeda", 99476}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.3, 40.2}],
      "\"Ichinohe\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Ichinohe", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.23, 39.980000000000004`}],
      "\"Iwate\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwate", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.3, 40.2}],
      RowBox[{"{", 
        RowBox[{"\"Ichinohe\"", ",", "15825"}], "}"}]],
     Annotation[#, {"Ichinohe", 15825}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.51, 42.980000000000004`}],
      "\"Iwanai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Iwanai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{140.51, 42.980000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Iwanai\"", ",", "15584"}], "}"}]],
     Annotation[#, {"Iwanai", 15584}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.06, 43.550000000000004`}],
      "\"Akabira\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Akabira", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.06, 43.550000000000004`}],
      RowBox[{"{", 
        RowBox[{"\"Akabira\"", ",", "14214"}], "}"}]],
     Annotation[#, {"Akabira", 14214}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 35.25}],
      "\"Hakone\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Hakone", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{139.11, 35.25}],
      RowBox[{"{", 
        RowBox[{"\"Hakone\"", ",", "13939"}], "}"}]],
     Annotation[#, {"Hakone", 13939}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.98, 43.07}],
      "\"Yubari\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yubari", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.98, 43.07}],
      RowBox[{"{", 
        RowBox[{"\"Yubari\"", ",", "12870"}], "}"}]],
     Annotation[#, {"Yubari", 12870}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.89000000000001`, 43.24}],
      "\"Mikasa\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mikasa", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.89000000000001`, 43.24}],
      RowBox[{"{", 
        RowBox[{"\"Mikasa\"", ",", "12102"}], "}"}]],
     Annotation[#, {"Mikasa", 12102}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{141.94, 39.47}],
      "\"Yamada\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Yamada", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.41, 33.59}],
      "\"Fukuoka\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Fukuoka", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{130.76, 33.56}],
      RowBox[{"{", 
        RowBox[{"\"Yamada\"", ",", "20144"}], "}"}]],
     Annotation[#, {"Yamada", 20144}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.06, 43.52}],
      "\"Utashinai\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Utashinai", "Tooltip"]& ], 
    TagBox[
     TooltipBox[PointBox[{142.06, 43.52}],
      RowBox[{"{", 
        RowBox[{"\"Utashinai\"", ",", "5162"}], "}"}]],
     Annotation[#, {"Utashinai", 5162}, "Tooltip"]& ]}},
  Background->RGBColor[0.020005, 0.719993, 0.799997]]], "Output"]
}, Open  ]],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: AstronomicalData", "Section"],

Cell["\<\
Static and dynamic properties of stars, planets, and other objects.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"DataTable", "[", "AstronomicalData", "]"}]], "Input"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["AstronomicalData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "156134", 
     RowBox[{"{", 
      RowBox[{"\<\"HIP4097\"\>", ",", "\<\"HIP87303\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "98", 
     RowBox[{"{", 
      RowBox[{"\<\"HDName\"\>", ",", "\<\"NGCNumber\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "76", 
     RowBox[{"{", 
      RowBox[{"\<\"JupiterFamilyComet\"\>", ",", "\<\"ClassSStar\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell["Scope of AstronomicalData", "PictureCaption"],

Cell["A list of solar system planets.", "MathCaption",
 CellChangeTimes->{{3.4191681845425997`*^9, 3.4191681849686003`*^9}}],

Cell[BoxData[
 RowBox[{"AstronomicalData", "[", "\"\<Planet\>\"", "]"}]], "Input"],

Cell["\<\
Make a graphic of solar system orbit paths with tooltips displaying images of \
each planet.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"LightGray", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"AstronomicalData", "[", 
          RowBox[{"#", ",", "\"\<OrbitPath\>\""}], "]"}], ",", 
         RowBox[{"Labeled", "[", 
          RowBox[{
           RowBox[{"AstronomicalData", "[", 
            RowBox[{"#", ",", "\"\<Image\>\""}], "]"}], ",", "#", ",", 
           RowBox[{"LabelStyle", "\[Rule]", "\"\<Menu\>\""}]}], "]"}]}], 
        "]"}], "&"}], "/@", 
      RowBox[{"AstronomicalData", "[", "\"\<Planet\>\"", "]"}]}]}], "}"}], 
   ",", 
   RowBox[{"Background", "\[Rule]", "Black"}]}], "]"}]], "Input"],

Cell["\<\
Varying distance of planets from Earth in 2011:\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2011", ",", "1", ",", "i"}], "}"}], ",", 
           RowBox[{"AstronomicalData", "[", 
            RowBox[{"#", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<Distance\>\"", ",", 
               RowBox[{"{", 
                RowBox[{"2011", ",", "1", ",", "i"}], "}"}]}], "}"}]}], 
            "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "365.25", ",", "10"}], "}"}]}], "]"}], 
       ",", "#"}], "]"}], "&"}], "/@", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Mercury\>\"", ",", "\"\<Venus\>\"", ",", "\"\<Mars\>\"", ",", 
      "\"\<Jupiter\>\"", ",", "\"\<Saturn\>\""}], "}"}]}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["Planet positions in 2011", "MoreExamplesSection"],

Cell["\<\
The ecliptic plane can be easily seen by plotting the equatorial coordinates \
(right ascension and declination) of the planets throughout the year. The \
ecliptic plane is tilted 23.5\[Degree] to the celestial equator.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ColorData", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"AstronomicalData", "[", 
                RowBox[{"#", ",", 
                 RowBox[{"{", 
                  RowBox[{"\"\<RightAscension\>\"", ",", 
                   RowBox[{"DateList", "[", 
                    RowBox[{"{", 
                    RowBox[{"2011", ",", "1", ",", "i"}], "}"}], "]"}]}], 
                  "}"}]}], "]"}]}], ",", 
              RowBox[{"AstronomicalData", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{"\"\<Declination\>\"", ",", 
                  RowBox[{"DateList", "[", 
                   RowBox[{"{", 
                    RowBox[{"2011", ",", "1", ",", "i"}], "}"}], "]"}]}], 
                 "}"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"#", "<>", "\"\< on \>\"", "<>", 
            RowBox[{"DateString", "[", 
             RowBox[{
              RowBox[{"DateList", "[", 
               RowBox[{"{", 
                RowBox[{"2011", ",", "1", ",", "i"}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
               "\"\<DayNameShort\>\"", ",", "\"\< \>\"", ",", "\"\<Day\>\"", 
                ",", "\"\< \>\"", ",", "\"\<MonthNameShort\>\"", ",", 
                "\"\< \>\"", ",", "\"\<Year\>\""}], "}"}]}], "]"}]}]}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "365.25", ",", "10"}], "}"}]}], "]"}], 
       "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Mercury\>\"", ",", "\"\<Venus\>\"", ",", "\"\<Mars\>\"", ",", 
        "\"\<Jupiter\>\"", ",", "\"\<Saturn\>\""}], "}"}]}]}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "24"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "90"}], ",", "90"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "i"}], ",", 
          RowBox[{"Superscript", "[", 
           RowBox[{"i", ",", "\"\<h\>\""}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "24", ",", "2"}], "}"}]}], "]"}], ",", 
      "Automatic"}], "}"}]}]}], "]"}]], "Input"],

Cell["", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: ElementData", "Section"],

Cell["\<\
Covers the entire periodic table, from hydrogen to element 118, Ununoctium.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "ElementData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["ElementData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "118", 
     RowBox[{"{", 
      RowBox[{"\<\"Ununpentium\"\>", ",", "\<\"Promethium\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "86", 
     RowBox[{"{", 
      RowBox[{"\<\"Period\"\>", ",", "\<\"NeelPoint\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "56", 
     RowBox[{"{", 
      RowBox[{"\<\"Group10Elements\"\>", ",", "\<\"Semiconductor\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of ElementData", "PictureCaption"],

Cell[TextData[{
 "Use ",
 ButtonBox["LatticeData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LatticeData"],
 " to get detailed information on solid state structures."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{"\"\<Titanium\>\"", ",", "\"\<CrystalStructure\>\""}], 
  "]"}]], "Input",
 CellID->1068126438],

Cell[BoxData[
 RowBox[{"LatticeData", "[", 
  RowBox[{"%", ",", "\"\<Image\>\""}], "]"}]], "Input",
 CellID->301539131],

Cell["Find how many elements were discovered in each country.", "MathCaption"],

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"Tally", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ElementData", "[", 
        RowBox[{"z", ",", "\"\<DiscoveryCountries\>\""}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "1", ",", "108"}], "}"}]}], "]"}], "]"}], "]"}], 
   ",", "Last"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell[TextData[{
 "Use ",
 ButtonBox["Manipulate",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Manipulate"],
 " to systematically explore the data."
}], "Text"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ElementData", "[", 
            RowBox[{"i", ",", "x"}], "]"}], ",", 
           RowBox[{"ElementData", "[", 
            RowBox[{"i", ",", "y"}], "]"}]}], "}"}], ",", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{"i", ",", "\"\< \>\"", ",", 
            RowBox[{"ElementData", "[", "i", "]"}]}], "}"}], "]"}]}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "118"}], "}"}]}], "]"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "\"\<AtomicNumber\>\""}], "}"}], ",", 
     RowBox[{"ElementData", "[", "\"\<Properties\>\"", "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"y", ",", "\"\<Density\>\""}], "}"}], ",", 
     RowBox[{"ElementData", "[", "\"\<Properties\>\"", "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"props", "=", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{"ElementData", "[", "\"\<Properties\>\"", "]"}], ",", 
       RowBox[{
        RowBox[{"NumberQ", "[", 
         RowBox[{"ElementData", "[", 
          RowBox[{"4", ",", "#"}], "]"}], "]"}], "&"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"Manipulate", "[", 
    RowBox[{
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ElementData", "[", 
              RowBox[{"z", ",", 
               RowBox[{"props", "[", 
                RowBox[{"[", 
                 RowBox[{"p", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
             
             RowBox[{"ElementData", "[", 
              RowBox[{"z", ",", 
               RowBox[{"props", "[", 
                RowBox[{"[", 
                 RowBox[{"p", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"ElementData", "[", "z", "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "118"}], "}"}]}], "]"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ElementData", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"props", "[", 
                  RowBox[{"[", 
                   RowBox[{"p", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", 
                 "\"\<Description\>\""}], "]"}], ",", "\"\<  \>\"", ",", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ElementData", "[", 
                  RowBox[{"1", ",", 
                   RowBox[{"props", "[", 
                    RowBox[{"[", 
                    RowBox[{"p", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}], ",", 
                   "\"\<UnitsNotation\>\""}], "]"}], "/.", 
                 RowBox[{
                  RowBox[{"_Missing", "|", "_ElementData"}], "\[Rule]", 
                  "\"\<\>\""}]}], ")"}]}], "}"}], "]"}], ",", "Null"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"ElementData", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"props", "[", 
                  RowBox[{"[", 
                   RowBox[{"p", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                 "\"\<Description\>\""}], "]"}], ",", "\"\<  \>\"", ",", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ElementData", "[", 
                  RowBox[{"1", ",", 
                   RowBox[{"props", "[", 
                    RowBox[{"[", 
                    RowBox[{"p", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], ",", 
                   "\"\<UnitsNotation\>\""}], "]"}], "/.", 
                 RowBox[{
                  RowBox[{"_Missing", "|", "_ElementData"}], "\[Rule]", 
                  "\"\<\>\""}]}], ")"}]}], "}"}], "]"}], ",", "Null"}], 
           "}"}]}], "}"}]}], ",", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"90", ",", "15"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"50", ",", "20"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Blue"}], "]"}]}]}],
       "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"p", ",", 
         RowBox[{"{", 
          RowBox[{"17", ",", "45"}], "}"}], ",", "\"\<Properties\>\""}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Length", "[", "props", "]"}], ",", 
         RowBox[{"Length", "[", "props", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: IsotopeData", "Section"],

Cell["\<\
Static and decay properties of all nuclear isotopes.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "IsotopeData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["IsotopeData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "3182", 
     RowBox[{"{", 
      RowBox[{"\<\"Tellurium113\"\>", ",", "\<\"Technetium91\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "33", 
     RowBox[{"{", 
      RowBox[{"\<\"FullSymbol\"\>", ",", "\<\"StandardName\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "47", 
     RowBox[{"{", 
      RowBox[{"\<\"BetaPlusDelayedAlphaEmission\"\>", 
       ",", "\<\"BetaDelayedTritonEmission\"\>", ",", "\<\"\[Ellipsis]\"\>"}],
       "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of IsotopeData", "PictureCaption"],

Cell["Find the distribution of lifetimes.", "MathCaption",
 CellChangeTimes->{{3.4191683133766003`*^9, 3.4191683138115997`*^9}}],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"-", "30"}], ",", "30"}], "}"}]}], "]"}], ",", 
      RowBox[{"BinCounts", "[", 
       RowBox[{
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Log", "[", 
             RowBox[{"10", ",", 
              RowBox[{"IsotopeData", "[", 
               RowBox[{"#", ",", "\"\<Lifetime\>\""}], "]"}]}], "]"}], "&"}], 
           "/@", 
           RowBox[{"IsotopeData", "[", "]"}]}], ",", "_Real"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "30.5"}], ",", "30.5", ",", "1"}], "}"}]}], "]"}]}], 
     "}"}], "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Axes", "\[Rule]", "None"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SubscriptBox[\(log\), \(10\)]\) \[Tau]\>\"", ",", "None"}], 
     "}"}]}]}], "]"}]], "Input",
 CellID->977521728],

Cell["Make an isotope chart of lifetimes.", "MathCaption",
 CellChangeTimes->{{3.4191683177706003`*^9, 3.4191683181436*^9}}],

Cell[BoxData[
 RowBox[{"g", "=", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "-", "z"}], ",", "z", ",", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"IsotopeData", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"z", ",", "a"}], "}"}], ",", "\"\<Lifetime\>\""}], 
          "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "1", ",", "118"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"IsotopeData", "[", 
          RowBox[{"#", ",", "\"\<MassNumber\>\""}], "]"}], "&"}], "/@", 
        RowBox[{"IsotopeData", "[", "z", "]"}]}]}], "}"}]}], "]"}], "//", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"#", ",", "1"}], "]"}], "&"}]}]}]], "Input",
 CellID->12496365],

Cell[TextData[{
 "Number of neutrons (",
 Cell[BoxData[
  FormBox["N", TraditionalForm]]],
 ") on the horizontal axis and the number of protons (",
 Cell[BoxData[
  FormBox["Z", TraditionalForm]]],
 ") on the vertical axis; color codes lifetime."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"ListDensityPlot", "[", 
  RowBox[{"g", ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<N\>\"", ",", "\"\<Z\>\""}], "}"}]}]}], "]"}]], "Input"],

Cell["\<\
Draw a decay network for those isotopes with a mass number between 100 and \
102.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"is", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"IsotopeData", "[", "]"}], ",", 
     RowBox[{
      RowBox[{"100", "\[LessEqual]", 
       RowBox[{"IsotopeData", "[", 
        RowBox[{"#1", ",", "\"\<MassNumber\>\""}], "]"}], "\[LessEqual]", 
       "102"}], "&"}]}], "]"}]}], ";"}]], "Input",
 CellID->303285230],

Cell[BoxData[
 RowBox[{"LayeredGraphPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"IsotopeData", "[", 
             RowBox[{"#1", ",", "\"\<Symbol\>\""}], "]"}], "&"}], ")"}], "/@", 
          RowBox[{"(", 
           RowBox[{"i", "\[Rule]", "#1"}], ")"}]}], "&"}], ")"}], "/@", 
       RowBox[{"IsotopeData", "[", 
        RowBox[{"i", ",", "\"\<DaughterNuclides\>\""}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "is"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"DirectedEdges", "\[Rule]", "True"}], ",", 
   RowBox[{"VertexLabeling", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellID->1336166279],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: ChemicalData", "Section"],

Cell["\<\
Structural, physical and other properties of chemical compounds.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "ChemicalData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["ChemicalData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "43987", 
     RowBox[{"{", 
      RowBox[{"\<\"Bio5AMP\"\>", ",", "\<\"IodinePentafluoride\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "101", 
     RowBox[{"{", 
      RowBox[{"\<\"LowerExplosiveLimit\"\>", ",", "\<\"RTECSClasses\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "131", 
     RowBox[{"{", 
      RowBox[{"\<\"LewisBases\"\>", ",", "\<\"CalciumCarbonatePolymorphs\"\>",
        ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of ChemicalData", "PictureCaption"],

Cell["Use string patterns to find a compound.", "MathCaption",
 CellChangeTimes->{{3.4191682312455997`*^9, 3.4191682316586*^9}}],

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{
   RowBox[{"ChemicalData", "[", "\"\<*chloro*\>\"", "]"}], ",", "10"}], 
  "]"}]], "Input"],

Cell["Find the melting point of ibuprofen.", "MathCaption",
 CellChangeTimes->{{3.4191682337376003`*^9, 3.4191682343506002`*^9}}],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", 
  RowBox[{"\"\<Ibuprofen\>\"", ",", "\"\<MeltingPoint\>\""}], "]"}]], "Input"],

Cell["Find the structure diagram for riboflavin.", "MathCaption",
 CellChangeTimes->{{3.4191682385495996`*^9, 3.4191682392595997`*^9}}],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", "\"\<Riboflavin\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", 
  RowBox[{"\"\<Riboflavin\>\"", ",", "\"\<EdgeRules\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", 
  RowBox[{"\"\<Riboflavin\>\"", ",", "\"\<VertexTypes\>\""}], "]"}]], "Input"],

Cell["\<\
Find the 3D molecular structure for the cholesterol molecule.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", 
  RowBox[{"\"\<Cholesterol\>\"", ",", "\"\<MoleculePlot\>\""}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"ChemicalData", "[", 
  RowBox[{"\"\<Cholesterol\>\"", ",", "\"\<AtomPositions\>\""}], 
  "]"}]], "Input"],

Cell[TextData[{
 "Create a table of various chemical properties (code for ",
 StyleBox["ChemicalTable", "MR"],
 " at end of notebook)."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"ChemicalTable", "[", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Cyclohexanol\>\"", ",", "\"\<Acetone\>\"", ",", 
    "\"\<DiethylEther\>\"", ",", "\"\<Tetrahydrofuran\>\"", ",", 
    "\"\<DimethylSulfoxide\>\""}], "}"}], "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: GenomeData", "Section"],

Cell["\<\
Access the nearly 40,000 genes from the human genome.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "GenomeData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["GenomeData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "39920", 
     RowBox[{"{", 
      RowBox[{"\<\"LOC100134290\"\>", ",", "\<\"LOC100129705\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "41", 
     RowBox[{"{", 
      RowBox[{"\<\"BiologicalProcesses\"\>", 
       ",", "\<\"GBandStainingCodes\"\>", ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "188", 
     RowBox[{"{", 
      RowBox[{"\<\"Transcription\"\>", ",", "\<\"Microsome\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of GenomeData", "PictureCaption"],

Cell["Here are the genes on human chromosome 22:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GenomeData", "[", "\"\<Chromosome22Genes\>\"", "]"}]], "Input"],

Cell["And here is one particular gene from this chromosome:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GenomeData", "[", "\"\<C22CTA250D109\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"GenomeData", "[", 
  RowBox[{"\"\<C22CTA250D109\>\"", ",", "\"\<SequenceLength\>\""}], 
  "]"}]], "Input"],

Cell["Find the 15 shortest genes in the human genome:", "MathCaption",
 CellID->21466432],

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{
   RowBox[{"Sort", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GenomeData", "[", 
         RowBox[{"#", ",", "\"\<SequenceLength\>\""}], "]"}], ",", "#"}], 
       "}"}], "&"}], "/@", 
     RowBox[{"GenomeData", "[", "]"}]}], "]"}], ",", "15"}], "]"}]], "Input",
 CellID->137344771],

Cell["\<\
This finds the positions on the human genome at which this DNA sequence \
occurs.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"GenomeLookup", "[", "\"\<CTCTCTAACTAAAT\>\"", "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: WeatherData", "Section"],

Cell[TextData[{
 "Access over ",
 Cell[BoxData[
  FormBox["21000", TraditionalForm]]],
 " weather stations around the world; current and historical data."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "WeatherData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["WeatherData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "21922", 
     RowBox[{"{", 
      RowBox[{"\<\"WMO67979\"\>", ",", "\<\"C6163\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "43", 
     RowBox[{"{", 
      RowBox[{"\<\"AlternateStandardNames\"\>", 
       ",", "\<\"MeanTemperature\"\>", ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "4", 
     RowBox[{"{", 
      RowBox[{"\<\"NCDC\"\>", ",", "\<\"WBAN\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of WeatherData", "PictureCaption"],

Cell["\<\
Get information for Champaign IL using either the city name, a specific \
weather station, or latitude/longitude coordinates.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"\"\<Champaign\>\"", ",", "\"\<Temperature\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"\"\<KCMI\>\"", ",", "\"\<WindSpeed\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"coords", "=", 
  RowBox[{"CityData", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<Champaign\>\"", ",", "\"\<Illinois\>\"", ",", 
      "\"\<UnitedStates\>\""}], "}"}], ",", "\"\<Coordinates\>\""}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"WeatherData", "[", 
  RowBox[{"coords", ",", "\"\<Humidity\>\""}], "]"}]], "Input"],

Cell["Range of daily temperatures for the past six months.", "MathCaption",
 CellChangeTimes->{{3.4792262228255453`*^9, 3.479226223041026*^9}}],

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"WeatherData", "[", 
       RowBox[{"\"\<KCMI\>\"", ",", "#1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"DateString", "[", 
           RowBox[{"DatePlus", "[", 
            RowBox[{"-", "180"}], "]"}], "]"}], ",", 
          RowBox[{"DateString", "[", 
           RowBox[{"DatePlus", "[", "0", "]"}], "]"}], ",", "\"\<Day\>\""}], 
         "}"}]}], "]"}], "&"}], ")"}], "/@", 
    RowBox[{"{", 
     RowBox[{
     "\"\<MeanTemperature\>\"", ",", "\"\<MaxTemperature\>\"", ",", 
      "\"\<MinTemperature\>\""}], "}"}]}], ",", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"True", ",", "False", ",", "False"}], "}"}]}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"2", "\[Rule]", 
      RowBox[{"{", "3", "}"}]}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4792262193992567`*^9, 3.4792262195892897`*^9}}],

Cell["\<\

\
\>", "Spacer"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: FinancialData", "Section"],

Cell["\<\
Current and historical financial and economic data from all over the world.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "FinancialData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["FinancialData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "145503", 
     RowBox[{"{", 
      RowBox[{"\<\"F:3AC\"\>", ",", "\<\"NYM:KIQ11\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "74", 
     RowBox[{"{", 
      RowBox[{"\<\"CumulativeFractionalChange\"\>", 
       ",", "\<\"DividendYield\"\>", ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "8", 
     RowBox[{"{", 
      RowBox[{"\<\"Indices\"\>", ",", "\<\"Currencies\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of FinancialData", "PictureCaption"],

Cell["\<\
Find the current net asset value for the Vanguard Windsor II fund.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"FinancialData", "[", "\"\<VWNFX\>\"", "]"}]], "Input"],

Cell["Plot the log of the S&P500 for all available dates:", "MathCaption",
 CellID->16278858],

Cell[BoxData[
 RowBox[{"DateListLogPlot", "[", 
  RowBox[{"FinancialData", "[", 
   RowBox[{"\"\<SP500\>\"", ",", "All"}], "]"}], "]"}]], "Input"],

Cell["\<\
Find members of the Dow Jones Industrial Average with low 50-day volatilities:\
\>", "MathCaption",
 CellID->110245438],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"FinancialData", "[", 
     RowBox[{"\"\<^DJI\>\"", ",", "\"\<Members\>\""}], "]"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"FinancialData", "[", 
       RowBox[{"#", ",", "\"\<Volatility50Day\>\""}], "]"}], "<", "0.20"}], 
     "&"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FinancialData", "[", 
    RowBox[{"#", ",", "\"\<StandardName\>\""}], "]"}], "&"}], "/@", 
  "%"}]}], "Input",
 CellID->26927731],

Cell["First few members of the Frankfurt exchange:", "MathCaption",
 CellID->33817476],

Cell[BoxData[
 RowBox[{"frankMems", "=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"FinancialData", "[", 
     RowBox[{"\"\<Frankfurt\>\"", ",", "\"\<Members\>\""}], "]"}], ",", 
    "10"}], "]"}]}]], "Input",
 CellID->6430592],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FinancialData", "[", 
    RowBox[{"#", ",", "\"\<StandardName\>\""}], "]"}], "&"}], "/@", 
  "frankMems"}]], "Input"],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell["\<\
Plot cumulative returns for various mutual funds from 1996 to the present.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"VanguardFunds", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\"\<VFINX\>\"", ",", "\"\<VEXPX\>\"", ",", "\"\<VWNFX\>\"", ",", 
     "\"\<VWUSX\>\""}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"data", "=", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"FinancialData", "[", 
        RowBox[{"#", ",", "\"\<CumulativeReturn\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"1996", ",", "1", ",", "1"}], "}"}], ",", 
           RowBox[{"DatePlus", "[", "0", "]"}]}], "}"}]}], "]"}], ",", "#"}], 
      "]"}], "&"}], "/@", "VanguardFunds"}]}], ";"}], "\n", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Bottom"}]}], "]"}]}], "Input"],

Cell["\<\
Plot closing prices for the Nikkei 225 together with highs and lows for each \
day for the past 120 days.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FinancialData", "[", 
       RowBox[{"\"\<^N225\>\"", ",", "#1", ",", 
        RowBox[{"DatePlus", "[", 
         RowBox[{"-", "120"}], "]"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<High\>\"", ",", "\"\<Low\>\"", ",", "\"\<Close\>\""}], 
      "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"False", ",", "False", ",", "True"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", "\[Rule]", 
      RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
   RowBox[{"FillingStyle", "\[Rule]", "Brown"}]}], "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: WordData", "Section"],

Cell["\<\
Access built-in multilingual dictionaries, information on word meaning, \
structure and usage, as well as the relationship between words.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "WordData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["WordData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "149191", 
     RowBox[{"{", 
      RowBox[{"\<\"gyroplane\"\>", ",", "\<\"libertarianism\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "37", 
     RowBox[{"{", 
      RowBox[{"\<\"MorphologicalDerivatives\"\>", 
       ",", "\<\"SimilarAdjectives\"\>", ",", "\<\"\[Ellipsis]\"\>"}], 
      "}"}]},
    {"\<\"Classes\"\>", "10", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\<\"Interjection\"\>", "\[Rule]", "9"}], ",", 
       RowBox[{"\<\"Conjunction\"\>", "\[Rule]", "6"}], 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of WordData", "PictureCaption"],

Cell["Examples:", "MathCaption"],

Cell[BoxData[
 RowBox[{"WordData", "[", "\"\<read\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WordData", "[", 
   RowBox[{"\"\<read\>\"", ",", "\"\<Definitions\>\""}], "]"}], "//", 
  "TableForm"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"WordData", "[", 
   RowBox[{"\"\<increase\>\"", ",", "\"\<Synonyms\>\""}], "]"}], "//", 
  "TableForm"}]], "Input"],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell["Hyphenation:", "Text"],

Cell[BoxData[
 RowBox[{"wddata", "=", 
  RowBox[{"WordData", "[", 
   RowBox[{"\"\<innovation\>\"", ",", "\"\<Hyphenation\>\""}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"StringJoin", ",", 
   RowBox[{"Riffle", "[", 
    RowBox[{"wddata", ",", "\"\<-\>\""}], "]"}]}], "]"}]], "Input"],

Cell["De-Britishification:", "MathCaption"],

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Outer", "[", 
    RowBox[{"WordData", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<color\>\"", ",", "\"\<curb\>\"", ",", "\"\<metre\>\"", ",", 
       "\"\<tire\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<AmericanSpelling\>\"", ",", "\"\<BritishSpelling\>\""}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<American\>\"", ",", "\"\<British\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input"],

Cell[TextData[{
 "Create a list of words in ",
 ButtonBox["WordData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/WordData"],
 " for which the American spelling is different than the British spelling."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{"Shallow", "[", 
  RowBox[{"brit", "=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"WordData", "[", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"WordData", "[", 
        RowBox[{"#", ",", "\"\<AmericanSpelling\>\""}], "]"}], "\[NotEqual]", 
       
       RowBox[{"WordData", "[", 
        RowBox[{"#", ",", "\"\<BritishSpelling\>\""}], "]"}]}], "&"}]}], 
    "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{"brit", ",", 
   RowBox[{
    RowBox[{"StringMatchQ", "[", 
     RowBox[{"#", ",", "\"\<colo*\>\""}], "]"}], "&"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"brit2amer", "=", 
   RowBox[{"Rule", "@@@", 
    RowBox[{"Union", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"WordData", "[", 
          RowBox[{"#", ",", "\"\<BritishSpelling\>\""}], "]"}], ",", 
         RowBox[{"WordData", "[", 
          RowBox[{"#", ",", "\"\<AmericanSpelling\>\""}], "]"}]}], "}"}], 
       "&"}], "/@", "brit"}], "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "str", "=", 
   "\"\<When I parked my car at the freshly painted kerb next to the parking \
metre I got paint on my tyre and changed its colour\>\""}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"StringJoin", "@@", 
  RowBox[{"Riffle", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"StringSplit", "[", "str", "]"}], "/.", "brit2amer"}], ",", 
    "\"\< \>\""}], "]"}]}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: DictionaryLookup", "Section"],

Cell["Find words in dictionaries.", "Text"],

Cell["Scope: available dictionaries.", "MathCaption"],

Cell[BoxData[
 RowBox[{"DictionaryLookup", "[", "All", "]"}]], "Input",
 CellID->781000318],

Cell["Usage.", "MathCaption"],

Cell[BoxData[
 RowBox[{"?", "DictionaryLookup"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DictionaryLookup", "[", "]"}], "//", "Length"}]], "Input"],

Cell[BoxData[
 RowBox[{"DictionaryLookup", "[", "\"\<lemo*\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DictionaryLookup", "[", 
  RowBox[{"\"\<lemo*\>\"", ",", "4"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"DictionaryLookup", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<Spanish\>\"", ",", 
    RowBox[{
    "\"\<a\>\"", "~~", "__", "~~", "\"\<\[NTilde]\>\"", "~~", "__", "~~", 
     "\"\<r\>\""}]}], "}"}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell["Palindromes:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Palindromes", "[", "len_Integer", "]"}], ":=", 
  RowBox[{"DictionaryLookup", "[", 
   RowBox[{"x__", "/;", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", "==", 
       RowBox[{"StringReverse", "[", "x", "]"}]}], " ", "&&", " ", 
      RowBox[{
       RowBox[{"StringLength", "[", "x", "]"}], "\[Equal]", "len"}]}], 
     ")"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Palindromes", "[", "5", "]"}]], "Input"],

Cell["Anagrams:", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Anagrams", "[", "str_String", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", "=", 
      RowBox[{"Sort", "[", 
       RowBox[{"Characters", "[", "str", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"DictionaryLookup", "[", 
     RowBox[{"x__", "/;", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"Characters", "[", "x", "]"}], "]"}], "\[Equal]", "c"}]}], 
     "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"Anagrams", "[", "\"\<elvis\>\"", "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: GraphData", "Section"],

Cell["\<\
Access properties of named and enumerated graphs.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "GraphData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["GraphData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "5326", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\<\"Turan\"\>", ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "8"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\<\"Fullerene\"\>", ",", 
         RowBox[{"{", 
          RowBox[{"48", ",", "157"}], "}"}]}], "}"}], 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Properties\"\>", "282", 
     RowBox[{"{", 
      RowBox[{"\<\"Triangulated\"\>", ",", "\<\"Square\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "163", 
     RowBox[{"{", 
      RowBox[{"\<\"FiveleapersTour\"\>", ",", "\<\"Circulant\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of GraphData", "PictureCaption"],

Cell["\<\
Characteristic polynomials for Foster (cubic symmetric) graphs.\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphData", "[", "\"\<Foster*\>\"", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GraphData", "[", 
    RowBox[{"\"\<Foster098A\>\"", ",", "\"\<CharacteristicPolynomial\>\""}], 
    "]"}], "[", "x", "]"}], "//", "TraditionalForm"}]], "Input",
 CellChangeTimes->{{3.4191710668816*^9, 3.4191710844056*^9}}],

Cell["Compare its 2D representation and its toric structure in 3D.", \
"MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GraphData", "[", 
      RowBox[{"\"\<Foster098A\>\"", ",", "\"\<Image\>\""}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"GraphPlot3D", "[", 
      RowBox[{
       RowBox[{"GraphData", "[", 
        RowBox[{"\"\<Foster098A\>\"", ",", "\"\<EdgeRules\>\""}], "]"}], ",", 
       
       RowBox[{"Boxed", "\[Rule]", "False"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input"],

Cell[TextData[{
 "Look at all graphs and properties. (The function ",
 StyleBox["CollapseFriends", "MR"],
 " is defined at the end of this notebook.)"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Friends", "=", 
   RowBox[{"First", "/@", 
    RowBox[{"Split", "[", 
     RowBox[{
      RowBox[{"GraphData", "[", "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"CollapseFriends", "[", "#1", "]"}], "\[Equal]", 
        RowBox[{"CollapseFriends", "[", "#2", "]"}]}], "&"}]}], "]"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"GraphData", "[", "g", "]"}], ",", 
      RowBox[{"GraphData", "[", 
       RowBox[{"g", ",", "p"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"g", ",", "Friends"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"Complement", "@@", 
      RowBox[{"GraphData", "/@", 
       RowBox[{"{", 
        RowBox[{"\"\<Properties\>\"", ",", "\"\<Classes\>\""}], "}"}]}]}]}], 
    "}"}]}], "]"}]], "Input",
 CellID->95596341],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell["Embeddings:", "Text"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"GraphData", "[", 
      RowBox[{"\"\<TesseractGraph\>\"", ",", "\"\<AllImages\>\""}], "]"}], 
     ",", "6"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"10", " ", "72"}]}]}], "]"}]], "Input"],

Cell["Find out more:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphData", "[", 
  RowBox[{"\"\<TesseractGraph\>\"", ",", "\"\<Information\>\""}], 
  "]"}]], "Input"],

Cell["Tables of graphs with known embeddings:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Tooltip", "@@", 
         RowBox[{"GraphData", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<Image\>\"", ",", "\"\<Name\>\""}], "}"}]}], "]"}]}], 
        ")"}], "&"}], "/@", 
      RowBox[{"Take", "[", 
       RowBox[{
        RowBox[{"GraphData", "[", 
         RowBox[{"\"\<VertexCoordinates\>\"", ",", "\"\<Defined\>\""}], "]"}],
         ",", "60"}], "]"}]}], ",", "10"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Examples: PolyhedronData", "Section"],

Cell["\<\
Geometry and properties of polyhedra.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DataTable", "[", "PolyhedronData", "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["PolyhedronData", "Section",
      StripOnInput->False,
      FontFamily->"Lucida Grande",
      FontSize->18], "\[SpanFromLeft]", "\[SpanFromLeft]"},
    {"\<\"\"\>", \
"\<\"\\!\\(\\*\\nStyleBox[\\\"Length\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\>\
", "\<\"\\!\\(\\*\\nStyleBox[\\\"Examples\\\",\\nFontSlant->\\\"Italic\\\"]\\)\
\"\>"},
    {"\<\"Entities\"\>", "195", 
     RowBox[{"{", 
      RowBox[{"\<\"GyroelongatedTriangularCupola\"\>", 
       ",", "\<\"RhombicHexecontahedron\"\>", ",", "\<\"\[Ellipsis]\"\>"}], 
      "}"}]},
    {"\<\"Properties\"\>", "98", 
     RowBox[{"{", 
      RowBox[{"\<\"Amphichiral\"\>", ",", "\<\"Pyramid\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]},
    {"\<\"Classes\"\>", "33", 
     RowBox[{"{", 
      RowBox[{"\<\"Platonic\"\>", ",", "\<\"Simplex\"\>", 
       ",", "\<\"\[Ellipsis]\"\>"}], "}"}]}
   },
   AutoDelete->False,
   BaseStyle->{"Menu", FontSize -> 16},
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "Rows" -> {{Baseline}}, 
     "ItemsIndexed" -> {{3, 1} -> {Left, Inherited}, {5, 1} -> {
        Left, Inherited}}},
   GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {
       RGBColor[0.9, 0.9, 0.9], {
        GrayLevel[1], 
        RGBColor[0.95, 0.9, 0.95]}}},
   GridBoxDividers->{"Columns" -> {
       RGBColor[0.2, 0.2, 0.2], {
        RGBColor[0.75, 0.75, 0.75]}, 
       RGBColor[0.2, 0.2, 0.2]}, "Rows" -> {
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], 
       RGBColor[0.2, 0.2, 0.2], {False}, 
       RGBColor[0.2, 0.2, 0.2]}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1.25}}}],
  "Grid"]], "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 GeneratedCell->True,
 CellAutoOverwrite->True]
}, {2}]],

Cell["Scope of PolyhedronData", "PictureCaption"],

Cell["Solids:", "MathCaption"],

Cell[BoxData[
 RowBox[{"PolyhedronData", "[", "\"\<Platonic\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.4191714458826*^9, 3.4191714810716*^9}}],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"#", ",", "\"\<Image\>\""}], "]"}], ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"PolyhedronData", "[", 
           RowBox[{"#", ",", "\"\<Name\>\""}], "]"}], ",", "14"}], "]"}]}]}], 
      "]"}], "&"}], "/@", 
    RowBox[{"PolyhedronData", "[", "\"\<Platonic\>\"", "]"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "1024"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Friends", "=", 
   RowBox[{"First", "/@", 
    RowBox[{"Split", "[", 
     RowBox[{
      RowBox[{"PolyhedronData", "[", "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"CollapseFriends", "[", "#1", "]"}], "\[Equal]", 
        RowBox[{"CollapseFriends", "[", "#2", "]"}]}], "&"}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellTags->"DecayNetworkPlot"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PolyhedronData", "[", "g", "]"}], ",", 
      RowBox[{"PolyhedronData", "[", 
       RowBox[{"g", ",", "p"}], "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"g", ",", "Friends"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"Complement", "@@", 
      RowBox[{"PolyhedronData", "/@", 
       RowBox[{"{", 
        RowBox[{"\"\<Properties\>\"", ",", "\"\<Classes\>\""}], "}"}]}]}]}], 
    "}"}]}], "]"}]], "Input",
 CellID->2001766748],

Cell[CellGroupData[{

Cell["More examples", "MoreExamplesSection"],

Cell["Dual compounds.", "Text"],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PolyhedronData", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<PentagonalHexecontahedron\>\"", ",", "#"}], "}"}], ",", 
      "\"\<Faces\>\""}], "]"}], "&"}], "/@", 
   RowBox[{"{", 
    RowBox[{"\"\<Laevo\>\"", ",", "\"\<Dextro\>\""}], "}"}]}], "]"}]], "Input",\

 CellID->1241146727],

Cell["Nets:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"Partition", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"PolyhedronData", "[", 
           RowBox[{"#", ",", "\"\<NetImage\>\""}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"PolyhedronData", "[", 
          RowBox[{"#", ",", "\"\<Image\>\""}], "]"}]}], "]"}], "]"}], "&"}], "/@", 
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<NetImage\>\"", ",", "\"\<Defined\>\""}], "]"}]}], ",", 
    "20"}], "]"}], "]"}]], "Input",
 CellID->796903008],

Cell["Skeletons:", "MathCaption"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{"Tooltip", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"PolyhedronData", "[", 
            RowBox[{"#", ",", "\"\<SkeletonImage\>\""}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"PolyhedronData", "[", 
           RowBox[{"#", ",", "\"\<Name\>\""}], "]"}]}], "]"}], "]"}], "&"}], "/@", 
      RowBox[{"PolyhedronData", "[", 
       RowBox[{"\"\<SkeletonImage\>\"", ",", "\"\<Defined\>\""}], "]"}]}], 
     ",", "20"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]], "Input"],

Cell["\<\

\
\>", "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Tips & Tricks", "Section"],

Cell["\<\
In this section we provide several tips that you might find useful in working \
with the data collections.\
\>", "Text",
 CellChangeTimes->{{3.479218892591113*^9, 3.4792189164066963`*^9}}],

Cell[CellGroupData[{

Cell["Programming tip", "MoreExamplesSection",
 CellChangeTimes->{{3.479218926529038*^9, 3.4792189269192677`*^9}, {
  3.4792189652025223`*^9, 3.479218971689074*^9}, {3.479225939657831*^9, 
  3.4792259413839617`*^9}}],

Cell[TextData[{
 "Use ",
 ButtonBox["Outer",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Outer"],
 " to get several properties for a set of entities. For example, here are the \
population, GDP, and life expectancy for four different countries."
}], "Text"],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Outer", "[", 
   RowBox[{"CountryData", ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Canada\>\"", ",", "\"\<Sweden\>\"", ",", "\"\<Thailand\>\"", ",", 
      "\"\<Egypt\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<GDP\>\"", ",", "\"\<LifeExpectancy\>\"", ",", 
      "\"\<Population\>\""}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4792259812208433`*^9, 3.479226042830393*^9}, {
  3.479226120602969*^9, 3.479226128648849*^9}}],

Cell[BoxData[
 RowBox[{"BubbleChart", "[", "data", "]"}]], "Input",
 CellChangeTimes->{{3.479226093543871*^9, 3.47922609710213*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Screens", "MoreExamplesSection",
 CellChangeTimes->{{3.479218926529038*^9, 3.4792189269192677`*^9}, {
  3.4792189652025223`*^9, 3.479218971689074*^9}, {3.479225939657831*^9, 
  3.4792259413839617`*^9}, {3.479226595039057*^9, 3.479226603164487*^9}, {
  3.479227275017395*^9, 3.479227278900021*^9}}],

Cell["\<\
You can use pattern matching to screen entities based on some criteria you \
are interested in. For example, the following computations find those \
countries for which there is no information giving the fraction of the \
population living in poverty.\
\>", "Text",
 CellChangeTimes->{{3.479226606789041*^9, 3.47922660754871*^9}, {
  3.479226982057704*^9, 3.479227045673695*^9}, {3.479227289746073*^9, 
  3.479227290393297*^9}}],

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{"CountryData", "[", 
        RowBox[{"#", ",", "\"\<PovertyFraction\>\""}], "]"}]}], "}"}], "&"}], 
    ",", 
    RowBox[{"CountryData", "[", "All", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.479226635646509*^9, 3.479226770051619*^9}}],

Cell["\<\
Here is the list of countries for which this data is missing.\
\>", "MathCaption",
 CellChangeTimes->{{3.4792268367810783`*^9, 3.47922684489189*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cases", "[", 
   RowBox[{"data", ",", 
    RowBox[{"{", 
     RowBox[{"country_", ",", "_Missing"}], "}"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4792267864718018`*^9, 3.4792268269333887`*^9}, {
  3.479226860062435*^9, 3.479226862735421*^9}}],

Cell["\<\
Alternately, here is the list of countries for which we do have the data.\
\>", "MathCaption",
 CellChangeTimes->{{3.479226881054346*^9, 3.479226893797118*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteCases", "[", 
   RowBox[{"data", ",", 
    RowBox[{"{", 
     RowBox[{"country_", ",", "_Missing"}], "}"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"All", ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.479226874455785*^9, 3.479226875270447*^9}}],

Cell["\<\
Screen stocks from biotech firms based on PEG and PE ratios (may take a while \
to compute).\
\>", "MathCaption",
 CellID->12442663],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"FinancialData", "[", 
     RowBox[{"\"\<Biotechnology\>\"", ",", "\"\<Members\>\""}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"FinancialData", "[", 
        RowBox[{"#", ",", "\"\<PEGRatio\>\""}], "]"}], "<", "1.5"}], "&&", 
      RowBox[{
       RowBox[{"FinancialData", "[", 
        RowBox[{"#", ",", "\"\<PERatio\>\""}], "]"}], "<", "25"}]}], "&"}]}], 
   "]"}], "//", "Quiet"}]], "Input",
 CellID->251992734],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"NASDAQ:CBPO\"\>", ",", "\<\"NASDAQ:GILD\"\>", 
   ",", "\<\"NASDAQ:JAZZ\"\>", ",", "\<\"NASDAQ:PDLI\"\>", 
   ",", "\<\"NYSE:AOB\"\>", ",", "\<\"NYSE:CBM\"\>", 
   ",", "\<\"NYSE:MRX\"\>"}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"FinancialData", "[", 
    RowBox[{"#", ",", " ", "\"\<Name\>\""}], "]"}], " ", "&"}], " ", "/@", 
  " ", "%"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"China Biologic Products, Incorporated\"\>", 
     ",", "\<\"Name\"\>"}], "]"}], ",", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"Gilead Sciences, Inc.\"\>", ",", "\<\"Name\"\>"}], "]"}], 
   ",", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"Jazz Pharmaceuticals, Inc.\"\>", ",", "\<\"Name\"\>"}], 
    "]"}], ",", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"PDL BioPharma, Inc.\"\>", ",", "\<\"Name\"\>"}], "]"}], ",", 
   
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"American Oriental Bioengineering, Inc.\"\>", 
     ",", "\<\"Name\"\>"}], "]"}], ",", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"Cambrex Corporation\"\>", ",", "\<\"Name\"\>"}], "]"}], ",", 
   
   RowBox[{"FinancialData", "[", 
    RowBox[{"\<\"Medicis Pharmaceuticals Corporation\"\>", 
     ",", "\<\"Name\"\>"}], "]"}]}], "}"}]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Where are the caches?", "MoreExamplesSection",
 CellChangeTimes->{{3.479218926529038*^9, 3.4792189269192677`*^9}, {
  3.4792189652025223`*^9, 3.479218971689074*^9}}],

Cell["\<\
Here is the directory where the data is stored on your computer.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"SystemOpen", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"$UserBaseDirectory", ",", "\"\<Paclets\>\""}], "}"}], "]"}], 
  "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rebuild the caches", "MoreExamplesSection",
 CellChangeTimes->{{3.479218998859424*^9, 3.479219002145884*^9}}],

Cell["\<\
Occasionally you might want to rebuild the cached paclet information. The \
following command rescans the paclet directories and rebuilds the cached \
indexes for each.\
\>", "Text",
 CellChangeTimes->{{3.4792190576620693`*^9, 3.479219101821782*^9}, 
   3.479219142665751*^9}],

Cell[BoxData[
 RowBox[{"RebuildPacletData", "[", "]"}]], "Input",
 CellChangeTimes->{{3.4792175715083227`*^9, 3.4792175846311398`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Turn off automatic updating", "MoreExamplesSection",
 CellChangeTimes->{{3.479219011283986*^9, 3.479219019162472*^9}}],

Cell[TextData[{
 "If you want to force ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to work from your cached directories and avoid automatic updates (useful \
during presentations, for example), you can turn this feature off with an \
internal function."
}], "Text",
 CellChangeTimes->{{3.479219156777095*^9, 3.47921919809746*^9}}],

Cell[BoxData[
 RowBox[{"PacletManager`$AllowDataUpdates", "=", "False"}]], "Input",
 CellChangeTimes->{{3.479217590652417*^9, 3.479217624690936*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Further Resources", "Section"],

Cell[TextData[{
 "Source information is available for the data collections by clicking the \
link at the bottom of the documentation page for each collection. For \
example, source information for ",
 ButtonBox["ElementData",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/ElementData"],
 " can be found at ",
 ButtonBox["reference.wolfram.com/mathematica/note/\
ElementDataSourceInformation.html",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://reference.wolfram.com/mathematica/note/\
ElementDataSourceInformation.html"], None}],
 ". Additional information can be found at these sites:"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Wolfram|Alpha:",
 ButtonBox[" www.wolframalpha.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolframalpha.com"], None},
  ButtonNote->"http://www.wolframalpha.com"]
}], "Item"],

Cell[TextData[{
 "Wolfram Library Archive: ",
 ButtonBox["library.wolfram.com",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://library.wolfram.com"], None}]
}], "Item"],

Cell[TextData[{
 "Training from Wolfram Education Group: ",
 ButtonBox["www.wolfram.com/weg",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/services/education/"], None}]
}], "Item"]
}, Open  ]],

Cell[TextData[{
 "If you have not yet given the latest version of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " a test drive, be sure to check the box provided in the seminar survey, \
indicating you want to download a free trial version of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Initializations", "Section",
 InitializationGroup->True],

Cell[CellGroupData[{

Cell["Colors used in map of Japan", "MoreExamplesSection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DarkOliveGreen", "=", 
   RowBox[{
    RowBox[{"ColorData", "[", "\"\<Legacy\>\"", "]"}], "[", 
    "\"\<DarkOliveGreen\>\"", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Cerulean", "=", 
   RowBox[{
    RowBox[{"ColorData", "[", "\"\<Legacy\>\"", "]"}], "[", 
    "\"\<Cerulean\>\"", "]"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Function for GraphData and PolyhedronData examples", \
"MoreExamplesSection",
 CellTags->"DecayNetworkPlot"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CollapseFriends", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"StringSplit", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", "x", "}"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "DigitCharacter"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellTags->"DecayNetworkPlot",
 CellID->732056656]
}, Closed]],

Cell[CellGroupData[{

Cell["ChemicalTable", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChemicalTable", "[", "chemicals_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"labels", ",", "style", ",", "data", ",", "img"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"labels", "=", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Name\>\"", ",", "\"\<Structural Diagram\>\"", ",", 
        "\"\<Molecular Formula\>\"", ",", "\"\<Molecular Weight\>\"", ",", 
        "\"\<Density (g\[ThinSpace]\!\(\*SuperscriptBox[\(cm\), \
\(-3\)]\))\>\"", ",", "\"\<Dielectric Constant\>\"", ",", 
        "\"\<Boiling Point (\[Degree]C)\>\"", ",", 
        "\"\<Flash Point (\[Degree]C)\>\"", ",", "\"\<NFPA Label\>\""}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"style", ":=", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"#", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontWeight", "\[Rule]", "Bold"}]}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"data", "=", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"ChemicalData", "[", 
            RowBox[{"#", ",", "property"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"property", ",", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Name\>\"", ",", "\"\<ColorStructureDiagram\>\"", ",", 
               "\"\<FormulaDisplay\>\"", ",", "\"\<MolecularWeight\>\"", ",", 
               "\"\<DensityGramsPerCC\>\"", ",", "\"\<DielectricConstant\>\"",
                ",", "\"\<BoilingPoint\>\"", ",", "\"\<FlashPoint\>\"", ",", 
               "\"\<NFPALabel\>\""}], "}"}]}], "}"}]}], "]"}], "&"}], "/@", 
        "chemicals"}], ")"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"img", "=", 
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"Join", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"style", "/@", "labels"}], "}"}], ",", "data"}], "]"}],
             "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Frame", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Background", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"LightYellow", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", "White"}], 
                 "}"}], "}"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Alignment", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Left", ",", 
                RowBox[{"{", "Center", "}"}]}], "}"}], ",", "Center"}], 
             "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "Bold", 
         ",", "13"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"img", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"_", "?", "NumericQ"}]}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", "110"}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", "x_List"}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"1.2", "*", "x"}]}], ")"}]}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["ChemicalProperties", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ChemicalProperties", "[", "chemical_String", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"labels", ",", "style", ",", "data", ",", "result", ",", "img"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"labels", "=", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Name\>\"", ",", "\"\<Structural Diagram\>\"", ",", 
        "\"\<Molecular Formula\>\"", ",", "\"\<Molecular Weight\>\"", ",", 
        "\"\<Density (g\[ThinSpace]\!\(\*SuperscriptBox[\(cm\), \
\(-3\)]\))\>\"", ",", "\"\<Dielectric Constant\>\"", ",", 
        "\"\<Boiling Point (\[Degree]C)\>\"", ",", 
        "\"\<Flash Point (\[Degree]C)\>\"", ",", "\"\<NFPA Label\>\""}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"style", ":=", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"#", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
         RowBox[{"FontWeight", "\[Rule]", "Bold"}]}], "]"}], "&"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"data", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"ChemicalData", "[", 
         RowBox[{"chemical", ",", "#"}], "]"}], "&"}], "/@", 
       RowBox[{"ChemicalData", "[", "\"\<Properties\>\"", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"result", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"style", "/@", 
           RowBox[{"ChemicalData", "[", "\"\<Properties\>\"", "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", "data", "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"img", "=", 
      RowBox[{"Text", "[", 
       RowBox[{"Style", "[", 
        RowBox[{
         RowBox[{"Grid", "[", 
          RowBox[{
           RowBox[{"PrependTo", "[", 
            RowBox[{"result", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<Property\>\"", ",", "chemical"}], "}"}]}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Frame", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Background", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"None", ",", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"GrayLevel", "[", "0.9", "]"}], ",", "White"}], 
                 "}"}], "}"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Alignment", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Left", ",", 
                RowBox[{"{", "Center", "}"}]}], "}"}], ",", "Center"}], 
             "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "Bold", 
         ",", "13"}], "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"img", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"_", "?", "NumericQ"}]}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", "110"}], ")"}]}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", "x_List"}], ")"}], "\[Rule]", 
         RowBox[{"(", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"1.2", "*", "x"}]}], ")"}]}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["DisplayTable", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayCell", "[", "expr_", "]"}], ":=", 
  RowBox[{"CellPrint", "[", 
   RowBox[{"TextCell", "[", 
    RowBox[{"expr", ",", "\"\<DisplayFormula\>\"", ",", 
     RowBox[{"ShowStringCharacters", "\[Rule]", "False"}]}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DisplayTable", "[", 
   RowBox[{"list_List", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "Grid", "]"}]}]}], "]"}], ":=", 
  RowBox[{"DisplayCell", "@", 
   RowBox[{"Grid", "[", 
    RowBox[{"list", ",", "opts", ",", 
     RowBox[{"Dividers", "\[Rule]", "All"}], ",", 
     RowBox[{"Spacings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1.2"}], "}"}]}], ",", 
     RowBox[{"Alignment", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Center", ",", "Center"}], "}"}]}], ",", 
     RowBox[{"BaseStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Verdana\>\""}], "}"}]}], ",", 
     RowBox[{"Background", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Hue", "[", 
            RowBox[{".6", ",", ".15", ",", ".9"}], "]"}], ",", 
           RowBox[{"GrayLevel", "[", ".9", "]"}]}], "}"}], "}"}]}], "}"}]}], 
     ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Thick", ",", "White"}], "]"}]}]}], "]"}]}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["DataTable", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DataTable", "[", "fun_Symbol", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "data", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"data", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"fun", ",", "\"\<Section\>\"", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Lucida Grande\>\""}], ",", 
            RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], ",", 
          "SpanFromLeft"}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<\>\"", ",", "\"\<\!\(\*
StyleBox[\"Length\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"Examples\",
FontSlant->\"Italic\"]\)\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<Entities\>\"", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"fun", "[", "]"}], "]"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{"fun", "[", "]"}], ",", "2"}], "]"}], ",", 
            "\"\<\[Ellipsis]\>\""}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<Properties\>\"", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"fun", "[", "\"\<Properties\>\"", "]"}], "]"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{"fun", "[", "\"\<Properties\>\"", "]"}], ",", "2"}], 
             "]"}], ",", "\"\<\[Ellipsis]\>\""}], "]"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<Classes\>\"", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"fun", "[", "\"\<Classes\>\"", "]"}], "]"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"RandomChoice", "[", 
             RowBox[{
              RowBox[{"fun", "[", "\"\<Classes\>\"", "]"}], ",", "2"}], "]"}],
             ",", "\"\<\[Ellipsis]\>\""}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"CellPrint", "[", 
      RowBox[{"TextCell", "[", 
       RowBox[{
        RowBox[{"Grid", "[", 
         RowBox[{"data", ",", 
          RowBox[{"Frame", "\[Rule]", "All"}], ",", 
          RowBox[{"BaseStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<Menu\>\"", ",", 
             RowBox[{"FontSize", "\[Rule]", "16"}]}], "}"}]}], ",", 
          RowBox[{"Spacings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"1", ",", "1.25"}], "}"}]}], ",", 
          RowBox[{"Alignment", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Center", ",", "Baseline", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "Left"}], ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", "Left"}]}], 
              "}"}]}], "}"}]}], ",", 
          RowBox[{"Background", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"None", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Lighter", "[", 
                RowBox[{"Black", ",", ".9"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"White", ",", 
                 RowBox[{"Lighter", "[", 
                  RowBox[{
                   RowBox[{"Blend", "[", 
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue"}], "}"}], "]"}], ",", ".9"}], 
                  "]"}]}], "}"}]}], "}"}]}], "}"}]}], ",", 
          RowBox[{"Dividers", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"Lighter", "[", 
                 RowBox[{"Gray", ",", ".5"}], "]"}], "}"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}], ",", 
               RowBox[{"{", "False", "}"}], ",", 
               RowBox[{"Darker", "[", 
                RowBox[{"Gray", ",", ".6"}], "]"}]}], "}"}]}], "}"}]}]}], 
         "]"}], ",", "\"\<DisplayDataTable\>\""}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1243, 871},
WindowMargins->{{28, Automatic}, {Automatic, 0}},
WindowTitle->"S21 Working with Data Collections",
ShowSelection->True,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefinitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{84, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontWeight -> "Plain", FontColor -> 
             RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}, FontWeight -> "Plain"]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"]], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          StyleData["DisplayDataTable"], 
          CellMargins -> {{100, 100}, {20, 20}}, ShowStringCharacters -> 
          False], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontFamily -> "Helvetica", 
             FontSize -> 17]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]]}, Closed]]}, Open]]}, Visible -> False, 
  FrontEndVersion -> 
  "8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, 2011)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[614, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[1508, 64, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[2208, 98, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[6693, 285, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[7608, 324, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[9077, 384, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[10154, 429, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[13105, 539, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[15549, 653, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[17186, 723, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[19617, 823, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[20133, 852, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[20786, 885, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[21447, 919, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[21836, 936, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[34599, 1335, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[589636, 16729, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[597148, 16953, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[606603, 17240, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[613155, 17452, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[617369, 17589, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[620902, 17708, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[625333, 17850, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[631336, 18049, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[637091, 18249, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[639277, 18341, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[645445, 18550, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[651621, 18755, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[659161, 18996, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[660919, 19063, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]},
 "DecayNetworkPlot"->{
  Cell[648601, 18646, 391, 12, 102, "Input",
   CellTags->"DecayNetworkPlot"],
  Cell[661556, 19090, 114, 2, 49, "MoreExamplesSection",
   CellTags->"DecayNetworkPlot"],
  Cell[661673, 19094, 397, 12, 48, "Input",
   CellTags->"DecayNetworkPlot",
   CellID->732056656]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 710189, 20230},
 {"DecayNetworkPlot", 712886, 20291}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[614, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[681, 26, 46, 0, 172, "Title"],
Cell[730, 28, 169, 6, 156, "Subtitle"],
Cell[902, 36, 129, 6, 191, "Subsubtitle"],
Cell[1034, 44, 437, 15, 64, "DateSection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1508, 64, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1597, 69, 27, 0, 98, "Section"],
Cell[1627, 71, 76, 0, 46, "Text"],
Cell[CellGroupData[{
Cell[1728, 75, 60, 0, 46, "Item"],
Cell[1791, 77, 111, 3, 46, "Item"],
Cell[1905, 82, 106, 3, 46, "Item"],
Cell[2014, 87, 57, 0, 46, "Item"],
Cell[2074, 89, 52, 0, 46, "Item"]
}, Open  ]],
Cell[2141, 92, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2208, 98, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[2297, 103, 24, 0, 98, "Section"],
Cell[2324, 105, 323, 7, 104, "Text"],
Cell[CellGroupData[{
Cell[2672, 116, 591, 23, 80, "Item"],
Cell[3266, 141, 782, 31, 80, "Item"],
Cell[4051, 174, 590, 23, 47, "Item"],
Cell[4644, 199, 398, 15, 47, "Item"],
Cell[5045, 216, 667, 27, 80, "Item"],
Cell[5715, 245, 473, 19, 47, "Item"]
}, Open  ]],
Cell[6203, 267, 420, 10, 133, "Text"],
Cell[6626, 279, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6693, 285, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[6782, 290, 51, 0, 98, "Section"],
Cell[6836, 292, 177, 5, 76, "Text"],
Cell[7016, 299, 160, 6, 66, "MathCaption"],
Cell[7179, 307, 77, 1, 36, "Input"],
Cell[7259, 310, 84, 1, 36, "Input"],
Cell[7346, 313, 133, 2, 36, "Input"],
Cell[7482, 317, 77, 1, 36, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7608, 324, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[7697, 329, 67, 0, 98, "Section"],
Cell[7767, 331, 119, 3, 46, "Text"],
Cell[7889, 336, 73, 1, 36, "Input"],
Cell[7965, 339, 213, 6, 36, "Input"],
Cell[8181, 347, 49, 0, 65, "MathCaption"],
Cell[8233, 349, 242, 5, 67, "Input"],
Cell[8478, 356, 41, 0, 65, "MathCaption"],
Cell[8522, 358, 151, 3, 36, "Input"],
Cell[8676, 363, 47, 0, 65, "MathCaption"],
Cell[8726, 365, 272, 8, 36, "Input"],
Cell[9001, 375, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9077, 384, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[9166, 389, 68, 0, 98, "Section"],
Cell[9237, 391, 191, 5, 76, "Text"],
Cell[CellGroupData[{
Cell[9453, 400, 184, 5, 80, "Item"],
Cell[9640, 407, 265, 6, 113, "Item"],
Cell[9908, 415, 164, 5, 46, "Item"]
}, Open  ]],
Cell[10087, 423, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10154, 429, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[10243, 434, 37, 0, 98, "Section"],
Cell[10283, 436, 204, 6, 76, "Text"],
Cell[10490, 444, 48, 0, 41, "WolframAlphaShort"],
Cell[10541, 446, 63, 0, 41, "WolframAlphaShort"],
Cell[10607, 448, 156, 5, 65, "MathCaption"],
Cell[10766, 455, 55, 1, 36, "Input"],
Cell[10824, 458, 308, 7, 59, "Input"],
Cell[11135, 467, 231, 5, 95, "MathCaption"],
Cell[11369, 474, 1513, 47, 150, "Input"],
Cell[12885, 523, 27, 3, 33, "Spacer"],
Cell[12915, 528, 120, 3, 46, "Text"],
Cell[13038, 533, 18, 0, 20, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13105, 539, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[13194, 544, 66, 0, 98, "Section"],
Cell[13263, 546, 68, 0, 46, "Text"],
Cell[CellGroupData[{
Cell[13356, 550, 593, 24, 80, "Item"],
Cell[13952, 576, 949, 39, 80, "Item"],
Cell[14904, 617, 385, 15, 80, "Item"]
}, Open  ]],
Cell[15304, 635, 18, 0, 20, "Spacer"],
Cell[15325, 637, 145, 5, 46, "Text"],
Cell[15473, 644, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15549, 653, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[15638, 658, 31, 0, 98, "Section"],
Cell[15672, 660, 320, 10, 47, "Text"],
Cell[15995, 672, 128, 3, 37, "Input"],
Cell[16126, 677, 115, 2, 37, "Input"],
Cell[16244, 681, 114, 2, 37, "Input"],
Cell[16361, 685, 18, 0, 20, "Spacer"],
Cell[16382, 687, 104, 2, 65, "MathCaption"],
Cell[16489, 691, 120, 2, 37, "Input"],
Cell[16612, 695, 119, 2, 37, "Input"],
Cell[16734, 699, 18, 0, 20, "Spacer"],
Cell[16755, 701, 72, 0, 65, "MathCaption"],
Cell[16830, 703, 212, 6, 37, "Input"],
Cell[17045, 711, 62, 1, 37, "Input"],
Cell[17110, 714, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17186, 723, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[17275, 728, 63, 0, 98, "Section"],
Cell[17341, 730, 416, 12, 76, "Text"],
Cell[17760, 744, 29, 0, 65, "MathCaption"],
Cell[17792, 746, 125, 2, 37, "Input"],
Cell[17920, 750, 153, 4, 37, "Input"],
Cell[18076, 756, 116, 2, 37, "Input"],
Cell[18195, 760, 141, 3, 37, "Input"],
Cell[18339, 765, 18, 0, 20, "Spacer"],
Cell[18360, 767, 230, 6, 66, "MathCaption"],
Cell[18593, 775, 140, 3, 37, "Input"],
Cell[18736, 780, 62, 1, 37, "Input"],
Cell[18801, 783, 18, 0, 20, "Spacer"],
Cell[18822, 785, 68, 0, 65, "MathCaption"],
Cell[18893, 787, 111, 2, 37, "Input"],
Cell[19007, 791, 18, 0, 20, "Spacer"],
Cell[19028, 793, 44, 0, 65, "MathCaption"],
Cell[19075, 795, 139, 3, 37, "Input"],
Cell[19217, 800, 18, 0, 20, "Spacer"],
Cell[19238, 802, 29, 0, 65, "MathCaption"],
Cell[19270, 804, 119, 2, 37, "Input"],
Cell[19392, 808, 146, 4, 37, "Input"],
Cell[19541, 814, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19617, 823, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[19706, 828, 58, 0, 98, "Section"],
Cell[19767, 830, 115, 4, 47, "Text"],
Cell[19885, 836, 66, 1, 37, "Input"],
Cell[19954, 839, 100, 2, 37, "Input"],
Cell[20057, 843, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20133, 852, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20222, 857, 60, 0, 98, "Section"],
Cell[20285, 859, 132, 4, 47, "Text"],
Cell[20420, 865, 101, 2, 37, "Input",
 CellID->426380316],
Cell[20524, 869, 100, 2, 37, "Input",
 CellID->12846291],
Cell[20627, 873, 80, 1, 37, "Input"],
Cell[20710, 876, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20786, 885, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20875, 890, 57, 0, 98, "Section"],
Cell[20935, 892, 126, 4, 47, "Text"],
Cell[21064, 898, 83, 1, 37, "Input"],
Cell[21150, 901, 77, 1, 37, "Input"],
Cell[21230, 904, 138, 4, 37, "Input"],
Cell[21371, 910, 27, 3, 33, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21447, 919, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[21536, 924, 27, 0, 98, "Section"],
Cell[21566, 926, 221, 4, 75, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21836, 936, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[21925, 941, 40, 0, 98, "Section"],
Cell[21968, 943, 88, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[22081, 949, 125, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[22209, 953, 1895, 48, 231, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[24116, 1004, 46, 0, 37, "PictureCaption"],
Cell[24165, 1006, 53, 0, 65, "MathCaption"],
Cell[24221, 1008, 114, 2, 37, "Input"],
Cell[24338, 1012, 60, 0, 65, "MathCaption"],
Cell[24401, 1014, 617, 15, 84, "Input"],
Cell[25021, 1031, 94, 2, 65, "MathCaption"],
Cell[25118, 1035, 689, 21, 85, "Input"],
Cell[25810, 1058, 148, 4, 37, "Input"],
Cell[25961, 1064, 27, 3, 33, "Spacer"],
Cell[CellGroupData[{
Cell[26013, 1071, 119, 1, 57, "MoreExamplesSection"],
Cell[26135, 1074, 300, 8, 46, "Text"],
Cell[26438, 1084, 1167, 35, 84, "Input",
 CellID->653064214]
}, Closed]],
Cell[CellGroupData[{
Cell[27642, 1124, 49, 0, 49, "MoreExamplesSection"],
Cell[27694, 1126, 105, 2, 81, "MathCaption"],
Cell[27802, 1130, 271, 8, 48, "Input",
 CellID->611876539],
Cell[28076, 1140, 534, 16, 76, "Input",
 CellID->206798417],
Cell[28613, 1158, 161, 6, 81, "MathCaption"],
Cell[28777, 1166, 631, 17, 77, "Input",
 CellID->421547818],
Cell[29411, 1185, 63, 0, 81, "MathCaption"],
Cell[29477, 1187, 2914, 80, 248, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[32428, 1272, 48, 0, 49, "MoreExamplesSection"],
Cell[32479, 1274, 113, 3, 81, "MathCaption"],
Cell[32595, 1279, 1922, 47, 248, "Input"],
Cell[34520, 1328, 18, 0, 25, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34599, 1335, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[34688, 1340, 37, 0, 123, "Section"],
Cell[34728, 1342, 55, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[34808, 1348, 4635, 113, 691, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[39446, 1463, 1944, 50, 283, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[41402, 1516, 43, 0, 46, "PictureCaption"],
Cell[41448, 1518, 117, 1, 81, "MathCaption"],
Cell[41568, 1521, 159, 4, 45, "Input"],
Cell[41730, 1527, 83, 2, 81, "MathCaption"],
Cell[41816, 1531, 350, 11, 45, "Input"],
Cell[42169, 1544, 85, 1, 81, "MathCaption"],
Cell[42257, 1547, 196, 6, 45, "Input"],
Cell[42456, 1555, 56, 0, 81, "MathCaption"],
Cell[42515, 1557, 1006, 29, 158, "Input"],
Cell[CellGroupData[{
Cell[43546, 1590, 43, 0, 71, "MoreExamplesSection"],
Cell[43592, 1592, 253, 7, 93, "Text"],
Cell[43848, 1601, 67, 0, 81, "MathCaption"],
Cell[43918, 1603, 233, 6, 76, "Input"],
Cell[44154, 1611, 190, 4, 117, "MathCaption"],
Cell[44347, 1617, 424, 11, 106, "Input"],
Cell[44774, 1630, 334, 6, 117, "MathCaption"],
Cell[45111, 1638, 111, 3, 46, "Input"],
Cell[45225, 1643, 881, 23, 106, "Input"],
Cell[46109, 1668, 105, 3, 46, "Input"],
Cell[46217, 1673, 208, 8, 82, "MathCaption"],
Cell[46428, 1683, 731, 21, 106, "Input"],
Cell[47162, 1706, 140, 3, 81, "MathCaption"],
Cell[47305, 1711, 409, 10, 46, "Input"],
Cell[47717, 1723, 233, 6, 46, "Input"],
Cell[47953, 1731, 165, 3, 82, "MathCaption"],
Cell[48121, 1736, 466, 15, 76, "Input"],
Cell[48590, 1753, 210, 6, 81, "MathCaption"],
Cell[CellGroupData[{
Cell[48825, 1763, 780, 19, 162, "Input"],
Cell[49608, 1784, 539925, 14932, 506, "Output"]
}, Open  ]],
Cell[589548, 16719, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[589636, 16729, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[589725, 16734, 45, 0, 123, "Section"],
Cell[589773, 16736, 91, 2, 58, "Text"],
Cell[589867, 16740, 77, 1, 45, "Input"],
Cell[589947, 16743, 1838, 47, 279, "DisplayDataTable"],
Cell[591788, 16792, 51, 0, 46, "PictureCaption"],
Cell[591842, 16794, 124, 1, 81, "MathCaption"],
Cell[591969, 16797, 82, 1, 45, "Input"],
Cell[592054, 16800, 123, 3, 118, "MathCaption"],
Cell[592180, 16805, 710, 19, 158, "Input"],
Cell[592893, 16826, 78, 2, 81, "MathCaption"],
Cell[592974, 16830, 961, 27, 158, "Input"],
Cell[CellGroupData[{
Cell[593960, 16861, 55, 0, 71, "MoreExamplesSection"],
Cell[594018, 16863, 243, 4, 95, "Text"],
Cell[594264, 16869, 2802, 75, 277, "Input"],
Cell[597069, 16946, 18, 0, 25, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[597148, 16953, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[597237, 16958, 40, 0, 123, "Section"],
Cell[597280, 16960, 99, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[597404, 16966, 125, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[597532, 16970, 1889, 48, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[599433, 17021, 46, 0, 46, "PictureCaption"],
Cell[599482, 17023, 190, 6, 81, "MathCaption"],
Cell[599675, 17031, 149, 4, 45, "Input",
 CellID->1068126438],
Cell[599827, 17037, 119, 3, 45, "Input",
 CellID->301539131],
Cell[599949, 17042, 78, 0, 81, "MathCaption"],
Cell[600030, 17044, 386, 11, 102, "Input"],
Cell[CellGroupData[{
Cell[600441, 17059, 44, 0, 71, "MoreExamplesSection"],
Cell[600488, 17061, 162, 6, 57, "Text"],
Cell[600653, 17069, 1312, 37, 162, "Input"],
Cell[601968, 17108, 4544, 120, 426, "Input"],
Cell[606515, 17230, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[606603, 17240, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[606692, 17245, 40, 0, 123, "Section"],
Cell[606735, 17247, 76, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[606836, 17253, 125, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[606964, 17257, 1932, 49, 283, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[608908, 17309, 46, 0, 46, "PictureCaption"],
Cell[608957, 17311, 128, 1, 81, "MathCaption"],
Cell[609088, 17314, 1237, 36, 189, "Input",
 CellID->977521728],
Cell[610328, 17352, 124, 1, 81, "MathCaption"],
Cell[610455, 17355, 872, 27, 102, "Input",
 CellID->12496365],
Cell[611330, 17384, 265, 8, 118, "MathCaption"],
Cell[611598, 17394, 197, 5, 45, "Input"],
Cell[611798, 17401, 112, 3, 81, "MathCaption"],
Cell[611913, 17406, 365, 11, 45, "Input",
 CellID->303285230],
Cell[612281, 17419, 795, 22, 130, "Input",
 CellID->1336166279],
Cell[613079, 17443, 27, 3, 42, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[613155, 17452, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[613244, 17457, 41, 0, 123, "Section"],
Cell[613288, 17459, 88, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[613401, 17465, 126, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[613530, 17469, 1923, 48, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[615465, 17520, 47, 0, 46, "PictureCaption"],
Cell[615515, 17522, 128, 1, 81, "MathCaption"],
Cell[615646, 17525, 140, 4, 45, "Input"],
Cell[615789, 17531, 129, 1, 81, "MathCaption"],
Cell[615921, 17534, 123, 2, 45, "Input"],
Cell[616047, 17538, 135, 1, 81, "MathCaption"],
Cell[616185, 17541, 82, 1, 45, "Input"],
Cell[616270, 17544, 121, 2, 45, "Input"],
Cell[616394, 17548, 123, 2, 45, "Input"],
Cell[616520, 17552, 92, 2, 81, "MathCaption"],
Cell[616615, 17556, 128, 3, 45, "Input"],
Cell[616746, 17561, 129, 3, 45, "Input"],
Cell[616878, 17566, 154, 4, 119, "MathCaption"],
Cell[617035, 17572, 255, 6, 74, "Input"],
Cell[617293, 17580, 27, 3, 42, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[617369, 17589, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[617458, 17594, 39, 0, 123, "Section"],
Cell[617500, 17596, 77, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[617602, 17602, 124, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[617729, 17606, 1910, 48, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[619651, 17657, 45, 0, 46, "PictureCaption"],
Cell[619699, 17659, 65, 0, 81, "MathCaption"],
Cell[619767, 17661, 87, 1, 45, "Input"],
Cell[619857, 17664, 76, 0, 81, "MathCaption"],
Cell[619936, 17666, 83, 1, 45, "Input"],
Cell[620022, 17669, 130, 3, 45, "Input"],
Cell[620155, 17674, 89, 1, 81, "MathCaption",
 CellID->21466432],
Cell[620247, 17677, 372, 12, 74, "Input",
 CellID->137344771],
Cell[620622, 17691, 112, 3, 81, "MathCaption"],
Cell[620737, 17696, 86, 1, 45, "Input"],
Cell[620826, 17699, 27, 3, 42, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[620902, 17708, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[620991, 17713, 40, 0, 123, "Section"],
Cell[621034, 17715, 166, 5, 58, "Text"],
Cell[CellGroupData[{
Cell[621225, 17724, 125, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[621353, 17728, 1884, 48, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[623249, 17779, 46, 0, 46, "PictureCaption"],
Cell[623298, 17781, 156, 3, 118, "MathCaption"],
Cell[623457, 17786, 121, 2, 45, "Input"],
Cell[623581, 17790, 114, 2, 45, "Input"],
Cell[623698, 17794, 259, 8, 74, "Input"],
Cell[623960, 17804, 107, 2, 45, "Input"],
Cell[624070, 17808, 143, 1, 81, "MathCaption"],
Cell[624216, 17811, 1038, 28, 158, "Input"],
Cell[625257, 17841, 27, 3, 42, "Spacer"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[625333, 17850, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[625422, 17855, 42, 0, 123, "Section"],
Cell[625467, 17857, 99, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[625591, 17863, 127, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[625721, 17867, 1899, 48, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[627632, 17918, 48, 0, 46, "PictureCaption"],
Cell[627683, 17920, 97, 2, 81, "MathCaption"],
Cell[627783, 17924, 78, 1, 45, "Input"],
Cell[627864, 17927, 93, 1, 81, "MathCaption",
 CellID->16278858],
Cell[627960, 17930, 146, 3, 45, "Input"],
Cell[628109, 17935, 129, 3, 81, "MathCaption",
 CellID->110245438],
Cell[628241, 17940, 521, 16, 102, "Input",
 CellID->26927731],
Cell[628765, 17958, 86, 1, 81, "MathCaption",
 CellID->33817476],
Cell[628854, 17961, 234, 7, 45, "Input",
 CellID->6430592],
Cell[629091, 17970, 164, 5, 45, "Input"],
Cell[CellGroupData[{
Cell[629280, 17979, 44, 0, 71, "MoreExamplesSection"],
Cell[629327, 17981, 98, 2, 57, "Text"],
Cell[629428, 17985, 878, 24, 162, "Input"],
Cell[630309, 18011, 136, 3, 81, "MathCaption"],
Cell[630448, 18016, 797, 21, 76, "Input"],
Cell[631248, 18039, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[631336, 18049, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[631425, 18054, 37, 0, 123, "Section"],
Cell[631465, 18056, 161, 3, 95, "Text"],
Cell[CellGroupData[{
Cell[631651, 18063, 122, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[631776, 18067, 1987, 51, 279, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[633775, 18121, 43, 0, 46, "PictureCaption"],
Cell[633821, 18123, 32, 0, 81, "MathCaption"],
Cell[633856, 18125, 72, 1, 45, "Input"],
Cell[633931, 18128, 149, 4, 45, "Input"],
Cell[634083, 18134, 150, 4, 45, "Input"],
Cell[CellGroupData[{
Cell[634258, 18142, 44, 0, 71, "MoreExamplesSection"],
Cell[634305, 18144, 28, 0, 57, "Text"],
Cell[634336, 18146, 152, 4, 46, "Input"],
Cell[634491, 18152, 162, 4, 46, "Input"],
Cell[634656, 18158, 43, 0, 81, "MathCaption"],
Cell[634702, 18160, 585, 17, 76, "Input"],
Cell[635290, 18179, 223, 6, 81, "MathCaption"],
Cell[635516, 18187, 432, 13, 105, "Input"],
Cell[635951, 18202, 183, 5, 46, "Input"],
Cell[636137, 18209, 446, 13, 105, "Input"],
Cell[636586, 18224, 205, 5, 105, "Input"],
Cell[636794, 18231, 206, 6, 46, "Input"],
Cell[637003, 18239, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[637091, 18249, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[637180, 18254, 45, 0, 123, "Section"],
Cell[637228, 18256, 43, 0, 58, "Text"],
Cell[637274, 18258, 53, 0, 81, "MathCaption"],
Cell[637330, 18260, 91, 2, 45, "Input",
 CellID->781000318],
Cell[637424, 18264, 29, 0, 81, "MathCaption"],
Cell[637456, 18266, 59, 1, 45, "Input"],
Cell[637518, 18269, 93, 2, 45, "Input"],
Cell[637614, 18273, 81, 1, 45, "Input"],
Cell[637698, 18276, 104, 2, 45, "Input"],
Cell[637805, 18280, 234, 6, 47, "Input"],
Cell[CellGroupData[{
Cell[638064, 18290, 44, 0, 71, "MoreExamplesSection"],
Cell[638111, 18292, 28, 0, 57, "Text"],
Cell[638142, 18294, 389, 11, 78, "Input"],
Cell[638534, 18307, 64, 1, 46, "Input"],
Cell[638601, 18310, 32, 0, 82, "MathCaption"],
Cell[638636, 18312, 474, 14, 78, "Input"],
Cell[639113, 18328, 73, 1, 46, "Input"],
Cell[639189, 18331, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[639277, 18341, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[639366, 18346, 38, 0, 123, "Section"],
Cell[639407, 18348, 73, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[639505, 18354, 123, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[639631, 18358, 2122, 56, 283, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[641765, 18417, 44, 0, 46, "PictureCaption"],
Cell[641812, 18419, 94, 2, 81, "MathCaption"],
Cell[641909, 18423, 76, 1, 45, "Input"],
Cell[641988, 18426, 269, 6, 74, "Input"],
Cell[642260, 18434, 85, 1, 81, "MathCaption"],
Cell[642348, 18437, 574, 15, 130, "Input"],
Cell[642925, 18454, 169, 4, 119, "MathCaption"],
Cell[643097, 18460, 355, 11, 102, "Input"],
Cell[643455, 18473, 577, 18, 74, "Input",
 CellID->95596341],
Cell[CellGroupData[{
Cell[644057, 18495, 44, 0, 71, "MoreExamplesSection"],
Cell[644104, 18497, 27, 0, 57, "Text"],
Cell[644134, 18499, 324, 9, 46, "Input"],
Cell[644461, 18510, 37, 0, 81, "MathCaption"],
Cell[644501, 18512, 127, 3, 46, "Input"],
Cell[644631, 18517, 62, 0, 81, "MathCaption"],
Cell[644696, 18519, 658, 19, 105, "Input"],
Cell[645357, 18540, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[645445, 18550, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[645534, 18555, 43, 0, 123, "Section"],
Cell[645580, 18557, 61, 2, 58, "Text"],
Cell[CellGroupData[{
Cell[645666, 18563, 128, 2, 45, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[645797, 18567, 1919, 49, 283, "DisplayDataTable",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, {2}]],
Cell[647728, 18619, 49, 0, 46, "PictureCaption"],
Cell[647780, 18621, 30, 0, 81, "MathCaption"],
Cell[647813, 18623, 144, 2, 45, "Input"],
Cell[647960, 18627, 638, 17, 158, "Input"],
Cell[648601, 18646, 391, 12, 102, "Input",
 CellTags->"DecayNetworkPlot"],
Cell[648995, 18660, 594, 18, 102, "Input",
 CellID->2001766748],
Cell[CellGroupData[{
Cell[649614, 18682, 44, 0, 71, "MoreExamplesSection"],
Cell[649661, 18684, 31, 0, 57, "Text"],
Cell[649695, 18686, 378, 12, 76, "Input",
 CellID->1241146727],
Cell[650076, 18700, 28, 0, 81, "MathCaption"],
Cell[650107, 18702, 658, 18, 133, "Input",
 CellID->796903008],
Cell[650768, 18722, 33, 0, 81, "MathCaption"],
Cell[650804, 18724, 726, 19, 162, "Input"],
Cell[651533, 18745, 27, 3, 41, "Spacer"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[651621, 18755, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[651710, 18760, 32, 0, 123, "Section"],
Cell[651745, 18762, 198, 4, 95, "Text"],
Cell[CellGroupData[{
Cell[651968, 18770, 216, 3, 71, "MoreExamplesSection"],
Cell[652187, 18775, 260, 7, 93, "Text"],
Cell[652450, 18784, 504, 13, 76, "Input"],
Cell[652957, 18799, 132, 2, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[653126, 18806, 303, 4, 60, "MoreExamplesSection"],
Cell[653432, 18812, 438, 8, 128, "Text"],
Cell[653873, 18822, 386, 11, 46, "Input"],
Cell[654262, 18835, 159, 3, 81, "MathCaption"],
Cell[654424, 18840, 346, 9, 48, "Input"],
Cell[654773, 18851, 170, 3, 81, "MathCaption"],
Cell[654946, 18856, 299, 8, 48, "Input"],
Cell[655248, 18866, 142, 4, 82, "MathCaption",
 CellID->12442663],
Cell[CellGroupData[{
Cell[655415, 18874, 546, 16, 105, "Input",
 CellID->251992734],
Cell[655964, 18892, 252, 5, 68, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[656253, 18902, 168, 5, 36, "Input"],
Cell[656424, 18909, 941, 23, 330, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[657414, 18938, 171, 2, 60, "MoreExamplesSection"],
Cell[657588, 18942, 88, 2, 57, "Text"],
Cell[657679, 18946, 185, 5, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[657901, 18956, 115, 1, 60, "MoreExamplesSection"],
Cell[658019, 18959, 286, 6, 93, "Text"],
Cell[658308, 18967, 135, 2, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[658480, 18974, 124, 1, 60, "MoreExamplesSection"],
Cell[658607, 18977, 341, 8, 93, "Text"],
Cell[658951, 18987, 149, 2, 46, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[659161, 18996, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[659250, 19001, 36, 0, 122, "Section"],
Cell[659289, 19003, 611, 15, 165, "Text"],
Cell[CellGroupData[{
Cell[659925, 19022, 216, 7, 57, "Item"],
Cell[660144, 19031, 179, 6, 57, "Item"],
Cell[660326, 19039, 209, 6, 57, "Item"]
}, Open  ]],
Cell[660550, 19048, 320, 9, 135, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[660919, 19063, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[661008, 19068, 62, 1, 123, "Section",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[661095, 19073, 58, 0, 57, "MoreExamplesSection"],
Cell[661156, 19075, 363, 10, 76, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[661556, 19090, 114, 2, 49, "MoreExamplesSection",
 CellTags->"DecayNetworkPlot"],
Cell[661673, 19094, 397, 12, 48, "Input",
 CellTags->"DecayNetworkPlot",
 CellID->732056656]
}, Closed]],
Cell[CellGroupData[{
Cell[662107, 19111, 44, 0, 49, "MoreExamplesSection"],
Cell[662154, 19113, 3739, 91, 606, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[665930, 19209, 49, 0, 49, "MoreExamplesSection"],
Cell[665982, 19211, 3544, 89, 520, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[669563, 19305, 43, 0, 49, "MoreExamplesSection"],
Cell[669609, 19307, 282, 7, 103, "Input"],
Cell[669894, 19316, 1162, 31, 217, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[671093, 19352, 40, 0, 49, "MoreExamplesSection"],
Cell[671136, 19354, 4896, 120, 384, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
